  #include <sys/errno.h>
  #include <fcntl.h>
  #include <unistd.h>

#include "pxll.h"

static int lookup_field (int tag, int label);

static
inline
pxll_int
get_typecode (object * ob)
{
  if (IMMEDIATE(ob)) {
    if (IS_INTEGER(ob)) {
      return TC_INT;
    } else {
      return (pxll_int)ob & 0xff;
    }
  } else {
    return (pxll_int)*((pxll_int *)ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case (object * ob)
{
  if (is_immediate (ob)) {
    if (is_int (ob)) {
      return TC_INT;
    } else {
      return (pxll_int) ob;
    }
  } else {
    return (pxll_int)*((pxll_int *)ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case_noint (object * ob)
{
  if (is_immediate (ob)) {
    return (pxll_int) ob;
  } else {
    return (pxll_int) * ((pxll_int*) ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case_imm (object * ob)
{
  return (pxll_int)ob;
}

static
inline
pxll_int
get_case_tup (object * ob)
{
  return (pxll_int)*((pxll_int *)ob) & 0xff;
}

static
inline
pxll_int
get_imm_payload (object * ob)
{
  return ((pxll_int) ob) >> 8;
}

static
pxll_int
get_tuple_size (object * ob)
{
  header * h = (header *) ob;
  return (*h)>>8;
}

static
void
indent (int n)
{
  while (n--) {
    fprintf (stdout, "  ");
  }
}

void print_string (object * ob, int quoted);
void print_list (pxll_pair * l);

// this is kinda lame, it's part pretty-printer, part not.
static
object *
dump_object (object * ob, int depth)
{
  // indent (depth);
  if (depth > 100) {
    fprintf (stdout , "...");
    return (object *) PXLL_UNDEFINED;
  }
  if (!ob) {
    fprintf (stdout, "<null>");
  } else if (is_int (ob)) {
    // integer
    fprintf (stdout, "%zd", unbox (ob));
  } else {
    int tc = is_immediate (ob);
    switch (tc) {
    case TC_CHAR:
      if ((pxll_int)ob>>8 == 257) {
	// deliberately out-of-range character
	fprintf (stdout, "#\\eof");
      } else {
	char ch = ((char)((pxll_int)ob>>8));
	switch (ch) {
	case '\000': fprintf (stdout, "#\\nul"); break;
	case ' '   : fprintf (stdout, "#\\space"); break;
	case '\n'  : fprintf (stdout, "#\\newline"); break;
	case '\r'  : fprintf (stdout, "#\\return"); break;
	case '\t'  : fprintf (stdout, "#\\tab"); break;
	default    : fprintf (stdout, "#\\%c", ch);
	}
      }
      break;
    case TC_BOOL:
      fprintf (stdout, ((pxll_int)ob >> 8) & 0xff ? "#t" : "#f");
      break;
    case TC_NIL:
      fprintf (stdout, "()");
      break;
    case TC_UNDEFINED:
      fprintf (stdout, "#u");
      break;
    case TC_EMPTY_VECTOR:
      fprintf (stdout, "#()");
      break;
    case 0: {
      // structure
      header h = (header) (ob[0]);
      int tc = h & 0xff;
      switch (tc) {
      case TC_SAVE: {
	// XXX fix me - now holds saved registers
        pxll_save * s = (pxll_save* ) ob;
        fprintf (stdout, "<save pc=%p\n", s->pc);
        dump_object ((object *) s->lenv, depth+1); fprintf (stdout, "\n");
        dump_object ((object *) s->next, depth+1); fprintf (stdout, ">");
      }
        break;
      case TC_CLOSURE: {
        pxll_closure * c = (pxll_closure *) ob;
        //fprintf (stdout, "<closure pc=%p\n", c->pc);
        //dump_object ((object *) c->lenv, depth+1); fprintf (stdout, ">\n");
	fprintf (stdout, "<closure pc=%p lenv=%p>", c->pc, c->lenv);
      }
        break;
      case TC_TUPLE: {
        pxll_tuple * t = (pxll_tuple *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "<tuple\n");
        for (i=0; i < n-1; i++) {
          dump_object ((object *) t->val[i], depth + 1); fprintf (stdout, "\n");
        }
        dump_object ((object *) t->next, depth + 1);
        fprintf (stdout, ">");
      }
	break;
      case TC_VECTOR: {
        pxll_vector * t = (pxll_vector *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "#(");
        for (i=0; i < n; i++) {
          dump_object ((object *) t->val[i], depth+1);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, ")");
      }
	break;
      case TC_VEC16: {
        pxll_vec16 * t = (pxll_vec16 *) ob;
        pxll_int n = t->len;
        int i;
	fprintf (stdout, "#16(");
        for (i=0; i < n; i++) {
	  fprintf (stdout, "%d", t->data[i]);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, ")");
      }
	break;
      case TC_PAIR:
	print_list ((pxll_pair *) ob);
        break;
      case TC_STRING:
	print_string (ob, 1);
	break;
      case TC_BUFFER: {
	pxll_int n = get_tuple_size (ob);
	fprintf (stdout, "<buffer %" PRIuPTR " words %" PRIuPTR " bytes>", n, n * (sizeof(pxll_int)));
	break;
      }
      case TC_SYMBOL:
	print_string (ob[1], 0);
	break;
      default: {
        pxll_vector * t = (pxll_vector *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "{u%d ", (tc - TC_USEROBJ)>>2);
        for (i=0; i < n; i++) {
          dump_object ((object *) t->val[i], depth+1);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, "}");
      }
      }
    }
      break;
    case TC_USERIMM:
      // a user immediate unit-type...
      fprintf (stdout, "<u%" PRIuPTR ">", (((pxll_int)ob)>>8));
    }
  }
  return (object *) PXLL_UNDEFINED;
}

// for gdb...
void
DO (object * x)
{
  dump_object (x, 0);
  fprintf (stdout, "\n");
  fflush (stdout);
}

// for debugging
void
stack_depth_indent (object * k)
{
  while (k != PXLL_NIL) {
    k = k[1];
    fprintf (stderr, "  ");
  }
}

void
print_string (object * ob, int quoted)
{
  pxll_string * s = (pxll_string *) ob;
  char * ps = s->data;
  int i;
  //fprintf (stderr, "<printing string of len=%d (tuple-len=%d)>\n", s->len, get_tuple_size (ob));
  if (quoted) {
    fputc ('"', stdout);
  }
  for (i=0; i < (s->len); i++, ps++) {
    if (*ps == '"') {
      fputc ('\\', stdout);
      fputc ('"', stdout);
    } else {
      if (isprint(*ps)) {
	fputc (*ps, stdout);
      } else {
	fprintf (stdout, "\\0x%02x", *ps);
      }
    }
    if (i > 50) {
      fprintf (stdout, "...");
      break;
    }
  }
  if (quoted) {
    fputc ('"', stdout);
  }
}

void
print_list (pxll_pair * l)
{
  fprintf (stdout, "(");
  while (1) {
    object * car = l->car;
    object * cdr = l->cdr;
    dump_object (car, 0);
    if (cdr == PXLL_NIL) {
      fprintf (stdout, ")");
      break;
    } else if (!is_immediate (cdr) && GET_TYPECODE (*cdr) == TC_PAIR) {
      fprintf (stdout, " ");
      l = (pxll_pair *) cdr;
    } else {
      fprintf (stdout, " . ");
      dump_object (cdr, 0);
      fprintf (stdout, ")");
      break;
    }
  }
}

int
read_header (FILE * file)
{
  int depth = 0;
  // tiny lisp 'skipper' (as opposed to 'reader')
  do {
    char ch = fgetc (file);
    switch (ch) {
    case '(':
      depth++;
      break;
    case ')':
      depth--;
      break;
    case '"':
      while (fgetc (file) != '"') {
        // empty body
      }
      break;
    default:
      break;
    }
  } while (depth);
  // read terminating newline
  fgetc (file);
  return 0;
}

#ifndef NO_RANGE_CHECK
// used to check array references.  some day we might try to teach
//   the compiler when/how to skip doing this...
static
void
inline
range_check (unsigned int length, unsigned int index)
{
  if (index >= length) {
    fprintf (stderr, "array/string reference out of range: %d[%d]\n", length, index);
    abort();
  }
}
#else
static
void
inline
range_check (unsigned int length, unsigned int index)
{
}
#endif

pxll_int verbose_gc = 1;
pxll_int clear_fromspace = 0;
pxll_int clear_tospace = 0;

pxll_int vm (int argc, char * argv[]);

#include "rdtsc.h"

unsigned long long gc_ticks = 0;

static
void
clear_space (object * p, pxll_int n)
{
  while (n--) {
    *p++ = PXLL_NIL;
  }
}

int
main (int argc, char * argv[])
{
  heap0 = malloc (sizeof (object) * heap_size);
  heap1 = malloc (sizeof (object) * heap_size);
  if (!heap0 || !heap1) {
    fprintf (stderr, "unable to allocate heap\n");
    return -1;
  } else {
    unsigned long long t0, t1;
    pxll_int result;
    if (clear_tospace) {
      clear_space (heap0, heap_size);
    }
    t0 = rdtsc();
    result = vm (argc, argv);
    t1 = rdtsc();
    dump_object ((object *) result, 0);
    fprintf (stdout, "\n");
    fprintf (stderr, "{total ticks: %lld gc ticks: %lld}\n", t1 - t0, gc_ticks);
    return (int) result;
  }
}

// CONSTRUCTED LITERALS //
pxll_string constructed_0 = {STRING_HEADER(8), 8, "system: " };
pxll_string constructed_1 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_2 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_3 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_4 = {STRING_HEADER(6), 6, ".c -o " };
pxll_string constructed_5 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_6 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_7 = {STRING_HEADER(2), 2, "-O" };
pxll_string constructed_8 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_9 = {STRING_HEADER(6), 6, "CFLAGS" };
pxll_string constructed_10 = {STRING_HEADER(2), 2, "CC" };
pxll_string constructed_11 = {STRING_HEADER(13), 13, "compiling...\n" };
pxll_string constructed_12 = {STRING_HEADER(6), 6, "done.\n" };
pxll_string constructed_13 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_14 = {STRING_HEADER(10), 10, "  } break;" };
pxll_string constructed_15 = {STRING_HEADER(10), 10, "     case " };
pxll_string constructed_16 = {STRING_HEADER(9), 9, ": return " };
pxll_string constructed_17 = {STRING_HEADER(8), 8, "; break;" };
pxll_string constructed_18 = {STRING_HEADER(18), 18, "  switch (label) {" };
pxll_string constructed_19 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_20 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_21 = {STRING_HEADER(16), 16, "{ switch (tag) {" };
pxll_string constructed_22 = {STRING_HEADER(44), 44, "static int lookup_field (int tag, int label)" };
pxll_string constructed_23 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_24 = {STRING_HEADER(25), 25, "return (pxll_int) result;" };
pxll_string constructed_25 = {STRING_HEADER(8), 8, "Lreturn:" };
pxll_string constructed_26 = {STRING_HEADER(37), 37, "abcdefghijklmnopqrstuvwxyz_0123456789" };
pxll_string constructed_27 = {STRING_HEADER(5), 5, "_bang" };
pxll_string constructed_28 = {STRING_HEADER(6), 6, "_splat" };
pxll_string constructed_29 = {STRING_HEADER(9), 9, "_question" };
pxll_string constructed_30 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_31 = {STRING_HEADER(5), 5, "_plus" };
pxll_string constructed_32 = {STRING_HEADER(8), 8, "_percent" };
pxll_int constructed_33[] = {UPTR(33,21),UOHEAD(3,1),9474,UPTR0(32),UITAG(0),UOHEAD(3,1),11010,UPTR0(31),UPTR(33,1),UOHEAD(3,1),11522,UPTR0(30),UPTR(33,5),UOHEAD(3,1),16130,UPTR0(29),UPTR(33,9),UOHEAD(3,1),10754,UPTR0(28),UPTR(33,13),UOHEAD(3,1),8450,UPTR0(27),UPTR(33,17)};
pxll_string constructed_34 = {STRING_HEADER(5), 5, "minus" };
pxll_string constructed_35 = {STRING_HEADER(1), 1, "_" };
pxll_int constructed_36[] = {TC_NIL};
pxll_int constructed_37[] = {TC_NIL};
pxll_string constructed_38 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_39 = {STRING_HEADER(20), 20, "(pxll_int)PXLL_FALSE" };
pxll_string constructed_40 = {STRING_HEADER(5), 5, "false" };
// symbol false
pxll_int constructed_41[] = {UPTR(41,1), SYMBOL_HEADER, UPTR0(40), INTCON(0)};
pxll_string constructed_42 = {STRING_HEADER(19), 19, "(pxll_int)PXLL_TRUE" };
pxll_string constructed_43 = {STRING_HEADER(4), 4, "true" };
// symbol true
pxll_int constructed_44[] = {UPTR(44,1), SYMBOL_HEADER, UPTR0(43), INTCON(1)};
pxll_string constructed_45 = {STRING_HEADER(4), 4, "bool" };
// symbol bool
pxll_int constructed_46[] = {UPTR(46,1), SYMBOL_HEADER, UPTR0(45), INTCON(2)};
pxll_string constructed_47 = {STRING_HEADER(6), 6, "TC_NIL" };
pxll_string constructed_48 = {STRING_HEADER(3), 3, "nil" };
// symbol nil
pxll_int constructed_49[] = {UPTR(49,1), SYMBOL_HEADER, UPTR0(48), INTCON(3)};
pxll_string constructed_50 = {STRING_HEADER(4), 4, "list" };
// symbol list
pxll_int constructed_51[] = {UPTR(51,1), SYMBOL_HEADER, UPTR0(50), INTCON(4)};
pxll_string constructed_52 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_53 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_54 = {STRING_HEADER(9), 9, "TC_SYMBOL" };
pxll_string constructed_55 = {STRING_HEADER(1), 1, "t" };
// symbol t
pxll_int constructed_56[] = {UPTR(56,1), SYMBOL_HEADER, UPTR0(55), INTCON(5)};
pxll_string constructed_57 = {STRING_HEADER(6), 6, "symbol" };
// symbol symbol
pxll_int constructed_58[] = {UPTR(58,1), SYMBOL_HEADER, UPTR0(57), INTCON(6)};
pxll_string constructed_59 = {STRING_HEADER(7), 7, "TC_PAIR" };
pxll_string constructed_60 = {STRING_HEADER(4), 4, "cons" };
// symbol cons
pxll_int constructed_61[] = {UPTR(61,1), SYMBOL_HEADER, UPTR0(60), INTCON(7)};
pxll_string constructed_62 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_63 = {STRING_HEADER(1), 1, ")" };
pxll_int constructed_64[] = {TC_NIL};
pxll_string constructed_65 = {STRING_HEADER(3), 3, "..." };
// symbol ...
pxll_int constructed_66[] = {UPTR(66,1), SYMBOL_HEADER, UPTR0(65), INTCON(8)};
pxll_string constructed_67 = {STRING_HEADER(79), 79, "Why, sometimes I've believed as many as six impossible things before breakfast." };
pxll_string constructed_68 = {STRING_HEADER(29), 29, "\n***\nRuntime Error, halting: " };
pxll_string constructed_69 = {STRING_HEADER(4), 4, "FUN_" };
pxll_string constructed_70 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_71 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_72 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_73 = {STRING_HEADER(12), 12, "PXLL_RETURN(" };
pxll_string constructed_74 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_75 = {STRING_HEADER(14), 14, " = (object *) " };
pxll_string constructed_76 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_77 = {STRING_HEADER(8), 8, "// dead " };
pxll_string constructed_78 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_79 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_80 = {STRING_HEADER(26), 26, " = (object*) &constructed_" };
pxll_string constructed_81 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_82 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_83 = {STRING_HEADER(26), 26, " = (object *) constructed_" };
pxll_string constructed_84 = {STRING_HEADER(4), 4, "[0];" };
pxll_string constructed_85 = {STRING_HEADER(6), 6, "string" };
// symbol string
pxll_int constructed_86[] = {UPTR(86,1), SYMBOL_HEADER, UPTR0(85), INTCON(9)};
pxll_string constructed_87 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_88 = {STRING_HEADER(8), 8, "} else {" };
pxll_string constructed_89 = {STRING_HEADER(17), 17, "if PXLL_IS_TRUE(r" };
pxll_string constructed_90 = {STRING_HEADER(3), 3, ") {" };
pxll_string constructed_91 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_92 = {STRING_HEADER(8), 8, "} else {" };
pxll_string constructed_93 = {STRING_HEADER(16), 16, "if PXLL_IS_TRUE(" };
pxll_string constructed_94 = {STRING_HEADER(3), 3, ") {" };
pxll_string constructed_95 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_96 = {STRING_HEADER(5), 5, "arrow" };
// symbol arrow
pxll_int constructed_97[] = {UPTR(97,1), SYMBOL_HEADER, UPTR0(96), INTCON(10)};
pxll_string constructed_98 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_99 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_100 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_101 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_102 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_103 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_104 = {STRING_HEADER(8), 8, "[1] = &&" };
pxll_string constructed_105 = {STRING_HEADER(3), 3, "; r" };
pxll_string constructed_106 = {STRING_HEADER(11), 11, "[2] = lenv;" };
pxll_string constructed_107 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_108 = {STRING_HEADER(28), 28, " = allocate (TC_CLOSURE, 2);" };
pxll_string constructed_109 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_110 = {STRING_HEADER(15), 15, "check_heap (0);" };
pxll_string constructed_111 = {STRING_HEADER(49), 49, "stack_depth_indent(k); fprintf (stderr, \">> [%d] " };
pxll_string constructed_112 = {STRING_HEADER(15), 15, "\\n\", __LINE__);" };
pxll_string constructed_113 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_114 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_115 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_116 = {STRING_HEADER(7), 7, "// def " };
pxll_string constructed_117 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_118 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_119 = {STRING_HEADER(4), 4, "top[" };
pxll_string constructed_120 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_121 = {STRING_HEADER(9), 9, "((object*" };
pxll_string constructed_122 = {STRING_HEADER(8), 8, ") lenv) " };
pxll_string constructed_123 = {STRING_HEADER(1), 1, "[" };
pxll_string constructed_124 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_125 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_126 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_127 = {STRING_HEADER(4), 4, "top[" };
pxll_string constructed_128 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_129 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_130 = {STRING_HEADER(9), 9, "((object*" };
pxll_string constructed_131 = {STRING_HEADER(8), 8, ") lenv) " };
pxll_string constructed_132 = {STRING_HEADER(1), 1, "[" };
pxll_string constructed_133 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_134 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_135 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_136 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_137 = {STRING_HEADER(7), 7, "top = r" };
pxll_string constructed_138 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_139 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_140 = {STRING_HEADER(23), 23, " = allocate (TC_TUPLE, " };
pxll_string constructed_141 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_142 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_143 = {STRING_HEADER(12), 12, " = (object*)" };
pxll_string constructed_144 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_145 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_146 = {STRING_HEADER(13), 13, " = allocate (" };
pxll_string constructed_147 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_148 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_149 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_150 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_151 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_152 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_153 = {STRING_HEADER(1), 1, "[" };
pxll_string constructed_154 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_155 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_156 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_157 = {STRING_HEADER(10), 10, " = result;" };
pxll_string constructed_158 = {STRING_HEADER(24), 24, "; lenv = k[2]; k = k[1];" };
pxll_string constructed_159 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_160 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_161 = {STRING_HEADER(5), 5, " = k[" };
pxll_string constructed_162 = {STRING_HEADER(1), 1, "]" };
pxll_string constructed_163 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_164 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_165 = {STRING_HEADER(7), 7, "[1] = r" };
pxll_string constructed_166 = {STRING_HEADER(13), 13, "[2]; lenv = r" };
pxll_string constructed_167 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_168 = {STRING_HEADER(8), 8, "lenv = r" };
pxll_string constructed_169 = {STRING_HEADER(5), 5, "[2]; " };
pxll_string constructed_170 = {STRING_HEADER(7), 7, "goto *r" };
pxll_string constructed_171 = {STRING_HEADER(4), 4, "[1];" };
pxll_string constructed_172 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_173 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_174 = {STRING_HEADER(32), 32, "t[1] = k; t[2] = lenv; t[3] = &&" };
pxll_string constructed_175 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_176 = {STRING_HEADER(8), 8, "; k = t;" };
pxll_string constructed_177 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_178 = {STRING_HEADER(2), 2, "t[" };
pxll_string constructed_179 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_180 = {STRING_HEADER(23), 23, "t = allocate (TC_SAVE, " };
pxll_string constructed_181 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_182 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_183 = {STRING_HEADER(7), 7, "[1] = r" };
pxll_string constructed_184 = {STRING_HEADER(13), 13, "[2]; lenv = r" };
pxll_string constructed_185 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_186 = {STRING_HEADER(8), 8, "lenv = r" };
pxll_string constructed_187 = {STRING_HEADER(5), 5, "[2]; " };
pxll_string constructed_188 = {STRING_HEADER(7), 7, "goto *r" };
pxll_string constructed_189 = {STRING_HEADER(4), 4, "[1];" };
pxll_string constructed_190 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_191 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_192 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_193 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_194 = {STRING_HEADER(5), 5, "lenv[" };
pxll_string constructed_195 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_196 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_197 = {STRING_HEADER(16), 16, "lenv = ((object " };
pxll_string constructed_198 = {STRING_HEADER(6), 6, ")lenv)" };
pxll_string constructed_199 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_200 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_201 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_202 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_203 = {STRING_HEADER(20), 20, "[1] = lenv; lenv = r" };
pxll_string constructed_204 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_205 = {STRING_HEADER(15), 15, "lenv = lenv[1];" };
pxll_string constructed_206 = {STRING_HEADER(5), 5, "k = r" };
pxll_string constructed_207 = {STRING_HEADER(11), 11, "; // %putcc" };
pxll_string constructed_208 = {STRING_HEADER(6), 6, "primop" };
pxll_string constructed_209 = {STRING_HEADER(6), 6, "%putcc" };
// symbol %putcc
pxll_int constructed_210[] = {UPTR(210,1), SYMBOL_HEADER, UPTR0(209), INTCON(11)};
pxll_string constructed_211 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_212 = {STRING_HEADER(15), 15, " = k; // %getcc" };
pxll_string constructed_213 = {STRING_HEADER(6), 6, "%getcc" };
// symbol %getcc
pxll_int constructed_214[] = {UPTR(214,1), SYMBOL_HEADER, UPTR0(213), INTCON(12)};
pxll_string constructed_215 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_216 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_217 = {STRING_HEADER(3), 3, "(((" };
pxll_string constructed_218 = {STRING_HEADER(15), 15, "*)((pxll_int*)r" };
pxll_string constructed_219 = {STRING_HEADER(5), 5, ")+1)[" };
pxll_string constructed_220 = {STRING_HEADER(2), 2, "])" };
pxll_string constructed_221 = {STRING_HEADER(2), 2, "((" };
pxll_string constructed_222 = {STRING_HEADER(7), 7, ")unbox(" };
pxll_string constructed_223 = {STRING_HEADER(2), 2, "))" };
pxll_string constructed_224 = {STRING_HEADER(37), 37, "lookup-cast: can't cast from int to: " };
pxll_string constructed_225 = {STRING_HEADER(3), 3, "int" };
// symbol int
pxll_int constructed_226[] = {UPTR(226,1), SYMBOL_HEADER, UPTR0(225), INTCON(13)};
pxll_string constructed_227 = {STRING_HEADER(43), 43, "lookup-cast: unable to cast between types: " };
pxll_string constructed_228 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_229 = {STRING_HEADER(5), 5, "%cset" };
// symbol %cset
pxll_int constructed_230[] = {UPTR(230,1), SYMBOL_HEADER, UPTR0(229), INTCON(14)};
pxll_string constructed_231 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_232 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_233 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_234 = {STRING_HEADER(3), 3, "(((" };
pxll_string constructed_235 = {STRING_HEADER(15), 15, "*)((pxll_int*)r" };
pxll_string constructed_236 = {STRING_HEADER(5), 5, ")+1)[" };
pxll_string constructed_237 = {STRING_HEADER(2), 2, "])" };
pxll_string constructed_238 = {STRING_HEADER(5), 5, "%cget" };
// symbol %cget
pxll_int constructed_239[] = {UPTR(239,1), SYMBOL_HEADER, UPTR0(238), INTCON(15)};
pxll_string constructed_240 = {STRING_HEADER(24), 24, "PXLL_UNDEFINED; result=r" };
pxll_string constructed_241 = {STRING_HEADER(15), 15, "; goto Lreturn;" };
pxll_string constructed_242 = {STRING_HEADER(5), 5, "%exit" };
// symbol %exit
pxll_int constructed_243[] = {UPTR(243,1), SYMBOL_HEADER, UPTR0(242), INTCON(16)};
pxll_string constructed_244 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_245 = {STRING_HEADER(48), 48, " = alloc_no_clear (TC_BUFFER, HOW_MANY (sizeof (" };
pxll_string constructed_246 = {STRING_HEADER(11), 11, ") * unbox(r" };
pxll_string constructed_247 = {STRING_HEADER(21), 21, "), sizeof (object)));" };
pxll_string constructed_248 = {STRING_HEADER(24), 24, "%callocate: dead target?" };
pxll_string constructed_249 = {STRING_HEADER(10), 10, "%callocate" };
// symbol %callocate
pxll_int constructed_250[] = {UPTR(250,1), SYMBOL_HEADER, UPTR0(249), INTCON(17)};
pxll_string constructed_251 = {STRING_HEADER(13), 13, "ensure_heap (" };
pxll_string constructed_252 = {STRING_HEADER(9), 9, ", unbox(r" };
pxll_string constructed_253 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_254 = {STRING_HEADER(12), 12, "%ensure-heap" };
// symbol %ensure-heap
pxll_int constructed_255[] = {UPTR(255,1), SYMBOL_HEADER, UPTR0(254), INTCON(18)};
pxll_string constructed_256 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_257 = {STRING_HEADER(7), 7, ")->val[" };
pxll_string constructed_258 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_259 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_260 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_261 = {STRING_HEADER(36), 36, ")->val[lookup_field((GET_TYPECODE(*r" };
pxll_string constructed_262 = {STRING_HEADER(17), 17, ")-TC_USEROBJ)>>2," };
pxll_string constructed_263 = {STRING_HEADER(6), 6, ")] = r" };
pxll_string constructed_264 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_265 = {STRING_HEADER(11), 11, "%record-set" };
// symbol %record-set
pxll_int constructed_266[] = {UPTR(266,1), SYMBOL_HEADER, UPTR0(265), INTCON(19)};
pxll_string constructed_267 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_268 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_269 = {STRING_HEADER(7), 7, ")->val[" };
pxll_string constructed_270 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_271 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_272 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_273 = {STRING_HEADER(36), 36, ")->val[lookup_field((GET_TYPECODE(*r" };
pxll_string constructed_274 = {STRING_HEADER(17), 17, ")-TC_USEROBJ)>>2," };
pxll_string constructed_275 = {STRING_HEADER(3), 3, ")];" };
pxll_string constructed_276 = {STRING_HEADER(11), 11, "%record-get" };
// symbol %record-get
pxll_int constructed_277[] = {UPTR(277,1), SYMBOL_HEADER, UPTR0(276), INTCON(20)};
pxll_string constructed_278 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_279 = {STRING_HEADER(14), 14, ")->val[unbox(r" };
pxll_string constructed_280 = {STRING_HEADER(6), 6, ")] = r" };
pxll_string constructed_281 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_282 = {STRING_HEADER(41), 41, "range_check (GET_TUPLE_LENGTH(*(object*)r" };
pxll_string constructed_283 = {STRING_HEADER(10), 10, "), unbox(r" };
pxll_string constructed_284 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_285 = {STRING_HEADER(10), 10, "%array-set" };
// symbol %array-set
pxll_int constructed_286[] = {UPTR(286,1), SYMBOL_HEADER, UPTR0(285), INTCON(21)};
pxll_string constructed_287 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_288 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_289 = {STRING_HEADER(14), 14, ")->val[unbox(r" };
pxll_string constructed_290 = {STRING_HEADER(3), 3, ")];" };
pxll_string constructed_291 = {STRING_HEADER(41), 41, "range_check (GET_TUPLE_LENGTH(*(object*)r" };
pxll_string constructed_292 = {STRING_HEADER(10), 10, "), unbox(r" };
pxll_string constructed_293 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_294 = {STRING_HEADER(10), 10, "%array-ref" };
// symbol %array-ref
pxll_int constructed_295[] = {UPTR(295,1), SYMBOL_HEADER, UPTR0(294), INTCON(22)};
pxll_string constructed_296 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_297 = {STRING_HEADER(3), 3, "  r" };
pxll_string constructed_298 = {STRING_HEADER(5), 5, " = t;" };
pxll_string constructed_299 = {STRING_HEADER(21), 21, "  for (i=0; i<unbox(r" };
pxll_string constructed_300 = {STRING_HEADER(20), 20, "); i++) { t[i+1] = r" };
pxll_string constructed_301 = {STRING_HEADER(3), 3, "; }" };
pxll_string constructed_302 = {STRING_HEADER(40), 40, "  t = alloc_no_clear (TC_VECTOR, unbox(r" };
pxll_string constructed_303 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_304 = {STRING_HEADER(11), 11, "if (unbox(r" };
pxll_string constructed_305 = {STRING_HEADER(11), 11, ") == 0) { r" };
pxll_string constructed_306 = {STRING_HEADER(39), 39, " = (object *) TC_EMPTY_VECTOR; } else {" };
pxll_string constructed_307 = {STRING_HEADER(12), 12, "%make-vector" };
// symbol %make-vector
pxll_int constructed_308[] = {UPTR(308,1), SYMBOL_HEADER, UPTR0(307), INTCON(23)};
pxll_string constructed_309 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_310 = {STRING_HEADER(13), 13, " = UOBJ_GET(r" };
pxll_string constructed_311 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_312 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_313 = {STRING_HEADER(6), 6, "%nvget" };
// symbol %nvget
pxll_int constructed_314[] = {UPTR(314,1), SYMBOL_HEADER, UPTR0(313), INTCON(24)};
pxll_string constructed_315 = {STRING_HEADER(29), 29, "emit-primop: no such datatype" };
pxll_string constructed_316 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_317 = {STRING_HEADER(12), 12, " = (object*)" };
pxll_string constructed_318 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_319 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_320 = {STRING_HEADER(5), 5, " = t;" };
pxll_string constructed_321 = {STRING_HEADER(2), 2, "t[" };
pxll_string constructed_322 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_323 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_324 = {STRING_HEADER(20), 20, "t = alloc_no_clear (" };
pxll_string constructed_325 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_326 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_327 = {STRING_HEADER(6), 6, "%dtcon" };
// symbol %dtcon
pxll_int constructed_328[] = {UPTR(328,1), SYMBOL_HEADER, UPTR0(327), INTCON(25)};
pxll_string constructed_329 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_330 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_331 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_332 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_333 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_334 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_335 = {STRING_HEADER(7), 7, "fatbar_" };
pxll_string constructed_336 = {STRING_HEADER(8), 8, "_over: ;" };
pxll_string constructed_337 = {STRING_HEADER(7), 7, "fatbar_" };
pxll_string constructed_338 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_339 = {STRING_HEADER(12), 12, "goto fatbar_" };
pxll_string constructed_340 = {STRING_HEADER(6), 6, "_over;" };
pxll_string constructed_341 = {STRING_HEADER(12), 12, "goto fatbar_" };
pxll_string constructed_342 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_343 = {STRING_HEADER(16), 16, "lenv = ((object " };
pxll_string constructed_344 = {STRING_HEADER(6), 6, ")lenv)" };
pxll_string constructed_345 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_346 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_347 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_348 = {STRING_HEADER(11), 11, "emit-nvcase" };
pxll_string constructed_349 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_350 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_351 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_352 = {STRING_HEADER(8), 8, "} break;" };
pxll_string constructed_353 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_354 = {STRING_HEADER(6), 6, "case (" };
pxll_string constructed_355 = {STRING_HEADER(4), 4, "): {" };
pxll_string constructed_356 = {STRING_HEADER(8), 8, "switch (" };
pxll_string constructed_357 = {STRING_HEADER(3), 3, " (r" };
pxll_string constructed_358 = {STRING_HEADER(4), 4, ")) {" };
pxll_string constructed_359 = {STRING_HEADER(8), 8, "get_case" };
pxll_string constructed_360 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_361 = {STRING_HEADER(2), 2, "};" };
pxll_string constructed_362 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_363 = {STRING_HEADER(8), 8, "} break;" };
pxll_string constructed_364 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_365 = {STRING_HEADER(6), 6, "case (" };
pxll_string constructed_366 = {STRING_HEADER(4), 4, "): {" };
pxll_string constructed_367 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_368 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_369 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_370 = {STRING_HEADER(32), 32, "variant constructor never called" };
pxll_string constructed_371 = {STRING_HEADER(25), 25, "switch (get_case_noint (r" };
pxll_string constructed_372 = {STRING_HEADER(4), 4, ")) {" };
pxll_string constructed_373 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_374 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_375 = {STRING_HEADER(3), 3, ": r" };
pxll_string constructed_376 = {STRING_HEADER(9), 9, " = heap0[" };
pxll_string constructed_377 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_378 = {STRING_HEADER(14), 14, "  switch (n) {" };
pxll_string constructed_379 = {STRING_HEADER(26), 26, "void gc_regs_out (int n) {" };
pxll_string constructed_380 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_381 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_382 = {STRING_HEADER(8), 8, ": heap1[" };
pxll_string constructed_383 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_384 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_385 = {STRING_HEADER(14), 14, "  switch (n) {" };
pxll_string constructed_386 = {STRING_HEADER(25), 25, "void gc_regs_in (int n) {" };
pxll_string constructed_387 = {STRING_HEADER(19), 19, "register object * r" };
pxll_string constructed_388 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_389 = {STRING_HEADER(37), 37, "pxll_int pxll_internal_symbols[] = {(" };
pxll_string constructed_390 = {STRING_HEADER(16), 16, "<<8)|TC_VECTOR, " };
pxll_string constructed_391 = {STRING_HEADER(2), 2, "};" };
pxll_string constructed_392 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_393 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_394 = {STRING_HEADER(3), 3, ",1)" };
pxll_int constructed_395[] = {TC_NIL};
pxll_string constructed_396 = {STRING_HEADER(24), 24, "pxll_string constructed_" };
pxll_string constructed_397 = {STRING_HEADER(18), 18, " = {STRING_HEADER(" };
pxll_string constructed_398 = {STRING_HEADER(3), 3, "), " };
pxll_string constructed_399 = {STRING_HEADER(3), 3, ", \"" };
pxll_string constructed_400 = {STRING_HEADER(4), 4, "\" };" };
pxll_int constructed_401[] = {TC_NIL};
pxll_string constructed_402 = {STRING_HEADER(2), 2, "\\\"" };
pxll_string constructed_403 = {STRING_HEADER(2), 2, "\\\\" };
pxll_string constructed_404 = {STRING_HEADER(2), 2, "\\t" };
pxll_string constructed_405 = {STRING_HEADER(2), 2, "\\n" };
pxll_string constructed_406 = {STRING_HEADER(2), 2, "\\r" };
pxll_string constructed_407 = {STRING_HEADER(1), 1, "0" };
pxll_string constructed_408 = {STRING_HEADER(2), 2, "00" };
pxll_string constructed_409 = {STRING_HEADER(3), 3, "000" };
pxll_string constructed_410 = {STRING_HEADER(30), 30, "unable to oct-encode character" };
pxll_int constructed_411[] = {TC_NIL};
pxll_string constructed_412 = {STRING_HEADER(21), 21, "pxll_int constructed_" };
pxll_string constructed_413 = {STRING_HEADER(11), 11, "[] = {UPTR(" };
pxll_string constructed_414 = {STRING_HEADER(26), 26, ",1), SYMBOL_HEADER, UPTR0(" };
pxll_string constructed_415 = {STRING_HEADER(10), 10, "), INTCON(" };
pxll_string constructed_416 = {STRING_HEADER(3), 3, ")};" };
pxll_string constructed_417 = {STRING_HEADER(10), 10, "// symbol " };
pxll_string constructed_418 = {STRING_HEADER(21), 21, "pxll_int constructed_" };
pxll_string constructed_419 = {STRING_HEADER(6), 6, "[] = {" };
pxll_string constructed_420 = {STRING_HEADER(2), 2, "};" };
pxll_string constructed_421 = {STRING_HEADER(1), 1, "," };
pxll_int constructed_422[] = {TC_NIL};
pxll_string constructed_423 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_424 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_425 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_426 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_427 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_428 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_429 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_430 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_431 = {STRING_HEADER(14), 14, "<<8)|TC_VECTOR" };
pxll_string constructed_432 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_433 = {STRING_HEADER(3), 3, ",1)" };
pxll_string constructed_434 = {STRING_HEADER(15), 15, "unknown symbol?" };
pxll_string constructed_435 = {STRING_HEADER(6), 6, "UPTR0(" };
pxll_string constructed_436 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_437 = {STRING_HEADER(29), 29, "emit-constructed: lost string" };
pxll_string constructed_438 = {STRING_HEADER(6), 6, "TC_NIL" };
pxll_string constructed_439 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_440 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_441 = {STRING_HEADER(11), 11, "CONS_HEADER" };
pxll_string constructed_442 = {STRING_HEADER(7), 7, "UOHEAD(" };
pxll_string constructed_443 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_444 = {STRING_HEADER(1), 1, ")" };
pxll_int constructed_445[] = {TC_NIL};
pxll_string constructed_446 = {STRING_HEADER(39), 39, "template strings not found in header.c?" };
pxll_int constructed_447[] = {TC_NIL};
pxll_string constructed_448 = {STRING_HEADER(8), 8, "header.c" };
pxll_string constructed_449 = {STRING_HEADER(10), 10, "#include <" };
pxll_string constructed_450 = {STRING_HEADER(1), 1, ">" };
pxll_string constructed_451 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_452 = {STRING_HEADER(16), 16, "\n-- C output --\n" };
pxll_string constructed_453 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_454 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_455 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_456 = {STRING_HEADER(18), 18, "\n-- exceptions --\n" };
pxll_string constructed_457 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_458 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_459 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_460 = {STRING_HEADER(22), 22, "\n-- variant labels --\n" };
pxll_string constructed_461 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_462 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_463 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_464 = {STRING_HEADER(15), 15, "\n-- symbols --\n" };
pxll_string constructed_465 = {STRING_HEADER(15), 15, "\n-- records --\n" };
pxll_string constructed_466 = {STRING_HEADER(14), 14, "\n-- labels --\n" };
pxll_string constructed_467 = {STRING_HEADER(17), 17, "\n-- datatypes --\n" };
pxll_string constructed_468 = {STRING_HEADER(11), 11, "\n-- RTL --\n" };
pxll_string constructed_469 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_470 = {STRING_HEADER(2), 2, "  " };
pxll_int constructed_471[] = {TC_NIL};
pxll_int constructed_472[] = {TC_NIL};
pxll_int constructed_473[] = {TC_NIL};
pxll_string constructed_474 = {STRING_HEADER(16), 16, "unbound variable" };
pxll_string constructed_475 = {STRING_HEADER(15), 15, "empty sequence?" };
pxll_string constructed_476 = {STRING_HEADER(6), 6, "vector" };
// symbol vector
pxll_int constructed_477[] = {UPTR(477,1), SYMBOL_HEADER, UPTR0(476), INTCON(26)};
pxll_string constructed_478 = {STRING_HEADER(11), 11, "constructor" };
// symbol constructor
pxll_int constructed_479[] = {UPTR(479,1), SYMBOL_HEADER, UPTR0(478), INTCON(27)};
pxll_string constructed_480 = {STRING_HEADER(13), 13, "c-conditional" };
pxll_string constructed_481 = {STRING_HEADER(3), 3, "pop" };
pxll_int constructed_482[] = {TC_NIL};
pxll_string constructed_483 = {STRING_HEADER(28), 28, "c-call function in register?" };
pxll_string constructed_484 = {STRING_HEADER(20), 20, "c-call: no function?" };
pxll_string constructed_485 = {STRING_HEADER(11), 11, "%exn-handle" };
// symbol %exn-handle
pxll_int constructed_486[] = {UPTR(486,1), SYMBOL_HEADER, UPTR0(485), INTCON(28)};
pxll_string constructed_487 = {STRING_HEADER(10), 10, "%exn-raise" };
// symbol %exn-raise
pxll_int constructed_488[] = {UPTR(488,1), SYMBOL_HEADER, UPTR0(487), INTCON(29)};
pxll_string constructed_489 = {STRING_HEADER(6), 6, "buffer" };
// symbol buffer
pxll_int constructed_490[] = {UPTR(490,1), SYMBOL_HEADER, UPTR0(489), INTCON(30)};
pxll_string constructed_491 = {STRING_HEADER(5), 5, "%rset" };
// symbol %rset
pxll_int constructed_492[] = {UPTR(492,1), SYMBOL_HEADER, UPTR0(491), INTCON(31)};
pxll_string constructed_493 = {STRING_HEADER(8), 8, "%raccess" };
// symbol %raccess
pxll_int constructed_494[] = {UPTR(494,1), SYMBOL_HEADER, UPTR0(493), INTCON(32)};
pxll_int constructed_495[] = {TC_NIL};
pxll_string constructed_496 = {STRING_HEADER(6), 6, "%rmake" };
// symbol %rmake
pxll_int constructed_497[] = {UPTR(497,1), SYMBOL_HEADER, UPTR0(496), INTCON(33)};
pxll_string constructed_498 = {STRING_HEADER(18), 18, "malformed %rextend" };
pxll_string constructed_499 = {STRING_HEADER(8), 8, "%rextend" };
// symbol %rextend
pxll_int constructed_500[] = {UPTR(500,1), SYMBOL_HEADER, UPTR0(499), INTCON(34)};
pxll_string constructed_501 = {STRING_HEADER(23), 23, "c-record-extension: NYI" };
pxll_string constructed_502 = {STRING_HEADER(22), 22, "unknown variant label?" };
pxll_string constructed_503 = {STRING_HEADER(16), 16, "bad %vcon params" };
pxll_string constructed_504 = {STRING_HEADER(5), 5, "%vcon" };
// symbol %vcon
pxll_int constructed_505[] = {UPTR(505,1), SYMBOL_HEADER, UPTR0(504), INTCON(35)};
pxll_string constructed_506 = {STRING_HEADER(7), 7, "%fatbar" };
// symbol %fatbar
pxll_int constructed_507[] = {UPTR(507,1), SYMBOL_HEADER, UPTR0(506), INTCON(36)};
pxll_string constructed_508 = {STRING_HEADER(21), 21, "%fail without fatbar?" };
pxll_string constructed_509 = {STRING_HEADER(5), 5, "%fail" };
// symbol %fail
pxll_int constructed_510[] = {UPTR(510,1), SYMBOL_HEADER, UPTR0(509), INTCON(37)};
pxll_string constructed_511 = {STRING_HEADER(12), 12, "%match-error" };
// symbol %match-error
pxll_int constructed_512[] = {UPTR(512,1), SYMBOL_HEADER, UPTR0(511), INTCON(38)};
pxll_string constructed_513 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_514 = {STRING_HEADER(16), 16, "incomplete match" };
pxll_int constructed_515[] = {TC_NIL};
pxll_string constructed_516 = {STRING_HEADER(13), 13, "add-free-regs" };
pxll_string constructed_517 = {STRING_HEADER(3), 3, "top" };
// symbol top
pxll_int constructed_518[] = {UPTR(518,1), SYMBOL_HEADER, UPTR0(517), INTCON(39)};
pxll_int constructed_519[] = {UPTR(519,1),CONS_HEADER,UPTR(518,1),TC_NIL};
pxll_string constructed_520 = {STRING_HEADER(7), 7, "cps...\n" };
pxll_string constructed_521 = {STRING_HEADER(20), 20, "\n-- after typing --\n" };
pxll_string constructed_522 = {STRING_HEADER(16), 16, "  unifying with " };
pxll_string constructed_523 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_524 = {STRING_HEADER(15), 15, "global type of " };
pxll_string constructed_525 = {STRING_HEADER(4), 4, " is " };
pxll_string constructed_526 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_527 = {STRING_HEADER(6), 6, "rlabel" };
// symbol rlabel
pxll_int constructed_528[] = {UPTR(528,1), SYMBOL_HEADER, UPTR0(527), INTCON(40)};
pxll_string constructed_529 = {STRING_HEADER(31), 31, "unify-exception-types: bad type" };
pxll_int constructed_530[] = {TC_NIL};
pxll_string constructed_531 = {STRING_HEADER(28), 28, "apply-tenv: unbound variable" };
pxll_string constructed_532 = {STRING_HEADER(3), 3, "raw" };
// symbol raw
pxll_int constructed_533[] = {UPTR(533,1), SYMBOL_HEADER, UPTR0(532), INTCON(41)};
pxll_string constructed_534 = {STRING_HEADER(26), 26, "strange constructor scheme" };
pxll_string constructed_535 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_536 = {STRING_HEADER(28), 28, "wrong number of args to cexp" };
pxll_string constructed_537 = {STRING_HEADER(20), 20, "malformed arrow type" };
pxll_string constructed_538 = {STRING_HEADER(21), 21, "malformed conditional" };
pxll_string constructed_539 = {STRING_HEADER(15), 15, "empty sequence?" };
pxll_int constructed_540[] = {TC_NIL};
pxll_int constructed_541[] = {TC_NIL};
pxll_string constructed_542 = {STRING_HEADER(1), 1, "?" };
// symbol ?
pxll_int constructed_543[] = {UPTR(543,1), SYMBOL_HEADER, UPTR0(542), INTCON(42)};
pxll_string constructed_544 = {STRING_HEADER(11), 11, "empty call?" };
pxll_int constructed_545[] = {TC_NIL};
pxll_int constructed_546[] = {TC_NIL};
pxll_int constructed_547[] = {TC_NIL};
pxll_int constructed_548[] = {TC_NIL};
pxll_int constructed_549[] = {TC_NIL};
pxll_int constructed_550[] = {TC_NIL};
pxll_int constructed_551[] = {TC_NIL};
pxll_int constructed_552[] = {TC_NIL};
pxll_int constructed_553[] = {TC_NIL};
pxll_string constructed_554 = {STRING_HEADER(4), 4, "rsum" };
// symbol rsum
pxll_int constructed_555[] = {UPTR(555,1), SYMBOL_HEADER, UPTR0(554), INTCON(43)};
pxll_string constructed_556 = {STRING_HEADER(37), 37, "unify-handlers: expected row sum type" };
pxll_string constructed_557 = {STRING_HEADER(16), 16, "type-of-handle: " };
pxll_string constructed_558 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_559 = {STRING_HEADER(22), 22, "%exn-handle: bad arity" };
pxll_string constructed_560 = {STRING_HEADER(19), 19, "bad exception type:" };
pxll_string constructed_561 = {STRING_HEADER(20), 20, "bad exception type:\n" };
pxll_string constructed_562 = {STRING_HEADER(21), 21, "%exn-raise: bad arity" };
pxll_string constructed_563 = {STRING_HEADER(31), 31, "wrong number of args to primapp" };
pxll_string constructed_564 = {STRING_HEADER(15), 15, "type-of-primapp" };
pxll_string constructed_565 = {STRING_HEADER(12), 12, "continuation" };
// symbol continuation
pxll_int constructed_566[] = {UPTR(566,1), SYMBOL_HEADER, UPTR0(565), INTCON(44)};
pxll_int constructed_567[] = {TC_NIL};
pxll_string constructed_568 = {STRING_HEADER(3), 3, "pre" };
// symbol pre
pxll_int constructed_569[] = {UPTR(569,1), SYMBOL_HEADER, UPTR0(568), INTCON(45)};
pxll_string constructed_570 = {STRING_HEADER(7), 7, "product" };
// symbol product
pxll_int constructed_571[] = {UPTR(571,1), SYMBOL_HEADER, UPTR0(570), INTCON(46)};
pxll_int constructed_572[] = {TC_NIL};
pxll_string constructed_573 = {STRING_HEADER(32), 32, "lookup-primapp: no such datatype" };
pxll_string constructed_574 = {STRING_HEADER(24), 24, "bad parameters to primop" };
pxll_int constructed_575[] = {TC_NIL};
pxll_int constructed_576[] = {TC_NIL};
pxll_string constructed_577 = {STRING_HEADER(32), 32, "lookup-primapp: no such datatype" };
pxll_string constructed_578 = {STRING_HEADER(8), 8, "rproduct" };
// symbol rproduct
pxll_int constructed_579[] = {UPTR(579,1), SYMBOL_HEADER, UPTR0(578), INTCON(47)};
pxll_int constructed_580[] = {TC_NIL};
pxll_int constructed_581[] = {TC_NIL};
pxll_string constructed_582 = {STRING_HEADER(8), 8, "rdefault" };
// symbol rdefault
pxll_int constructed_583[] = {UPTR(583,1), SYMBOL_HEADER, UPTR0(582), INTCON(48)};
pxll_int constructed_584[] = {TC_NIL};
pxll_string constructed_585 = {STRING_HEADER(3), 3, "abs" };
// symbol abs
pxll_int constructed_586[] = {UPTR(586,1), SYMBOL_HEADER, UPTR0(585), INTCON(49)};
pxll_int constructed_587[] = {TC_NIL};
pxll_int constructed_588[] = {TC_NIL};
pxll_int constructed_589[] = {TC_NIL};
pxll_string constructed_590 = {STRING_HEADER(14), 14, "lookup-primapp" };
pxll_string constructed_591 = {STRING_HEADER(16), 16, "malformed pvcase" };
pxll_string constructed_592 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_593 = {STRING_HEADER(10), 10, "typing NYI" };
pxll_int constructed_594[] = {TC_NIL};
pxll_string constructed_595 = {STRING_HEADER(23), 23, "instantiate-type-scheme" };
pxll_string constructed_596 = {STRING_HEADER(10), 10, "typing...\n" };
pxll_int constructed_597[] = {TC_NIL};
pxll_string constructed_598 = {STRING_HEADER(3), 3, "pop" };
pxll_int constructed_599[] = {TC_NIL};
pxll_int constructed_600[] = {TC_NIL};
pxll_int constructed_601[] = {TC_NIL};
pxll_int constructed_602[] = {TC_NIL};
pxll_int constructed_603[] = {TC_NIL};
pxll_int constructed_604[] = {TC_NIL};
pxll_string constructed_605 = {STRING_HEADER(31), 31, "strongly-connected components:\n" };
pxll_string constructed_606 = {STRING_HEADER(20), 20, "after second round:\n" };
pxll_int constructed_607[] = {TC_NIL};
pxll_int constructed_608[] = {TC_NIL};
pxll_string constructed_609 = {STRING_HEADER(7), 7, "lambda_" };
pxll_string constructed_610 = {STRING_HEADER(6), 6, "lambda" };
// symbol lambda
pxll_int constructed_611[] = {UPTR(611,1), SYMBOL_HEADER, UPTR0(610), INTCON(50)};
pxll_int constructed_612[] = {TC_NIL};
pxll_int constructed_613[] = {TC_NIL};
pxll_int constructed_614[] = {TC_NIL};
pxll_int constructed_615[] = {TC_NIL};
pxll_string constructed_616 = {STRING_HEADER(2), 2, ".c" };
pxll_string constructed_617 = {STRING_HEADER(9), 9, "find-base" };
pxll_string constructed_618 = {STRING_HEADER(1), 1, "." };
pxll_string constructed_619 = {STRING_HEADER(3), 3, "scm" };
pxll_string constructed_620 = {STRING_HEADER(2), 2, "if" };
// symbol if
pxll_int constructed_621[] = {UPTR(621,1), SYMBOL_HEADER, UPTR0(620), INTCON(51)};
pxll_string constructed_622 = {STRING_HEADER(4), 4, "set!" };
// symbol set!
pxll_int constructed_623[] = {UPTR(623,1), SYMBOL_HEADER, UPTR0(622), INTCON(52)};
pxll_string constructed_624 = {STRING_HEADER(5), 5, "begin" };
// symbol begin
pxll_int constructed_625[] = {UPTR(625,1), SYMBOL_HEADER, UPTR0(624), INTCON(53)};
pxll_string constructed_626 = {STRING_HEADER(8), 8, "function" };
// symbol function
pxll_int constructed_627[] = {UPTR(627,1), SYMBOL_HEADER, UPTR0(626), INTCON(54)};
pxll_string constructed_628 = {STRING_HEADER(5), 5, "vcase" };
// symbol vcase
pxll_int constructed_629[] = {UPTR(629,1), SYMBOL_HEADER, UPTR0(628), INTCON(55)};
pxll_string constructed_630 = {STRING_HEADER(9), 9, "let-splat" };
// symbol let-splat
pxll_int constructed_631[] = {UPTR(631,1), SYMBOL_HEADER, UPTR0(630), INTCON(56)};
pxll_string constructed_632 = {STRING_HEADER(5), 5, "match" };
// symbol match
pxll_int constructed_633[] = {UPTR(633,1), SYMBOL_HEADER, UPTR0(632), INTCON(57)};
pxll_string constructed_634 = {STRING_HEADER(8), 8, "cinclude" };
// symbol cinclude
pxll_int constructed_635[] = {UPTR(635,1), SYMBOL_HEADER, UPTR0(634), INTCON(58)};
pxll_string constructed_636 = {STRING_HEADER(9), 9, "cverbatim" };
// symbol cverbatim
pxll_int constructed_637[] = {UPTR(637,1), SYMBOL_HEADER, UPTR0(636), INTCON(59)};
pxll_string constructed_638 = {STRING_HEADER(7), 7, "%nvcase" };
// symbol %nvcase
pxll_int constructed_639[] = {UPTR(639,1), SYMBOL_HEADER, UPTR0(638), INTCON(60)};
pxll_string constructed_640 = {STRING_HEADER(6), 6, "%%cexp" };
// symbol %%cexp
pxll_int constructed_641[] = {UPTR(641,1), SYMBOL_HEADER, UPTR0(640), INTCON(61)};
pxll_string constructed_642 = {STRING_HEADER(16), 16, "malformed %%cexp" };
pxll_string constructed_643 = {STRING_HEADER(21), 21, "malformed <cverbatim>" };
pxll_string constructed_644 = {STRING_HEADER(20), 20, "malformed <cinclude>" };
pxll_int constructed_645[] = {TC_NIL};
pxll_int constructed_646[] = {TC_NIL};
pxll_string constructed_647 = {STRING_HEADER(3), 3, "let" };
// symbol let
pxll_int constructed_648[] = {UPTR(648,1), SYMBOL_HEADER, UPTR0(647), INTCON(62)};
pxll_string constructed_649 = {STRING_HEADER(4), 4, "with" };
// symbol with
pxll_int constructed_650[] = {UPTR(650,1), SYMBOL_HEADER, UPTR0(649), INTCON(63)};
pxll_string constructed_651 = {STRING_HEADER(26), 26, "malformed match expression" };
pxll_string constructed_652 = {STRING_HEADER(10), 10, "  parsed: " };
pxll_string constructed_653 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_654 = {STRING_HEADER(21), 21, "user type in define: " };
pxll_string constructed_655 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_656 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_657 = {STRING_HEADER(3), 3, "arg" };
pxll_string constructed_658 = {STRING_HEADER(1), 1, ":" };
pxll_int constructed_659[] = {TC_NIL};
pxll_int constructed_660[] = {TC_NIL};
pxll_int constructed_661[] = {TC_NIL};
pxll_int constructed_662[] = {TC_NIL};
pxll_int constructed_663[] = {TC_NIL};
pxll_string constructed_664 = {STRING_HEADER(4), 4, "else" };
// symbol else
pxll_int constructed_665[] = {UPTR(665,1), SYMBOL_HEADER, UPTR0(664), INTCON(64)};
pxll_string constructed_666 = {STRING_HEADER(10), 10, "split-alts" };
pxll_int constructed_667[] = {TC_NIL};
pxll_string constructed_668 = {STRING_HEADER(1), 1, "_" };
// symbol _
pxll_int constructed_669[] = {UPTR(669,1), SYMBOL_HEADER, UPTR0(668), INTCON(65)};
pxll_int constructed_670[] = {TC_NIL};
pxll_int constructed_671[] = {TC_NIL};
pxll_string constructed_672 = {STRING_HEADER(12), 12, "expand-vcase" };
pxll_string constructed_673 = {STRING_HEADER(18), 18, "malformed FUNCTION" };
pxll_string constructed_674 = {STRING_HEADER(16), 16, "malformed LAMBDA" };
pxll_string constructed_675 = {STRING_HEADER(30), 30, "malformed binding in LET-SPLAT" };
pxll_string constructed_676 = {STRING_HEADER(19), 19, "malformed LET-SPLAT" };
pxll_string constructed_677 = {STRING_HEADER(11), 11, "empty BEGIN" };
pxll_string constructed_678 = {STRING_HEADER(14), 14, "malformed set!" };
pxll_string constructed_679 = {STRING_HEADER(14), 14, "malformed set!" };
pxll_string constructed_680 = {STRING_HEADER(14), 14, "malformed <if>" };
pxll_int constructed_681[] = {TC_NIL};
pxll_string constructed_682 = {STRING_HEADER(1), 1, "o" };
// symbol o
pxll_int constructed_683[] = {UPTR(683,1), SYMBOL_HEADER, UPTR0(682), INTCON(66)};
pxll_string constructed_684 = {STRING_HEADER(7), 7, "%method" };
// symbol %method
pxll_int constructed_685[] = {UPTR(685,1), SYMBOL_HEADER, UPTR0(684), INTCON(67)};
pxll_int constructed_686[] = {TC_NIL};
pxll_int constructed_687[] = {TC_NIL};
pxll_int constructed_688[] = {TC_NIL};
pxll_string constructed_689 = {STRING_HEADER(20), 20, "malformed definition" };
pxll_string constructed_690 = {STRING_HEADER(2), 2, "->" };
// symbol ->
pxll_int constructed_691[] = {UPTR(691,1), SYMBOL_HEADER, UPTR0(690), INTCON(68)};
pxll_string constructed_692 = {STRING_HEADER(6), 6, "%typed" };
// symbol %typed
pxll_int constructed_693[] = {UPTR(693,1), SYMBOL_HEADER, UPTR0(692), INTCON(69)};
pxll_string constructed_694 = {STRING_HEADER(18), 18, "malformed <define>" };
pxll_string constructed_695 = {STRING_HEADER(6), 6, "define" };
// symbol define
pxll_int constructed_696[] = {UPTR(696,1), SYMBOL_HEADER, UPTR0(695), INTCON(70)};
pxll_int constructed_697[] = {TC_NIL};
pxll_string constructed_698 = {STRING_HEADER(2), 2, ")\n" };
pxll_string constructed_699 = {STRING_HEADER(2), 2, "\n\t" };
pxll_string constructed_700 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_701 = {STRING_HEADER(3), 3, ">\n\t" };
pxll_string constructed_702 = {STRING_HEADER(8), 8, "(macro <" };
pxll_string constructed_703 = {STRING_HEADER(5), 5, "  -> " };
pxll_string constructed_704 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_705 = {STRING_HEADER(16), 16, "expanding macro " };
pxll_string constructed_706 = {STRING_HEADER(4), 4, " in " };
pxll_string constructed_707 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_708 = {STRING_HEADER(28), 28, "no matching clause for macro" };
pxll_int constructed_709[] = {TC_NIL};
pxll_string constructed_710 = {STRING_HEADER(27), 27, "malformed macro definition:" };
pxll_string constructed_711 = {STRING_HEADER(27), 27, "malformed macro definition:" };
pxll_string constructed_712 = {STRING_HEADER(8), 8, "defmacro" };
// symbol defmacro
pxll_int constructed_713[] = {UPTR(713,1), SYMBOL_HEADER, UPTR0(712), INTCON(71)};
pxll_string constructed_714 = {STRING_HEADER(25), 25, "malformed alt in datatype" };
pxll_string constructed_715 = {STRING_HEADER(23), 23, "no such alt in datatype" };
pxll_string constructed_716 = {STRING_HEADER(23), 23, "no such alt in datatype" };
pxll_string constructed_717 = {STRING_HEADER(18), 18, "malformed datatype" };
pxll_string constructed_718 = {STRING_HEADER(8), 8, "datatype" };
// symbol datatype
pxll_int constructed_719[] = {UPTR(719,1), SYMBOL_HEADER, UPTR0(718), INTCON(72)};
pxll_int constructed_720[] = {TC_NIL};
pxll_int constructed_721[] = {TC_NIL};
pxll_string constructed_722 = {STRING_HEADER(3), 3, "fix" };
// symbol fix
pxll_int constructed_723[] = {UPTR(723,1), SYMBOL_HEADER, UPTR0(722), INTCON(73)};
pxll_int constructed_724[] = {TC_NIL};
pxll_string constructed_725 = {STRING_HEADER(39), 39, "unexpected s-expression in transformer:" };
pxll_string constructed_726 = {STRING_HEADER(2), 2, "-O" };
pxll_string constructed_727 = {STRING_HEADER(2), 2, "-m" };
pxll_string constructed_728 = {STRING_HEADER(2), 2, "-f" };
pxll_string constructed_729 = {STRING_HEADER(2), 2, "-t" };
pxll_string constructed_730 = {STRING_HEADER(2), 2, "-v" };
pxll_string constructed_731 = {STRING_HEADER(2), 2, "-c" };
pxll_string constructed_732 = {STRING_HEADER(16), 16, "self/selfmac.scm" };
pxll_int constructed_733[] = {TC_NIL};
pxll_int constructed_734[] = {TC_NIL};
pxll_string constructed_735 = {STRING_HEADER(0), 0, "" };
pxll_int constructed_736[] = {TC_NIL};
pxll_int constructed_737[] = {TC_NIL};
pxll_int constructed_738[] = {TC_NIL};
pxll_int constructed_739[] = {TC_NIL};
pxll_string constructed_740 = {STRING_HEADER(31), 31, "Usage: compile <irken-src-file>" };
pxll_string constructed_741 = {STRING_HEADER(3), 3, "-I." };
pxll_string constructed_742 = {STRING_HEADER(3), 3, "gcc" };
pxll_string constructed_743 = {STRING_HEADER(28), 28, "// REGISTER_DECLARATIONS //\n" };
pxll_string constructed_744 = {STRING_HEADER(27), 27, "// CONSTRUCTED LITERALS //\n" };
pxll_string constructed_745 = {STRING_HEADER(95), 95, "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~ " };
pxll_string constructed_746 = {STRING_HEADER(7), 7, "uint8_t" };
// symbol uint8_t
pxll_int constructed_747[] = {UPTR(747,1), SYMBOL_HEADER, UPTR0(746), INTCON(74)};
pxll_string constructed_748 = {STRING_HEADER(8), 8, "uint16_t" };
// symbol uint16_t
pxll_int constructed_749[] = {UPTR(749,1), SYMBOL_HEADER, UPTR0(748), INTCON(75)};
pxll_string constructed_750 = {STRING_HEADER(8), 8, "uint32_t" };
// symbol uint32_t
pxll_int constructed_751[] = {UPTR(751,1), SYMBOL_HEADER, UPTR0(750), INTCON(76)};
pxll_string constructed_752 = {STRING_HEADER(8), 8, "uint64_t" };
// symbol uint64_t
pxll_int constructed_753[] = {UPTR(753,1), SYMBOL_HEADER, UPTR0(752), INTCON(77)};
pxll_string constructed_754 = {STRING_HEADER(6), 6, "int8_t" };
// symbol int8_t
pxll_int constructed_755[] = {UPTR(755,1), SYMBOL_HEADER, UPTR0(754), INTCON(78)};
pxll_string constructed_756 = {STRING_HEADER(7), 7, "int16_t" };
// symbol int16_t
pxll_int constructed_757[] = {UPTR(757,1), SYMBOL_HEADER, UPTR0(756), INTCON(79)};
pxll_string constructed_758 = {STRING_HEADER(7), 7, "int32_t" };
// symbol int32_t
pxll_int constructed_759[] = {UPTR(759,1), SYMBOL_HEADER, UPTR0(758), INTCON(80)};
pxll_string constructed_760 = {STRING_HEADER(7), 7, "int64_t" };
// symbol int64_t
pxll_int constructed_761[] = {UPTR(761,1), SYMBOL_HEADER, UPTR0(760), INTCON(81)};
pxll_int constructed_762[] = {UPTR(762,22),CONS_HEADER,UPTR(761,1),TC_NIL,CONS_HEADER,UPTR(759,1),UPTR(762,1),CONS_HEADER,UPTR(757,1),UPTR(762,4),CONS_HEADER,UPTR(755,1),UPTR(762,7),CONS_HEADER,UPTR(753,1),UPTR(762,10),CONS_HEADER,UPTR(751,1),UPTR(762,13),CONS_HEADER,UPTR(749,1),UPTR(762,16),CONS_HEADER,UPTR(747,1),UPTR(762,19)};
pxll_string constructed_763 = {STRING_HEADER(1), 1, "L" };
pxll_int constructed_764[] = {TC_NIL};
pxll_string constructed_765 = {STRING_HEADER(26), 26, "key already present in map" };
pxll_int constructed_766[] = {TC_NIL};
pxll_int constructed_767[] = {TC_NIL};
pxll_int constructed_768[] = {TC_NIL};
pxll_int constructed_769[] = {TC_NIL};
pxll_string constructed_770 = {STRING_HEADER(4), 4, "char" };
// symbol char
pxll_int constructed_771[] = {UPTR(771,1), SYMBOL_HEADER, UPTR0(770), INTCON(82)};
pxll_string constructed_772 = {STRING_HEADER(9), 9, "undefined" };
// symbol undefined
pxll_int constructed_773[] = {UPTR(773,1), SYMBOL_HEADER, UPTR0(772), INTCON(83)};
pxll_int constructed_774[] = {TC_NIL};
pxll_int constructed_775[] = {TC_NIL};
pxll_int constructed_776[] = {TC_NIL};
pxll_int constructed_777[] = {TC_NIL};
pxll_int constructed_778[] = {TC_NIL};
pxll_int constructed_779[] = {TC_NIL};
pxll_int constructed_780[] = {UPTR(780,10),CONS_HEADER,3330,TC_NIL,CONS_HEADER,2562,UPTR(780,1),CONS_HEADER,2306,UPTR(780,4),CONS_HEADER,8194,UPTR(780,7)};
pxll_string constructed_781 = {STRING_HEADER(10), 10, "0123456789" };
pxll_string constructed_782 = {STRING_HEADER(52), 52, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" };
pxll_string constructed_783 = {STRING_HEADER(7), 7, "()[]{}:" };
pxll_int constructed_784[] = {UPTR(784,10),CONS_HEADER,3330,TC_NIL,CONS_HEADER,2562,UPTR(784,1),CONS_HEADER,2306,UPTR(784,4),CONS_HEADER,8194,UPTR(784,7)};
pxll_int constructed_785[] = {UPTR(785,29),UOHEAD(3,1),14082,15,UITAG(0),UOHEAD(3,1),13826,13,UPTR(785,1),UOHEAD(3,1),13570,11,UPTR(785,5),UOHEAD(3,1),13314,9,UPTR(785,9),UOHEAD(3,1),13058,7,UPTR(785,13),UOHEAD(3,1),12802,5,UPTR(785,17),UOHEAD(3,1),12546,3,UPTR(785,21),UOHEAD(3,1),12290,1,UPTR(785,25)};
pxll_int constructed_786[] = {UPTR(786,37),UOHEAD(3,1),14594,19,UITAG(0),UOHEAD(3,1),14338,17,UPTR(786,1),UOHEAD(3,1),14082,15,UPTR(786,5),UOHEAD(3,1),13826,13,UPTR(786,9),UOHEAD(3,1),13570,11,UPTR(786,13),UOHEAD(3,1),13314,9,UPTR(786,17),UOHEAD(3,1),13058,7,UPTR(786,21),UOHEAD(3,1),12802,5,UPTR(786,25),UOHEAD(3,1),12546,3,UPTR(786,29),UOHEAD(3,1),12290,1,UPTR(786,33)};
pxll_int constructed_787[] = {UPTR(787,85),UOHEAD(3,1),17922,31,UITAG(0),UOHEAD(3,1),17666,29,UPTR(787,1),UOHEAD(3,1),17410,27,UPTR(787,5),UOHEAD(3,1),17154,25,UPTR(787,9),UOHEAD(3,1),16898,23,UPTR(787,13),UOHEAD(3,1),16642,21,UPTR(787,17),UOHEAD(3,1),26114,31,UPTR(787,21),UOHEAD(3,1),25858,29,UPTR(787,25),UOHEAD(3,1),25602,27,UPTR(787,29),UOHEAD(3,1),25346,25,UPTR(787,33),UOHEAD(3,1),25090,23,UPTR(787,37),UOHEAD(3,1),24834,21,UPTR(787,41),UOHEAD(3,1),14594,19,UPTR(787,45),UOHEAD(3,1),14338,17,UPTR(787,49),UOHEAD(3,1),14082,15,UPTR(787,53),UOHEAD(3,1),13826,13,UPTR(787,57),UOHEAD(3,1),13570,11,UPTR(787,61),UOHEAD(3,1),13314,9,UPTR(787,65),UOHEAD(3,1),13058,7,UPTR(787,69),UOHEAD(3,1),12802,5,UPTR(787,73),UOHEAD(3,1),12546,3,UPTR(787,77),UOHEAD(3,1),12290,1,UPTR(787,81)};
pxll_string constructed_788 = {STRING_HEADER(0), 0, "" };
pxll_int constructed_789[] = {UPTR(789,1),(16<<8)|TC_VECTOR,12290,12546,12802,13058,13314,13570,13826,14082,14338,14594,24834,25090,25346,25602,25858,26114};
pxll_string constructed_790 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_791 = {STRING_HEADER(30), 30, "malformed cexp template string" };
pxll_string constructed_792 = {STRING_HEADER(1), 1, "%" };
pxll_string constructed_793 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_794 = {STRING_HEADER(30), 30, "malformed cexp template string" };
pxll_string constructed_795 = {STRING_HEADER(9), 9, "(object*)" };
pxll_string constructed_796 = {STRING_HEADER(3), 3, "ptr" };
// symbol ptr
pxll_int constructed_797[] = {UPTR(797,1), SYMBOL_HEADER, UPTR0(796), INTCON(84)};
pxll_string constructed_798 = {STRING_HEADER(9), 9, "(object*)" };
pxll_string constructed_799 = {STRING_HEADER(7), 7, "cstring" };
// symbol cstring
pxll_int constructed_800[] = {UPTR(800,1), SYMBOL_HEADER, UPTR0(799), INTCON(85)};
pxll_string constructed_801 = {STRING_HEADER(10), 10, "PXLL_TEST(" };
pxll_string constructed_802 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_803 = {STRING_HEADER(14), 14, "box((pxll_int)" };
pxll_string constructed_804 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_805 = {STRING_HEADER(14), 14, "box((pxll_int)" };
pxll_string constructed_806 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_807 = {STRING_HEADER(7), 7, "struct " };
pxll_string constructed_808 = {STRING_HEADER(6), 6, "struct" };
// symbol struct
pxll_int constructed_809[] = {UPTR(809,1), SYMBOL_HEADER, UPTR0(808), INTCON(86)};
pxll_string constructed_810 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_811 = {STRING_HEADER(2), 2, "*)" };
pxll_string constructed_812 = {STRING_HEADER(15), 15, "malformed ctype" };
pxll_string constructed_813 = {STRING_HEADER(16), 16, "((pxll_string*)(" };
pxll_string constructed_814 = {STRING_HEADER(2), 2, "))" };
pxll_string constructed_815 = {STRING_HEADER(25), 25, "unknown raw type in %cexp" };
pxll_string constructed_816 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_817 = {STRING_HEADER(16), 16, "(((pxll_vector*)" };
pxll_string constructed_818 = {STRING_HEADER(5), 5, ")+1))" };
pxll_string constructed_819 = {STRING_HEADER(7), 7, "(char*)" };
pxll_string constructed_820 = {STRING_HEADER(16), 16, "((pxll_string*)(" };
pxll_string constructed_821 = {STRING_HEADER(8), 8, "))->data" };
pxll_string constructed_822 = {STRING_HEADER(6), 6, "unbox(" };
pxll_string constructed_823 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_824 = {STRING_HEADER(6), 6, "unbox(" };
pxll_string constructed_825 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_826 = {STRING_HEADER(8), 8, "wrap-in:" };
pxll_string constructed_827 = {STRING_HEADER(27), 27, "expected immediate literal " };
pxll_string constructed_828 = {STRING_HEADER(17), 17, "inline: bad arity" };
pxll_int constructed_829[] = {TC_NIL};
pxll_string constructed_830 = {STRING_HEADER(2), 2, "_i" };
pxll_int constructed_831[] = {TC_NIL};
pxll_int constructed_832[] = {TC_NIL};
pxll_int constructed_833[] = {TC_NIL};
pxll_int constructed_834[] = {TC_NIL};
pxll_string constructed_835 = {STRING_HEADER(2), 2, "_i" };
pxll_int constructed_836[] = {TC_NIL};
pxll_string constructed_837 = {STRING_HEADER(43), 43, "inline-application - inlining non-function?" };
pxll_int constructed_838[] = {TC_NIL};
pxll_int constructed_839[] = {TC_NIL};
pxll_int constructed_840[] = {TC_NIL};
pxll_int constructed_841[] = {TC_NIL};
pxll_int constructed_842[] = {TC_NIL};
pxll_int constructed_843[] = {TC_NIL};
pxll_int constructed_844[] = {TC_NIL};
pxll_string constructed_845 = {STRING_HEADER(33), 33, "find-escaping-funs: failed lookup" };
pxll_int constructed_846[] = {TC_NIL};
pxll_int constructed_847[] = {TC_NIL};
pxll_int constructed_848[] = {TC_NIL};
pxll_string constructed_849 = {STRING_HEADER(11), 11, "simpleopt: " };
pxll_string constructed_850 = {STRING_HEADER(1), 1, "\n" };
pxll_int constructed_851[] = {TC_NIL};
pxll_int constructed_852[] = {TC_NIL};
pxll_string constructed_853 = {STRING_HEADER(3), 3, "moo" };
// symbol moo
pxll_int constructed_854[] = {UPTR(854,1), SYMBOL_HEADER, UPTR0(853), INTCON(87)};
pxll_string constructed_855 = {STRING_HEADER(10), 10, "type error" };
pxll_string constructed_856 = {STRING_HEADER(14), 14, "\nType Error:\n\t" };
pxll_string constructed_857 = {STRING_HEADER(2), 2, "\n\t" };
pxll_string constructed_858 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_859 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_860 = {STRING_HEADER(5), 5, "- ret" };
pxll_string constructed_861 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_862 = {STRING_HEADER(4), 4, "tail" };
pxll_string constructed_863 = {STRING_HEADER(6), 6, "trcall" };
pxll_string constructed_864 = {STRING_HEADER(3), 3, "lit" };
pxll_string constructed_865 = {STRING_HEADER(6), 6, "litcon" };
pxll_string constructed_866 = {STRING_HEADER(4), 4, "cexp" };
pxll_string constructed_867 = {STRING_HEADER(4), 4, "test" };
pxll_string constructed_868 = {STRING_HEADER(3), 3, "jmp" };
pxll_string constructed_869 = {STRING_HEADER(5), 5, "close" };
pxll_string constructed_870 = {STRING_HEADER(3), 3, "ref" };
pxll_string constructed_871 = {STRING_HEADER(3), 3, "set" };
pxll_string constructed_872 = {STRING_HEADER(4), 4, "stor" };
pxll_string constructed_873 = {STRING_HEADER(6), 6, "invoke" };
pxll_string constructed_874 = {STRING_HEADER(3), 3, "env" };
pxll_string constructed_875 = {STRING_HEADER(5), 5, "alloc" };
pxll_string constructed_876 = {STRING_HEADER(4), 4, "push" };
pxll_string constructed_877 = {STRING_HEADER(3), 3, "pop" };
pxll_string constructed_878 = {STRING_HEADER(6), 6, "primop" };
pxll_string constructed_879 = {STRING_HEADER(4), 4, "move" };
pxll_string constructed_880 = {STRING_HEADER(6), 6, "fatbar" };
pxll_string constructed_881 = {STRING_HEADER(4), 4, "fail" };
pxll_string constructed_882 = {STRING_HEADER(8), 8, "testcexp" };
pxll_string constructed_883 = {STRING_HEADER(6), 6, "nvcase" };
pxll_string constructed_884 = {STRING_HEADER(6), 6, "pvcase" };
pxll_string constructed_885 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_886 = {STRING_HEADER(1), 1, "-" };
pxll_string constructed_887 = {STRING_HEADER(2), 2, "- " };
pxll_string constructed_888 = {STRING_HEADER(8), 8, "k/target" };
pxll_string constructed_889 = {STRING_HEADER(6), 6, "k/free" };
pxll_int constructed_890[] = {TC_NIL};
pxll_int constructed_891[] = {TC_NIL};
pxll_string constructed_892 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_893 = {STRING_HEADER(22), 22, "unhandled literal type" };
pxll_int constructed_894[] = {TC_NIL};
pxll_int constructed_895[] = {TC_NIL};
pxll_int constructed_896[] = {TC_NIL};
pxll_string constructed_897 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_898 = {STRING_HEADER(9), 9, "let_subst" };
// symbol let_subst
pxll_int constructed_899[] = {UPTR(899,1), SYMBOL_HEADER, UPTR0(898), INTCON(88)};
pxll_string constructed_900 = {STRING_HEADER(6), 6, "letrec" };
// symbol letrec
pxll_int constructed_901[] = {UPTR(901,1), SYMBOL_HEADER, UPTR0(900), INTCON(89)};
pxll_string constructed_902 = {STRING_HEADER(7), 7, "literal" };
// symbol literal
pxll_int constructed_903[] = {UPTR(903,1), SYMBOL_HEADER, UPTR0(902), INTCON(90)};
pxll_string constructed_904 = {STRING_HEADER(5), 5, "quote" };
// symbol quote
pxll_int constructed_905[] = {UPTR(905,1), SYMBOL_HEADER, UPTR0(904), INTCON(91)};
pxll_string constructed_906 = {STRING_HEADER(28), 28, "null primapp missing params?" };
pxll_string constructed_907 = {STRING_HEADER(14), 14, "syntax error: " };
pxll_string constructed_908 = {STRING_HEADER(16), 16, "syntax error 2: " };
pxll_int constructed_909[] = {TC_NIL};
pxll_int constructed_910[] = {TC_NIL};
pxll_int constructed_911[] = {TC_NIL};
pxll_int constructed_912[] = {TC_NIL};
pxll_int constructed_913[] = {TC_NIL};
pxll_int constructed_914[] = {TC_NIL};
pxll_string constructed_915 = {STRING_HEADER(15), 15, "unpack-bindings" };
pxll_int constructed_916[] = {TC_NIL};
pxll_string constructed_917 = {STRING_HEADER(16), 16, "malformed formal" };
pxll_string constructed_918 = {STRING_HEADER(7), 7, "varref " };
pxll_string constructed_919 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_920 = {STRING_HEADER(7), 7, "varset " };
pxll_string constructed_921 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_922 = {STRING_HEADER(8), 8, "literal " };
pxll_string constructed_923 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_924 = {STRING_HEADER(5), 5, "cexp " };
pxll_string constructed_925 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_926 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_927 = {STRING_HEADER(11), 11, "sequence : " };
pxll_string constructed_928 = {STRING_HEADER(14), 14, "conditional : " };
pxll_string constructed_929 = {STRING_HEADER(7), 7, "call : " };
pxll_string constructed_930 = {STRING_HEADER(9), 9, "function " };
pxll_string constructed_931 = {STRING_HEADER(2), 2, " (" };
pxll_string constructed_932 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_933 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_934 = {STRING_HEADER(5), 5, "fix (" };
pxll_string constructed_935 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_936 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_937 = {STRING_HEADER(7), 7, "nvcase " };
pxll_string constructed_938 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_939 = {STRING_HEADER(3), 3, ") (" };
pxll_string constructed_940 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_941 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_942 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_943 = {STRING_HEADER(6), 6, "subst " };
pxll_string constructed_944 = {STRING_HEADER(2), 2, "->" };
pxll_string constructed_945 = {STRING_HEADER(8), 8, "primapp " };
pxll_string constructed_946 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_947 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_948 = {STRING_HEADER(5), 5, "let (" };
pxll_string constructed_949 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_950 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_951 = {STRING_HEADER(1), 1, " " };
pxll_int constructed_952[] = {TC_NIL};
pxll_string constructed_953 = {STRING_HEADER(2), 2, "#u" };
pxll_string constructed_954 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_955 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_956 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_957 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_958 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_959 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_960 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_961 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_962 = {STRING_HEADER(2), 2, "#(" };
pxll_string constructed_963 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_964 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_965 = {STRING_HEADER(20), 20, "unpack-fix: no body?" };
pxll_string constructed_966 = {STRING_HEADER(12), 12, "varref->name" };
pxll_string constructed_967 = {STRING_HEADER(4), 4, "  )\n" };
pxll_string constructed_968 = {STRING_HEADER(4), 4, "  (:" };
pxll_string constructed_969 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_970 = {STRING_HEADER(2), 2, ")\n" };
pxll_string constructed_971 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_972 = {STRING_HEADER(10), 10, "(datatype " };
pxll_int constructed_973[] = {TC_NIL};
pxll_int constructed_974[] = {TC_NIL};
pxll_int constructed_975[] = {TC_NIL};
pxll_int constructed_976[] = {TC_NIL};
pxll_int constructed_977[] = {TC_NIL};
pxll_string constructed_978 = {STRING_HEADER(1), 1, "." };
// symbol .
pxll_int constructed_979[] = {UPTR(979,1), SYMBOL_HEADER, UPTR0(978), INTCON(92)};
pxll_string constructed_980 = {STRING_HEADER(17), 17, "malformed pattern" };
pxll_int constructed_981[] = {TC_NIL};
pxll_string constructed_982 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_983 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_984 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_985 = {STRING_HEADER(15), 15, "stack underflow" };
pxll_string constructed_986 = {STRING_HEADER(15), 15, "stack underflow" };
pxll_int constructed_987[] = {TC_NIL};
pxll_string constructed_988 = {STRING_HEADER(21), 21, "not a literal pattern" };
pxll_string constructed_989 = {STRING_HEADER(20), 20, "not a record pattern" };
pxll_string constructed_990 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_991 = {STRING_HEADER(40), 40, "record pattern with different label sigs" };
pxll_string constructed_992 = {STRING_HEADER(6), 6, "record" };
// symbol record
pxll_int constructed_993[] = {UPTR(993,1), SYMBOL_HEADER, UPTR0(992), INTCON(93)};
pxll_string constructed_994 = {STRING_HEADER(33), 33, "arity mismatch in variant pattern" };
pxll_int constructed_995[] = {TC_NIL};
pxll_int constructed_996[] = {TC_NIL};
pxll_string constructed_997 = {STRING_HEADER(39), 39, "more than one datatype in pattern match" };
pxll_string constructed_998 = {STRING_HEADER(8), 8, "variable" };
// symbol variable
pxll_int constructed_999[] = {UPTR(999,1), SYMBOL_HEADER, UPTR0(998), INTCON(94)};
pxll_string constructed_1000 = {STRING_HEADER(8), 8, "string=?" };
// symbol string=?
pxll_int constructed_1001[] = {UPTR(1001,1), SYMBOL_HEADER, UPTR0(1000), INTCON(95)};
pxll_string constructed_1002 = {STRING_HEADER(3), 3, "eq?" };
// symbol eq?
pxll_int constructed_1003[] = {UPTR(1003,1), SYMBOL_HEADER, UPTR0(1002), INTCON(96)};
pxll_string constructed_1004 = {STRING_HEADER(19), 19, "empty pattern list?" };
pxll_string constructed_1005 = {STRING_HEADER(29), 29, "remove-first-pat: empty pats?" };
pxll_string constructed_1006 = {STRING_HEADER(1), 1, "m" };
pxll_int constructed_1007[] = {TC_NIL};
pxll_int constructed_1008[] = {TC_NIL};
pxll_string constructed_1009 = {STRING_HEADER(14), 14, "bad record sig" };
pxll_string constructed_1010 = {STRING_HEADER(26), 26, "unable to get record sig: " };
pxll_string constructed_1011 = {STRING_HEADER(1), 1, "\n" };
pxll_int constructed_1012[] = {TC_NIL};
pxll_string constructed_1013 = {STRING_HEADER(8), 8, "bad type" };
pxll_string constructed_1014 = {STRING_HEADER(15), 15, "malformed type?" };
pxll_int constructed_1015[] = {TC_NIL};
pxll_string constructed_1016 = {STRING_HEADER(14), 14, "bad arrow type" };
pxll_string constructed_1017 = {STRING_HEADER(19), 19, "malformed predicate" };
pxll_string constructed_1018 = {STRING_HEADER(1), 1, "t" };
pxll_string constructed_1019 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_1020 = {STRING_HEADER(2), 2, "->" };
pxll_string constructed_1021 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_1022 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_1023 = {STRING_HEADER(3), 3, ")->" };
pxll_string constructed_1024 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_1025 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_1026 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_1027 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_1028 = {STRING_HEADER(18), 18, "expected sexp:list" };
pxll_string constructed_1029 = {STRING_HEADER(13), 13, "expected list" };
pxll_int constructed_1030[] = {TC_NIL};
pxll_int constructed_1031[] = {TC_NIL};
pxll_int constructed_1032[] = {TC_NIL};
pxll_string constructed_1033 = {STRING_HEADER(36), 36, "unexpected args to ellipsis-sub-envs" };
pxll_int constructed_1034[] = {TC_NIL};
pxll_int constructed_1035[] = {TC_NIL};
pxll_string constructed_1036 = {STRING_HEADER(2), 2, "()" };
pxll_string constructed_1037 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_1038 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_1039 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_1040 = {STRING_HEADER(1), 1, "'" };
pxll_string constructed_1041 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_1042 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_1043 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_1044 = {STRING_HEADER(1), 1, "\"" };
pxll_string constructed_1045 = {STRING_HEADER(1), 1, "\"" };
pxll_string constructed_1046 = {STRING_HEADER(2), 2, "#\\" };
pxll_string constructed_1047 = {STRING_HEADER(2), 2, "#t" };
pxll_string constructed_1048 = {STRING_HEADER(2), 2, "#f" };
pxll_string constructed_1049 = {STRING_HEADER(2), 2, "#u" };
pxll_string constructed_1050 = {STRING_HEADER(2), 2, "#(" };
pxll_string constructed_1051 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_1052 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_1053 = {STRING_HEADER(1), 1, "{" };
pxll_string constructed_1054 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_1055 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_1056 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_1057 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_1058 = {STRING_HEADER(1), 1, "." };
pxll_string constructed_1059 = {STRING_HEADER(3), 3, "..." };
pxll_string constructed_1060 = {STRING_HEADER(1), 1, "=" };
pxll_string constructed_1061 = {STRING_HEADER(9), 9, "sexp->int" };
pxll_string constructed_1062 = {STRING_HEADER(12), 12, "sexp->symbol" };
pxll_int constructed_1063[] = {TC_NIL};
pxll_string constructed_1064 = {STRING_HEADER(7), 7, "include" };
// symbol include
pxll_int constructed_1065[] = {UPTR(1065,1), SYMBOL_HEADER, UPTR0(1064), INTCON(97)};
pxll_int constructed_1066[] = {TC_NIL};
pxll_string constructed_1067 = {STRING_HEADER(13), 13, "bad hex digit" };
pxll_string constructed_1068 = {STRING_HEADER(30), 30, "expected closing ]/} character" };
pxll_string constructed_1069 = {STRING_HEADER(22), 22, "unexpected close-paren" };
pxll_string constructed_1070 = {STRING_HEADER(3), 3, "nul" };
pxll_string constructed_1071 = {STRING_HEADER(3), 3, "eof" };
pxll_string constructed_1072 = {STRING_HEADER(3), 3, "tab" };
pxll_string constructed_1073 = {STRING_HEADER(6), 6, "return" };
pxll_string constructed_1074 = {STRING_HEADER(5), 5, "space" };
pxll_string constructed_1075 = {STRING_HEADER(7), 7, "newline" };
pxll_string constructed_1076 = {STRING_HEADER(22), 22, "bad character constant" };
pxll_string constructed_1077 = {STRING_HEADER(12), 12, "syntax error" };
pxll_string constructed_1078 = {STRING_HEADER(15), 15, "expected symbol" };
pxll_string constructed_1079 = {STRING_HEADER(36), 36, "no dots allowed in constructor names" };
pxll_string constructed_1080 = {STRING_HEADER(5), 5, "comma" };
// symbol comma
pxll_int constructed_1081[] = {UPTR(1081,1), SYMBOL_HEADER, UPTR0(1080), INTCON(98)};
pxll_int constructed_1082[] = {TC_NIL};
pxll_string constructed_1083 = {STRING_HEADER(30), 30, "bad backslash escape in string" };
pxll_int constructed_1084[] = {TC_NIL};
pxll_string constructed_1085 = {STRING_HEADER(30), 30, "expected '=' in record literal" };
pxll_int constructed_1086[] = {TC_NIL};
pxll_string constructed_1087 = {STRING_HEADER(22), 22, "unexpected end of file" };
pxll_string constructed_1088 = {STRING_HEADER(18), 18, "bad decimal digit?" };
pxll_int constructed_1089[] = {TC_NIL};
pxll_string constructed_1090 = {STRING_HEADER(22), 22, "unexpected end-of-file" };
pxll_string constructed_1091 = {STRING_HEADER(13), 13, "reading file " };
pxll_int constructed_1092[] = {TC_NIL};
pxll_int constructed_1093[] = {TC_NIL};
pxll_string constructed_1094 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_1095 = {STRING_HEADER(13), 13, "open() failed" };
pxll_int constructed_1096[] = {TC_NIL};
pxll_int constructed_1097[] = {TC_NIL};
pxll_int constructed_1098[] = {TC_NIL};
pxll_int constructed_1099[] = {TC_NIL};
pxll_int constructed_1100[] = {TC_NIL};
pxll_int constructed_1101[] = {TC_NIL};
pxll_int constructed_1102[] = {UPTR(1102,1),(0<<8)|TC_VECTOR};
pxll_int constructed_1103[] = {TC_NIL};
pxll_string constructed_1104 = {STRING_HEADER(29), 29, "every2?: unequal-length lists" };
pxll_string constructed_1105 = {STRING_HEADER(31), 31, "for-each2: unequal-length lists" };
pxll_int constructed_1106[] = {TC_NIL};
pxll_int constructed_1107[] = {TC_NIL};
pxll_string constructed_1108 = {STRING_HEADER(26), 26, "map2: unequal-length lists" };
pxll_int constructed_1109[] = {TC_NIL};
pxll_int constructed_1110[] = {TC_NIL};
pxll_int constructed_1111[] = {TC_NIL};
pxll_string constructed_1112 = {STRING_HEADER(23), 23, "list index out of range" };
pxll_string constructed_1113 = {STRING_HEADER(23), 23, "list index out of range" };
pxll_int constructed_1114[] = {TC_NIL};
pxll_string constructed_1115 = {STRING_HEADER(4), 4, "last" };
pxll_string constructed_1116 = {STRING_HEADER(3), 3, "cdr" };
pxll_string constructed_1117 = {STRING_HEADER(3), 3, "car" };
pxll_string constructed_1118 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_1119 = {STRING_HEADER(17), 17, "lookup-label-code" };
pxll_string constructed_1120 = {STRING_HEADER(25), 25, "vars-get-var: no such var" };
pxll_int pxll_internal_symbols[] = {(99<<8)|TC_VECTOR, UPTR(41,1), UPTR(44,1), UPTR(46,1), UPTR(49,1), UPTR(51,1), UPTR(56,1), UPTR(58,1), UPTR(61,1), UPTR(66,1), UPTR(86,1), UPTR(97,1), UPTR(210,1), UPTR(214,1), UPTR(226,1), UPTR(230,1), UPTR(239,1), UPTR(243,1), UPTR(250,1), UPTR(255,1), UPTR(266,1), UPTR(277,1), UPTR(286,1), UPTR(295,1), UPTR(308,1), UPTR(314,1), UPTR(328,1), UPTR(477,1), UPTR(479,1), UPTR(486,1), UPTR(488,1), UPTR(490,1), UPTR(492,1), UPTR(494,1), UPTR(497,1), UPTR(500,1), UPTR(505,1), UPTR(507,1), UPTR(510,1), UPTR(512,1), UPTR(518,1), UPTR(528,1), UPTR(533,1), UPTR(543,1), UPTR(555,1), UPTR(566,1), UPTR(569,1), UPTR(571,1), UPTR(579,1), UPTR(583,1), UPTR(586,1), UPTR(611,1), UPTR(621,1), UPTR(623,1), UPTR(625,1), UPTR(627,1), UPTR(629,1), UPTR(631,1), UPTR(633,1), UPTR(635,1), UPTR(637,1), UPTR(639,1), UPTR(641,1), UPTR(648,1), UPTR(650,1), UPTR(665,1), UPTR(669,1), UPTR(683,1), UPTR(685,1), UPTR(691,1), UPTR(693,1), UPTR(696,1), UPTR(713,1), UPTR(719,1), UPTR(723,1), UPTR(747,1), UPTR(749,1), UPTR(751,1), UPTR(753,1), UPTR(755,1), UPTR(757,1), UPTR(759,1), UPTR(761,1), UPTR(771,1), UPTR(773,1), UPTR(797,1), UPTR(800,1), UPTR(809,1), UPTR(854,1), UPTR(899,1), UPTR(901,1), UPTR(903,1), UPTR(905,1), UPTR(979,1), UPTR(993,1), UPTR(999,1), UPTR(1001,1), UPTR(1003,1), UPTR(1065,1), UPTR(1081,1)};

pxll_int
vm (int argc, char * argv[])
{
  register object * lenv = PXLL_NIL;
  register object * k = PXLL_NIL;
// REGISTER_DECLARATIONS //
  register object * r0;
  register object * r1;
  register object * r2;
  register object * r3;
  register object * r4;
  register object * r5;
  register object * r6;
  register object * r7;
  void gc_regs_in (int n) {
    switch (n) {
    case 8: heap1[10] = r7;
    case 7: heap1[9] = r6;
    case 6: heap1[8] = r5;
    case 5: heap1[7] = r4;
    case 4: heap1[6] = r3;
    case 3: heap1[5] = r2;
    case 2: heap1[4] = r1;
    case 1: heap1[3] = r0;
  }}
  void gc_regs_out (int n) {
    switch (n) {
    case 8: r7 = heap0[10];
    case 7: r6 = heap0[9];
    case 6: r5 = heap0[8];
    case 5: r4 = heap0[7];
    case 4: r3 = heap0[6];
    case 3: r2 = heap0[5];
    case 2: r1 = heap0[4];
    case 1: r0 = heap0[3];
  }}
  object * top = PXLL_NIL; // top-level (i.e. 'global') environment
  object * t = 0; // temp - for swaps & building tuples
  object * result;
  object * limit = heap0 + (heap_size - head_room);
  object * freep = heap0;
  int i; // loop counter
  
#define PXLL_RETURN(d)	result = r##d; goto *k[3]

#include "gc.c"

  // check heap is called at the top of each allocating function.
  //  [by locating the check at the top, we avoid considering any
  //   registers as roots of the gc...]
  void check_heap (int nfree) {
    if (freep >= limit) {
      uint64_t t0, t1;
      t0 = rdtsc();
      gc_flip (nfree);
      t1 = rdtsc();
      gc_ticks += t1 - t0;
    }
  }

  void ensure_heap (int nfree, pxll_int size) {
    if (freep + size + 1 >= limit) {
      uint64_t t0, t1;
      t0 = rdtsc();
      gc_flip (nfree);
      t1 = rdtsc();
      gc_ticks += t1 - t0;
    }
  }

  object * allocate (pxll_int tc, pxll_int size) {
    object * save = freep;
    *freep = (object*) (size<<8 | (tc & 0xff));
#if 1
    // at least on the g5, this technique is considerably faster than using memset
    //   in gc_flip() to 'pre-clear' the heap... probably a cache effect...
    while (size--) {
      // this keeps gc from being confused by partially-filled objects.
      *(++freep) = PXLL_NIL;
    }
    ++freep;
#else
    // if you use this version, be sure to set <clear_tospace>!
    freep += size + 1;
#endif
    return save;  
  }

  // this is emitted by the backend for %make-tuple
  object * alloc_no_clear (pxll_int tc, pxll_int size) {
    object * save = freep;
    *freep = (object*) (size<<8 | (tc & 0xff));
    freep += size + 1;
    return save;  
  }

  // gcc inlines/unrolls these nicely, they allow more compact code
  // Note: I'm not using these any longer, because there's a huge
  //   impact on compile times - 11m vs 50m when I tested it.
  inline object * varref (pxll_int depth, pxll_int index)
  {
    object * walk = lenv;
    while (depth--) {
      walk = walk[1];
    }
    return walk[index+2];
  }

  inline void varset (pxll_int depth, pxll_int index, object * val)
  {
    object * walk = lenv;
    while (depth--) {
      walk = walk[1];
    }
    walk[index+2] = val;
  }

  
  // these could probably be written in irken...
  pxll_int dump_image (char * filename, object * closure) {
    FILE * dump_file = fopen (filename, "wb");
    pxll_int offset;
    pxll_int size;
    object * start;
    // do a gc for a compact dump
    closure = gc_dump (closure);
    // for now, start at the front of the heap
    start = heap0;
    size = freep - start;
    offset = (pxll_int) heap0;
    // XXX add endian indicator...
    fprintf (dump_file, "(pxll image %" PRIuPTR " %p)\n", sizeof (pxll_int), start);
    fwrite (&offset, sizeof(pxll_int), 1, dump_file);
    fwrite (&size, sizeof(pxll_int), 1, dump_file);
    fwrite (start, sizeof(pxll_int), size, dump_file);
    fclose (dump_file);
    return size;
  }

  object * load_image (char * filename) {
    FILE * load_file = fopen (filename, "rb");
    if (!load_file) {
      abort();
    } else {
      object * start, * thunk;
      pxll_int size;
      read_header (load_file);	// XXX verify header...
      fread (&start, sizeof(pxll_int), 1, load_file);
      fread (&size, sizeof(pxll_int), 1, load_file);
      fread (heap1, sizeof(pxll_int), size, load_file);
      fprintf (stderr, "size=%d\n", (int) size);
      // relocate heap0
      gc_relocate (4, heap1, heap1 + size, start - heap1);
      // replace roots
      lenv  = (object *) heap1[0];
      k     = (object *) heap1[1];
      top   = (object *) heap1[2];
      thunk = (object *) heap1[3];
      freep = heap1 + size;
      // swap heaps
      { object * temp = heap0; heap0 = heap1; heap1 = temp; }
      return thunk;
    }
  }

  k = allocate (TC_SAVE, 3);
  k[1] = (object *) PXLL_NIL; // top of stack
  k[2] = (object *) PXLL_NIL; // null environment
  k[3] = &&Lreturn; // continuation that will return from this function.
  // --- BEGIN USER PROGRAM ---
  r0 = allocate (TC_TUPLE, 211);
  top = r0;
  r0[1] = lenv; lenv = r0;
  // def list:cons_3
  goto L0;
  FUN_list_3acons_3:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L0:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list_3acons_3; r1[2] = lenv;
  r0[2] = r1;
  // def sexp:symbol_15
  goto L1;
  FUN_sexp_3asymbol_15:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3asymbol_15; r1[2] = lenv;
  r0[3] = r1;
  // def sexp:int_19
  goto L2;
  FUN_sexp_3aint_19:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3aint_19; r1[2] = lenv;
  r0[4] = r1;
  // def vars-get-var_247
  goto L3;
  FUN_vars_get_var_247:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[17];
    r1[2] = r2;
    r2 = top[84];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L4; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L4:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_1120;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L3:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_vars_get_var_247; r1[2] = lenv;
  r0[5] = r1;
  // def vars-set-flag!_249
  goto L5;
  FUN_vars_set_flag_bang_249:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = top[5];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L6; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
    L6:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,74)];
    r0[2] = r1;
    r0 = ((object***) lenv) [1][1][4];
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
    lenv = lenv[1];
    r1 = ((object*) lenv) [2];
    ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,74)] = r0;
    PXLL_RETURN(0);
  L5:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_vars_set_flag_bang_249; r1[2] = lenv;
  r0[6] = r1;
  // def add-var_251
  goto L7;
  FUN_add_var_251:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][3];
    r2 = ((pxll_vector*)r2)->val[17];
    r1[2] = r2;
    r2 = top[84];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L8; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L8:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object**) lenv) [1][3];
        r1 = ((pxll_vector*)r1)->val[17];
        r0[2] = r1;
        r1 = top[84];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[4] = r1;
        r1 = allocate (UOTAG(25), 5);
        r2 = (object *) 1;
        r1[1] = r2;
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = (object *) 1;
        r1[4] = r2;
        r2 = (object *) 1;
        r1[5] = r2;
        r0[5] = r1;
        r1 = top[74];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L9; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_409;
        L9:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object**) lenv) [1][3];
        ((pxll_vector*)r1)->val[17] = r0;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L7:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_add_var_251; r1[2] = lenv;
  r0[7] = r1;
  // def add-vars_252
  goto L10;
  FUN_add_vars_252:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def add_667
    goto L11;
    FUN_add_667:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][3];
      r0[3] = r1;
      r1 = top[7];
      r0[1] = r1[2]; lenv = r0; goto FUN_add_var_251;
    L11:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_667; r1[2] = lenv;
    r0[2] = r1;
    // def search_668
    goto L12;
    FUN_search_668:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L13; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L13:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L14; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L14:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L15; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L15:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[3] = r1;
          r1 = top[7];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L16; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_add_var_251;
          L16:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_439;
        }
      }
      goto fatbar_439_over;
      fatbar_439:
      r0 = (object *) 14;
      fatbar_439_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[37];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L12:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_search_668; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN_search_668;
  L10:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_add_vars_252; r1[2] = lenv;
  r0[8] = r1;
  // def lookup-label-code_254
  goto L17;
  FUN_lookup_label_code_254:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_680
    goto L18;
    FUN_loop_680:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_1119;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[3] = r1;
          r1 = top[15];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*****) lenv) [1][1][1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object*) lenv) [3];
                PXLL_RETURN(0);
              } else {
                r0 = ((object**) lenv) [1][3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                goto FUN_loop_680;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L18:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_680; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][3];
    r1 = ((pxll_vector*)r1)->val[6];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_680;
  L17:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lookup_label_code_254; r1[2] = lenv;
  r0[9] = r1;
  // def terpri_261
  goto L19;
  FUN_terpri_261:
    r0 = (object *) 2562;
    r0 = box((pxll_int)fputc (GET_CHAR(r0), stdout));
    PXLL_RETURN(0);
  L19:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_terpri_261; r1[2] = lenv;
  r0[10] = r1;
  // def =_262
  goto L20;
  FUN__3d_262:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    PXLL_RETURN(0);
  L20:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__3d_262; r1[2] = lenv;
  r0[11] = r1;
  // def <_264
  goto L21;
  FUN__3c_264:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L21:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__3c_264; r1[2] = lenv;
  r0[12] = r1;
  // def +_270
  goto L22;
  FUN__plus_270:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    PXLL_RETURN(0);
  L22:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__plus_270; r1[2] = lenv;
  r0[13] = r1;
  // def eq?_286
  goto L23;
  FUN_eq_question_286:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(r1==r0);
    PXLL_RETURN(0);
  L23:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_eq_question_286; r1[2] = lenv;
  r0[14] = r1;
  // def error1_294
  goto L24;
  FUN_error1_294:
    check_heap (0);
    r0 = top[161];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L25; ; k = t;
    lenv = r0[2]; goto *r0[1];
    L25:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_1118;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_1118;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_68;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_68;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [3];
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = ((object*) lenv) [3];
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
  L24:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_error1_294; r1[2] = lenv;
  r0[15] = r1;
  // def id_297
  goto L26;
  FUN_id_297:
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L26:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_id_297; r1[2] = lenv;
  r0[16] = r1;
  // def callcc_298
  goto L27;
  FUN_callcc_298:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = k; // %getcc
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L27:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_callcc_298; r1[2] = lenv;
  r0[17] = r1;
  // def throw_299
  goto L28;
  FUN_throw_299:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    k = r1; // %putcc
    PXLL_RETURN(0);
  L28:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_throw_299; r1[2] = lenv;
  r0[18] = r1;
  // def pair->first_300
  goto L29;
  FUN_pair__3efirst_300:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case_noint (r0)) {
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L29:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pair__3efirst_300; r1[2] = lenv;
  r0[19] = r1;
  // def pair->second_301
  goto L30;
  FUN_pair__3esecond_301:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case_noint (r0)) {
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L30:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pair__3esecond_301; r1[2] = lenv;
  r0[20] = r1;
  // def car_311
  goto L31;
  FUN_car_311:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1117;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1117;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L31:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_car_311; r1[2] = lenv;
  r0[21] = r1;
  // def cdr_312
  goto L32;
  FUN_cdr_312:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1116;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1116;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L32:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cdr_312; r1[2] = lenv;
  r0[22] = r1;
  // def reverse-onto_313
  goto L33;
  FUN_reverse_onto_313:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = top[23];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
      } break;
    }
    PXLL_RETURN(0);
  L33:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_reverse_onto_313; r1[2] = lenv;
  r0[23] = r1;
  // def length_316
  goto L34;
  FUN_length_316:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def fun_792
    goto L35;
    FUN_fun_792:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = (object *) 3;
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_fun_792;
        } break;
      }
      PXLL_RETURN(0);
    L35:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fun_792; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_fun_792;
  L34:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_length_316; r1[2] = lenv;
  r0[24] = r1;
  // def last_319
  goto L36;
  FUN_last_319:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1115;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1115;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_438;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_438_over;
        fatbar_438:
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = top[25];
        r0[1] = r1[2]; lenv = r0; goto FUN_last_319;
        fatbar_438_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L36:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_last_319; r1[2] = lenv;
  r0[25] = r1;
  // def member?_320
  goto L37;
  FUN_member_question_320:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L38; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L38:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[4] = r1;
          r1 = top[26];
          r0[1] = r1[2]; lenv = r0; goto FUN_member_question_320;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L37:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_member_question_320; r1[2] = lenv;
  r0[26] = r1;
  // def member-eq?_321
  goto L39;
  FUN_member_eq_question_321:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[27];
          r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_321;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L39:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_member_eq_question_321; r1[2] = lenv;
  r0[27] = r1;
  // def remove-eq_322
  goto L40;
  FUN_remove_eq_322:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1114[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = top[28];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L41; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_remove_eq_322;
          L41:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L40:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_remove_eq_322; r1[2] = lenv;
  r0[28] = r1;
  // def nth_323
  goto L42;
  FUN_nth_323:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_1113;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_1113;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) 1;
        r1 = ((object**) lenv) [1][3];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } else {
          goto fatbar_437;
        }
        PXLL_RETURN(0);
        goto fatbar_437_over;
        fatbar_437:
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) 3;
        r2 = ((object**) lenv) [1][3];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        r0[3] = r1;
        r1 = top[29];
        r0[1] = r1[2]; lenv = r0; goto FUN_nth_323;
        fatbar_437_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L42:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_nth_323; r1[2] = lenv;
  r0[29] = r1;
  // def index-eq_324
  goto L43;
  FUN_index_eq_324:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_821
    goto L44;
    FUN_loop_821:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object*) &constructed_68;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_1112;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_1112;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object****) lenv) [1][1][1][2];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object**) lenv) [1][2];
            PXLL_RETURN(0);
          } else {
            r0 = (object *) 3;
            r1 = ((object**) lenv) [1][2];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            r1 = ((object*) lenv) [3];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            lenv[3] = r1;
            goto FUN_loop_821;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L44:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_821; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_821;
  L43:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_index_eq_324; r1[2] = lenv;
  r0[30] = r1;
  // def slice_325
  goto L45;
  FUN_slice_325:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][4];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) constructed_1110[0];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_829
      goto L46;
      FUN_loop_829:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][3];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L47; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
          L47:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r2 = ((object*) lenv) [4];
          lenv[2] = r1;
          lenv[3] = r0;
          lenv[4] = r2;
          goto FUN_loop_829;
        } else {
          r0 = ((object***) lenv) [1][1][4];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L48; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
            L48:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object**) lenv) [1][4];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r1 = (object *) 3;
            r2 = ((object*) lenv) [3];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = top[22];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L49; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_cdr_312;
            L49:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv[2] = r2;
            lenv[3] = r1;
            lenv[4] = r0;
            goto FUN_loop_829;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = (object *) constructed_36[0];
            r0[3] = r1;
            r1 = top[23];
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L46:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_829; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 4);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) constructed_1111[0];
      r0[4] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_829;
    }
    PXLL_RETURN(0);
  L45:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_slice_325; r1[2] = lenv;
  r0[31] = r1;
  // def range_326
  goto L50;
  FUN_range_326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_834
    goto L51;
    FUN_loop_834:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_834;
      }
      PXLL_RETURN(0);
    L51:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_834; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 3;
    r2 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = (object*)TC_NIL;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_834;
  L50:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_range_326; r1[2] = lenv;
  r0[32] = r1;
  // def n-of_327
  goto L52;
  FUN_n_of_327:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_839
    goto L53;
    FUN_loop_839:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<=unbox(r0))) {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [3];
        r1 = ((object***) lenv) [1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_839;
      }
      PXLL_RETURN(0);
    L53:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_839; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object*)TC_NIL;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_839;
  L52:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_n_of_327; r1[2] = lenv;
  r0[33] = r1;
  // def map_328
  goto L54;
  FUN_map_328:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1109[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L55; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L55:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object*) lenv) [3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L56; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L56:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L54:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_map_328; r1[2] = lenv;
  r0[34] = r1;
  // def map2_329
  goto L57;
  FUN_map2_329:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) constructed_1107[0];
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_436;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][4];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L58; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L58:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            r1[4] = r2;
            r2 = top[35];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L59; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map2_329;
            L59:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = ((object*) lenv) [5];
            r1 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_436;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_436_over;
    fatbar_436:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_1108;
    r0[2] = r1;
    r1 = allocate (UOTAG(1), 2);
    r2 = ((object*) lenv) [3];
    r1[1] = r2;
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_436_over: ;
    PXLL_RETURN(0);
  L57:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_map2_329; r1[2] = lenv;
  r0[35] = r1;
  // def filter_330
  goto L60;
  FUN_filter_330:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1106[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L61; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L61:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = top[36];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L62; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_filter_330;
          L62:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[36];
          r0[1] = r1[2]; lenv = r0; goto FUN_filter_330;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L60:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_filter_330; r1[2] = lenv;
  r0[36] = r1;
  // def for-each_331
  goto L63;
  FUN_for_each_331:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L64; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L64:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = top[37];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
      } break;
    }
    PXLL_RETURN(0);
  L63:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_for_each_331; r1[2] = lenv;
  r0[37] = r1;
  // def for-each2_332
  goto L65;
  FUN_for_each2_332:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_435;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][4];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L66; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L66:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object***) lenv) [1][1][2];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r0[3] = r1;
            r1 = ((object*) lenv) [3];
            r0[4] = r1;
            r1 = top[38];
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_332;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_435;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_435_over;
    fatbar_435:
    r0 = (object*) &constructed_68;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_68;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_1105;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_1105;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_435_over: ;
    PXLL_RETURN(0);
  L65:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_for_each2_332; r1[2] = lenv;
  r0[38] = r1;
  // def fold_333
  goto L67;
  FUN_fold_333:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L68; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L68:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object*) lenv) [3];
        r2 = ((object**) lenv) [1][2];
        lenv = ((object *)lenv)[1];
        lenv[2] = r2;
        lenv[3] = r0;
        lenv[4] = r1;
        goto FUN_fold_333;
      } break;
    }
    PXLL_RETURN(0);
  L67:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_fold_333; r1[2] = lenv;
  r0[39] = r1;
  // def foldr_334
  goto L69;
  FUN_foldr_334:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r1[4] = r2;
        r2 = top[40];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L70; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_foldr_334;
        L70:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      } break;
    }
    PXLL_RETURN(0);
  L69:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_foldr_334; r1[2] = lenv;
  r0[40] = r1;
  // def some?_335
  goto L71;
  FUN_some_question_335:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L72; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L72:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[41];
          r0[1] = r1[2]; lenv = r0; goto FUN_some_question_335;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L71:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_some_question_335; r1[2] = lenv;
  r0[41] = r1;
  // def every?_336
  goto L73;
  FUN_every_question_336:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L74; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L74:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[42];
          r0[1] = r1[2]; lenv = r0; goto FUN_every_question_336;
        } else {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L73:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_every_question_336; r1[2] = lenv;
  r0[42] = r1;
  // def every2?_337
  goto L75;
  FUN_every2_question_337:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_434;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][4];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L76; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L76:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r1 = ((object***) lenv) [1][1][2];
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r0[4] = r1;
              r1 = top[43];
              r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_337;
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_434;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_434_over;
    fatbar_434:
    r0 = (object*) &constructed_68;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_68;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_1104;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_1104;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_434_over: ;
    PXLL_RETURN(0);
  L75:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_every2_question_337; r1[2] = lenv;
  r0[43] = r1;
  // def pack_339
  goto L77;
  FUN_pack_339:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def pack2_900
    goto L78;
    FUN_pack2_900:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L79; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L79:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L80; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L80:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object**) lenv) [1][3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            r1 = ((object**) lenv) [1][4];
            r2 = ((object*) lenv) [3];
            lenv = ((object *)lenv)[1];
            lenv[2] = r2;
            lenv[3] = r0;
            lenv[4] = r1;
            goto FUN_pack2_900;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][3];
            r1[2] = r2;
            r2 = (object *) constructed_36[0];
            r1[3] = r2;
            r2 = top[23];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L81; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
            L81:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object**) lenv) [1][3];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = (object*)TC_NIL;
            r2[2] = r3;
            r2 = ((object*) lenv) [2];
            r3 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r1[3] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[4] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L82; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pack2_900;
            L82:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L78:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pack2_900; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1103[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_pack2_900;
      } break;
    }
    PXLL_RETURN(0);
  L77:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pack_339; r1[2] = lenv;
  r0[44] = r1;
  // def list->vector_341
  goto L83;
  FUN_list__3evector_341:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_913
    goto L84;
    FUN_recur_913:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][2];
          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
          ((pxll_vector*)r2)->val[unbox(r0)] = r1;
          r0 = (object *) 3;
          r1 = ((object**) lenv) [1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_recur_913;
        } break;
      }
      PXLL_RETURN(0);
    L84:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_913; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1102[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[24];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L85; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
        L85:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        ensure_heap (1, unbox(r1));
        r1 = ((object*) lenv) [2];
        r2 = ((object*) lenv) [3];
        if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
          t = alloc_no_clear (TC_VECTOR, unbox(r2));
          for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
          r1 = t;
        }
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = (object *) 1;
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_recur_913;
      } break;
    }
    PXLL_RETURN(0);
  L83:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list__3evector_341; r1[2] = lenv;
  r0[45] = r1;
  // def sort_342
  goto L86;
  FUN_sort_342:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def halve_925
    goto L87;
    FUN_halve_925:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (UOTAG(1), 2);
          r1 = ((object*) lenv) [2];
          r0[1] = r1;
          r1 = (object *) constructed_1100[0];
          r0[2] = r1;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (UOTAG(1), 2);
              r1 = ((object**) lenv) [1][2];
              r0[1] = r1;
              r1 = (object *) constructed_1101[0];
              r0[2] = r1;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_433;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_433_over;
          fatbar_433:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L88; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_halve_925;
          L88:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = allocate (UOTAG(1), 2);
              r1 = ((object*) lenv) [3];
              r2 = ((object***) lenv) [1][1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[1] = r1;
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
          fatbar_433_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L87:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_halve_925; r1[2] = lenv;
    r0[2] = r1;
    // def merge-sort_926
    goto L89;
    FUN_merge_sort_926:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_432;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_432_over;
      fatbar_432:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L90; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_halve_925;
      L90:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L91; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_merge_sort_926;
          L91:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L92; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_merge_sort_926;
          L92:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_929_i85
          goto L93;
          FUN_loop_929_i85:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = ((object*) lenv) [3];
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object**) lenv) [1][3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = ((object**) lenv) [1][2];
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = ((object**) lenv) [1][2];
                    r0[2] = r1;
                    r1 = ((object*) lenv) [2];
                    r0[3] = r1;
                    r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L94; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L94:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    if PXLL_IS_TRUE(r0) {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object***) lenv) [1][1][3];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r3 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[3] = r2;
                      r2 = ((object*****) lenv) [1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L95; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_929_i85;
                      L95:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object***) lenv) [1][1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object***) lenv) [1][1][3];
                      r3 = ((object***) lenv) [1][1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r1[3] = r2;
                      r2 = ((object*****) lenv) [1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L96; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_929_i85;
                      L96:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    }
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L93:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_929_i85; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][4];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_929_i85;
        } break;
      }
      PXLL_RETURN(0);
      fatbar_432_over: ;
      PXLL_RETURN(0);
    L89:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_merge_sort_926; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][3];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN_merge_sort_926;
  L86:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sort_342; r1[2] = lenv;
  r0[46] = r1;
  // def substring_347
  goto L97;
  FUN_substring_347:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][4];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = ((object**) lenv) [1][3];
    r1 = (object *) 1;
    r2 = ((object**) lenv) [1][2];
    r3 = ((object*) lenv) [2];
    r4 = ((object*) lenv) [3];
    (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [3];
    PXLL_RETURN(0);
  L97:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_substring_347; r1[2] = lenv;
  r0[47] = r1;
  // def char->string_350
  goto L98;
  FUN_char__3estring_350:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 3;
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = (object *) 3;
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
    r0 = (object *) 1;
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L98:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_char__3estring_350; r1[2] = lenv;
  r0[48] = r1;
  // def string-concat_354
  goto L99;
  FUN_string_concat_354:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def loop_974
    goto L100;
    FUN_loop_974:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object***) lenv) [1][1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_974;
        } break;
      }
      PXLL_RETURN(0);
    L100:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_loop_974; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object***) lenv) [1][1][2];
    r1[2] = r2;
    r2 = (object *) 1;
    r1[3] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L101; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_loop_974;
    L101:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_981
    goto L102;
    FUN_loop_981:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object***) lenv) [1][1][3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object***) lenv) [1][1][3];
          r2 = ((object**) lenv) [1][2];
          r3 = ((object*) lenv) [2];
          r4 = ((object*****) lenv) [1][1][1][1][3];
          r0 = (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object***) lenv) [1][1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_981;
        } break;
      }
      PXLL_RETURN(0);
    L102:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_981; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_981;
  L99:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_concat_354; r1[2] = lenv;
  r0[49] = r1;
  // def string-join_355
  goto L103;
  FUN_string_join_355:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def sj_988
    goto L104;
    FUN_sj_988:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L105; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L105:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r3 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_36[0];
              r1[3] = r2;
              r2 = top[23];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L106; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
              L106:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r0[2] = r1;
              r1 = top[49];
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
            } break;
            default: {
              goto fatbar_431;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_431_over;
          fatbar_431:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][3];
          r2 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_sj_988;
          fatbar_431_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L104:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_sj_988; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = top[49];
      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
    } else {
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = (object *) constructed_1099[0];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_sj_988;
    }
    PXLL_RETURN(0);
  L103:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_join_355; r1[2] = lenv;
  r0[50] = r1;
  // def string-split_356
  goto L107;
  FUN_string_split_356:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_995
    goto L108;
    FUN_loop_995:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = box((pxll_int)((pxll_string*)(r1))->len);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object****) lenv) [1][1][1][2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[4] = r2;
        r2 = top[47];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L109; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_substring_347;
        L109:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) constructed_36[0];
        r0[3] = r1;
        r1 = top[23];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r2 = ((object****) lenv) [1][1][1][2];
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = ((object**) lenv) [1][2];
        r2 = ((object****) lenv) [1][1][1][2];
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[2] = r1;
        r0 = ((object****) lenv) [1][1][1][3];
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[4] = r2;
          r2 = top[47];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L110; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_substring_347;
          L110:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object**) lenv) [1][4];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = (object *) 3;
          r2 = ((object*) lenv) [2];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r2 = (object *) 3;
          r3 = ((object*) lenv) [2];
          r2 = box((pxll_int)unbox(r3)+unbox(r2));
          lenv[2] = r2;
          lenv[3] = r1;
          lenv[4] = r0;
          goto FUN_loop_995;
        } else {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [4];
          lenv[2] = r0;
          lenv[3] = r1;
          lenv[4] = r2;
          goto FUN_loop_995;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L108:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_995; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = (object *) constructed_1098[0];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_995;
  L107:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_split_356; r1[2] = lenv;
  r0[51] = r1;
  // def string-compare_357
  goto L111;
  FUN_string_compare_357:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
      r1 = ((object*) lenv) [2];
    } else {
      r1 = ((object*) lenv) [3];
    }
    r2 = ((object**) lenv) [1][3];
    r3 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)memcmp (((pxll_string*)(r3))->data, ((pxll_string*)(r2))->data, unbox(r1)));
    r0[4] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [4];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
          r0 = (object *) -1;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 3;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [4];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L111:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_compare_357; r1[2] = lenv;
  r0[52] = r1;
  // def string-find_358
  goto L112;
  FUN_string_find_358:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[3] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object*) lenv) [3];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
      r0 = (object *) -1;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1008
      goto L113;
      FUN_loop_1008:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)-unbox(r0));
          PXLL_RETURN(0);
        } else {
          r0 = ((object***) lenv) [1][1][3];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) -1;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*****) lenv) [1][1][1][1][2];
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*****) lenv) [1][1][1][1][2];
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*****) lenv) [1][1][1][1][3];
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
              r1 = ((object*) lenv) [3];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              r1 = (object *) 3;
              r2 = ((object*) lenv) [2];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_1008;
            } else {
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              r1 = (object *) 1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1008;
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L113:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1008; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1008;
    }
    PXLL_RETURN(0);
  L112:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_find_358; r1[2] = lenv;
  r0[53] = r1;
  // def string<?_360
  goto L114;
  FUN_string_3c_question_360:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = top[52];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L115; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
    L115:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L114:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_3c_question_360; r1[2] = lenv;
  r0[54] = r1;
  // def zero-terminate_362
  goto L116;
  FUN_zero_terminate_362:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = (object *) 3;
    r2 = ((object*) lenv) [2];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][2];
    range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][2];
    r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
    r0[4] = r1;
    r0 = (object *) 2;
    r1 = ((object*) lenv) [4];
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = box((pxll_int)((pxll_string*)(r1))->len);
      r0[2] = r1;
      r1 = (object *) 3;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[3] = r1;
      r1 = ((object*) lenv) [3];
      r1 = box((pxll_int)string_tuple_length (unbox(r1)));
      ensure_heap (1, unbox(r1));
      r1 = ((object*) lenv) [3];
      r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
      r0[4] = r1;
      r0 = (object *) 1;
      r1 = (object *) 1;
      r2 = ((object**) lenv) [1][2];
      r3 = ((object*) lenv) [2];
      r4 = ((object*) lenv) [4];
      (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
      r0 = ((object*) lenv) [2];
      r1 = ((object*) lenv) [4];
      range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
      r0 = ((object*) lenv) [2];
      r1 = (object *) 2;
      r2 = ((object*) lenv) [4];
      (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
      r0 = ((object*) lenv) [4];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L116:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_zero_terminate_362; r1[2] = lenv;
  r0[55] = r1;
  // def list->string_363
  goto L117;
  FUN_list__3estring_363:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L118; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L118:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1022
    goto L119;
    FUN_loop_1022:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object***) lenv) [1][1][3];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object****) lenv) [1][1][1][3];
          range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          r2 = ((object****) lenv) [1][1][1][3];
          (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
          r0 = (object *) 3;
          r1 = ((object**) lenv) [1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_1022;
        } break;
      }
      PXLL_RETURN(0);
    L119:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1022; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1022;
  L117:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list__3estring_363; r1[2] = lenv;
  r0[56] = r1;
  // def string->list_364
  goto L120;
  FUN_string__3elist_364:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1028
    goto L121;
    FUN_loop_1028:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 3;
        r2 = ((object**) lenv) [1][3];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r2 = ((object****) lenv) [1][1][1][2];
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = ((object*) lenv) [2];
        r2 = ((object****) lenv) [1][1][1][2];
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r1 = (object *) 3;
        r2 = ((object*) lenv) [3];
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
        lenv[2] = r0;
        lenv[3] = r1;
        goto FUN_loop_1028;
      }
      PXLL_RETURN(0);
    L121:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1028; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1028;
  L120:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string__3elist_364; r1[2] = lenv;
  r0[57] = r1;
  // def int->string_366
  goto L122;
  FUN_int__3estring_366:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r1 = (object *) 1;
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 12290;
      r0[2] = r1;
      r1 = top[48];
      r0[1] = r1[2]; lenv = r0; goto FUN_char__3estring_350;
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1037
      goto L123;
      FUN_loop_1037:
        check_heap (0);
        r0 = ((object*) lenv) [2];
        r1 = (object *) 1;
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r2 = ((object***) lenv) [1][1][2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
            r1 = ((object*) lenv) [3];
            r2 = (object *) 11522;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
          } else {
            r1 = ((object*) lenv) [3];
          }
          r0[2] = r1;
          r1 = top[56];
          r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_363;
        } else {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) 21;
          r2 = ((object**) lenv) [1][2];
          r1 = box((pxll_int)unbox(r2) % unbox(r1));
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r2 = (object *) 97;
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r1 = TO_CHAR(unbox(r1));
          r0[4] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = (object *) 21;
          r2 = ((object*) lenv) [2];
          r1 = box((pxll_int)unbox(r2)/unbox(r1));
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_1037;
        }
        PXLL_RETURN(0);
      L123:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1037; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r2 = ((object**) lenv) [1][2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
        r1 = ((object**) lenv) [1][2];
        r2 = (object *) 1;
        r1 = box((pxll_int)unbox(r2)-unbox(r1));
      } else {
        r1 = ((object**) lenv) [1][2];
      }
      r0[2] = r1;
      r1 = (object *) constructed_1097[0];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1037;
    }
    PXLL_RETURN(0);
  L122:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_int__3estring_366; r1[2] = lenv;
  r0[58] = r1;
  // def int->hex-string_367
  goto L124;
  FUN_int__3ehex_string_367:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1041
    goto L125;
    FUN_loop_1041:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r1 = (object *) 1;
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) 1;
        r2 = ((object***) lenv) [1][1][2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
          r1 = ((object*) lenv) [3];
          r2 = (object *) 11522;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
        } else {
          r1 = ((object*) lenv) [3];
        }
        r0[2] = r1;
        r1 = top[56];
        r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_363;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 31;
        r2 = ((object**) lenv) [1][2];
        r1 = box((pxll_int)unbox(r2)&unbox(r1));
        r2 = top[162];
        range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
        r1 = ((pxll_vector*)r2)->val[unbox(r1)];
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r1 = (object *) 9;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)>>unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_1041;
      }
      PXLL_RETURN(0);
    L125:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1041; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 1;
    r2 = ((object**) lenv) [1][2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
      r1 = ((object**) lenv) [1][2];
      r2 = (object *) 1;
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
    } else {
      r1 = ((object**) lenv) [1][2];
    }
    r0[2] = r1;
    r1 = (object *) constructed_1096[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1041;
  L124:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_int__3ehex_string_367; r1[2] = lenv;
  r0[59] = r1;
  // def pad_369
  goto L126;
  FUN_pad_369:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
      r0 = ((object**) lenv) [1][3];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r2 = ((object***) lenv) [1][1][2];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[2] = r1;
      r0 = ((object***) lenv) [1][1][4];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = (object *) 8194;
        r3[3] = r4;
        r4 = top[33];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L127; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_n_of_327;
        L127:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L128; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_list__3estring_363;
        L128:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object****) lenv) [1][1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = (object *) 8194;
        r3[3] = r4;
        r4 = top[33];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L129; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_n_of_327;
        L129:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = top[56];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L130; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_list__3estring_363;
        L130:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = ((object****) lenv) [1][1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L126:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pad_369; r1[2] = lenv;
  r0[60] = r1;
  // def copy-cstring_374
  goto L131;
  FUN_copy_cstring_374:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)strlen((char*)r1));
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = ((object*) lenv) [2];
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = ((object**) lenv) [1][2];
    r1 = ((object*) lenv) [2];
    r2 = ((object*) lenv) [3];
    (memcpy (((pxll_string*)(r2))->data, (char*)r0, unbox(r1)), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [3];
    PXLL_RETURN(0);
  L131:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_copy_cstring_374; r1[2] = lenv;
  r0[61] = r1;
  // def open_375
  goto L132;
  FUN_open_375:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[55];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L133; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_362;
    L133:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r2 = ((object**) lenv) [1][3];
    r3 = ((object**) lenv) [1][4];
    r1 = box((pxll_int)open (((pxll_string*)(r1))->data, unbox(r2), unbox(r3)));
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>=unbox(r0))) {
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_1095;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[55];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L134; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_362;
      L134:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    }
    PXLL_RETURN(0);
  L132:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_open_375; r1[2] = lenv;
  r0[62] = r1;
  // def file/open-read_382
  goto L135;
  FUN_file_2fopen_read_382:
    check_heap (0);
    r0 = allocate (UOTAG(24), 4);
    r1 = (object *) 32769;
    r1 = box((pxll_int)string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = (object *) 32769;
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[1] = r1;
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[163];
    r1[3] = r2;
    r2 = (object *) 1;
    r1[4] = r2;
    r2 = top[62];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L136; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_open_375;
    L136:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = (object *) 1;
    r0[4] = r1;
    PXLL_RETURN(0);
  L135:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fopen_read_382; r1[2] = lenv;
  r0[63] = r1;
  // def file/fill-buffer_387
  goto L137;
  FUN_file_2ffill_buffer_387:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[4] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [2];
    r1 = box((pxll_int)read (unbox(r3), ((pxll_string*)(r1))->data, unbox(r2)));
    r0[5] = r1;
    r1 = ((object*) lenv) [5];
    r0[6] = r1;
    r0 = ((object*) lenv) [6];
    r1 = ((object**) lenv) [1][2];
    ((pxll_vector*)r1)->val[1] = r0;
    r0 = (object *) 1;
    r1 = ((object**) lenv) [1][2];
    ((pxll_vector*)r1)->val[3] = r0;
    r0 = ((object*) lenv) [6];
    PXLL_RETURN(0);
  L137:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2ffill_buffer_387; r1[2] = lenv;
  r0[64] = r1;
  // def file/read-buffer_388
  goto L138;
  FUN_file_2fread_buffer_388:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = ((object**) lenv) [1][2];
      r0 = ((pxll_vector*)r0)->val[1];
      r1 = ((object**) lenv) [1][2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = allocate (TC_TUPLE, 4);
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r0[4] = r1;
      r1 = top[47];
      r0[1] = r1[2]; lenv = r0; goto FUN_substring_347;
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[64];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L139; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2ffill_buffer_387;
      L139:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object*) &constructed_1094;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[1];
        r1[4] = r2;
        r2 = top[47];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L140; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_substring_347;
        L140:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[1] = r0;
        r0 = (object *) 1;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[3] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L138:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fread_buffer_388; r1[2] = lenv;
  r0[65] = r1;
  // def file/read-char_389
  goto L141;
  FUN_file_2fread_char_389:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = (object *) 3;
      r2 = ((object*) lenv) [3];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[4] = r1;
      r0 = ((object*) lenv) [4];
      r1 = ((object*) lenv) [2];
      range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
      r0 = ((object*) lenv) [4];
      r1 = ((object*) lenv) [2];
      r0 = TO_CHAR(((unsigned char *)((pxll_string*)(r1))->data)[unbox(r0)]);
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[64];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L142; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2ffill_buffer_387;
      L142:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 65794;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[66];
        r0[1] = r1[2]; lenv = r0; goto FUN_file_2fread_char_389;
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L141:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fread_char_389; r1[2] = lenv;
  r0[66] = r1;
  // def alist/lookup_396
  goto L143;
  FUN_alist_2flookup_396:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object*)UITAG(1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = top[67];
          r0[1] = r1[2]; lenv = r0; goto FUN_alist_2flookup_396;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L143:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2flookup_396; r1[2] = lenv;
  r0[67] = r1;
  // def alist/get_398
  goto L144;
  FUN_alist_2fget_398:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = top[67];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L145; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
    L145:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      } break;
    }
    PXLL_RETURN(0);
  L144:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2fget_398; r1[2] = lenv;
  r0[68] = r1;
  // def alist/iterate_399
  goto L146;
  FUN_alist_2fiterate_399:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L147; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L147:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = top[69];
        r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
      } break;
    }
    PXLL_RETURN(0);
  L146:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2fiterate_399; r1[2] = lenv;
  r0[69] = r1;
  // def alist->keys_401
  goto L148;
  FUN_alist__3ekeys_401:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object*)TC_NIL;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[70];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L149; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist__3ekeys_401;
        L149:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L148:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist__3ekeys_401; r1[2] = lenv;
  r0[70] = r1;
  // def alist/length_403
  goto L150;
  FUN_alist_2flength_403:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[71];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L151; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flength_403;
        L151:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L150:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2flength_403; r1[2] = lenv;
  r0[71] = r1;
  // def tree/skew_407
  goto L152;
  FUN_tree_2fskew_407:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)>unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
    } else {
      r0 = (object *) 6;
    }
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 11);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[4] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r1 = ((pxll_vector*)r1)->val[1];
      r0[5] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[6] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[7] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[8] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[9] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r2 = ((pxll_vector*)r2)->val[3];
      r1[2] = r2;
      r2 = top[72];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L153; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fskew_407;
      L153:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[10] = r1;
      r1 = allocate (UOTAG(17), 5);
      r2 = ((object*) lenv) [7];
      r1[1] = r2;
      r2 = ((object*) lenv) [9];
      r1[2] = r2;
      r2 = ((object*) lenv) [6];
      r1[3] = r2;
      r2 = ((object*) lenv) [10];
      r1[4] = r2;
      r2 = ((object*) lenv) [8];
      r1[5] = r2;
      r0[11] = r1;
      r0 = allocate (UOTAG(17), 5);
      r1 = ((object*) lenv) [3];
      r0[1] = r1;
      r1 = ((object*) lenv) [5];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = ((object*) lenv) [11];
      r0[4] = r1;
      r1 = ((object*) lenv) [4];
      r0[5] = r1;
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L152:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fskew_407; r1[2] = lenv;
  r0[72] = r1;
  // def tree/split_408
  goto L154;
  FUN_tree_2fsplit_408:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[3];
    r1 = ((pxll_vector*)r1)->val[3];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r1 = (object *) 1;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(unbox(r2)==unbox(r1));
      r0[3] = r1;
      r0 = (object *) 6;
      r1 = ((object*) lenv) [3];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
    } else {
      r0 = (object *) 6;
    }
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 12);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r2 = (object *) 3;
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[4] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[5] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[6] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[7] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[8] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[1];
      r0[9] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r1 = ((pxll_vector*)r1)->val[1];
      r0[10] = r1;
      r1 = allocate (UOTAG(17), 5);
      r2 = ((object*) lenv) [7];
      r1[1] = r2;
      r2 = ((object*) lenv) [9];
      r1[2] = r2;
      r2 = ((object*) lenv) [6];
      r1[3] = r2;
      r2 = ((object*) lenv) [10];
      r1[4] = r2;
      r2 = ((object*) lenv) [8];
      r1[5] = r2;
      r0[11] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r2 = ((pxll_vector*)r2)->val[3];
      r2 = ((pxll_vector*)r2)->val[3];
      r1[2] = r2;
      r2 = top[73];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L155; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fsplit_408;
      L155:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[12] = r1;
      r0 = allocate (UOTAG(17), 5);
      r1 = ((object*) lenv) [4];
      r0[1] = r1;
      r1 = ((object*) lenv) [11];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r0[3] = r1;
      r1 = ((object*) lenv) [12];
      r0[4] = r1;
      r1 = ((object*) lenv) [5];
      r0[5] = r1;
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L154:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fsplit_408; r1[2] = lenv;
  r0[73] = r1;
  // def tree/insert_409
  goto L156;
  FUN_tree_2finsert_409:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1196
    goto L157;
    FUN_loop_1196:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (UOTAG(17), 5);
        r1 = ((object***) lenv) [1][1][4];
        r0[1] = r1;
        r1 = top[168];
        r0[2] = r1;
        r1 = (object *) 3;
        r0[3] = r1;
        r1 = top[168];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[5] = r1;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object***) lenv) [1][1][4];
        r2[2] = r3;
        r3 = ((object*) lenv) [2];
        r3 = ((pxll_vector*)r3)->val[0];
        r2[3] = r3;
        r3 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L158; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto *r3[1];
        L158:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        if PXLL_IS_TRUE(r2) {
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[2];
          r2[2] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[0];
          r2[3] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[4];
          r2[4] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][2];
          r4 = ((pxll_vector*)r4)->val[1];
          r3[2] = r4;
          r4 = ((object***) lenv) [1][1][2];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L159; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_loop_1196;
          L159:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[5] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[3];
          r2[6] = r3;
          r2 = allocate (UOTAG(17), 5);
          r3 = ((object*) lenv) [3];
          r2[1] = r3;
          r3 = ((object*) lenv) [5];
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r2[3] = r3;
          r3 = ((object*) lenv) [6];
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r2[5] = r3;
          lenv = lenv[1];
        } else {
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[2];
          r2[2] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[0];
          r2[3] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[4];
          r2[4] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = ((pxll_vector*)r3)->val[1];
          r2[5] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][2];
          r4 = ((pxll_vector*)r4)->val[3];
          r3[2] = r4;
          r4 = ((object***) lenv) [1][1][2];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L160; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_loop_1196;
          L160:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[6] = r3;
          r2 = allocate (UOTAG(17), 5);
          r3 = ((object*) lenv) [3];
          r2[1] = r3;
          r3 = ((object*) lenv) [5];
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r2[3] = r3;
          r3 = ((object*) lenv) [6];
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r2[5] = r3;
          lenv = lenv[1];
        }
        r1[2] = r2;
        r2 = top[72];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L161; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fskew_407;
        L161:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = top[73];
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fsplit_408;
      }
      PXLL_RETURN(0);
    L157:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1196; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1196;
  L156:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2finsert_409; r1[2] = lenv;
  r0[74] = r1;
  // def tree/member_411
  goto L162;
  FUN_tree_2fmember_411:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def member0_1210
    goto L163;
    FUN_member0_1210:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object*)UITAG(1);
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object***) lenv) [1][1][4];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L164; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L164:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = ((object*) lenv) [2];
          r0 = ((pxll_vector*)r0)->val[1];
          lenv[2] = r0;
          goto FUN_member0_1210;
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[0];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L165; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L165:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*) lenv) [2];
            r0 = ((pxll_vector*)r0)->val[3];
            lenv[2] = r0;
            goto FUN_member0_1210;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = ((pxll_vector*)r1)->val[4];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L163:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_member0_1210; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_member0_1210;
  L162:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fmember_411; r1[2] = lenv;
  r0[75] = r1;
  // def tree/inorder_412
  goto L166;
  FUN_tree_2finorder_412:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_1214
    goto L167;
    FUN_recur_1214:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[1];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L168; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_recur_1214;
        L168:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L169; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L169:
        ; lenv = k[2]; k = k[1];
        r0 = ((object*) lenv) [2];
        r0 = ((pxll_vector*)r0)->val[3];
        lenv[2] = r0;
        goto FUN_recur_1214;
      }
      PXLL_RETURN(0);
    L167:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_1214; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][3];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_1214;
  L166:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2finorder_412; r1[2] = lenv;
  r0[76] = r1;
  // def tree/reverse_413
  goto L170;
  FUN_tree_2freverse_413:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_1218
    goto L171;
    FUN_recur_1218:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L172; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_recur_1218;
        L172:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L173; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L173:
        ; lenv = k[2]; k = k[1];
        r0 = ((object*) lenv) [2];
        r0 = ((pxll_vector*)r0)->val[1];
        lenv[2] = r0;
        goto FUN_recur_1218;
      }
      PXLL_RETURN(0);
    L171:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_1218; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][3];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_1218;
  L170:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2freverse_413; r1[2] = lenv;
  r0[77] = r1;
  // def tree/keys_414
  goto L174;
  FUN_tree_2fkeys_414:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_1093[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_4461
    goto L175;
    FUN_lambda_4461:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      ((object**) lenv) [1][2] = r0;
      PXLL_RETURN(0);
    L175:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_4461; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[77];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L176; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_413;
    L176:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L174:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fkeys_414; r1[2] = lenv;
  r0[78] = r1;
  // def tree/values_415
  goto L177;
  FUN_tree_2fvalues_415:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_1092[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_4478
    goto L178;
    FUN_lambda_4478:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      ((object**) lenv) [1][2] = r0;
      PXLL_RETURN(0);
    L178:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_4478; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[77];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L179; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_413;
    L179:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L177:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fvalues_415; r1[2] = lenv;
  r0[79] = r1;
  // def symbol->string_418
  goto L180;
  FUN_symbol__3estring_418:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L180:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol__3estring_418; r1[2] = lenv;
  r0[80] = r1;
  // def intern-symbol_420
  goto L181;
  FUN_intern_symbol_420:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = top[170];
    r0[2] = r1;
    r1 = top[54];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[5] = r1;
    r1 = top[74];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L182; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_409;
    L182:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    top[170] = r0;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = top[169];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = (object *) 3;
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    lenv = lenv[1];
    top[169] = r0;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L181:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_intern_symbol_420; r1[2] = lenv;
  r0[81] = r1;
  // def string->symbol_421
  goto L183;
  FUN_string__3esymbol_421:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = top[170];
    r1[2] = r2;
    r2 = top[54];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L184; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L184:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = top[169];
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_SYMBOL,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[81];
        r0[1] = r1[2]; lenv = r0; goto FUN_intern_symbol_420;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L183:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string__3esymbol_421; r1[2] = lenv;
  r0[82] = r1;
  // def symbol<?_422
  goto L185;
  FUN_symbol_3c_question_422:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][2];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][3];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[52];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L186; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
    L186:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [4];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L185:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_3c_question_422; r1[2] = lenv;
  r0[83] = r1;
  // def symbol-index<?_423
  goto L187;
  FUN_symbol_index_3c_question_423:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][2];
    r2 = UOBJ_GET(r2,1);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object***) lenv) [1][1][3];
    r2 = UOBJ_GET(r2,1);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L187:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_index_3c_question_423; r1[2] = lenv;
  r0[84] = r1;
  // def char-class_425
  goto L188;
  FUN_char_class_425:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 513;
    ensure_heap (1, unbox(r1));
    r1 = (object *) 6;
    r2 = (object *) 513;
    if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
      t = alloc_no_clear (TC_VECTOR, unbox(r2));
      for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
      r1 = t;
    }
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def in-class?_1256
    goto L189;
    FUN_in_class_question_1256:
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)GET_CHAR(r0));
      r1 = ((object***) lenv) [1][1][2];
      range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r0));
      r0 = ((pxll_vector*)r1)->val[unbox(r0)];
      PXLL_RETURN(0);
    L189:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_in_class_question_1256; r1[2] = lenv;
    r0[2] = r1;
    // def loop_1258
    goto L190;
    FUN_loop_1258:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object**) lenv) [1][2];
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)GET_CHAR(r0));
          r1 = (object *) 262;
          r2 = ((object****) lenv) [1][1][1][2];
          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
          ((pxll_vector*)r2)->val[unbox(r0)] = r1;
          r0 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_1258;
        } break;
      }
      PXLL_RETURN(0);
    L190:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1258; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1258;
  L188:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_char_class_425; r1[2] = lenv;
  r0[85] = r1;
  // def reader_426
  goto L191;
  FUN_reader_426:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 65794;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 10);
    r0[1] = lenv; lenv = r0;
    // def skip-whitespace_1268
    goto L192;
    FUN_skip_whitespace_1268:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1289
      goto L193;
      FUN_loop_1289:
        check_heap (0);
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 15106;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop_1287_i257
            goto L194;
            FUN_loop_1287_i257:
              check_heap (0);
              r0 = (object *) 2562;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_429;
              }
              PXLL_RETURN(0);
              goto fatbar_429_over;
              fatbar_429:
              r0 = (object *) 3330;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_430;
              }
              PXLL_RETURN(0);
              goto fatbar_430_over;
              fatbar_430:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L195; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L195:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L196; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L196:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              lenv[2] = r0;
              goto FUN_loop_1287_i257;
              fatbar_430_over: ;
              PXLL_RETURN(0);
              fatbar_429_over: ;
              PXLL_RETURN(0);
            L194:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop_1287_i257; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            r1[2] = r2;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L197; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L197:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object******) lenv) [1][1][1][1][1][2] = r1;
            r1 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L198; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_loop_1287_i257;
            L198:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*****) lenv) [1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L199; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L199:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object****) lenv) [1][1][1][2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object****) lenv) [1][1][1][2];
            lenv[2] = r0;
            goto FUN_loop_1289;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = top[179];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L200; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L200:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[2] = r1;
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L201; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L201:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*****) lenv) [1][1][1][1][2] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*****) lenv) [1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L202; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L202:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object****) lenv) [1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object****) lenv) [1][1][1][2];
              lenv[2] = r0;
              goto FUN_loop_1289;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L193:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1289; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L203; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L203:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1289;
    L192:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_skip_whitespace_1268; r1[2] = lenv;
    r0[2] = r1;
    // def read-atom_1269
    goto L204;
    FUN_read_atom_1269:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) 12290;
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1294
      goto L205;
      FUN_loop_1294:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L206; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L206:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*****) lenv) [1][1][1][1][2] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = ((object*****) lenv) [1][1][1][1][2];
        ((object***) lenv) [1][1][4] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 11778;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          ((object***) lenv) [1][1][3] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 7;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[180];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L207; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L207:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
            } else {
              r0 = (object *) 7;
            }
          }
        } else {
          goto fatbar_425;
        }
        goto fatbar_425_over;
        fatbar_425:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 5;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 13;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[180];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L208; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L208:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 13;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[181];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L209; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L209:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
              } else {
                r0 = (object *) 7;
              }
            }
          }
        } else {
          goto fatbar_426;
        }
        goto fatbar_426_over;
        fatbar_426:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[180];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L210; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L210:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[181];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L211; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L211:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
              } else {
                r0 = (object *) 7;
              }
            }
          }
        } else {
          goto fatbar_427;
        }
        goto fatbar_427_over;
        fatbar_427:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 9;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 11522;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[181];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L212; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L212:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object***) lenv) [1][1][4];
                r0[2] = r1;
                r1 = top[180];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L213; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L213:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                if PXLL_IS_TRUE(r0) {
                  r0 = (object *) 15;
                } else {
                  r0 = (object *) 7;
                }
              }
            }
          }
        } else {
          goto fatbar_428;
        }
        goto fatbar_428_over;
        fatbar_428:
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_67;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_67;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        fatbar_428_over: ;
        fatbar_427_over: ;
        fatbar_426_over: ;
        fatbar_425_over: ;
        ((object***) lenv) [1][1][2] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 9;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)<unbox(r0));
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L214; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L214:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object******) lenv) [1][1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r1 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          lenv[2] = r0;
          goto FUN_loop_1294;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 9;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object*) &constructed_68;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_68;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_1090;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_1090;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 15;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object******) lenv) [1][1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L215; t[4] = r0; k = t;
              lenv = r1[2]; goto *r1[1];
              L215:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              ((object******) lenv) [1][1][1][1][1][2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              ((object*) lenv) [2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (UOTAG(0), 4);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L216; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L216:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r1[2] = r2;
            r2 = top[56];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L217; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_363;
            L217:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[1] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r1 = (object *) 13;
            r2 = ((object*) lenv) [2];
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            lenv = lenv[1];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L218; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L218:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r0[4] = r1;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L205:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1294; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1089[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1294;
    L204:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_atom_1269; r1[2] = lenv;
    r0[3] = r1;
    // def read_1273
    goto L219;
    FUN_read_1273:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L220; t[4] = r0; k = t;
      lenv = r1[2]; goto FUN_skip_whitespace_1268;
      L220:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object*****) lenv) [1][1][1][1][2];
      r2[2] = r3;
      r2 = (object *) 65794;
      r3 = ((object*) lenv) [2];
      r2 = PXLL_TEST(r3==r2);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r2) {
        r2 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L221; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L221:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        ((object****) lenv) [1][1][1][2] = r2;
      } else {
        r2 = (object *) 14;
      }
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10498;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_68;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1069;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1069;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
      } else {
        goto fatbar_385;
      }
      goto fatbar_385_over;
      fatbar_385:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8962;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L222; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L222:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L223; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L223:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object****) lenv) [1][1][1][2] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object****) lenv) [1][1][1][2];
        ((object*) lenv) [2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 10242;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][7];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L224; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_list_1278;
          L224:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(7),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_387;
        }
        goto fatbar_387_over;
        fatbar_387:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29954;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L225; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L225:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
        } else {
          goto fatbar_388;
        }
        goto fatbar_388_over;
        fatbar_388:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21762;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L226; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L226:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
        } else {
          goto fatbar_389;
        }
        goto fatbar_389_over;
        fatbar_389:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 26114;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L227; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L227:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_390;
        }
        goto fatbar_390_over;
        fatbar_390:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 17922;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L228; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L228:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_391;
        }
        goto fatbar_391_over;
        fatbar_391:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29698;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L229; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L229:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_392;
        }
        goto fatbar_392_over;
        fatbar_392:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21506;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L230; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L230:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_393;
        }
        goto fatbar_393_over;
        fatbar_393:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 28418;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L231; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L231:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L232; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_oct_int_1283;
          L232:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_394;
        }
        goto fatbar_394_over;
        fatbar_394:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 20226;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L233; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L233:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L234; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_oct_int_1283;
          L234:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_395;
        }
        goto fatbar_395_over;
        fatbar_395:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 30722;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L235; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L235:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L236; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_hex_int_1282;
          L236:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_396;
        }
        goto fatbar_396_over;
        fatbar_396:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 22530;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L237; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L237:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L238; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_hex_int_1282;
          L238:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_397;
        }
        goto fatbar_397_over;
        fatbar_397:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 23554;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L239; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L239:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L240; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_atom_1269;
          L240:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          switch (get_case_noint (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,2);
              r1[3] = r2;
              r1 = (object *) 3;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
              } else {
                goto fatbar_400;
              }
              goto fatbar_400_over;
              fatbar_400:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1070;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L241; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L241:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_401;
              }
              goto fatbar_401_over;
              fatbar_401:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1071;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L242; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L242:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 65794;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_402;
              }
              goto fatbar_402_over;
              fatbar_402:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1072;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L243; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L243:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2306;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_403;
              }
              goto fatbar_403_over;
              fatbar_403:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1073;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L244; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L244:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 3330;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_404;
              }
              goto fatbar_404_over;
              fatbar_404:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1074;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L245; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L245:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 8194;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_405;
              }
              goto fatbar_405_over;
              fatbar_405:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1075;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L246; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L246:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2562;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_399;
              }
              fatbar_405_over: ;
              fatbar_404_over: ;
              fatbar_403_over: ;
              fatbar_402_over: ;
              fatbar_401_over: ;
              fatbar_400_over: ;
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_399;
            };
          }
          goto fatbar_399_over;
          fatbar_399:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_1076;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L247; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L247:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_399_over: ;
          lenv = lenv[1];
        } else {
          goto fatbar_398;
        }
        goto fatbar_398_over;
        fatbar_398:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_1077;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[15];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L248; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
        L248:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        fatbar_398_over: ;
        fatbar_397_over: ;
        fatbar_396_over: ;
        fatbar_395_over: ;
        fatbar_394_over: ;
        fatbar_393_over: ;
        fatbar_392_over: ;
        fatbar_391_over: ;
        fatbar_390_over: ;
        fatbar_389_over: ;
        fatbar_388_over: ;
        fatbar_387_over: ;
      } else {
        goto fatbar_386;
      }
      goto fatbar_386_over;
      fatbar_386:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 14850;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L249; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L249:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L250; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_atom_1269;
        L250:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        switch (get_case_noint (r2)) {
          default: {
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,1);
            r2[3] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,3);
            r2[4] = r3;
            r2 = ((object*) lenv) [3];
            switch (get_case (r2)) {
              case ((pxll_int)PXLL_TRUE): {
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1078;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[15];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L251; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_294;
                L251:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
              } break;
              default: {
                r2 = (object *) 1;
                r3 = ((object*) lenv) [4];
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object*) lenv) [2];
                  r2[2] = r3;
                  r3 = top[82];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L252; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_421;
                  L252:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                } else {
                  goto fatbar_407;
                }
                goto fatbar_407_over;
                fatbar_407:
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1079;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[15];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L253; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_294;
                L253:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                fatbar_407_over: ;
              } break;
            }
            lenv = lenv[1];
          } break;
        }
        r1[3] = r2;
        r1 = ((object*) lenv) [3];
        r2 = (object *) constructed_49[0];
        t = alloc_no_clear (UOTAG(9),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_406;
      }
      goto fatbar_406_over;
      fatbar_406:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 11266;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L254; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L254:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_1081[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L255; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1273;
        L255:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_408;
      }
      goto fatbar_408_over;
      fatbar_408:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 9986;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L256; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L256:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_905[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L257; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1273;
        L257:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_409;
      }
      goto fatbar_409_over;
      fatbar_409:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8706;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L258; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L258:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1329_i366_i440
        goto L259;
        FUN_loop_1329_i366_i440:
          check_heap (0);
          r0 = (object *) 23554;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L260; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L260:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L261; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L261:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            ((object*) lenv) [2] = r0;
            r0 = (object *) 23554;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L262; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L262:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 23554;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440;
            } else {
              goto fatbar_412;
            }
            PXLL_RETURN(0);
            goto fatbar_412_over;
            fatbar_412:
            r0 = (object *) 8706;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L263; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L263:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 8706;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440;
            } else {
              goto fatbar_413;
            }
            PXLL_RETURN(0);
            goto fatbar_413_over;
            fatbar_413:
            r0 = (object *) 29698;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L264; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L264:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2306;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440;
            } else {
              goto fatbar_414;
            }
            PXLL_RETURN(0);
            goto fatbar_414_over;
            fatbar_414:
            r0 = (object *) 28162;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L265; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L265:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2562;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440;
            } else {
              goto fatbar_415;
            }
            PXLL_RETURN(0);
            goto fatbar_415_over;
            fatbar_415:
            r0 = (object *) 29186;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L266; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L266:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 3330;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440;
            } else {
              goto fatbar_416;
            }
            PXLL_RETURN(0);
            goto fatbar_416_over;
            fatbar_416:
            r0 = (object *) 22530;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L267; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L267:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L268; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto FUN_read_hex_code_1276;
              L268:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440;
            } else {
              goto fatbar_417;
            }
            PXLL_RETURN(0);
            goto fatbar_417_over;
            fatbar_417:
            r0 = (object *) 30722;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L269; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L269:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][2] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][2];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L270; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto FUN_read_hex_code_1276;
              L270:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440;
            } else {
              goto fatbar_418;
            }
            PXLL_RETURN(0);
            goto fatbar_418_over;
            fatbar_418:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_1083;
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = top[15];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
            fatbar_418_over: ;
            PXLL_RETURN(0);
            fatbar_417_over: ;
            PXLL_RETURN(0);
            fatbar_416_over: ;
            PXLL_RETURN(0);
            fatbar_415_over: ;
            PXLL_RETURN(0);
            fatbar_414_over: ;
            PXLL_RETURN(0);
            fatbar_413_over: ;
            PXLL_RETURN(0);
            fatbar_412_over: ;
            PXLL_RETURN(0);
          } else {
            goto fatbar_411;
          }
          PXLL_RETURN(0);
          goto fatbar_411_over;
          fatbar_411:
          r0 = (object *) 8706;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L271; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L271:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L272; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L272:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[56];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L273; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_363;
            L273:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            goto fatbar_419;
          }
          PXLL_RETURN(0);
          goto fatbar_419_over;
          fatbar_419:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L274; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L274:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L275; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L275:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object******) lenv) [1][1][1][1][1][2] = r0;
          } else {
            r0 = (object *) 14;
          }
          r0 = ((object******) lenv) [1][1][1][1][1][2];
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_1329_i366_i440;
          fatbar_419_over: ;
          PXLL_RETURN(0);
          fatbar_411_over: ;
          PXLL_RETURN(0);
        L259:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1329_i366_i440; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object******) lenv) [1][1][1][1][1][2];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r2) {
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L276; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L276:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*****) lenv) [1][1][1][1][2] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r2 = (object *) constructed_1082[0];
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L277; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1329_i366_i440;
        L277:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
      } else {
        goto fatbar_410;
      }
      goto fatbar_410_over;
      fatbar_410:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 31490;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L278; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L278:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1336_i400_i440
        goto L279;
        FUN_loop_1336_i400_i440:
          check_heap (0);
          r0 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L280; ; k = t;
          lenv = r0[2]; goto FUN_skip_whitespace_1268;
          L280:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          r1[2] = r2;
          r1 = (object *) 65794;
          r2 = ((object*) lenv) [2];
          r1 = PXLL_TEST(r2==r1);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r1) {
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L281; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L281:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object*******) lenv) [1][1][1][1][1][1][2] = r1;
          } else {
            r1 = (object *) 14;
          }
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 32002;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L282; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L282:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = (object *) constructed_36[0];
            r1[3] = r2;
            r2 = top[23];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L283; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
            L283:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(8),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def loop_1341_i407_i440
            goto L284;
            FUN_loop_1341_i407_i440:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = top[182];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L285; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L285:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 262;
              } else {
                r0 = (object *) 11778;
                r1 = ((object*) lenv) [3];
                r0 = PXLL_TEST(r1==r0);
              }
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L286; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L286:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = (object *) 65794;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                if PXLL_IS_TRUE(r0) {
                  r0 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L287; ; k = t;
                  lenv = r0[2]; goto *r0[1];
                  L287:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2] = r0;
                } else {
                  r0 = (object *) 14;
                }
                r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                r1 = ((object*) lenv) [2];
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r2 = (object *) 6;
                lenv[2] = r1;
                lenv[3] = r0;
                lenv[4] = r2;
                goto FUN_loop_1341_i407_i440;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_36[0];
                r2[3] = r3;
                r3 = top[23];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L288; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
                L288:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = top[56];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L289; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_363;
                L289:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = top[82];
                r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_421;
              }
              PXLL_RETURN(0);
            L284:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_loop_1341_i407_i440; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r2 = (object *) constructed_1086[0];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
            r2[2] = r3;
            r2 = (object *) 65794;
            r3 = ((object*) lenv) [2];
            r2 = PXLL_TEST(r3==r2);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r2) {
              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L290; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L290:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              ((object*********) lenv) [1][1][1][1][1][1][1][1][2] = r2;
            } else {
              r2 = (object *) 14;
            }
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            r1[3] = r2;
            r2 = (object *) 6;
            r1[4] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L291; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_loop_1341_i407_i440;
            L291:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r0[2] = r1;
            r0 = (object *) constructed_66[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 6;
              t = alloc_no_clear (UOTAG(4),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(0),2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[3] = r1;
              r0 = ((object****) lenv) [1][1][1][2];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              goto FUN_loop_1336_i400_i440;
            } else {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L292; ; k = t;
              lenv = r0[2]; goto FUN_skip_whitespace_1268;
              L292:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
              r1[2] = r2;
              r1 = (object *) 65794;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L293; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L293:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][2] = r1;
              } else {
                r1 = (object *) 14;
              }
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              r0[2] = r1;
              r1 = (object *) 15618;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              r0[3] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_1085;
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[3] = r1;
                r1 = top[15];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L294; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L294:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][2] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L295; t[4] = r0; k = t;
                lenv = r1[2]; goto FUN_read_1273;
                L295:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (UOTAG(0),2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = ((object*****) lenv) [1][1][1][1][2];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                lenv = ((object ***)lenv)[1][1][1];
                lenv[2] = r0;
                goto FUN_loop_1336_i400_i440;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L279:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1336_i400_i440; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) constructed_1084[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L296; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1336_i400_i440;
        L296:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
      } else {
        goto fatbar_420;
      }
      goto fatbar_420_over;
      fatbar_420:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10242;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][7];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L297; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_list_1278;
        L297:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_421;
      }
      goto fatbar_421_over;
      fatbar_421:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_68;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1087;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1087;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
      } else {
        goto fatbar_422;
      }
      goto fatbar_422_over;
      fatbar_422:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L298; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto FUN_read_atom_1269;
      L298:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      switch (get_case_noint (r1)) {
        default: {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,2);
          r1[4] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,3);
          r1[5] = r2;
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case ((pxll_int)PXLL_TRUE): {
              r1 = allocate (TC_TUPLE, 5);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
              r1[2] = r2;
              r2 = (object *) 11522;
              r3 = ((object*) lenv) [2];
              r2 = PXLL_TEST(r3==r2);
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(r2) {
                r2 = (object *) 3;
              } else {
                r2 = (object *) 1;
              }
              r1[4] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              // def loop_1349_i428_i440
              goto L299;
              FUN_loop_1349_i428_i440:
                check_heap (0);
                r0 = ((object****) lenv) [1][1][1][4];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = ((object***) lenv) [1][1][3];
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object*) lenv) [3];
                    r1 = (object *) 1;
                    r0 = box((pxll_int)unbox(r1)-unbox(r0));
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object*) lenv) [3];
                    PXLL_RETURN(0);
                  }
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[172];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                  r1[3] = r2;
                  r2 = top[67];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L300; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
                  L300:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UITAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_1088;
                      r0[2] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][2];
                      r0[3] = r1;
                      r1 = top[15];
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = (object *) 21;
                      r2 = ((object****) lenv) [1][1][1][3];
                      r1 = box((pxll_int)unbox(r2)*unbox(r1));
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][2];
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv = lenv[1];
                      r1 = (object *) 3;
                      r2 = ((object***) lenv) [1][1][2];
                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                      lenv = ((object **)lenv)[1][1];
                      lenv[2] = r1;
                      lenv[3] = r0;
                      goto FUN_loop_1349_i428_i440;
                    } break;
                  }
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              L299:
              r3 = allocate (TC_CLOSURE, 2);
              r3[1] = &&FUN_loop_1349_i428_i440; r3[2] = lenv;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][4];
              r2[2] = r3;
              r3 = (object *) 1;
              r2[3] = r3;
              r3 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L301; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_loop_1349_i428_i440;
              L301:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[5] = r2;
              r1 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(5),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
            } break;
            default: {
              r1 = (object *) 1;
              r2 = ((object*) lenv) [5];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[82];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L302; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_421;
                L302:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
              } else {
                goto fatbar_423;
              }
              goto fatbar_423_over;
              fatbar_423:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = box((pxll_int)((pxll_string*)(r2))->len);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][5];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[82];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L303; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_421;
                L303:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                // def loop_1298_i439_i440
                goto L304;
                FUN_loop_1298_i439_i440:
                  check_heap (0);
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[82];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L305; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
                          L305:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(1),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_424;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_424_over;
                      fatbar_424:
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = ((object****) lenv) [1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L306; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_1298_i439_i440;
                      L306:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = top[82];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L307; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
                      L307:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      r1 = ((object*) lenv) [2];
                      t = alloc_no_clear (UOTAG(10),2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                      fatbar_424_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = (object*) &constructed_68;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_68;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_67;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_67;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L304:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_loop_1298_i439_i440; r2[2] = lenv;
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 3);
                r4 = ((object***) lenv) [1][1][2];
                r3[2] = r4;
                r4 = (object *) 11778;
                r3[3] = r4;
                r4 = top[51];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L308; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_string_split_356;
                L308:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_36[0];
                r2[3] = r3;
                r3 = top[23];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L309; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
                L309:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L310; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_loop_1298_i439_i440;
                L310:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
              }
              fatbar_423_over: ;
            } break;
          }
          lenv = lenv[1];
        } break;
      }
      lenv = lenv[1];
      fatbar_422_over: ;
      fatbar_421_over: ;
      fatbar_420_over: ;
      fatbar_410_over: ;
      fatbar_409_over: ;
      fatbar_408_over: ;
      fatbar_406_over: ;
      fatbar_386_over: ;
      fatbar_385_over: ;
      lenv = lenv[1];
      r0[2] = r1;
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L311; ; k = t;
      lenv = r0[2]; goto FUN_skip_whitespace_1268;
      L311:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L312; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L312:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[2] = r1;
      r0 = (object *) 14850;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[2] = r1;
        r0 = ((object******) lenv) [1][1][1][1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L313; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L313:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object*****) lenv) [1][1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L314; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_read_1273;
        L314:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object***) lenv) [1][1][2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(9),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_382;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_382;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_382_over;
        fatbar_382:
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_49[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 7);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_685[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[3] = r1;
              r1 = (object*)TC_NIL;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object*****) lenv) [1][1][1][1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = ((object*) lenv) [5];
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[6] = r1;
              r1 = ((object*) lenv) [6];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[7] = r1;
              r0 = ((object*) lenv) [7];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_383;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_383;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_383_over;
        fatbar_383:
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) constructed_693[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r2 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r2 = ((object****) lenv) [1][1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r0 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_383_over: ;
        PXLL_RETURN(0);
        fatbar_382_over: ;
        PXLL_RETURN(0);
      } else {
        goto fatbar_381;
      }
      PXLL_RETURN(0);
      goto fatbar_381_over;
      fatbar_381:
      r0 = (object *) 23298;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r1[2] = r2;
        r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L315; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L315:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object******) lenv) [1][1][1][1][1][2] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L316; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1273;
        L316:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L317; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_skip_whitespace_1268;
        L317:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r2) {
          r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L318; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L318:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*******) lenv) [1][1][1][1][1][1][2] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
        r1[2] = r2;
        r1 = (object *) 23810;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r1[2] = r2;
          r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L319; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L319:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*******) lenv) [1][1][1][1][1][1][2] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = ((object*) lenv) [2];
        } else {
          r1 = (object*) &constructed_68;
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_1068;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_1068;
          PXLL_UNDEFINED; result=r1; goto Lreturn;
        }
        lenv = lenv[1];
        r0[2] = r1;
        r1 = (object *) constructed_295[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = (object*)TC_NIL;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = ((object*) lenv) [8];
        r2 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[9] = r1;
        r0 = ((object*) lenv) [9];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_384;
      }
      PXLL_RETURN(0);
      goto fatbar_384_over;
      fatbar_384:
      r0 = ((object**) lenv) [1][2];
      PXLL_RETURN(0);
      fatbar_384_over: ;
      PXLL_RETURN(0);
      fatbar_381_over: ;
      PXLL_RETURN(0);
    L219:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_1273; r1[2] = lenv;
    r0[4] = r1;
    // def read-hex-digit_1275
    goto L320;
    FUN_read_hex_digit_1275:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[171];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[67];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L321; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
      L321:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*) &constructed_68;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_1067;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_1067;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L320:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_digit_1275; r1[2] = lenv;
    r0[5] = r1;
    // def read-hex-code_1276
    goto L322;
    FUN_read_hex_code_1276:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][2];
      r2[2] = r3;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L323; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L323:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][2] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L324; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_read_hex_digit_1275;
      L324:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][2];
      r2[2] = r3;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L325; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L325:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][2] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L326; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_read_hex_digit_1275;
      L326:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = (object *) 17;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)<<unbox(r1));
      r0[4] = r1;
      r1 = ((object*) lenv) [3];
      r2 = ((object*) lenv) [4];
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[5] = r1;
      r0 = ((object*) lenv) [5];
      r0 = TO_CHAR(unbox(r0));
      PXLL_RETURN(0);
    L322:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_code_1276; r1[2] = lenv;
    r0[6] = r1;
    // def read-list_1278
    goto L327;
    FUN_read_list_1278:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = ((object****) lenv) [1][1][1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L328; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L328:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      ((object***) lenv) [1][1][2] = r0;
      r0 = ((object*) lenv) [2];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1332
      goto L329;
      FUN_loop_1332:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L330; ; k = t;
        lenv = r0[2]; goto FUN_skip_whitespace_1268;
        L330:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L331; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L331:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][2] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 10498;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L332; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L332:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object******) lenv) [1][1][1][1][1][2] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = (object *) constructed_36[0];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L333; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_read_1273;
          L333:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r0;
          goto FUN_loop_1332;
        }
        PXLL_RETURN(0);
      L329:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1332; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1066[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1332;
    L327:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_list_1278; r1[2] = lenv;
    r0[7] = r1;
    // def read-hex-int_1282
    goto L334;
    FUN_read_hex_int_1282:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L335; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L335:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L336; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L336:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1355
      goto L337;
      FUN_loop_1355:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[171];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[67];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L338; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
        L338:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L339; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L339:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L340; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L340:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 33;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1355;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L337:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1355; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L341; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L341:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1355;
    L334:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_int_1282; r1[2] = lenv;
    r0[8] = r1;
    // def read-oct-int_1283
    goto L342;
    FUN_read_oct_int_1283:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L343; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L343:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L344; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L344:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1361
      goto L345;
      FUN_loop_1361:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[173];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[67];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L346; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
        L346:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L347; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L347:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L348; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L348:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 17;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1361;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L345:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1361; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L349; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L349:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1361;
    L342:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_oct_int_1283; r1[2] = lenv;
    r0[9] = r1;
    // def loop_1368_i582
    goto L350;
    FUN_loop_1368_i582:
      check_heap (0);
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L351; ; k = t;
      lenv = r0[2]; goto FUN_skip_whitespace_1268;
      L351:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L352; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L352:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][2] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][2];
      r0[2] = r1;
      r0 = (object *) 65794;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = (object *) constructed_36[0];
        r0[3] = r1;
        r1 = top[23];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L353; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_read_1273;
        L353:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_1065[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = ((object**) lenv) [1][3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[87];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L354; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_427;
                                  L354:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_36[0];
                                  r1[3] = r2;
                                  r2 = top[23];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L355; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                                  L355:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_36[0];
                                  r1[3] = r2;
                                  r2 = top[23];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L356; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                                  L356:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                  r0[3] = r1;
                                  r1 = top[23];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L357; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
                                  L357:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = result;
                                  lenv = lenv[1];
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  lenv[2] = r0;
                                  goto FUN_loop_1368_i582;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_380;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_380;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_380;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_380;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_380;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_380;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_380;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_380_over;
        fatbar_380:
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_loop_1368_i582;
        fatbar_380_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L350:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1368_i582; r1[2] = lenv;
    r0[10] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) constructed_1063[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [10];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1368_i582;
  L191:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_reader_426; r1[2] = lenv;
  r0[86] = r1;
  // def read-file_427
  goto L358;
  FUN_read_file_427:
    check_heap (0);
    r0 = (object*) &constructed_1091;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_1091;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = ((object*) lenv) [2];
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[63];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L359; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_file_2fopen_read_382;
    L359:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    // def lambda_6390
    goto L360;
    FUN_lambda_6390:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = top[66];
      r0[1] = r1[2]; lenv = r0; goto FUN_file_2fread_char_389;
    L360:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_6390; r1[2] = lenv;
    r0[3] = r1;
    r1 = (object *) 65794;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 10);
    r0[1] = lenv; lenv = r0;
    // def skip-whitespace_1268_i0
    goto L361;
    FUN_skip_whitespace_1268_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1289_i0
      goto L362;
      FUN_loop_1289_i0:
        check_heap (0);
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 15106;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop_1287_i257_i0
            goto L363;
            FUN_loop_1287_i257_i0:
              check_heap (0);
              r0 = (object *) 2562;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_378;
              }
              PXLL_RETURN(0);
              goto fatbar_378_over;
              fatbar_378:
              r0 = (object *) 3330;
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_379;
              }
              PXLL_RETURN(0);
              goto fatbar_379_over;
              fatbar_379:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L364; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L364:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L365; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L365:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              lenv[2] = r0;
              goto FUN_loop_1287_i257_i0;
              fatbar_379_over: ;
              PXLL_RETURN(0);
              fatbar_378_over: ;
              PXLL_RETURN(0);
            L363:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop_1287_i257_i0; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object******) lenv) [1][1][1][1][1][4];
            r1[2] = r2;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L366; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L366:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object******) lenv) [1][1][1][1][1][4] = r1;
            r1 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L367; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L367:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object****) lenv) [1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L368; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L368:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object****) lenv) [1][1][1][4] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object****) lenv) [1][1][1][4];
            lenv[2] = r0;
            goto FUN_loop_1289_i0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = top[179];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L369; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L369:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][4];
              r0[2] = r1;
              r0 = ((object*****) lenv) [1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L370; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L370:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*****) lenv) [1][1][1][1][4] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object****) lenv) [1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L371; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L371:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object****) lenv) [1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object****) lenv) [1][1][1][4];
              lenv[2] = r0;
              goto FUN_loop_1289_i0;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L362:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1289_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L372; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L372:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L361:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_skip_whitespace_1268_i0; r1[2] = lenv;
    r0[2] = r1;
    // def read-atom_1269_i0
    goto L373;
    FUN_read_atom_1269_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) 12290;
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1294_i0
      goto L374;
      FUN_loop_1294_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 65794;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L375; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L375:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*****) lenv) [1][1][1][1][4] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = ((object*****) lenv) [1][1][1][1][4];
        ((object***) lenv) [1][1][4] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 11778;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          ((object***) lenv) [1][1][3] = r0;
        } else {
          r0 = (object *) 14;
        }
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 7;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[180];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L376; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L376:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
            } else {
              r0 = (object *) 7;
            }
          }
        } else {
          goto fatbar_374;
        }
        goto fatbar_374_over;
        fatbar_374:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 5;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 13;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[180];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L377; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L377:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 13;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[181];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L378; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L378:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
              } else {
                r0 = (object *) 7;
              }
            }
          }
        } else {
          goto fatbar_375;
        }
        goto fatbar_375_over;
        fatbar_375:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r1 = top[180];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L379; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L379:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[181];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L380; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L380:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
              } else {
                r0 = (object *) 7;
              }
            }
          }
        } else {
          goto fatbar_376;
        }
        goto fatbar_376_over;
        fatbar_376:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 9;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 11522;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object***) lenv) [1][1][4];
              r0[2] = r1;
              r1 = top[181];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L381; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L381:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object***) lenv) [1][1][4];
                r0[2] = r1;
                r1 = top[180];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L382; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L382:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                if PXLL_IS_TRUE(r0) {
                  r0 = (object *) 15;
                } else {
                  r0 = (object *) 7;
                }
              }
            }
          }
        } else {
          goto fatbar_377;
        }
        goto fatbar_377_over;
        fatbar_377:
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_67;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_67;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        fatbar_377_over: ;
        fatbar_376_over: ;
        fatbar_375_over: ;
        fatbar_374_over: ;
        ((object***) lenv) [1][1][2] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[2] = r1;
        r0 = (object *) 9;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)<unbox(r0));
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][4];
          r0[2] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L383; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L383:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object******) lenv) [1][1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r1 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          lenv[2] = r0;
          goto FUN_loop_1294_i0;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r0 = (object *) 9;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object*) &constructed_68;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_68;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_1090;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_1090;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r0[2] = r1;
            r0 = (object *) 15;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object******) lenv) [1][1][1][1][1][4];
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][3];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L384; t[4] = r0; k = t;
              lenv = r1[2]; goto *r1[1];
              L384:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              ((object******) lenv) [1][1][1][1][1][4] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              ((object*) lenv) [2] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (UOTAG(0), 4);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L385; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L385:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r1[2] = r2;
            r2 = top[56];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L386; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_363;
            L386:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[1] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r1 = (object *) 13;
            r2 = ((object*) lenv) [2];
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            lenv = lenv[1];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L387; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L387:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r0[4] = r1;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L374:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1294_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1089[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L373:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_atom_1269_i0; r1[2] = lenv;
    r0[3] = r1;
    // def read_1273_i0
    goto L388;
    FUN_read_1273_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L389; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L389:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object*****) lenv) [1][1][1][1][4];
      r2[2] = r3;
      r2 = (object *) 65794;
      r3 = ((object*) lenv) [2];
      r2 = PXLL_TEST(r3==r2);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r2) {
        r2 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L390; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L390:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        ((object****) lenv) [1][1][1][4] = r2;
      } else {
        r2 = (object *) 14;
      }
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10498;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_68;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1069;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1069;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
      } else {
        goto fatbar_334;
      }
      goto fatbar_334_over;
      fatbar_334:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8962;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L391; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L391:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L392; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L392:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object****) lenv) [1][1][1][4] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object****) lenv) [1][1][1][4];
        ((object*) lenv) [2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 10242;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][7];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L393; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L393:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(7),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_336;
        }
        goto fatbar_336_over;
        fatbar_336:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29954;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L394; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L394:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
        } else {
          goto fatbar_337;
        }
        goto fatbar_337_over;
        fatbar_337:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21762;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L395; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L395:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
        } else {
          goto fatbar_338;
        }
        goto fatbar_338_over;
        fatbar_338:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 26114;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L396; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L396:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_339;
        }
        goto fatbar_339_over;
        fatbar_339:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 17922;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L397; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L397:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_340;
        }
        goto fatbar_340_over;
        fatbar_340:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 29698;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L398; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L398:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_341;
        }
        goto fatbar_341_over;
        fatbar_341:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 21506;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L399; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L399:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
        } else {
          goto fatbar_342;
        }
        goto fatbar_342_over;
        fatbar_342:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 28418;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L400; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L400:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L401; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L401:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_343;
        }
        goto fatbar_343_over;
        fatbar_343:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 20226;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L402; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L402:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][9];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L403; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L403:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_344;
        }
        goto fatbar_344_over;
        fatbar_344:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 30722;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L404; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L404:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L405; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L405:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_345;
        }
        goto fatbar_345_over;
        fatbar_345:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 22530;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L406; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L406:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][8];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L407; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L407:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
        } else {
          goto fatbar_346;
        }
        goto fatbar_346_over;
        fatbar_346:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r1 = (object *) 23554;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*****) lenv) [1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L408; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L408:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L409; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L409:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          switch (get_case_noint (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r2 = UOBJ_GET(r2,2);
              r1[3] = r2;
              r1 = (object *) 3;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                r2 = (object *) 1;
                r3 = ((object**) lenv) [1][2];
                r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
              } else {
                goto fatbar_349;
              }
              goto fatbar_349_over;
              fatbar_349:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1070;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L410; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L410:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_350;
              }
              goto fatbar_350_over;
              fatbar_350:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1071;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L411; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L411:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 65794;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_351;
              }
              goto fatbar_351_over;
              fatbar_351:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1072;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L412; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L412:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2306;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_352;
              }
              goto fatbar_352_over;
              fatbar_352:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1073;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L413; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L413:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 3330;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_353;
              }
              goto fatbar_353_over;
              fatbar_353:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1074;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L414; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L414:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 8194;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                goto fatbar_354;
              }
              goto fatbar_354_over;
              fatbar_354:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object*) &constructed_1075;
              r2[3] = r3;
              r3 = top[52];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L415; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
              L415:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2562;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_348;
              }
              fatbar_354_over: ;
              fatbar_353_over: ;
              fatbar_352_over: ;
              fatbar_351_over: ;
              fatbar_350_over: ;
              fatbar_349_over: ;
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_348;
            };
          }
          goto fatbar_348_over;
          fatbar_348:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_1076;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L416; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L416:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_348_over: ;
          lenv = lenv[1];
        } else {
          goto fatbar_347;
        }
        goto fatbar_347_over;
        fatbar_347:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_1077;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[15];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L417; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
        L417:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        fatbar_347_over: ;
        fatbar_346_over: ;
        fatbar_345_over: ;
        fatbar_344_over: ;
        fatbar_343_over: ;
        fatbar_342_over: ;
        fatbar_341_over: ;
        fatbar_340_over: ;
        fatbar_339_over: ;
        fatbar_338_over: ;
        fatbar_337_over: ;
        fatbar_336_over: ;
      } else {
        goto fatbar_335;
      }
      goto fatbar_335_over;
      fatbar_335:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 14850;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L418; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L418:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L419; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L419:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        switch (get_case_noint (r2)) {
          default: {
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,1);
            r2[3] = r3;
            r3 = ((object**) lenv) [1][2];
            r3 = UOBJ_GET(r3,3);
            r2[4] = r3;
            r2 = ((object*) lenv) [3];
            switch (get_case (r2)) {
              case ((pxll_int)PXLL_TRUE): {
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1078;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[15];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L420; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_294;
                L420:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
              } break;
              default: {
                r2 = (object *) 1;
                r3 = ((object*) lenv) [4];
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object*) lenv) [2];
                  r2[2] = r3;
                  r3 = top[82];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L421; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_421;
                  L421:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                } else {
                  goto fatbar_356;
                }
                goto fatbar_356_over;
                fatbar_356:
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_1079;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[15];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L422; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_294;
                L422:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                fatbar_356_over: ;
              } break;
            }
            lenv = lenv[1];
          } break;
        }
        r1[3] = r2;
        r1 = ((object*) lenv) [3];
        r2 = (object *) constructed_49[0];
        t = alloc_no_clear (UOTAG(9),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_355;
      }
      goto fatbar_355_over;
      fatbar_355:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 11266;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L423; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L423:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_1081[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L424; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L424:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_357;
      }
      goto fatbar_357_over;
      fatbar_357:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 9986;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L425; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L425:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_905[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L426; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L426:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_358;
      }
      goto fatbar_358_over;
      fatbar_358:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 8706;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L427; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L427:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1329_i366_i440_i0
        goto L428;
        FUN_loop_1329_i366_i440_i0:
          check_heap (0);
          r0 = (object *) 23554;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L429; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L429:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L430; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L430:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            ((object*) lenv) [2] = r0;
            r0 = (object *) 23554;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L431; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L431:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 23554;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440_i0;
            } else {
              goto fatbar_361;
            }
            PXLL_RETURN(0);
            goto fatbar_361_over;
            fatbar_361:
            r0 = (object *) 8706;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L432; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L432:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 8706;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440_i0;
            } else {
              goto fatbar_362;
            }
            PXLL_RETURN(0);
            goto fatbar_362_over;
            fatbar_362:
            r0 = (object *) 29698;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L433; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L433:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2306;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440_i0;
            } else {
              goto fatbar_363;
            }
            PXLL_RETURN(0);
            goto fatbar_363_over;
            fatbar_363:
            r0 = (object *) 28162;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L434; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L434:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 2562;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440_i0;
            } else {
              goto fatbar_364;
            }
            PXLL_RETURN(0);
            goto fatbar_364_over;
            fatbar_364:
            r0 = (object *) 29186;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L435; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L435:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = ((object*) lenv) [3];
              r2 = (object *) 3330;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440_i0;
            } else {
              goto fatbar_365;
            }
            PXLL_RETURN(0);
            goto fatbar_365_over;
            fatbar_365:
            r0 = (object *) 22530;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L436; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L436:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L437; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L437:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440_i0;
            } else {
              goto fatbar_366;
            }
            PXLL_RETURN(0);
            goto fatbar_366_over;
            fatbar_366:
            r0 = (object *) 30722;
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L438; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L438:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object******) lenv) [1][1][1][1][1][4] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = ((object******) lenv) [1][1][1][1][1][4];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object******) lenv) [1][1][1][1][1][6];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L439; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L439:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1329_i366_i440_i0;
            } else {
              goto fatbar_367;
            }
            PXLL_RETURN(0);
            goto fatbar_367_over;
            fatbar_367:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_1083;
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = top[15];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
            fatbar_367_over: ;
            PXLL_RETURN(0);
            fatbar_366_over: ;
            PXLL_RETURN(0);
            fatbar_365_over: ;
            PXLL_RETURN(0);
            fatbar_364_over: ;
            PXLL_RETURN(0);
            fatbar_363_over: ;
            PXLL_RETURN(0);
            fatbar_362_over: ;
            PXLL_RETURN(0);
            fatbar_361_over: ;
            PXLL_RETURN(0);
          } else {
            goto fatbar_360;
          }
          PXLL_RETURN(0);
          goto fatbar_360_over;
          fatbar_360:
          r0 = (object *) 8706;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L440; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L440:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L441; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L441:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[56];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L442; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_363;
            L442:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            goto fatbar_368;
          }
          PXLL_RETURN(0);
          goto fatbar_368_over;
          fatbar_368:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r0[2] = r1;
          r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L443; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L443:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = ((object******) lenv) [1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L444; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L444:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object******) lenv) [1][1][1][1][1][4] = r0;
          } else {
            r0 = (object *) 14;
          }
          r0 = ((object******) lenv) [1][1][1][1][1][4];
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_1329_i366_i440_i0;
          fatbar_368_over: ;
          PXLL_RETURN(0);
          fatbar_360_over: ;
          PXLL_RETURN(0);
        L428:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1329_i366_i440_i0; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object******) lenv) [1][1][1][1][1][4];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r2) {
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L445; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L445:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*****) lenv) [1][1][1][1][4] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r2 = (object *) constructed_1082[0];
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L446; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L446:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
      } else {
        goto fatbar_359;
      }
      goto fatbar_359_over;
      fatbar_359:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 31490;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L447; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L447:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object*****) lenv) [1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1336_i400_i440_i0
        goto L448;
        FUN_loop_1336_i400_i440_i0:
          check_heap (0);
          r0 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L449; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L449:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
          r1[2] = r2;
          r1 = (object *) 65794;
          r2 = ((object*) lenv) [2];
          r1 = PXLL_TEST(r2==r1);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r1) {
            r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L450; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L450:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            ((object*******) lenv) [1][1][1][1][1][1][4] = r1;
          } else {
            r1 = (object *) 14;
          }
          r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r0[2] = r1;
          r0 = (object *) 32002;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L451; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L451:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = (object *) constructed_36[0];
            r1[3] = r2;
            r2 = top[23];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L452; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
            L452:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(8),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def loop_1341_i407_i440_i0
            goto L453;
            FUN_loop_1341_i407_i440_i0:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = top[182];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L454; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L454:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 262;
              } else {
                r0 = (object *) 11778;
                r1 = ((object*) lenv) [3];
                r0 = PXLL_TEST(r1==r0);
              }
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                r0[2] = r1;
                r0 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L455; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L455:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                r0[2] = r1;
                r0 = (object *) 65794;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                if PXLL_IS_TRUE(r0) {
                  r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L456; ; k = t;
                  lenv = r0[2]; goto *r0[1];
                  L456:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4] = r0;
                } else {
                  r0 = (object *) 14;
                }
                r0 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                r1 = ((object*) lenv) [2];
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r2 = (object *) 6;
                lenv[2] = r1;
                lenv[3] = r0;
                lenv[4] = r2;
                goto FUN_loop_1341_i407_i440_i0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_36[0];
                r2[3] = r3;
                r3 = top[23];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L457; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
                L457:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = top[56];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L458; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_363;
                L458:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = top[82];
                r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_421;
              }
              PXLL_RETURN(0);
            L453:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_loop_1341_i407_i440_i0; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r2 = (object *) constructed_1086[0];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
            r2[2] = r3;
            r2 = (object *) 65794;
            r3 = ((object*) lenv) [2];
            r2 = PXLL_TEST(r3==r2);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r2) {
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L459; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L459:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              ((object*********) lenv) [1][1][1][1][1][1][1][1][4] = r2;
            } else {
              r2 = (object *) 14;
            }
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
            r1[3] = r2;
            r2 = (object *) 6;
            r1[4] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L460; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L460:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r0[2] = r1;
            r0 = (object *) constructed_66[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 6;
              t = alloc_no_clear (UOTAG(4),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(0),2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[3] = r1;
              r0 = ((object****) lenv) [1][1][1][2];
              r1 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              goto FUN_loop_1336_i400_i440_i0;
            } else {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L461; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L461:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
              r1[2] = r2;
              r1 = (object *) 65794;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L462; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L462:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][4] = r1;
              } else {
                r1 = (object *) 14;
              }
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
              r0[2] = r1;
              r1 = (object *) 15618;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              r0[3] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_1085;
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[3] = r1;
                r1 = top[15];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                r0[2] = r1;
                r0 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L463; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L463:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                ((object*********) lenv) [1][1][1][1][1][1][1][1][4] = r0;
                r0 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L464; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L464:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (UOTAG(0),2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = ((object*****) lenv) [1][1][1][1][2];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                lenv = ((object ***)lenv)[1][1][1];
                lenv[2] = r0;
                goto FUN_loop_1336_i400_i440_i0;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L448:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1336_i400_i440_i0; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) constructed_1084[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L465; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L465:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
      } else {
        goto fatbar_369;
      }
      goto fatbar_369_over;
      fatbar_369:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 10242;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object****) lenv) [1][1][1][7];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L466; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L466:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
      } else {
        goto fatbar_370;
      }
      goto fatbar_370_over;
      fatbar_370:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_68;
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_1087;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_1087;
        PXLL_UNDEFINED; result=r1; goto Lreturn;
      } else {
        goto fatbar_371;
      }
      goto fatbar_371_over;
      fatbar_371:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L467; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L467:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      switch (get_case_noint (r1)) {
        default: {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,2);
          r1[4] = r2;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,3);
          r1[5] = r2;
          r1 = ((object*) lenv) [3];
          switch (get_case (r1)) {
            case ((pxll_int)PXLL_TRUE): {
              r1 = allocate (TC_TUPLE, 5);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
              r2 = (object *) 1;
              r3 = ((object**) lenv) [1][2];
              r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
              r1[2] = r2;
              r2 = (object *) 11522;
              r3 = ((object*) lenv) [2];
              r2 = PXLL_TEST(r3==r2);
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              if PXLL_IS_TRUE(r2) {
                r2 = (object *) 3;
              } else {
                r2 = (object *) 1;
              }
              r1[4] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              // def loop_1349_i428_i440_i0
              goto L468;
              FUN_loop_1349_i428_i440_i0:
                check_heap (0);
                r0 = ((object****) lenv) [1][1][1][4];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = ((object***) lenv) [1][1][3];
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object*) lenv) [3];
                    r1 = (object *) 1;
                    r0 = box((pxll_int)unbox(r1)-unbox(r0));
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object*) lenv) [3];
                    PXLL_RETURN(0);
                  }
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[172];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                  r2 = ((object**) lenv) [1][2];
                  r3 = ((object*****) lenv) [1][1][1][1][2];
                  r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                  r1[3] = r2;
                  r2 = top[67];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L469; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
                  L469:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UITAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_1088;
                      r0[2] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][2];
                      r0[3] = r1;
                      r1 = top[15];
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = (object *) 21;
                      r2 = ((object****) lenv) [1][1][1][3];
                      r1 = box((pxll_int)unbox(r2)*unbox(r1));
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][2];
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv = lenv[1];
                      r1 = (object *) 3;
                      r2 = ((object***) lenv) [1][1][2];
                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                      lenv = ((object **)lenv)[1][1];
                      lenv[2] = r1;
                      lenv[3] = r0;
                      goto FUN_loop_1349_i428_i440_i0;
                    } break;
                  }
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              L468:
              r3 = allocate (TC_CLOSURE, 2);
              r3[1] = &&FUN_loop_1349_i428_i440_i0; r3[2] = lenv;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][4];
              r2[2] = r3;
              r3 = (object *) 1;
              r2[3] = r3;
              r3 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L470; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto *r3[1];
              L470:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[5] = r2;
              r1 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(5),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
            } break;
            default: {
              r1 = (object *) 1;
              r2 = ((object*) lenv) [5];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[82];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L471; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_421;
                L471:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
              } else {
                goto fatbar_372;
              }
              goto fatbar_372_over;
              fatbar_372:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object**) lenv) [1][2];
              r2 = box((pxll_int)((pxll_string*)(r2))->len);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][5];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[82];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L472; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_421;
                L472:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                // def loop_1298_i439_i440_i0
                goto L473;
                FUN_loop_1298_i439_i440_i0:
                  check_heap (0);
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[82];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L474; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
                          L474:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(1),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_373;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_373_over;
                      fatbar_373:
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = ((object****) lenv) [1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L475; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L475:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = top[82];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L476; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
                      L476:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      r1 = ((object*) lenv) [2];
                      t = alloc_no_clear (UOTAG(10),2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                      fatbar_373_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = (object*) &constructed_68;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_68;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_67;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_67;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L473:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_loop_1298_i439_i440_i0; r2[2] = lenv;
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 3);
                r4 = ((object***) lenv) [1][1][2];
                r3[2] = r4;
                r4 = (object *) 11778;
                r3[3] = r4;
                r4 = top[51];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L477; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_string_split_356;
                L477:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = (object *) constructed_36[0];
                r2[3] = r3;
                r3 = top[23];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L478; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
                L478:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L479; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L479:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
              }
              fatbar_372_over: ;
            } break;
          }
          lenv = lenv[1];
        } break;
      }
      lenv = lenv[1];
      fatbar_371_over: ;
      fatbar_370_over: ;
      fatbar_369_over: ;
      fatbar_359_over: ;
      fatbar_358_over: ;
      fatbar_357_over: ;
      fatbar_355_over: ;
      fatbar_335_over: ;
      fatbar_334_over: ;
      lenv = lenv[1];
      r0[2] = r1;
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L480; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L480:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L481; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L481:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[2] = r1;
      r0 = (object *) 14850;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][4];
        r0[2] = r1;
        r0 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L482; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L482:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object*****) lenv) [1][1][1][1][4] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L483; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L483:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object***) lenv) [1][1][2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(9),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_331;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_331;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_331_over;
        fatbar_331:
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_49[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 7);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_685[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[3] = r1;
              r1 = (object*)TC_NIL;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object*****) lenv) [1][1][1][1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = ((object*) lenv) [5];
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[6] = r1;
              r1 = ((object*) lenv) [6];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[7] = r1;
              r0 = ((object*) lenv) [7];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_332;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_332;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_332_over;
        fatbar_332:
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) constructed_693[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r2 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r2 = ((object****) lenv) [1][1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r0 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_332_over: ;
        PXLL_RETURN(0);
        fatbar_331_over: ;
        PXLL_RETURN(0);
      } else {
        goto fatbar_330;
      }
      PXLL_RETURN(0);
      goto fatbar_330_over;
      fatbar_330:
      r0 = (object *) 23298;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][4];
        r1[2] = r2;
        r1 = ((object******) lenv) [1][1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L484; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L484:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object******) lenv) [1][1][1][1][1][4] = r1;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L485; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L485:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L486; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L486:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object********) lenv) [1][1][1][1][1][1][1][4];
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r2) {
          r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L487; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L487:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          ((object*******) lenv) [1][1][1][1][1][1][4] = r2;
        } else {
          r2 = (object *) 14;
        }
        r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
        r1[2] = r2;
        r1 = (object *) 23810;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r1[2] = r2;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L488; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L488:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*******) lenv) [1][1][1][1][1][1][4] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1 = ((object*) lenv) [2];
        } else {
          r1 = (object*) &constructed_68;
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_1068;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_1068;
          PXLL_UNDEFINED; result=r1; goto Lreturn;
        }
        lenv = lenv[1];
        r0[2] = r1;
        r1 = (object *) constructed_295[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = (object*)TC_NIL;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = ((object*) lenv) [8];
        r2 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[9] = r1;
        r0 = ((object*) lenv) [9];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_333;
      }
      PXLL_RETURN(0);
      goto fatbar_333_over;
      fatbar_333:
      r0 = ((object**) lenv) [1][2];
      PXLL_RETURN(0);
      fatbar_333_over: ;
      PXLL_RETURN(0);
      fatbar_330_over: ;
      PXLL_RETURN(0);
    L388:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_1273_i0; r1[2] = lenv;
    r0[4] = r1;
    // def read-hex-digit_1275_i0
    goto L489;
    FUN_read_hex_digit_1275_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[171];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[67];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L490; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
      L490:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*) &constructed_68;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_1067;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_1067;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L489:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_digit_1275_i0; r1[2] = lenv;
    r0[5] = r1;
    // def read-hex-code_1276_i0
    goto L491;
    FUN_read_hex_code_1276_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][4];
      r2[2] = r3;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L492; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L492:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][4] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L493; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L493:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object****) lenv) [1][1][1][4];
      r2[2] = r3;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L494; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L494:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      ((object****) lenv) [1][1][1][4] = r2;
      r2 = ((object*) lenv) [2];
      lenv = lenv[1];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L495; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L495:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = (object *) 17;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)<<unbox(r1));
      r0[4] = r1;
      r1 = ((object*) lenv) [3];
      r2 = ((object*) lenv) [4];
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[5] = r1;
      r0 = ((object*) lenv) [5];
      r0 = TO_CHAR(unbox(r0));
      PXLL_RETURN(0);
    L491:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_code_1276_i0; r1[2] = lenv;
    r0[6] = r1;
    // def read-list_1278_i0
    goto L496;
    FUN_read_list_1278_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r0 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L497; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L497:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      ((object***) lenv) [1][1][4] = r0;
      r0 = ((object*) lenv) [2];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1332_i0
      goto L498;
      FUN_loop_1332_i0:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L499; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L499:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object******) lenv) [1][1][1][1][1][4];
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L500; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L500:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          ((object*****) lenv) [1][1][1][1][4] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = ((object*****) lenv) [1][1][1][1][4];
        r0[2] = r1;
        r0 = (object *) 10498;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][4];
          r0[2] = r1;
          r0 = ((object******) lenv) [1][1][1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L501; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L501:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object******) lenv) [1][1][1][1][1][4] = r0;
          r0 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = (object *) constructed_36[0];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L502; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L502:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r0;
          goto FUN_loop_1332_i0;
        }
        PXLL_RETURN(0);
      L498:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1332_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_1066[0];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L496:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_list_1278_i0; r1[2] = lenv;
    r0[7] = r1;
    // def read-hex-int_1282_i0
    goto L503;
    FUN_read_hex_int_1282_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L504; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L504:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L505; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L505:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][4] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1355_i0
      goto L506;
      FUN_loop_1355_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[171];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[67];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L507; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
        L507:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L508; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L508:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L509; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L509:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 33;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1355_i0;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L506:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1355_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L510; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L510:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L503:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_int_1282_i0; r1[2] = lenv;
    r0[8] = r1;
    // def read-oct-int_1283_i0
    goto L511;
    FUN_read_oct_int_1283_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object****) lenv) [1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L512; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L512:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object***) lenv) [1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][4];
        r0[2] = r1;
        r0 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L513; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L513:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][4] = r0;
        r0 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1361_i0
      goto L514;
      FUN_loop_1361_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[173];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[67];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L515; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
        L515:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L516; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L516:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            ((object********) lenv) [1][1][1][1][1][1][1][4] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L517; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L517:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              ((object*******) lenv) [1][1][1][1][1][1][4] = r0;
            } else {
              r0 = (object *) 14;
            }
            r0 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 17;
            r3 = ((object****) lenv) [1][1][1][2];
            r2 = box((pxll_int)unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = lenv[1];
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1361_i0;
          } break;
          default: {
            r0 = ((object****) lenv) [1][1][1][3];
            if PXLL_IS_TRUE(r0) {
              r0 = ((object**) lenv) [1][2];
              r1 = (object *) 1;
              r0 = box((pxll_int)unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L514:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1361_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L518; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L518:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L511:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_oct_int_1283_i0; r1[2] = lenv;
    r0[9] = r1;
    // def loop_1368_i582_i0
    goto L519;
    FUN_loop_1368_i582_i0:
      check_heap (0);
      r0 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L520; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L520:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = ((object*) lenv) [2];
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object****) lenv) [1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L521; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L521:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        ((object****) lenv) [1][1][1][4] = r1;
      } else {
        r1 = (object *) 14;
      }
      r1 = ((object****) lenv) [1][1][1][4];
      r0[2] = r1;
      r0 = (object *) 65794;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = (object *) constructed_36[0];
        r0[3] = r1;
        r1 = top[23];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L522; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L522:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_1065[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = ((object**) lenv) [1][3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[87];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L523; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_427;
                                  L523:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_36[0];
                                  r1[3] = r2;
                                  r2 = top[23];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L524; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                                  L524:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_36[0];
                                  r1[3] = r2;
                                  r2 = top[23];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L525; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                                  L525:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                  r0[3] = r1;
                                  r1 = top[23];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L526; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
                                  L526:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = result;
                                  lenv = lenv[1];
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  lenv[2] = r0;
                                  goto FUN_loop_1368_i582_i0;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_329;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_329;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_329;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_329;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_329;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_329;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_329;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_329_over;
        fatbar_329:
        r0 = ((object**) lenv) [1][2];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_loop_1368_i582_i0;
        fatbar_329_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L519:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1368_i582_i0; r1[2] = lenv;
    r0[10] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) constructed_1063[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [10];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L358:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_read_file_427; r1[2] = lenv;
  r0[87] = r1;
  // def sexp->symbol_429
  goto L527;
  FUN_sexp__3esymbol_429:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_328;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_328_over;
    fatbar_328:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_1062;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_328_over: ;
    PXLL_RETURN(0);
  L527:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp__3esymbol_429; r1[2] = lenv;
  r0[88] = r1;
  // def sexp->int_430
  goto L528;
  FUN_sexp__3eint_430:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_327;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_327_over;
    fatbar_327:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_1061;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_327_over: ;
    PXLL_RETURN(0);
  L528:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp__3eint_430; r1[2] = lenv;
  r0[89] = r1;
  // def field=?_431
  goto L529;
  FUN_field_3d_question_431:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = ((object**) lenv) [1][3];
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][3];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object***) lenv) [1][1][3];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object**) lenv) [1][2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r0[3] = r1;
      r1 = top[91];
      r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_432;
    } else {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L529:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_field_3d_question_431; r1[2] = lenv;
  r0[90] = r1;
  // def sexp=?_432
  goto L530;
  FUN_sexp_3d_question_432:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(6)): {
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (UITAG(6)): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(2)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[52];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L531; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
            L531:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) 1;
            r1 = ((object*) lenv) [3];
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(3)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = top[91];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = ((object*) lenv) [2];
            r0[4] = r1;
            r1 = top[43];
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_337;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = top[91];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = ((object*) lenv) [2];
            r0[4] = r1;
            r1 = top[43];
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_337;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(8)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = top[90];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = ((object*) lenv) [2];
            r0[4] = r1;
            r1 = top[43];
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_337;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = ((object*) lenv) [3];
              r1 = ((object**) lenv) [1][3];
              r0 = PXLL_TEST(r1==r0);
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[91];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L532; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_432;
            L532:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*) lenv) [3];
              r1 = ((object**) lenv) [1][3];
              r0 = PXLL_TEST(r1==r0);
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_326;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_326_over;
    fatbar_326:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_326_over: ;
    PXLL_RETURN(0);
  L530:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3d_question_432; r1[2] = lenv;
  r0[91] = r1;
  // def repr-field_434
  goto L533;
  FUN_repr_field_434:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = (object *) constructed_66[0];
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object*) &constructed_1059;
      PXLL_RETURN(0);
    } else {
      goto fatbar_325;
    }
    PXLL_RETURN(0);
    goto fatbar_325_over;
    fatbar_325:
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 6);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = ((object***) lenv) [1][1][2];
    r3 = UOBJ_GET(r3,0);
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = top[93];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L534; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_repr_435;
    L534:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = (object*)TC_NIL;
    r1[4] = r2;
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[5] = r2;
    r2 = ((object*) lenv) [5];
    r3 = (object*) &constructed_1060;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[6] = r2;
    r1 = ((object*) lenv) [6];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r0[2] = r1;
    r1 = top[49];
    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
    fatbar_325_over: ;
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L533:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_repr_field_434; r1[2] = lenv;
  r0[92] = r1;
  // def repr_435
  goto L535;
  FUN_repr_435:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_905[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = allocate (TC_TUPLE, 4);
                          r1[1] = lenv; lenv = r1;
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = ((object**) lenv) [1][2];
                          r2[2] = r3;
                          r3 = top[93];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L536; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_repr_435;
                          L536:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = (object*)TC_NIL;
                          r1[3] = r2;
                          r2 = ((object*) lenv) [3];
                          r3 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r3;
                          t[2] = r2;
                          r2 = t;
                          r1[4] = r2;
                          r1 = ((object*) lenv) [4];
                          r2 = (object*) &constructed_1040;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r2;
                          t[2] = r1;
                          r1 = t;
                          lenv = lenv[1];
                          r0[2] = r1;
                          r1 = top[49];
                          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_324;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_324;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_324;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_324;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_324;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_324_over;
        fatbar_324:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[93];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[34];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L537; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
        L537:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_1043;
        r2[3] = r3;
        r3 = top[50];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L538; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_355;
        L538:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_1042;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_1041;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        fatbar_324_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r3 = (object*) &constructed_1045;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_1044;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L539; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_350;
        L539:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_1046;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case ((pxll_int)PXLL_TRUE): {
            r0 = (object*) &constructed_1047;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_1048;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[58];
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_366;
      } break;
      case (UITAG(6)): {
        r0 = (object*) &constructed_1049;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[93];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[34];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L540; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
        L540:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_1052;
        r2[3] = r3;
        r3 = top[50];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L541; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_355;
        L541:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_1051;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_1050;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[92];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[34];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L542; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
        L542:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_1055;
        r2[3] = r3;
        r3 = top[50];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L543; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_355;
        L543:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_1054;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_1053;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_49[0];
        r3 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
          r2 = (object*) &constructed_1057;
        } else {
          r2 = ((object**) lenv) [1][2];
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = ((object***) lenv) [1][1][2];
          r3 = UOBJ_GET(r3,0);
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          lenv = lenv[1];
        }
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][3];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_1056;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[93];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L544; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_repr_435;
        L544:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][3];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_1058;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
    }
    PXLL_RETURN(0);
  L535:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_repr_435; r1[2] = lenv;
  r0[93] = r1;
  // def indent_436
  goto L545;
  FUN_indent_436:
    check_heap (0);
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) 262;
      PXLL_RETURN(0);
    } else {
      goto fatbar_323;
    }
    PXLL_RETURN(0);
    goto fatbar_323_over;
    fatbar_323:
    r0 = (object*) &constructed_1039;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_1039;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 3;
    r2 = ((object*) lenv) [2];
    r1 = box((pxll_int)unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = top[94];
    r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
    fatbar_323_over: ;
    PXLL_RETURN(0);
  L545:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_indent_436; r1[2] = lenv;
  r0[94] = r1;
  // def pp-size-field_437
  goto L546;
  FUN_pp_size_field_437:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 7);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = ((object*) lenv) [2];
    lenv = lenv[1];
    r0[4] = r1;
    r1 = ((object*) lenv) [4];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[5] = r1;
    r1 = (object *) 3;
    r2 = ((object*) lenv) [5];
    r1 = box((pxll_int)unbox(r2)+unbox(r1));
    r0[6] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [3];
    r1[2] = r2;
    r2 = top[96];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L547; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_438;
    L547:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[7] = r1;
    r0 = ((object*) lenv) [7];
    r1 = ((object*) lenv) [6];
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L546:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_size_field_437; r1[2] = lenv;
  r0[95] = r1;
  // def pp-size_438
  goto L548;
  FUN_pp_size_438:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = top[13];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[24];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L549; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
        L549:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = (object *) 3;
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[96];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L550; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L550:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = top[40];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_334;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = (object *) 5;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(3),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = top[93];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L551; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
        L551:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = (object *) 5;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[58];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L552; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_int__3estring_366;
        L552:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = (object *) 5;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = top[13];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[24];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L553; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
        L553:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = (object *) 5;
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[96];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L554; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L554:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = top[40];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_334;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = top[13];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[24];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L555; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
        L555:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[95];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L556; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L556:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = top[40];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_334;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 8);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[5] = r1;
        r1 = ((object*) lenv) [3];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][3];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[7] = r1;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [5];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        r0[8] = r1;
        r0 = ((object*) lenv) [8];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[96];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L557; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_438;
        L557:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = ((object*) lenv) [3];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][3];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r1 = box((pxll_int)((pxll_string*)(r1))->len);
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [4];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        r0[7] = r1;
        r0 = ((object*) lenv) [7];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L548:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_size_438; r1[2] = lenv;
  r0[96] = r1;
  // def pp_439
  goto L558;
  FUN_pp_439:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = top[96];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L559; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_438;
    L559:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 161;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][3];
      r1[2] = r2;
      r2 = top[93];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L560; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
      L560:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    } else {
      r0 = ((object**) lenv) [1][3];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*) &constructed_1036;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_1036;
              r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = (object*) &constructed_1038;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_1038;
              (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object****) lenv) [1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[97];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L561; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
              L561:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_7213
              goto L562;
              FUN_lambda_7213:
                check_heap (0);
                r0 = top[161];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L563; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L563:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 3;
                r2 = ((object*****) lenv) [1][1][1][1][2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                r0[2] = r1;
                r1 = top[94];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L564; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
                L564:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object *) 3;
                r2 = ((object*****) lenv) [1][1][1][1][2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[97];
                r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
              L562:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_7213; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object*) lenv) [3];
              r0[3] = r1;
              r1 = top[37];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L565; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
              L565:
              ; lenv = k[2]; k = k[1];
              r0 = (object*) &constructed_1037;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_1037;
              r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_322;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_322_over;
      fatbar_322:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][3];
      r1[2] = r2;
      r2 = top[93];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L566; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
      L566:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
      fatbar_322_over: ;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L558:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_439; r1[2] = lenv;
  r0[97] = r1;
  // def matches-list?_441
  goto L567;
  FUN_matches_list_question_441:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_320;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_66[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = allocate (TC_TUPLE, 3);
                      // def lambda_7303
                      goto L568;
                      FUN_lambda_7303:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object****) lenv) [1][1][1][2];
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[3] = r1;
                        r1 = top[99];
                        r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_443;
                      L568:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN_lambda_7303; r1[2] = lenv;
                      r0[2] = r1;
                      r1 = ((object****) lenv) [1][1][1][3];
                      r0[3] = r1;
                      r1 = top[42];
                      r0[1] = r1[2]; lenv = r0; goto FUN_every_question_336;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_321;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_321;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_321;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_321;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_321_over;
        fatbar_321:
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[99];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L569; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_443;
            L569:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = ((object*) lenv) [3];
              r1 = ((object**) lenv) [1][3];
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_matches_list_question_441;
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_320;
          }
        }
        PXLL_RETURN(0);
        fatbar_321_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_320_over;
    fatbar_320:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_320_over: ;
    PXLL_RETURN(0);
  L567:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_matches_list_question_441; r1[2] = lenv;
  r0[98] = r1;
  // def matches-pattern?_443
  goto L570;
  FUN_matches_pattern_question_443:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object***) lenv) [1][1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        lenv = lenv[1];
        r0[2] = r1;
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[3] = r1;
        r0 = (object *) 15362;
        r1 = ((object*) lenv) [3];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = ((object**) lenv) [1][3];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][2];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r1 = box((pxll_int)((pxll_string*)(r1))->len);
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 3;
              r2 = ((object**) lenv) [1][4];
              r1 = box((pxll_int)unbox(r2)-unbox(r1));
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][3];
              range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][3];
              r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
              r0[3] = r1;
              r0 = (object *) 15874;
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 4);
                r2 = ((object**) lenv) [1][3];
                r1[2] = r2;
                r2 = (object *) 3;
                r1[3] = r2;
                r2 = (object *) 3;
                r3 = ((object**) lenv) [1][4];
                r2 = box((pxll_int)unbox(r3)-unbox(r2));
                r1[4] = r2;
                r2 = top[47];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L571; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_substring_347;
                L571:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object***) lenv) [1][1][2];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = ((object*) lenv) [3];
                r1[3] = r2;
                r2 = top[52];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L572; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
                L572:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r0 = (object *) 1;
                r1 = ((object*) lenv) [4];
                r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                PXLL_RETURN(0);
              } else {
                r0 = (object *) 262;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_319;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_319_over;
          fatbar_319:
          r0 = (object *) 6;
          PXLL_RETURN(0);
          fatbar_319_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[98];
            r0[1] = r1[2]; lenv = r0; goto FUN_matches_list_question_441;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_318;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_318;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_318_over;
    fatbar_318:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(r1==r0);
    PXLL_RETURN(0);
    fatbar_318_over: ;
    PXLL_RETURN(0);
  L570:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_matches_pattern_question_443; r1[2] = lenv;
  r0[99] = r1;
  // def get-ellipsis-nestings_444
  goto L573;
  FUN_get_ellipsis_nestings_444:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def dolist_1486
    goto L574;
    FUN_dolist_1486:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_66[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object****) lenv) [1][1][1][2];
                        r1[2] = r2;
                        r2 = top[100];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L575; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
                        L575:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = (object*)TC_NIL;
                        r0[4] = r1;
                        r0 = ((object*) lenv) [4];
                        r1 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_317;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_317;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_317;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_317;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_317_over;
          fatbar_317:
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[100];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L576; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
          L576:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L577; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_dolist_1486;
          L577:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L578; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L578:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
          fatbar_317_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_316;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_316_over;
      fatbar_316:
      r0 = (object *) constructed_1035[0];
      PXLL_RETURN(0);
      fatbar_316_over: ;
      PXLL_RETURN(0);
    L574:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_dolist_1486; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_dolist_1486;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_315;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_315_over;
    fatbar_315:
    r0 = (object *) constructed_1034[0];
    PXLL_RETURN(0);
    fatbar_315_over: ;
    PXLL_RETURN(0);
  L573:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_ellipsis_nestings_444; r1[2] = lenv;
  r0[100] = r1;
  // def intersect?_445
  goto L579;
  FUN_intersect_question_445:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_314;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_7567
            goto L580;
            FUN_lambda_7567:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_7563
              goto L581;
              FUN_lambda_7563:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object**) lenv) [1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[101];
                r0[1] = r1[2]; lenv = r0; goto FUN_intersect_question_445;
              L581:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_7563; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[41];
              r0[1] = r1[2]; lenv = r0; goto FUN_some_question_335;
            L580:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_7567; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = top[41];
            r0[1] = r1[2]; lenv = r0; goto FUN_some_question_335;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_314;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_314;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_314_over;
    fatbar_314:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_314_over: ;
    PXLL_RETURN(0);
  L579:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_intersect_question_445; r1[2] = lenv;
  r0[101] = r1;
  // def ellipsis-sub-envs_446
  goto L582;
  FUN_ellipsis_sub_envs_446:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_1032[0];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r0[3] = r1;
                        r1 = top[101];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L583; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_intersect_question_445;
                        L583:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        if PXLL_IS_TRUE(r0) {
                          r0 = ((object*) lenv) [2];
                          PXLL_RETURN(0);
                        } else {
                          r0 = ((object****) lenv) [1][1][1][3];
                          r1 = ((object*****) lenv) [1][1][1][1][2];
                          lenv = ((object ****)lenv)[1][1][1][1];
                          lenv[2] = r1;
                          lenv[3] = r0;
                          goto FUN_ellipsis_sub_envs_446;
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ****)lenv)[1][1][1][1];
                        goto fatbar_313;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_313;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_313;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_313;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_313_over;
    fatbar_313:
    r0 = (object*) &constructed_68;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_68;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_1033;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_1033;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_313_over: ;
    PXLL_RETURN(0);
  L582:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_ellipsis_sub_envs_446; r1[2] = lenv;
  r0[102] = r1;
  // def get-bindings_447
  goto L584;
  FUN_get_bindings_447:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def dolist_1514
    goto L585;
    FUN_dolist_1514:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_66[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 10);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object****) lenv) [1][1][1][2];
                        r1[2] = r2;
                        r2 = top[100];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L586; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
                        L586:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        // def lambda_7683
                        goto L587;
                        FUN_lambda_7683:
                          check_heap (0);
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object******) lenv) [1][1][1][1][1][2];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[103];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L588; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_get_bindings_447;
                          L588:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(0),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        L587:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN_lambda_7683; r2[2] = lenv;
                        r1[2] = r2;
                        r2 = ((object*****) lenv) [1][1][1][1][3];
                        r1[3] = r2;
                        r2 = top[34];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L589; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                        L589:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r1 = ((object*) lenv) [4];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[5] = r1;
                        r1 = (object*)TC_NIL;
                        r0[6] = r1;
                        r1 = ((object*) lenv) [6];
                        r2 = ((object*) lenv) [5];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[7] = r1;
                        r1 = ((object*) lenv) [7];
                        r2 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[8] = r1;
                        r1 = ((object*) lenv) [8];
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[9] = r1;
                        r1 = (object*)TC_NIL;
                        r0[10] = r1;
                        r0 = ((object*) lenv) [10];
                        r1 = ((object*) lenv) [9];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_312;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_312;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_312;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_312;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_312_over;
          fatbar_312:
          r0 = ((object**) lenv) [1][3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = ((object*) lenv) [2];
              r1[3] = r2;
              r2 = top[103];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L590; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_get_bindings_447;
              L590:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = ((object*) lenv) [3];
              r1[3] = r2;
              r2 = ((object****) lenv) [1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L591; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_dolist_1514;
              L591:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[5] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [4];
              r1[2] = r2;
              r2 = (object *) constructed_36[0];
              r1[3] = r2;
              r2 = top[23];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L592; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
              L592:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object*) lenv) [5];
              r0[3] = r1;
              r1 = top[23];
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_311;
            }
          }
          PXLL_RETURN(0);
          fatbar_312_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_311;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_311_over;
      fatbar_311:
      r0 = (object *) constructed_1031[0];
      PXLL_RETURN(0);
      fatbar_311_over: ;
      PXLL_RETURN(0);
    L585:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_dolist_1514; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r2 = ((object***) lenv) [1][1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = (object*)TC_NIL;
        r0[7] = r1;
        r0 = ((object*) lenv) [7];
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object***) lenv) [1][1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_dolist_1514;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_310;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_310;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_310_over;
    fatbar_310:
    r0 = (object *) constructed_1030[0];
    PXLL_RETURN(0);
    fatbar_310_over: ;
    PXLL_RETURN(0);
  L584:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_bindings_447; r1[2] = lenv;
  r0[103] = r1;
  // def expand-pattern_449
  goto L593;
  FUN_expand_pattern_449:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[105];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L594; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_450;
        L594:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1530_i720
        goto L595;
        FUN_loop_1530_i720:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*)UITAG(1);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = ((object**) lenv) [1][2];
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                    r0 = ((object*) lenv) [2];
                                    t = alloc_no_clear (UOTAG(0),1);
                                    t[1] = r0;
                                    r0 = t;
                                    PXLL_RETURN(0);
                                  } else {
                                    r0 = ((object*****) lenv) [1][1][1][1][3];
                                    lenv = ((object *****)lenv)[1][1][1][1][1];
                                    lenv[2] = r0;
                                    goto FUN_loop_1530_i720;
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_309;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_309;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_309;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_309;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_309;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_309_over;
              fatbar_309:
              r0 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_loop_1530_i720;
              fatbar_309_over: ;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L595:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1530_i720; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L596; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1530_i720;
        L596:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = ((object**) lenv) [1][2];
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_308;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_308_over;
    fatbar_308:
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    fatbar_308_over: ;
    PXLL_RETURN(0);
  L593:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_expand_pattern_449; r1[2] = lenv;
  r0[104] = r1;
  // def expand-list_450
  goto L597;
  FUN_expand_list_450:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def sexp/append_1548
    goto L598;
    FUN_sexp_2fappend_1548:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L599; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L599:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } break;
        default: {
          goto fatbar_307;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_307_over;
      fatbar_307:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_1029;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_1029;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_307_over: ;
      PXLL_RETURN(0);
    L598:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_sexp_2fappend_1548; r1[2] = lenv;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_66[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 5);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = top[100];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L600; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
                  L600:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object*) lenv) [2];
                  r1[2] = r2;
                  r2 = ((object******) lenv) [1][1][1][1][1][3];
                  r1[3] = r2;
                  r2 = top[102];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L601; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_ellipsis_sub_envs_446;
                  L601:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (UOTAG(0)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = allocate (TC_TUPLE, 3);
                      // def lambda_7957
                      goto L602;
                      FUN_lambda_7957:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object******) lenv) [1][1][1][1][1][2];
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object*) lenv) [2];
                        r1[2] = r2;
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r1[3] = r2;
                        r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L603; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_sexp_2fappend_1548;
                        L603:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = top[104];
                        r0[1] = r1[2]; lenv = r0; goto FUN_expand_pattern_449;
                      L602:
                      r2 = allocate (TC_CLOSURE, 2);
                      r2[1] = &&FUN_lambda_7957; r2[2] = lenv;
                      r1[2] = r2;
                      r2 = ((object*) lenv) [2];
                      r1[3] = r2;
                      r2 = top[34];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L604; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                      L604:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                    } break;
                    default: {
                      goto fatbar_306;
                    }
                  }
                  goto fatbar_306_over;
                  fatbar_306:
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object*) &constructed_1028;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [3];
                  r1[3] = r2;
                  r2 = top[15];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L605; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                  L605:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  fatbar_306_over: ;
                  r0[4] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object***) lenv) [1][1][3];
                  r1[2] = r2;
                  r2 = ((object******) lenv) [1][1][1][1][1][3];
                  r1[3] = r2;
                  r2 = top[105];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L606; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_450;
                  L606:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[5] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object*) lenv) [4];
                  r1[2] = r2;
                  r2 = (object *) constructed_36[0];
                  r1[3] = r2;
                  r2 = top[23];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L607; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                  L607:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [5];
                  r0[3] = r1;
                  r1 = top[23];
                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
                } else {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_305;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_305;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_305;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_305_over;
        fatbar_305:
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][3];
        r1[3] = r2;
        r2 = top[104];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L608; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_pattern_449;
        L608:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][3];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][3];
        r1[3] = r2;
        r2 = top[105];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L609; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_450;
        L609:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_305_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_304;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_304_over;
    fatbar_304:
    r0 = ((object**) lenv) [1][2];
    PXLL_RETURN(0);
    fatbar_304_over: ;
    PXLL_RETURN(0);
  L597:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_expand_list_450; r1[2] = lenv;
  r0[105] = r1;
  // def pred_453
  goto L610;
  FUN_pred_453:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (UOTAG(23), 3);
    r2 = (object*)UITAG(1);
    r1[1] = r2;
    r2 = (object*)UITAG(1);
    r1[2] = r2;
    r2 = (object *) 6;
    r1[3] = r2;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][3];
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(1),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L610:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pred_453; r1[2] = lenv;
  r0[106] = r1;
  // def new-tvar_455
  goto L611;
  FUN_new_tvar_455:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = top[183];
    r1 = ((pxll_vector*)r1)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L612; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L612:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (UOTAG(23), 3);
    r2 = (object*)UITAG(1);
    r1[1] = r2;
    r2 = (object*)UITAG(1);
    r1[2] = r2;
    r2 = (object *) 6;
    r1[3] = r2;
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L611:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_new_tvar_455; r1[2] = lenv;
  r0[107] = r1;
  // def rlabel_460
  goto L613;
  FUN_rlabel_460:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_528[0];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r1[1] = lenv; lenv = r1;
    r2 = (object*)TC_NIL;
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r3 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[3] = r2;
    r2 = ((object*) lenv) [3];
    r3 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[4] = r2;
    r1 = ((object*) lenv) [4];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r0[3] = r1;
    r1 = top[106];
    r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
  L613:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_rlabel_460; r1[2] = lenv;
  r0[108] = r1;
  // def type-repr_464
  goto L614;
  FUN_type_repr_464:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[58];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L615; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
        L615:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_1018;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_97[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 8);
                      r1[1] = lenv; lenv = r1;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = ((object**) lenv) [1][2];
                      r2[2] = r3;
                      r3 = top[109];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L616; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_464;
                      L616:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = ((object***) lenv) [1][1][2];
                      r2[2] = r3;
                      r3 = top[109];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L617; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_464;
                      L617:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[3] = r2;
                      r2 = (object*)TC_NIL;
                      r1[4] = r2;
                      r2 = ((object*) lenv) [4];
                      r3 = (object*) &constructed_1021;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[5] = r2;
                      r2 = ((object*) lenv) [5];
                      r3 = ((object*) lenv) [3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[6] = r2;
                      r2 = ((object*) lenv) [6];
                      r3 = (object*) &constructed_1020;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[7] = r2;
                      r2 = ((object*) lenv) [7];
                      r3 = ((object*) lenv) [2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[8] = r2;
                      r1 = ((object*) lenv) [8];
                      r2 = (object*) &constructed_1019;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r2;
                      t[2] = r1;
                      r1 = t;
                      lenv = lenv[1];
                      r0[2] = r1;
                      r1 = top[49];
                      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_302;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_302;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_302_over;
              fatbar_302:
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 7);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = allocate (TC_TUPLE, 3);
              r4 = top[109];
              r3[2] = r4;
              r4 = ((object**) lenv) [1][3];
              r3[3] = r4;
              r4 = top[34];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L618; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
              L618:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = (object*) &constructed_1024;
              r2[3] = r3;
              r3 = top[50];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L619; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_join_355;
              L619:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = top[109];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L620; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_464;
              L620:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = (object*)TC_NIL;
              r1[4] = r2;
              r2 = ((object*) lenv) [4];
              r3 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              r3 = (object*) &constructed_1023;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = ((object*) lenv) [6];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[7] = r2;
              r1 = ((object*) lenv) [7];
              r2 = (object*) &constructed_1022;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r0[2] = r1;
              r1 = top[49];
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
              fatbar_302_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_301;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_301;
        }
        PXLL_RETURN(0);
        goto fatbar_301_over;
        fatbar_301:
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_303;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_303_over;
        fatbar_303:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 7);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][2];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[109];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][3];
        r3[3] = r4;
        r4 = top[34];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L621; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
        L621:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_1027;
        r2[3] = r3;
        r3 = top[50];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L622; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_355;
        L622:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = (object*) &constructed_1026;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = (object*) &constructed_1025;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        fatbar_303_over: ;
        PXLL_RETURN(0);
        fatbar_301_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L614:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_repr_464; r1[2] = lenv;
  r0[109] = r1;
  // def type->trec_466
  goto L623;
  FUN_type__3etrec_466:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L623:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type__3etrec_466; r1[2] = lenv;
  r0[110] = r1;
  // def type-find_467
  goto L624;
  FUN_type_find_467:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[110];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L625; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type__3etrec_466;
    L625:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = ((object**) lenv) [1][2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[111];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L626; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
        L626:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[1] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L624:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_find_467; r1[2] = lenv;
  r0[111] = r1;
  // def type-union_468
  goto L627;
  FUN_type_union_468:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[111];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L628; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
    L628:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = top[111];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L629; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
    L629:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = ((object**) lenv) [1][3];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][3];
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = ((object*) lenv) [2];
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L627:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_union_468; r1[2] = lenv;
  r0[112] = r1;
  // def parse-type*_469
  goto L630;
  FUN_parse_type_splat_469:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    // def arrow-type?_1638
    goto L631;
    FUN_arrow_type_question_1638:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_691[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 262;
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_300;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_300;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_300_over;
          fatbar_300:
          r0 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_arrow_type_question_1638;
          fatbar_300_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L631:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_arrow_type_question_1638; r1[2] = lenv;
    r0[2] = r1;
    // def parse-list_1641
    goto L632;
    FUN_parse_list_1641:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_905[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object**) lenv) [1][3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r1[2] = r2;
                            r2 = ((object**) lenv) [1][2];
                            r1[3] = r2;
                            r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
                            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,11)];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L633; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto *r2[1];
                            L633:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r0 = ((object*) lenv) [2];
                            switch (get_case (r0)) {
                              case (UOTAG(0)): {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r0 = ((object*) lenv) [2];
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = top[107];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L634; t[4] = r0; k = t;
                                lenv = r1[2]; goto FUN_new_tvar_455;
                                L634:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[2] = r1;
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                                r0[2] = r1;
                                r1 = ((object***) lenv) [1][1][2];
                                r0[3] = r1;
                                r1 = ((object*) lenv) [2];
                                r0[4] = r1;
                                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                                r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
                                r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,10)];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L635; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L635:
                                ; lenv = k[2]; k = k[1];
                                r0 = ((object*) lenv) [2];
                                PXLL_RETURN(0);
                              } break;
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object **)lenv)[1][1];
                            goto fatbar_297;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_297;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_297;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_297_over;
                fatbar_297:
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_1014;
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r0[3] = r1;
                r1 = top[15];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                fatbar_297_over: ;
                PXLL_RETURN(0);
              } else {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_296;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_296;
            }
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_296;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_296_over;
      fatbar_296:
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L636; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_arrow_type_question_1638;
      L636:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_1653_i798
        goto L637;
        FUN_loop_1653_i798:
          check_heap (0);
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_691[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object***) lenv) [1][1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object***) lenv) [1][1][3];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object**) lenv) [1][2];
                            r1[2] = r2;
                            r2 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L638; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_parse_1643;
                            L638:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object*****) lenv) [1][1][1][1][2];
                            r1[2] = r2;
                            r2 = (object *) constructed_36[0];
                            r1[3] = r2;
                            r2 = top[23];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L639; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                            L639:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[3] = r1;
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = (object *) constructed_97[0];
                            r0[2] = r1;
                            r1 = ((object*) lenv) [3];
                            r2 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r2;
                            t[2] = r1;
                            r1 = t;
                            r0[3] = r1;
                            r1 = top[106];
                            r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
                          } break;
                          default: {
                            lenv = ((object **)lenv)[1][1];
                            goto fatbar_298;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_298;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_298;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_298;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_298_over;
              fatbar_298:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = ((object******) lenv) [1][1][1][1][1][5];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L640; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_parse_1643;
              L640:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r1 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1653_i798;
              fatbar_298_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_1016;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][2];
              r0[3] = r1;
              r1 = top[15];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
            } break;
          }
          PXLL_RETURN(0);
        L637:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_1653_i798; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_1015[0];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_1653_i798;
      } else {
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [2];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object****) lenv) [1][1][1][5];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r1[3] = r2;
                r2 = top[34];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L641; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                L641:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = top[106];
                r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_299;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_299;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_299_over;
        fatbar_299:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_1017;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
        fatbar_299_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
      fatbar_296_over: ;
      PXLL_RETURN(0);
    L632:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_list_1641; r1[2] = lenv;
    r0[3] = r1;
    // def parse-field-list_1642
    goto L642;
    FUN_parse_field_list_1642:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_66[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = top[107];
                lenv = r0[2]; goto FUN_new_tvar_455;
              } break;
              default: {
                goto fatbar_295;
              }
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_295;
          }
          PXLL_RETURN(0);
          goto fatbar_295_over;
          fatbar_295:
          r0 = allocate (TC_TUPLE, 4);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_572[0];
          r1[3] = r2;
          r2 = top[106];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L643; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
          L643:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object**) lenv) [1][3];
          r2[2] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][5];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L644; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_parse_1643;
          L644:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) constructed_569[0];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[3] = r2;
          r2 = top[106];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L645; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
          L645:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L646; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_parse_field_list_1642;
          L646:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = top[108];
          r0[1] = r1[2]; lenv = r0; goto FUN_rlabel_460;
          fatbar_295_over: ;
          PXLL_RETURN(0);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) constructed_586[0];
          r1[2] = r2;
          r2 = (object *) constructed_584[0];
          r1[3] = r2;
          r2 = top[106];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L647; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
          L647:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) constructed_583[0];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[3] = r1;
          r1 = top[106];
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
        } break;
      }
      PXLL_RETURN(0);
    L642:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_field_list_1642; r1[2] = lenv;
    r0[4] = r1;
    // def parse_1643
    goto L648;
    FUN_parse_1643:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[190];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[67];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L649; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
          L649:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = (object *) constructed_1012[0];
              r0[3] = r1;
              r1 = top[106];
              r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
            } break;
          }
          PXLL_RETURN(0);
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_parse_list_1641;
        } break;
        case (UOTAG(8)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object***) lenv) [1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L650; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_parse_field_list_1642;
          L650:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) constructed_579[0];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[3] = r1;
          r1 = top[106];
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
        } break;
        default: {
          goto fatbar_294;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_294_over;
      fatbar_294:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_1013;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      fatbar_294_over: ;
      PXLL_RETURN(0);
    L648:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_1643; r1[2] = lenv;
    r0[5] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [5];
    r0[1] = r1[2]; lenv = r0; goto FUN_parse_1643;
  L630:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_parse_type_splat_469; r1[2] = lenv;
  r0[113] = r1;
  // def get-record-sig_471
  goto L651;
  FUN_get_record_sig_471:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_579[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def loop_1689
                  goto L652;
                  FUN_loop_1689:
                    check_heap (0);
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = (object *) constructed_583[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object**) lenv) [1][3];
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_292;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_292_over;
                        fatbar_292:
                        r0 = (object *) constructed_528[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = ((object**) lenv) [1][3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [2];
                                      switch (get_case (r0)) {
                                        case (UOTAG(1)): {
                                          r0 = allocate (TC_TUPLE, 2);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r0 = (object *) constructed_586[0];
                                          r1 = ((object*) lenv) [2];
                                          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                            r0 = ((object**) lenv) [1][3];
                                            switch (get_case (r0)) {
                                              case (TC_PAIR): {
                                                r0 = allocate (TC_TUPLE, 3);
                                                r0[1] = lenv; lenv = r0;
                                                r1 = ((object***) lenv) [1][1][3];
                                                r1 = UOBJ_GET(r1,0);
                                                r0[2] = r1;
                                                r1 = ((object***) lenv) [1][1][3];
                                                r1 = UOBJ_GET(r1,1);
                                                r0[3] = r1;
                                                r0 = ((object*) lenv) [3];
                                                switch (get_case (r0)) {
                                                  case (TC_NIL): {
                                                    r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                    r1 = ((object*) lenv) [2];
                                                    lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                    lenv[2] = r1;
                                                    lenv[3] = r0;
                                                    goto FUN_loop_1689;
                                                  } break;
                                                  default: {
                                                    lenv = ((object **)lenv)[1][1];
                                                    goto fatbar_293;
                                                  }
                                                }
                                                PXLL_RETURN(0);
                                              } break;
                                              default: {
                                                lenv = ((object *)lenv)[1];
                                                goto fatbar_293;
                                              }
                                            }
                                            PXLL_RETURN(0);
                                          } else {
                                            lenv = ((object *)lenv)[1];
                                            goto fatbar_293;
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          goto fatbar_293;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                      goto fatbar_293_over;
                                      fatbar_293:
                                      r0 = ((object*) lenv) [3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [3];
                                          switch (get_case (r0)) {
                                            case (TC_NIL): {
                                              r0 = ((object******) lenv) [1][1][1][1][1][3];
                                              r1 = ((object***) lenv) [1][1][2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r1;
                                              t[2] = r0;
                                              r0 = t;
                                              r1 = ((object*) lenv) [2];
                                              lenv = ((object *****)lenv)[1][1][1][1][1];
                                              lenv[2] = r1;
                                              lenv[3] = r0;
                                              goto FUN_loop_1689;
                                            } break;
                                            default: {
                                              lenv = ((object *****)lenv)[1][1][1][1][1];
                                              goto fatbar_291;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object ****)lenv)[1][1][1][1];
                                          goto fatbar_291;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                      fatbar_293_over: ;
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_291;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_291;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_291;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_291;
                        }
                        PXLL_RETURN(0);
                        fatbar_292_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        r0 = ((object*) lenv) [3];
                        r1 = (object *) constructed_66[0];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                    goto fatbar_291_over;
                    fatbar_291:
                    r0 = (object *) constructed_1008[0];
                    PXLL_RETURN(0);
                    fatbar_291_over: ;
                    PXLL_RETURN(0);
                  L652:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_loop_1689; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object***) lenv) [1][1][2];
                  r1[2] = r2;
                  r2 = (object *) constructed_1007[0];
                  r1[3] = r2;
                  r2 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L653; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_loop_1689;
                  L653:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = top[83];
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[3] = r1;
                  r1 = top[46];
                  r0[1] = r1[2]; lenv = r0; goto FUN_sort_342;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_290;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_290;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_290;
        }
        PXLL_RETURN(0);
        goto fatbar_290_over;
        fatbar_290:
        r0 = (object *) constructed_854[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = ((object*) lenv) [2];
                      lenv = ((object ***)lenv)[1][1][1];
                      lenv[2] = r0;
                      goto FUN_get_record_sig_471;
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_289;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_289;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_289;
            }
          }
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_289;
        }
        PXLL_RETURN(0);
        fatbar_290_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_289;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_289_over;
    fatbar_289:
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 5);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object***) lenv) [1][1][2];
    r3[2] = r4;
    r4 = top[109];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L654; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
    L654:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = (object*) &constructed_1011;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r2 = ((object*) lenv) [5];
    r3 = (object*) &constructed_1010;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L655; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L655:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_1009;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_289_over: ;
    PXLL_RETURN(0);
  L651:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_record_sig_471; r1[2] = lenv;
  r0[114] = r1;
  // def make-counter_474
  goto L656;
  FUN_make_counter_474:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def inc_1718
    goto L657;
    FUN_inc_1718:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      ((object***) lenv) [1][1][2] = r0;
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
    L657:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_inc_1718; r1[2] = lenv;
    r0[2] = r1;
    // def get_1719
    goto L658;
    FUN_get_1719:
      r0 = ((object**) lenv) [1][2];
      PXLL_RETURN(0);
    L658:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_get_1719; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (UOTAG(22), 2);
    r1 = ((object*) lenv) [3];
    r0[1] = r1;
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L656:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_counter_474; r1[2] = lenv;
  r0[115] = r1;
  // def new-match-var_478
  goto L659;
  FUN_new_match_var_478:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = top[193];
    r4 = ((pxll_vector*)r4)->val[1];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L660; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    lenv = r4[2]; goto *r4[1];
    L660:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[2] = r4;
    r4 = top[58];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L661; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
    L661:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = (object*) &constructed_1006;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L662; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L662:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = top[82];
    r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_421;
  L659:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_new_match_var_478; r1[2] = lenv;
  r0[116] = r1;
  // def notdotdotdot_479
  goto L663;
  FUN_notdotdotdot_479:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r0 = (object *) constructed_66[0];
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    } else {
      lenv = ((object *)lenv)[1];
      goto fatbar_288;
    }
    PXLL_RETURN(0);
    PXLL_RETURN(0);
    goto fatbar_288_over;
    fatbar_288:
    r0 = (object *) 262;
    PXLL_RETURN(0);
    fatbar_288_over: ;
    PXLL_RETURN(0);
  L663:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_notdotdotdot_479; r1[2] = lenv;
  r0[117] = r1;
  // def compile-pattern_480
  goto L664;
  FUN_compile_pattern_480:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 20);
    r0[1] = lenv; lenv = r0;
    // def remove-first-pat_1746
    goto L665;
    FUN_remove_first_pat_1746:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,1);
      r0[3] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [3];
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          lenv = ((object *)lenv)[1];
          goto fatbar_287;
        }
      }
      PXLL_RETURN(0);
      PXLL_RETURN(0);
      goto fatbar_287_over;
      fatbar_287:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_1005;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_1005;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_287_over: ;
      PXLL_RETURN(0);
    L665:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_remove_first_pat_1746; r1[2] = lenv;
    r0[2] = r1;
    // def first-pattern-kind_1747
    goto L666;
    FUN_first_pattern_kind_1747:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = (object *) constructed_903[0];
              PXLL_RETURN(0);
            } break;
            case (UOTAG(1)): {
              r0 = (object *) constructed_999[0];
              PXLL_RETURN(0);
            } break;
            case (UOTAG(2)): {
              r0 = (object *) constructed_479[0];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = (object *) constructed_993[0];
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          lenv = ((object *)lenv)[1];
          goto fatbar_286;
        }
      }
      PXLL_RETURN(0);
      PXLL_RETURN(0);
      goto fatbar_286_over;
      fatbar_286:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_1004;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_1004;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_286_over: ;
      PXLL_RETURN(0);
    L666:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_first_pattern_kind_1747; r1[2] = lenv;
    r0[3] = r1;
    // def compare-first-patterns_1748
    goto L667;
    FUN_compare_first_patterns_1748:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L668; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1747;
      L668:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L669; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1747;
      L669:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      PXLL_RETURN(0);
    L667:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compare_first_patterns_1748; r1[2] = lenv;
    r0[4] = r1;
    // def compile-match_1749
    goto L670;
    FUN_compile_match_1749:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = ((object*) lenv) [4];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_285;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_285_over;
      fatbar_285:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][4];
      r1[3] = r2;
      r2 = top[44];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L671; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pack_339;
      L671:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[24];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L672; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
      L672:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L673; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L673:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][6];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_group_1750;
      } else {
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_10052
        goto L674;
        FUN_lambda_10052:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][6];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L675; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_group_1750;
          L675:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object***) lenv) [1][1][4] = r0;
          PXLL_RETURN(0);
        L674:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_10052; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = (object *) constructed_36[0];
        r1[3] = r2;
        r2 = top[23];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L676; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
        L676:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = top[37];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L677; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
        L677:
        ; lenv = k[2]; k = k[1];
        r0 = ((object**) lenv) [1][4];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
      fatbar_285_over: ;
      PXLL_RETURN(0);
    L670:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compile_match_1749; r1[2] = lenv;
    r0[5] = r1;
    // def compile-group_1750
    goto L678;
    FUN_compile_group_1750:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][3];
      r2[2] = r3;
      r3 = top[21];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L679; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
      L679:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L680; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1747;
      L680:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) constructed_993[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object****) lenv) [1][1][1][3];
        r3[2] = r4;
        r4 = top[21];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L681; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_car_311;
        L681:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object**) lenv) [1][2];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        lenv = lenv[1];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L682; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L682:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][9];
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object*) lenv) [2];
        r2[2] = r3;
        r3 = ((object****) lenv) [1][1][1][11];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L683; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1756;
        L683:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L684; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L684:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_10326_i859
        goto L685;
        FUN_lambda_10326_i859:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = ((object***) lenv) [1][1][2];
          r3 = UOBJ_GET(r3,0);
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L686; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
          L686:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][9];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = ((object******) lenv) [1][1][1][1][1][11];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L687; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1756;
          L687:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = top[34];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L688; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
          L688:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = top[14];
          r1[2] = r2;
          r2 = ((object***) lenv) [1][1][3];
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r1[4] = r2;
          r2 = top[43];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L689; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_every2_question_337;
          L689:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [4];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_991;
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][3];
            r0[3] = r1;
            r1 = top[15];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L685:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_10326_i859; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L690; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
        L690:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = top[37];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L691; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
        L691:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 13);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = top[29];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L692; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
        L692:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10356_i859
        goto L693;
        FUN_lambda_10356_i859:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object***) lenv) [1][1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object****) lenv) [1][1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[2] = r3;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_990;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L694; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L694:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = top[82];
          r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_421;
        L693:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10356_i859; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L695; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L695:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10385_i859
        goto L696;
        FUN_lambda_10385_i859:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object***) lenv) [1][1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][10];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object*) lenv) [2];
          r3[2] = r4;
          r4 = top[21];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L697; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_car_311;
          L697:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = ((object*******) lenv) [1][1][1][1][1][1][11];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L698; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1756;
          L698:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = top[34];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L699; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
          L699:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L700; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
          L700:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*) lenv) [3];
          r2[2] = r3;
          r3 = (object *) constructed_36[0];
          r2[3] = r3;
          r3 = top[23];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L701; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
          L701:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L702; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L702:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object***) lenv) [1][1][2];
          r2 = UOBJ_GET(r2,1);
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0[6] = r1;
          r0 = ((object*) lenv) [6];
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        L696:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10385_i859; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L703; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L703:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[24];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L704; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
        L704:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_1877_i859
        goto L705;
        FUN__24loop_1877_i859:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][5];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [3];
            r0[2] = r1;
            r1 = (object *) constructed_36[0];
            r0[3] = r1;
            r1 = top[23];
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
          } else {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][3];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L706; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L706:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L707; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L707:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (UOTAG(10),2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = (object*)TC_NIL;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            r2 = ((object*) lenv) [6];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = ((object*) lenv) [8];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = ((object*) lenv) [9];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[10] = r1;
            r0 = ((object**) lenv) [1][3];
            r1 = ((object*) lenv) [10];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r1 = (object *) 3;
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN__24loop_1877_i859;
          }
          PXLL_RETURN(0);
        L705:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_1877_i859; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L708; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_1877_i859;
        L708:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r0[6] = r1;
        r1 = (object *) constructed_648[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = ((object*) lenv) [6];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object*****) lenv) [1][1][1][1][2];
        r3[2] = r4;
        r4 = top[22];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L709; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cdr_312;
        L709:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object**) lenv) [1][3];
        r3[2] = r4;
        r4 = (object *) constructed_36[0];
        r3[3] = r4;
        r4 = top[23];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L710; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
        L710:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = ((object*) lenv) [2];
        r2[3] = r3;
        r3 = top[23];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L711; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
        L711:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r1[2] = r2;
        r2 = ((object*) lenv) [4];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        r1[4] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][5];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L712; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1749;
        L712:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[9] = r1;
        r1 = (object*)TC_NIL;
        r0[10] = r1;
        r1 = ((object*) lenv) [10];
        r2 = ((object*) lenv) [9];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[11] = r1;
        r1 = ((object*) lenv) [11];
        r2 = ((object*) lenv) [8];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[12] = r1;
        r1 = ((object*) lenv) [12];
        r2 = ((object*) lenv) [7];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[13] = r1;
        r0 = ((object*) lenv) [13];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_279;
      }
      PXLL_RETURN(0);
      goto fatbar_279_over;
      fatbar_279:
      r0 = (object *) constructed_479[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object***) lenv) [1][1][3];
        r2[2] = r3;
        r3 = top[21];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L713; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
        L713:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][18];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L714; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_rule__3econstructor_dt_1767;
        L714:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][18];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][14];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L715; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_collect_1763;
        L715:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[70];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L716; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist__3ekeys_401;
        L716:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[24];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L717; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
        L717:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object *) 3;
        r3 = ((object*) lenv) [2];
        r2 = PXLL_TEST(unbox(r3)==unbox(r2));
        r1[3] = r2;
        r1 = (object *) 6;
        r2 = ((object*) lenv) [3];
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_997;
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L718; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L718:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
        } else {
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object****) lenv) [1][1][1][19];
          r1[2] = r2;
          r2 = ((object***) lenv) [1][1][3];
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][14];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L719; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_collect_1763;
          L719:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
        }
        r0[5] = r1;
        r1 = (object *) 1;
        r0[6] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*****) lenv) [1][1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[2];
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object***) lenv) [1][1][3];
        r3[2] = r4;
        r4 = top[21];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L720; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_car_311;
        L720:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = ((object****) lenv) [1][1][1][18];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L721; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_rule__3econstructor_dt_1767;
        L721:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = top[67];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L722; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
        L722:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[7] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][4];
        r1[2] = r2;
        r2 = top[191];
        r1[3] = r2;
        r2 = top[91];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L723; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_sexp_3d_question_432;
        L723:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        if PXLL_IS_TRUE(r1) {
          r1 = ((object***) lenv) [1][1][4];
        } else {
          r1 = top[192];
        }
        r0[8] = r1;
        r1 = (object *) constructed_996[0];
        r0[9] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_11047_i897
        goto L724;
        FUN_lambda_11047_i897:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][7];
          switch (get_case (r1)) {
            case (UITAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = ((object***) lenv) [1][1][3];
              r5 = ((pxll_vector*)r5)->val[4];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L725; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              lenv = r5[2]; goto *r5[1];
              L725:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = ((object**) lenv) [1][2];
              r5 = UOBJ_GET(r5,0);
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              lenv = lenv[1];
              lenv = lenv[1];
              r3[2] = r4;
              r4 = top[21];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L726; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_car_311;
              L726:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = ((object******) lenv) [1][1][1][1][1][17];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L727; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3esubs_1766;
              L727:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = top[24];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L728; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
              L728:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } break;
            default: {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object****) lenv) [1][1][1][7];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object***) lenv) [1][1][2];
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r3 = ((pxll_vector*)r3)->val[1];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L729; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto *r3[1];
              L729:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r1 = ((object*) lenv) [3];
              r1 = ((pxll_vector*)r1)->val[0];
              lenv = lenv[1];
            } break;
          }
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[116];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][20];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L730; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1772;
          L730:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          ensure_heap (1, unbox(r1));
          r1 = (object *) 262;
          r2 = ((object*) lenv) [2];
          if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
            t = alloc_no_clear (TC_VECTOR, unbox(r2));
            for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
            r1 = t;
          }
          r0[4] = r1;
          r1 = (object *) constructed_995[0];
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def frob-rule_1938_i897
          goto L731;
          FUN_frob_rule_1938_i897:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L732; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
            L732:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][17];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L733; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3esubs_1766;
            L733:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L734; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L734:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r2 = ((object*) lenv) [2];
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            r0[3] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [3];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_994;
              r0[2] = r1;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
              r0[3] = r1;
              r1 = top[15];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L735; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
              L735:
              ; lenv = k[2]; k = k[1];
              r0 = result;
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L736; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
            L736:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][17];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L737; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3esubs_1766;
            L737:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L738; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
            L738:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L739; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L739:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = top[23];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L740; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
            L740:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (UOTAG(0),2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[5] = r1;
            r0 = ((object*****) lenv) [1][1][1][1][5];
            r1 = ((object*) lenv) [5];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object****) lenv) [1][1][1][5] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_1944_i897
            goto L741;
            FUN__24loop_1944_i897:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][4];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L742; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L742:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_669[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = (object *) 14;
                    } else {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_281;
                    }
                    lenv = lenv[1];
                  } break;
                  default: {
                    goto fatbar_281;
                  }
                }
                goto fatbar_281_over;
                fatbar_281:
                r0 = ((object**) lenv) [1][2];
                r1 = (object *) 6;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
                ((pxll_vector*)r2)->val[unbox(r0)] = r1;
                fatbar_281_over: ;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_1944_i897;
              }
              PXLL_RETURN(0);
            L741:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_1944_i897; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_1944_i897;
            PXLL_RETURN(0);
          L731:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_frob_rule_1938_i897; r1[2] = lenv;
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = ((object****) lenv) [1][1][1][6];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          ((object****) lenv) [1][1][1][6] = r0;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[0];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L743; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L743:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L744; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L744:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def $loop_1949_i897
          goto L745;
          FUN__24loop_1949_i897:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = (object *) constructed_36[0];
              r0[3] = r1;
              r1 = top[23];
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r2 = ((object******) lenv) [1][1][1][1][1][4];
              range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
              r1 = ((pxll_vector*)r2)->val[unbox(r1)];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) constructed_669[0];
              } else {
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L746; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L746:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              }
              r0[2] = r1;
              r0 = ((object**) lenv) [1][3];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r1 = (object *) 3;
              r2 = ((object*) lenv) [2];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN__24loop_1949_i897;
            }
            PXLL_RETURN(0);
          L745:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN__24loop_1949_i897; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = (object*)TC_NIL;
          r1[3] = r2;
          r2 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L747; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN__24loop_1949_i897;
          L747:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 10);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][2];
          r2 = (object *) constructed_49[0];
          t = alloc_no_clear (UOTAG(9),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = top[34];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L748; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
          L748:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
          r3[2] = r4;
          r4 = top[22];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L749; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_cdr_312;
          L749:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = allocate (TC_TUPLE, 3);
          r4 = ((object*****) lenv) [1][1][1][1][3];
          r3[2] = r4;
          r4 = (object *) constructed_36[0];
          r3[3] = r4;
          r4 = top[23];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L750; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
          L750:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r2[3] = r3;
          r3 = top[23];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L751; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
          L751:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][5];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][8];
          r1[4] = r2;
          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L752; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1749;
          L752:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = (object*)TC_NIL;
          r0[7] = r1;
          r1 = ((object*) lenv) [7];
          r2 = ((object*) lenv) [6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r1 = ((object*) lenv) [8];
          r2 = ((object*) lenv) [5];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[9] = r1;
          r1 = ((object*) lenv) [9];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[10] = r1;
          r0 = ((object******) lenv) [1][1][1][1][1][9];
          r1 = ((object*) lenv) [10];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object*****) lenv) [1][1][1][1][9] = r0;
          PXLL_RETURN(0);
        L724:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_11047_i897; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = top[69];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L753; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
        L753:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][7];
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][7];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = ((pxll_vector*)r2)->val[3];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L754; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L754:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = ((object*) lenv) [2];
            r2 = ((object****) lenv) [1][1][1][6];
            r1 = PXLL_TEST(unbox(r2)<unbox(r1));
            lenv = lenv[1];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 6);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) constructed_665[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[2] = r2;
              r2 = (object*)TC_NIL;
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              r3 = ((object****) lenv) [1][1][1][8];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[4] = r2;
              r2 = ((object*) lenv) [4];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[6] = r2;
              r1 = ((object****) lenv) [1][1][1][9];
              r2 = ((object*) lenv) [6];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              ((object***) lenv) [1][1][9] = r1;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 12);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_629[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r2 = ((pxll_vector*)r2)->val[7];
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object******) lenv) [1][1][1][1][1][2];
            r2[2] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L755; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
            L755:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = (object*)TC_NIL;
            r1[7] = r2;
            r2 = ((object*) lenv) [7];
            r3 = ((object*) lenv) [6];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r2 = ((object*) lenv) [8];
            r3 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[9] = r2;
            r2 = ((object*) lenv) [9];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[10] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object****) lenv) [1][1][1][9];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L756; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L756:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[11] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = allocate (TC_TUPLE, 3);
            r4 = ((object*) lenv) [10];
            r3[2] = r4;
            r4 = (object *) constructed_36[0];
            r3[3] = r4;
            r4 = top[23];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L757; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
            L757:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = ((object*) lenv) [11];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L758; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L758:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[12] = r2;
            r1 = ((object*) lenv) [12];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            lenv = lenv[1];
            lenv = lenv[1];
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = top[191];
            r3 = ((object*****) lenv) [1][1][1][1][4];
            r2 = PXLL_TEST(r3==r2);
            r1[2] = r2;
            r1 = (object *) 6;
            r2 = ((object*) lenv) [2];
            r1 = PXLL_TEST(r2==r1);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 6);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) constructed_665[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[2] = r2;
              r2 = (object*)TC_NIL;
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              r3 = top[192];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[4] = r2;
              r2 = ((object*) lenv) [4];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[6] = r2;
              r1 = ((object***) lenv) [1][1][9];
              r2 = ((object*) lenv) [6];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              ((object**) lenv) [1][9] = r1;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 9);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_629[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*****) lenv) [1][1][1][1][2];
            r2[2] = r3;
            r3 = top[21];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L759; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
            L759:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = (object*)TC_NIL;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            r3 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = ((object*) lenv) [6];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object***) lenv) [1][1][9];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L760; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L760:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[8] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = allocate (TC_TUPLE, 3);
            r4 = ((object*) lenv) [7];
            r3[2] = r4;
            r4 = (object *) constructed_36[0];
            r3[3] = r4;
            r4 = top[23];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L761; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
            L761:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = ((object*) lenv) [8];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L762; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L762:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[9] = r2;
            r1 = ((object*) lenv) [9];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            lenv = lenv[1];
          } break;
        }
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = top[191];
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1 = PXLL_TEST(r2==r1);
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][7];
          r0[1] = r1[2]; lenv = r0; goto FUN_fatbar_1751;
        } else {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } else {
        goto fatbar_280;
      }
      PXLL_RETURN(0);
      goto fatbar_280_over;
      fatbar_280:
      r0 = (object *) constructed_999[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L763; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L763:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10231_i962
        goto L764;
        FUN_lambda_10231_i962:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L765; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
          L765:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[21];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L766; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
          L766:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r1[4] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][8];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L767; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_subst_1752;
          L767:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
          PXLL_RETURN(0);
        L764:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10231_i962; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L768; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L768:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[22];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L769; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
        L769:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[4] = r1;
        r1 = ((object****) lenv) [1][1][1][5];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_match_1749;
      } else {
        goto fatbar_282;
      }
      PXLL_RETURN(0);
      goto fatbar_282_over;
      fatbar_282:
      r0 = (object *) constructed_903[0];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_1890_i965
        goto L770;
        FUN_loop_1890_i965:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = ((object*) lenv) [3];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[21];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L771; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_car_311;
              L771:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = ((object**) lenv) [1][2];
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              lenv = lenv[1];
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[21];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L772; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
              L772:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object******) lenv) [1][1][1][1][1][12];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L773; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1760;
              L773:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              switch (get_case (r1)) {
                case (UOTAG(2)): {
                  r1 = (object *) constructed_1001[0];
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                } break;
                default: {
                  goto fatbar_284;
                }
              }
              goto fatbar_284_over;
              fatbar_284:
              r1 = (object *) constructed_1003[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              fatbar_284_over: ;
              r0[5] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = allocate (TC_TUPLE, 20);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) constructed_621[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object******) lenv) [1][1][1][1][1][2];
              r2[2] = r3;
              r3 = top[21];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L774; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
              L774:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[4] = r2;
              r2 = (object*)TC_NIL;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              r3 = ((object**) lenv) [1][4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = (object *) constructed_905[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[7] = r2;
              r2 = ((object*) lenv) [6];
              r3 = ((object*) lenv) [7];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[8] = r2;
              r2 = ((object*) lenv) [8];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[9] = r2;
              r2 = (object*)TC_NIL;
              r1[10] = r2;
              r2 = ((object*) lenv) [10];
              r3 = ((object*) lenv) [9];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[11] = r2;
              r2 = ((object*) lenv) [11];
              r3 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[12] = r2;
              r2 = ((object*) lenv) [12];
              r3 = ((object**) lenv) [1][5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[13] = r2;
              r2 = ((object*) lenv) [13];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[14] = r2;
              r2 = allocate (TC_TUPLE, 4);
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object******) lenv) [1][1][1][1][1][2];
              r3[2] = r4;
              r4 = top[22];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L775; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_cdr_312;
              L775:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r3[2] = r4;
              r4 = ((object**) lenv) [1][2];
              r3[3] = r4;
              r4 = top[34];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L776; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
              L776:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = top[192];
              r2[4] = r3;
              r3 = ((object*******) lenv) [1][1][1][1][1][1][5];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L777; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_compile_match_1749;
              L777:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[15] = r2;
              r2 = (object*)TC_NIL;
              r1[16] = r2;
              r2 = ((object*) lenv) [16];
              r3 = top[192];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[17] = r2;
              r2 = ((object*) lenv) [17];
              r3 = ((object*) lenv) [15];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[18] = r2;
              r2 = ((object*) lenv) [18];
              r3 = ((object*) lenv) [14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[19] = r2;
              r2 = ((object*) lenv) [19];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[20] = r2;
              r1 = ((object*) lenv) [20];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r0[3] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][7];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L778; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_fatbar_1751;
              L778:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r1 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_1890_i965;
            } break;
          }
          PXLL_RETURN(0);
        L770:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_1890_i965; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][13];
        r1[3] = r2;
        r2 = top[44];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L779; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_pack_339;
        L779:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_1890_i965;
      } else {
        goto fatbar_283;
      }
      PXLL_RETURN(0);
      goto fatbar_283_over;
      fatbar_283:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_67;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_67;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_283_over: ;
      PXLL_RETURN(0);
      fatbar_282_over: ;
      PXLL_RETURN(0);
      fatbar_280_over: ;
      PXLL_RETURN(0);
      fatbar_279_over: ;
      PXLL_RETURN(0);
    L678:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compile_group_1750; r1[2] = lenv;
    r0[6] = r1;
    // def fatbar_1751
    goto L780;
    FUN_fatbar_1751:
      check_heap (0);
      r0 = top[192];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } else {
        r0 = top[192];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 8);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r2 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[6] = r1;
          r1 = (object *) constructed_507[0];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[7] = r1;
          r1 = ((object*) lenv) [6];
          r2 = ((object*) lenv) [7];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r0 = ((object*) lenv) [8];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L780:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fatbar_1751; r1[2] = lenv;
    r0[7] = r1;
    // def subst_1752
    goto L781;
    FUN_subst_1752:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_669[0];
          r2 = ((object**) lenv) [1][2];
          r1 = PXLL_TEST(r2==r1);
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 12);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_899[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = (object*)TC_NIL;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = ((object*) lenv) [6];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = (object*)TC_NIL;
            r0[9] = r1;
            r1 = ((object*) lenv) [9];
            r2 = ((object***) lenv) [1][1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[10] = r1;
            r1 = ((object*) lenv) [10];
            r2 = ((object*) lenv) [8];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[11] = r1;
            r1 = ((object*) lenv) [11];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[12] = r1;
            r0 = ((object*) lenv) [12];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = ((object**) lenv) [1][4];
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_278;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_278_over;
      fatbar_278:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_67;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_67;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_278_over: ;
      PXLL_RETURN(0);
    L781:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_subst_1752; r1[2] = lenv;
    r0[8] = r1;
    // def fieldpair->label_1754
    goto L782;
    FUN_fieldpair__3elabel_1754:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L782:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fieldpair__3elabel_1754; r1[2] = lenv;
    r0[9] = r1;
    // def fieldpair->pattern_1755
    goto L783;
    FUN_fieldpair__3epattern_1755:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,1);
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L783:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fieldpair__3epattern_1755; r1[2] = lenv;
    r0[10] = r1;
    // def pattern->fieldpairs_1756
    goto L784;
    FUN_pattern__3efieldpairs_1756:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(3)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_277;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_277_over;
      fatbar_277:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_989;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_989;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_277_over: ;
      PXLL_RETURN(0);
    L784:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3efieldpairs_1756; r1[2] = lenv;
    r0[11] = r1;
    // def pattern->literal_1760
    goto L785;
    FUN_pattern__3eliteral_1760:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_276;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_276_over;
      fatbar_276:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_988;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_988;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_276_over: ;
      PXLL_RETURN(0);
    L785:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3eliteral_1760; r1[2] = lenv;
    r0[12] = r1;
    // def first-literal=?_1761
    goto L786;
    FUN_first_literal_3d_question_1761:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = ((object**) lenv) [1][3];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][3];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][2];
      r2[2] = r3;
      r3 = top[21];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L787; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
      L787:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = ((object****) lenv) [1][1][1][12];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L788; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1760;
      L788:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object*) lenv) [2];
      r2[2] = r3;
      r3 = top[21];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L789; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
      L789:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = ((object****) lenv) [1][1][1][12];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L790; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1760;
      L790:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = top[91];
      r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_432;
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L786:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_first_literal_3d_question_1761; r1[2] = lenv;
    r0[13] = r1;
    // def collect_1763
    goto L791;
    FUN_collect_1763:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1899
      goto L792;
      FUN_loop_1899:
        check_heap (0);
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L793; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L793:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [4];
            r1[3] = r2;
            r2 = top[67];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L794; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
            L794:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = ((object*) lenv) [5];
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = (object *) constructed_987[0];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 6);
                r1[1] = lenv; lenv = r1;
                // def push_1722_i1067
                goto L795;
                FUN_push_1722_i1067:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object**) lenv) [1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  ((object***) lenv) [1][1][2] = r0;
                  PXLL_RETURN(0);
                L795:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_push_1722_i1067; r2[2] = lenv;
                r1[2] = r2;
                // def pop_1723_i1067
                goto L796;
                FUN_pop_1723_i1067:
                  check_heap (0);
                  r0 = ((object**) lenv) [1][2];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = (object*) &constructed_68;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_68;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_986;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_986;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = ((object*) lenv) [2];
                      r0[4] = r1;
                      r0 = ((object*) lenv) [3];
                      ((object***) lenv) [1][1][2] = r0;
                      r0 = ((object*) lenv) [4];
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L796:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_pop_1723_i1067; r2[2] = lenv;
                r1[3] = r2;
                // def get_1724_i1067
                goto L797;
                FUN_get_1724_i1067:
                  r0 = ((object**) lenv) [1][2];
                  PXLL_RETURN(0);
                L797:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_get_1724_i1067; r2[2] = lenv;
                r1[4] = r2;
                // def top_1725_i1067
                goto L798;
                FUN_top_1725_i1067:
                  check_heap (0);
                  r0 = ((object**) lenv) [1][2];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = (object*) &constructed_68;
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_68;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_985;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_985;
                      PXLL_UNDEFINED; result=r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L798:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_top_1725_i1067; r2[2] = lenv;
                r1[5] = r2;
                // def stack-length_1726_i1067
                goto L799;
                FUN_stack_length_1726_i1067:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = ((object**) lenv) [1][2];
                  r0[2] = r1;
                  r1 = top[24];
                  r0[1] = r1[2]; lenv = r0; goto FUN_length_316;
                L799:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_stack_length_1726_i1067; r2[2] = lenv;
                r1[6] = r2;
                r1 = allocate (UOTAG(21), 5);
                r2 = ((object*) lenv) [4];
                r1[1] = r2;
                r2 = ((object*) lenv) [6];
                r1[2] = r2;
                r2 = ((object*) lenv) [3];
                r1[3] = r2;
                r2 = ((object*) lenv) [2];
                r1[4] = r2;
                r2 = ((object*) lenv) [5];
                r1[5] = r2;
                lenv = lenv[1];
                r0[3] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object**) lenv) [1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [3];
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L800; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L800:
                ; lenv = k[2]; k = k[1];
                r0 = ((object*) lenv) [3];
                r1 = ((object***) lenv) [1][1][2];
                r2 = ((object**) lenv) [1][4];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                r1 = ((object**) lenv) [1][3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_1899;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][5];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object**) lenv) [1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L801; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L801:
                ; lenv = k[2]; k = k[1];
                r0 = ((object**) lenv) [1][3];
                r1 = ((object***) lenv) [1][1][2];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN_loop_1899;
              } break;
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L792:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1899; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*)UITAG(0);
      r0[2] = r1;
      r1 = ((object**) lenv) [1][3];
      r0[3] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1899;
    L791:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_collect_1763; r1[2] = lenv;
    r0[14] = r1;
    // def pattern->dt_1764
    goto L802;
    FUN_pattern__3edt_1764:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_275;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_275_over;
      fatbar_275:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_984;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_984;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_275_over: ;
      PXLL_RETURN(0);
    L802:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3edt_1764; r1[2] = lenv;
    r0[15] = r1;
    // def pattern->alt_1765
    goto L803;
    FUN_pattern__3ealt_1765:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_274;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_274_over;
      fatbar_274:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_983;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_983;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_274_over: ;
      PXLL_RETURN(0);
    L803:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3ealt_1765; r1[2] = lenv;
    r0[16] = r1;
    // def pattern->subs_1766
    goto L804;
    FUN_pattern__3esubs_1766:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_273;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_273_over;
      fatbar_273:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_982;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_982;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_273_over: ;
      PXLL_RETURN(0);
    L804:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3esubs_1766; r1[2] = lenv;
    r0[17] = r1;
    // def rule->constructor-dt_1767
    goto L805;
    FUN_rule__3econstructor_dt_1767:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[21];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L806; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
      L806:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][15];
      r0[1] = r1[2]; lenv = r0; goto FUN_pattern__3edt_1764;
      PXLL_RETURN(0);
    L805:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_rule__3econstructor_dt_1767; r1[2] = lenv;
    r0[18] = r1;
    // def rule->constructor-alt_1768
    goto L807;
    FUN_rule__3econstructor_alt_1768:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[21];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L808; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
      L808:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][16];
      r0[1] = r1[2]; lenv = r0; goto FUN_pattern__3ealt_1765;
      PXLL_RETURN(0);
    L807:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_rule__3econstructor_alt_1768; r1[2] = lenv;
    r0[19] = r1;
    // def nthunk_1772
    goto L809;
    FUN_nthunk_1772:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) constructed_981[0];
        PXLL_RETURN(0);
      } else {
        goto fatbar_272;
      }
      PXLL_RETURN(0);
      goto fatbar_272_over;
      fatbar_272:
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L810; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L810:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = (object *) 3;
      r3 = ((object**) lenv) [1][2];
      r2 = box((pxll_int)unbox(r3)-unbox(r2));
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = ((object***) lenv) [1][1][20];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L811; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1772;
      L811:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
      fatbar_272_over: ;
      PXLL_RETURN(0);
    L809:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_nthunk_1772; r1[2] = lenv;
    r0[20] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def loop_1796_i1139
    goto L812;
    FUN_loop_1796_i1139:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) constructed_36[0];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_691[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object**) lenv) [1][3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*****) lenv) [1][1][1][1][2];
                    r1[2] = r2;
                    r2 = (object *) constructed_36[0];
                    r1[3] = r2;
                    r2 = top[23];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L813; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                    L813:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L814; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L814:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = ((object*) lenv) [3];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[4] = r1;
                    r0 = ((object*****) lenv) [1][1][1][1][3];
                    r1 = ((object*) lenv) [4];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r1 = ((object*) lenv) [3];
                    r2 = (object *) constructed_975[0];
                    lenv = ((object ***)lenv)[1][1][1];
                    lenv[2] = r2;
                    lenv[3] = r0;
                    lenv[4] = r1;
                    goto FUN_loop_1796_i1139;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_267;
                  }
                }
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_267;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_267;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_267_over;
          fatbar_267:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          // def parse-fieldpair_1774_i849_i1139
          goto L815;
          FUN_parse_fieldpair_1774_i849_i1139:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L816; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_kind_1775_i849_i1139;
            L816:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [4];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          L815:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_parse_fieldpair_1774_i849_i1139; r2[2] = lenv;
          r1[2] = r2;
          // def kind_1775_i849_i1139
          goto L817;
          FUN_kind_1775_i849_i1139:
            check_heap (0);
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(8)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object***) lenv) [1][1][2];
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = top[117];
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r2[3] = r3;
                r3 = top[36];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L818; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_filter_330;
                L818:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = top[34];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L819; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                L819:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(4)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(r1) {
                  r1 = (object *) constructed_44[0];
                } else {
                  r1 = (object *) constructed_41[0];
                }
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = (object *) constructed_976[0];
                r2 = (object *) constructed_46[0];
                t = alloc_no_clear (UOTAG(2),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = (object *) constructed_49[0];
                    r1 = (object *) constructed_977[0];
                    r2 = (object *) constructed_51[0];
                    t = alloc_no_clear (UOTAG(2),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = (object *) constructed_979[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = ((object*) lenv) [2];
                                  r0[2] = r1;
                                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_kind_1775_i849_i1139;
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_271;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_271;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_271;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_271_over;
                        fatbar_271:
                        r0 = (object *) constructed_905[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = ((object**) lenv) [1][3];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r1;
                                      r1 = t;
                                      r0[2] = r1;
                                      r0 = ((object*) lenv) [2];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r0;
                                      r0 = t;
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_270;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_270;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_270;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_270;
                        }
                        PXLL_RETURN(0);
                        fatbar_271_over: ;
                        PXLL_RETURN(0);
                      } break;
                      case (UOTAG(9)): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object*****) lenv) [1][1][1][1][3];
                        r1[2] = r2;
                        r2 = ((object**) lenv) [1][3];
                        r1[3] = r2;
                        r2 = top[34];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L820; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                        L820:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r0 = ((object*) lenv) [3];
                        r1 = ((object*) lenv) [4];
                        r2 = ((object*) lenv) [2];
                        t = alloc_no_clear (UOTAG(2),3);
                        t[1] = r2;
                        t[2] = r0;
                        t[3] = r1;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        goto fatbar_270;
                      }
                    }
                    PXLL_RETURN(0);
                    goto fatbar_270_over;
                    fatbar_270:
                    r0 = allocate (TC_TUPLE, 6);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object*****) lenv) [1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L821; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_kind_1775_i849_i1139;
                    L821:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][3];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r2;
                    r2 = t;
                    r1[2] = r2;
                    r2 = ((object*****) lenv) [1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L822; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_kind_1775_i849_i1139;
                    L822:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = (object*)TC_NIL;
                    r0[4] = r1;
                    r1 = ((object*) lenv) [4];
                    r2 = ((object*) lenv) [3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r0 = (object *) constructed_61[0];
                    r1 = ((object*) lenv) [6];
                    r2 = (object *) constructed_51[0];
                    t = alloc_no_clear (UOTAG(2),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                    fatbar_270_over: ;
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
                goto fatbar_269_over;
                fatbar_269:
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_980;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[15];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                fatbar_269_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_268;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_268_over;
            fatbar_268:
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_268_over: ;
            PXLL_RETURN(0);
          L817:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_kind_1775_i849_i1139; r2[2] = lenv;
          r1[3] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object*) lenv) [3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L823; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_kind_1775_i849_i1139;
          L823:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = ((object**) lenv) [1][3];
          r2 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          lenv[4] = r2;
          goto FUN_loop_1796_i1139;
          fatbar_267_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L812:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_loop_1796_i1139; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 4);
    r2 = (object *) constructed_974[0];
    r1[2] = r2;
    r2 = (object *) constructed_973[0];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][5];
    r1[4] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L824; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_loop_1796_i1139;
    L824:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object**) lenv) [1][2];
    r3[2] = r4;
    r4 = top[21];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L825; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_car_311;
    L825:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = ((object**) lenv) [1][2];
    r3 = UOBJ_GET(r3,0);
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    lenv = lenv[1];
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L826; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L826:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][4];
    switch (get_case (r1)) {
      case (TC_NIL): {
        r1 = (object *) 262;
      } break;
      default: {
        goto fatbar_266;
      }
    }
    goto fatbar_266_over;
    fatbar_266:
    r1 = (object *) 6;
    fatbar_266_over: ;
    if PXLL_IS_TRUE(r1) {
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [3];
      r1[2] = r2;
      r2 = top[116];
      r1[3] = r2;
      r2 = ((object**) lenv) [1][20];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L827; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1772;
      L827:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
    } else {
      r1 = ((object***) lenv) [1][1][4];
    }
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r1[3] = r2;
    r2 = top[191];
    r1[4] = r2;
    r2 = ((object**) lenv) [1][5];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L828; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1749;
    L828:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r0 = allocate (UOTAG(1), 2);
    r1 = ((object*) lenv) [4];
    r0[1] = r1;
    r1 = ((object*) lenv) [5];
    r0[2] = r1;
    PXLL_RETURN(0);
  L664:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_compile_pattern_480; r1[2] = lenv;
  r0[118] = r1;
  // def print-datatype_483
  goto L829;
  FUN_print_datatype_483:
    check_heap (0);
    r0 = (object*) &constructed_972;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_972;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[7];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = dump_object (r0, 0); fprintf (stdout, "\n");
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_13913
    goto L830;
    FUN_lambda_13913:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = ((object***) lenv) [1][1][2];
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = ((object****) lenv) [1][1][1][2];
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 3);
      r4 = allocate (TC_TUPLE, 3);
      r5 = top[109];
      r4[2] = r5;
      r5 = ((object***) lenv) [1][1][3];
      r5 = ((pxll_vector*)r5)->val[3];
      r4[3] = r5;
      r5 = top[34];
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L831; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
      L831:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = (object*) &constructed_971;
      r3[3] = r4;
      r4 = top[50];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L832; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
      L832:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_970;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_969;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_968;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L833; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L833:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L830:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_13913; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[6];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L834; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L834:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_967;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_967;
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    PXLL_RETURN(0);
  L829:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_print_datatype_483; r1[2] = lenv;
  r0[119] = r1;
  // def make-node_488
  goto L835;
  FUN_make_node_488:
    check_heap (0);
    r0 = allocate (UOTAG(20), 6);
    r1 = (object *) 1;
    r0[1] = r1;
    r1 = top[194];
    r1 = ((pxll_vector*)r1)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L836; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L836:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    // def lambda_13931_i1511
    goto L837;
    FUN_lambda_13931_i1511:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r0 = ((object**) lenv) [1][3];
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      PXLL_RETURN(0);
    L837:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_13931_i1511; r2[2] = lenv;
    r1[2] = r2;
    r2 = (object *) 3;
    r1[3] = r2;
    r2 = ((object*) lenv) [3];
    r1[4] = r2;
    r2 = top[39];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L838; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_fold_333;
    L838:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[5] = r1;
    r1 = top[195];
    r0[6] = r1;
    PXLL_RETURN(0);
  L835:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_node_488; r1[2] = lenv;
  r0[120] = r1;
  // def varref->name_491
  goto L839;
  FUN_varref__3ename_491:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_265;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_265_over;
    fatbar_265:
    r0 = (object*) &constructed_68;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_68;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_966;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_966;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_265_over: ;
    PXLL_RETURN(0);
  L839:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_varref__3ename_491; r1[2] = lenv;
  r0[121] = r1;
  // def node/if_495
  goto L840;
  FUN_node_2fif_495:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = ((object*) lenv) [4];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[5] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*)UITAG(6);
    r0[2] = r1;
    r1 = ((object*) lenv) [5];
    r0[3] = r1;
    r1 = top[120];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L840:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2fif_495; r1[2] = lenv;
  r0[122] = r1;
  // def node/function_496
  goto L841;
  FUN_node_2ffunction_496:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][3];
    r3 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(7),2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    r3 = ((object***) lenv) [1][1][5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[3] = r2;
    r2 = top[120];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L842; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
    L842:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object**) lenv) [1][4];
    switch (get_case (r0)) {
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case ((pxll_int)PXLL_FALSE): {
            r0 = ((object**) lenv) [1][2];
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_264;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_264;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_264_over;
    fatbar_264:
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][4];
    r0[2] = r1;
    r1 = top[200];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L843; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L843:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[113];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L844; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_parse_type_splat_469;
    L844:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    r1 = ((object*) lenv) [2];
    ((pxll_vector*)r1)->val[5] = r0;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    fatbar_264_over: ;
    PXLL_RETURN(0);
  L841:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2ffunction_496; r1[2] = lenv;
  r0[123] = r1;
  // def node/fix_500
  goto L845;
  FUN_node_2ffix_500:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L846; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L846:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L847; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L847:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(10),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [4];
    r0[3] = r1;
    r1 = top[120];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L845:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2ffix_500; r1[2] = lenv;
  r0[124] = r1;
  // def node/let_501
  goto L848;
  FUN_node_2flet_501:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L849; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L849:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L850; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L850:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(9),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [4];
    r0[3] = r1;
    r1 = top[120];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L848:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2flet_501; r1[2] = lenv;
  r0[125] = r1;
  // def node/nvcase_502
  goto L851;
  FUN_node_2fnvcase_502:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][6];
    r2 = ((object**) lenv) [1][7];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][4];
    r3 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(4),3);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    r1 = t;
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[120];
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L851:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2fnvcase_502; r1[2] = lenv;
  r0[126] = r1;
  // def unpack-fix_506
  goto L852;
  FUN_unpack_fix_506:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object *) constructed_36[0];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L853; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L853:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (UOTAG(4), 2);
        r1 = ((object*) lenv) [2];
        r0[1] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = (object *) constructed_36[0];
        r1[3] = r2;
        r2 = top[23];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L854; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
        L854:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_263;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_263_over;
    fatbar_263:
    r0 = (object*) &constructed_68;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_68;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_965;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_965;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_263_over: ;
    PXLL_RETURN(0);
  L852:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unpack_fix_506; r1[2] = lenv;
  r0[127] = r1;
  // def literal->string_507
  goto L855;
  FUN_literal__3estring_507:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8706;
        r2[2] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L856; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_350;
        L856:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8706;
        r2[2] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L857; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_350;
        L857:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[58];
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_366;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 7);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8962;
        r2[2] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L858; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_350;
        L858:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 23554;
        r2[2] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L859; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_350;
        L859:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[48];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L860; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_350;
        L860:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r2 = (object*)TC_NIL;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r1 = ((object*) lenv) [7];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
      case (UITAG(3)): {
        r0 = (object*) &constructed_953;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 8);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object***) lenv) [1][1][2];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r2 = ((object*) lenv) [2];
            lenv = lenv[1];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object***) lenv) [1][1][3];
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r2 = ((object*) lenv) [2];
            lenv = lenv[1];
            r1[3] = r2;
            r2 = (object*)TC_NIL;
            r1[4] = r2;
            r2 = ((object*) lenv) [4];
            r3 = (object*) &constructed_956;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            r3 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = ((object*) lenv) [6];
            r3 = (object*) &constructed_955;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = ((object*) lenv) [7];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r1 = ((object*) lenv) [8];
            r2 = (object*) &constructed_954;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r0[2] = r1;
            r1 = top[49];
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
          } break;
          default: {
            goto fatbar_262;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_262_over;
        fatbar_262:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 11);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][2];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][2];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object***) lenv) [1][1][3];
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        lenv = lenv[1];
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[128];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][4];
        r3[3] = r4;
        r4 = top[34];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L861; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
        L861:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_961;
        r2[3] = r3;
        r3 = top[50];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L862; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_355;
        L862:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r2 = (object*)TC_NIL;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_960;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r2 = ((object*) lenv) [7];
        r3 = (object*) &constructed_959;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[8] = r2;
        r2 = ((object*) lenv) [8];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[9] = r2;
        r2 = ((object*) lenv) [9];
        r3 = (object*) &constructed_958;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[10] = r2;
        r2 = ((object*) lenv) [10];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[11] = r2;
        r1 = ((object*) lenv) [11];
        r2 = (object*) &constructed_957;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        fatbar_262_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = top[128];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][2];
        r3[3] = r4;
        r4 = top[34];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L863; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
        L863:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_964;
        r2[3] = r3;
        r3 = top[50];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L864; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_355;
        L864:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_963;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_962;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      } break;
    }
    PXLL_RETURN(0);
  L855:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_literal__3estring_507; r1[2] = lenv;
  r0[128] = r1;
  // def flags-repr_508
  goto L865;
  FUN_flags_repr_508:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2378
    goto L866;
    FUN_loop_2378:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[56];
        r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_363;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 3;
        r2 = ((object**) lenv) [1][3];
        r1 = box((pxll_int)unbox(r2)&unbox(r1));
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [3];
          r0 = box((pxll_int)unbox(r1)>>unbox(r0));
          r1 = ((object*) lenv) [2];
          r2 = (object *) 12546;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_2378;
        } else {
          r0 = (object *) 3;
          r1 = ((object*) lenv) [3];
          r0 = box((pxll_int)unbox(r1)>>unbox(r0));
          r1 = ((object*) lenv) [2];
          r2 = (object *) 12290;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_2378;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L866:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2378; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_952[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2378;
  L865:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_flags_repr_508; r1[2] = lenv;
  r0[129] = r1;
  // def pp-node_510
  goto L867;
  FUN_pp_node_510:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def PP_2384
    goto L868;
    FUN__50_50_2384:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][2];
      r3 = ((pxll_vector*)r3)->val[5];
      r2[2] = r3;
      r3 = top[143];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L869; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_apply_subst_534;
      L869:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = top[109];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L870; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
      L870:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 12);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][2];
      r4 = ((pxll_vector*)r4)->val[1];
      r3[2] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L871; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
      L871:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = (object *) 13;
      r3[2] = r4;
      r4 = ((object*) lenv) [2];
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = top[60];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L872; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_369;
      L872:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][2];
      r4 = ((pxll_vector*)r4)->val[2];
      r3[2] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L873; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
      L873:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[4] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = (object *) 11;
      r3[2] = r4;
      r4 = ((object*) lenv) [4];
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = top[60];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L874; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_369;
      L874:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[5] = r3;
      r3 = top[198];
      r4 = (object *) 5;
      r3 = box((pxll_int)unbox(r4)+unbox(r3));
      r2[6] = r3;
      r3 = ((object***) lenv) [1][1][2];
      r3 = ((pxll_vector*)r3)->val[0];
      r2[7] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      // def loop_2378_i1
      goto L875;
      FUN_loop_2378_i1:
        check_heap (0);
        r0 = (object *) 1;
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = top[56];
          r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_363;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) 3;
          r2 = ((object**) lenv) [1][3];
          r1 = box((pxll_int)unbox(r2)&unbox(r1));
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 3;
            r1 = ((object*) lenv) [3];
            r0 = box((pxll_int)unbox(r1)>>unbox(r0));
            r1 = ((object*) lenv) [2];
            r2 = (object *) 12546;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_2378_i1;
          } else {
            r0 = (object *) 3;
            r1 = ((object*) lenv) [3];
            r0 = box((pxll_int)unbox(r1)>>unbox(r0));
            r1 = ((object*) lenv) [2];
            r2 = (object *) 12290;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_2378_i1;
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L875:
      r4 = allocate (TC_CLOSURE, 2);
      r4[1] = &&FUN_loop_2378_i1; r4[2] = lenv;
      r3[2] = r4;
      r3 = allocate (TC_TUPLE, 3);
      r4 = (object *) constructed_952[0];
      r3[2] = r4;
      r4 = ((object**) lenv) [1][7];
      r3[3] = r4;
      r4 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L876; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto *r4[1];
      L876:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      lenv = lenv[1];
      r2[8] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = ((object*) lenv) [6];
      r3[2] = r4;
      r4 = ((object*) lenv) [8];
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = top[60];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L877; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_369;
      L877:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[9] = r3;
      r3 = (object*)TC_NIL;
      r2[10] = r3;
      r3 = ((object*) lenv) [10];
      r4 = ((object*) lenv) [9];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[11] = r3;
      r3 = ((object*) lenv) [11];
      r4 = ((object*) lenv) [5];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[12] = r3;
      r2 = ((object*) lenv) [12];
      r3 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L878; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L878:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = top[161];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L879; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L879:
      ; lenv = k[2]; k = k[1];
      r0 = ((object*) lenv) [3];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [3];
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object *) 1;
      r1 = ((object**) lenv) [1][3];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) 262;
      } else {
        goto fatbar_261;
      }
      goto fatbar_261_over;
      fatbar_261:
      r0 = (object*) &constructed_951;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_951;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 3;
      r2 = ((object**) lenv) [1][3];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[2] = r1;
      r1 = top[94];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L880; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
      L880:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      fatbar_261_over: ;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_919;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_918;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L881; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L881:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_921;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_920;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L882; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L882:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][2];
          r3[2] = r4;
          r4 = top[128];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L883; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_literal__3estring_507;
          L883:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_923;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_922;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L884; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L884:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(3)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 8);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][3];
          r3[2] = r4;
          r4 = top[109];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L885; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
          L885:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_926;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object**) lenv) [1][4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = (object*) &constructed_925;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r2 = ((object*) lenv) [8];
          r3 = (object*) &constructed_924;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L886; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L886:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [5];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UITAG(5)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_927;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L887; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L887:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UITAG(6)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_928;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L888; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L888:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UITAG(8)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_929;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L889; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L889:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 9);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[80];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][3];
          r4[3] = r5;
          r5 = top[34];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L890; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
          L890:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_933;
          r3[3] = r4;
          r4 = top[50];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L891; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
          L891:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_932;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = (object*) &constructed_931;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = ((object*) lenv) [8];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r2 = ((object*) lenv) [9];
          r3 = (object*) &constructed_930;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L892; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L892:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [4];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[80];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][2];
          r4[3] = r5;
          r5 = top[34];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L893; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
          L893:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_936;
          r3[3] = r4;
          r4 = top[50];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L894; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
          L894:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_935;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_934;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L895; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L895:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(4)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 12);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[80];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][3];
          r4[3] = r5;
          r5 = top[34];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L896; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
          L896:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_942;
          r3[3] = r4;
          r4 = top[50];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L897; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
          L897:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[58];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][4];
          r4[3] = r5;
          r5 = top[34];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L898; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
          L898:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_941;
          r3[3] = r4;
          r4 = top[50];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L899; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
          L899:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r3 = (object*)TC_NIL;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = (object*) &constructed_940;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = ((object*) lenv) [4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = ((object*) lenv) [8];
          r4 = (object*) &constructed_939;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r3 = ((object*) lenv) [9];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[10] = r3;
          r3 = ((object*) lenv) [10];
          r4 = (object*) &constructed_938;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[11] = r3;
          r3 = ((object*) lenv) [11];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[12] = r3;
          r2 = ((object*) lenv) [12];
          r3 = (object*) &constructed_937;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L900; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L900:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [5];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(11)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 7);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[2] = r3;
          r3 = ((object**) lenv) [1][3];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][3];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_944;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r2 = ((object*) lenv) [7];
          r3 = (object*) &constructed_943;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L901; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L901:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [4];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        case (UOTAG(12)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 9);
          r2[1] = lenv; lenv = r2;
          r3 = ((object**) lenv) [1][2];
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = ((object***) lenv) [1][1][2];
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = ((object*) lenv) [2];
          lenv = lenv[1];
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][3];
          r3[2] = r4;
          r4 = top[93];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L902; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_repr_435;
          L902:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = (object*) &constructed_947;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = (object*) &constructed_946;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = ((object*) lenv) [8];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r2 = ((object*) lenv) [9];
          r3 = (object*) &constructed_945;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L903; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L903:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = ((object*) lenv) [4];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [4];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[80];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][2];
          r4[3] = r5;
          r5 = top[34];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L904; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
          L904:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_950;
          r3[3] = r4;
          r4 = top[50];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L905; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
          L905:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_949;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = ((object*) lenv) [6];
          r3 = (object*) &constructed_948;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L906; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L906:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [3];
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
        } break;
      }
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][3];
      r2 = (object *) 3;
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_14535_i1689
      goto L907;
      FUN_lambda_14535_i1689:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN__50_50_2384;
      L907:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_14535_i1689; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = top[37];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L868:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__50_50_2384; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L908; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN__50_50_2384;
    L908:
    ; lenv = k[2]; k = k[1];
    r0 = top[161];
    lenv = r0[2]; goto *r0[1];
  L867:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_node_510; r1[2] = lenv;
  r0[130] = r1;
  // def get-formals_511
  goto L909;
  FUN_get_formals_511:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def p_2412
    goto L910;
    FUN_p_2412:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_260;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_260_over;
      fatbar_260:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_917;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      fatbar_260_over: ;
      PXLL_RETURN(0);
    L910:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_p_2412; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object *) constructed_916[0];
    r1[3] = r2;
    r2 = ((object***) lenv) [1][1][2];
    r1[4] = r2;
    r2 = top[39];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L911; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_fold_333;
    L911:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = (object *) constructed_36[0];
    r0[3] = r1;
    r1 = top[23];
    r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
  L909:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_formals_511; r1[2] = lenv;
  r0[131] = r1;
  // def unpack-bindings_512
  goto L912;
  FUN_unpack_bindings_512:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2417
    goto L913;
    FUN_loop_2417:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (UOTAG(1), 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L914; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L914:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[1] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [4];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L915; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L915:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = ((object******) lenv) [1][1][1][1][1][3];
                              r1 = ((object**) lenv) [1][2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r1;
                              t[2] = r0;
                              r0 = t;
                              r1 = ((object******) lenv) [1][1][1][1][1][4];
                              r2 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r2 = ((object*****) lenv) [1][1][1][1][3];
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              lenv[2] = r2;
                              lenv[3] = r0;
                              lenv[4] = r1;
                              goto FUN_loop_2417;
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_259;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_259;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_259;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_259;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_259;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_259_over;
      fatbar_259:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_915;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      fatbar_259_over: ;
      PXLL_RETURN(0);
    L913:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2417; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) constructed_914[0];
    r0[3] = r1;
    r1 = (object *) constructed_913[0];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2417;
  L912:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unpack_bindings_512; r1[2] = lenv;
  r0[132] = r1;
  // def parse-cexp-sig_513
  goto L916;
  FUN_parse_cexp_sig_513:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = top[200];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L917; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L917:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r1[3] = r2;
    r2 = top[113];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L918; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_parse_type_splat_469;
    L918:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = allocate (UOTAG(2), 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[7];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L919; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L919:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[1] = r1;
    r1 = ((object*) lenv) [3];
    r0[2] = r1;
    PXLL_RETURN(0);
  L916:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_parse_cexp_sig_513; r1[2] = lenv;
  r0[133] = r1;
  // def sort-fix-inits_514
  goto L920;
  FUN_sort_fix_inits_514:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_912[0];
    r0[2] = r1;
    r1 = (object *) constructed_911[0];
    r0[3] = r1;
    r1 = (object *) constructed_910[0];
    r0[4] = r1;
    r1 = (object *) constructed_909[0];
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L921; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L921:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][6];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def $loop_2440
    goto L922;
    FUN__24loop_2440:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[29];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L923; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
        L923:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][3];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[29];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L924; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
        L924:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object******) lenv) [1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object*****) lenv) [1][1][1][1][2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object******) lenv) [1][1][1][1][1][4];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object*****) lenv) [1][1][1][1][4] = r0;
          } break;
          default: {
            goto fatbar_258;
          }
        }
        goto fatbar_258_over;
        fatbar_258:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][3];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        ((object*****) lenv) [1][1][1][1][3] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][5];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        ((object*****) lenv) [1][1][1][1][5] = r0;
        fatbar_258_over: ;
        lenv = lenv[1];
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        lenv[2] = r0;
        goto FUN__24loop_2440;
      }
      PXLL_RETURN(0);
    L922:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__24loop_2440; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L925; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2440;
    L925:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    lenv = lenv[1];
    r0 = allocate (UOTAG(3), 2);
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [2];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L926; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L926:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [4];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L927; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L927:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [3];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L928; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L928:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [5];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L929; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L929:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[1] = r1;
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][4];
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [2];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L930; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L930:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = ((object**) lenv) [1][5];
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [4];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L931; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L931:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [3];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L932; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L932:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [5];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L933; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L933:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[2] = r1;
    PXLL_RETURN(0);
  L920:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sort_fix_inits_514; r1[2] = lenv;
  r0[134] = r1;
  // def walk_515
  goto L934;
  FUN_walk_515:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_829[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_846[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_846[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_846[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(r1) {
          r1 = (object *) constructed_44[0];
        } else {
          r1 = (object *) constructed_41[0];
        }
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r2 = (object *) constructed_895[0];
        r3 = (object *) constructed_46[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_846[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object*)UITAG(3);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_846[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        // def lambda_15300
        goto L935;
        FUN_lambda_15300:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          r0 = allocate (TC_TUPLE, 8);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[135];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L936; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
          L936:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = (object*)TC_NIL;
          r0[6] = r1;
          r1 = ((object*) lenv) [6];
          r2 = ((object*) lenv) [5];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[7] = r1;
          r1 = ((object*) lenv) [7];
          r2 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r2 = (object *) constructed_500[0];
          t = alloc_no_clear (UOTAG(12),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = ((object*) lenv) [8];
          r0[3] = r1;
          r1 = top[120];
          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
          PXLL_RETURN(0);
        L935:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_15300; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r3 = (object *) constructed_497[0];
        t = alloc_no_clear (UOTAG(12),2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = (object *) constructed_896[0];
        r1[3] = r2;
        r2 = top[120];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L937; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
        L937:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r0[4] = r1;
        r1 = top[40];
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_334;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[135];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L938; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
        L938:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = (object*)TC_NIL;
        r0[6] = r1;
        r1 = ((object*) lenv) [6];
        r2 = ((object*) lenv) [5];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        r2 = (object *) constructed_494[0];
        t = alloc_no_clear (UOTAG(12),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(7),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = top[137];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L939; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
        L939:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_846[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 6);
        r3[1] = lenv; lenv = r3;
        r4 = ((object**) lenv) [1][2];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object***) lenv) [1][1][2];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r3[2] = r4;
        r4 = ((object**) lenv) [1][3];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object***) lenv) [1][1][3];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r3[3] = r4;
        r4 = (object*)TC_NIL;
        r3[4] = r4;
        r4 = ((object*) lenv) [4];
        r5 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[5] = r4;
        r4 = ((object*) lenv) [5];
        r5 = (object*) &constructed_897;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[6] = r4;
        r3 = ((object*) lenv) [6];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r2[2] = r3;
        r3 = top[49];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L940; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
        L940:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = top[82];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L941; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
        L941:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_829[0];
        r0[3] = r1;
        r1 = top[120];
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_899[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = ((object**) lenv) [1][3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [2];
                                      switch (get_case (r0)) {
                                        case (UOTAG(1)): {
                                          r0 = allocate (TC_TUPLE, 2);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r0 = ((object**) lenv) [1][3];
                                          switch (get_case (r0)) {
                                            case (TC_NIL): {
                                              r0 = ((object******) lenv) [1][1][1][1][1][3];
                                              switch (get_case (r0)) {
                                                case (TC_PAIR): {
                                                  r0 = allocate (TC_TUPLE, 3);
                                                  r0[1] = lenv; lenv = r0;
                                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                  r1 = UOBJ_GET(r1,0);
                                                  r0[2] = r1;
                                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                  r1 = UOBJ_GET(r1,1);
                                                  r0[3] = r1;
                                                  r0 = ((object*) lenv) [3];
                                                  switch (get_case (r0)) {
                                                    case (TC_NIL): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = ((object**) lenv) [1][2];
                                                      r1[2] = r2;
                                                      r2 = top[135];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L942; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                                      L942:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      r0[2] = r1;
                                                      r0 = allocate (TC_TUPLE, 3);
                                                      r1 = ((object***) lenv) [1][1][2];
                                                      r2 = ((object*****) lenv) [1][1][1][1][2];
                                                      t = alloc_no_clear (UOTAG(11),2);
                                                      t[1] = r2;
                                                      t[2] = r1;
                                                      r1 = t;
                                                      r0[2] = r1;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r1[1] = lenv; lenv = r1;
                                                      r2 = (object*)TC_NIL;
                                                      r1[2] = r2;
                                                      r1 = ((object*) lenv) [2];
                                                      r2 = ((object**) lenv) [1][2];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r2;
                                                      t[2] = r1;
                                                      r1 = t;
                                                      lenv = lenv[1];
                                                      r0[3] = r1;
                                                      r1 = top[120];
                                                      r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                                                    } break;
                                                    default: {
                                                      lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                      goto fatbar_245;
                                                    }
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                  goto fatbar_245;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_245;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_245;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_245;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_245;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_245;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_245;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_245;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_245;
                }
                PXLL_RETURN(0);
                goto fatbar_245_over;
                fatbar_245:
                r0 = (object *) constructed_901[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = top[132];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L943; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_bindings_512;
                          L943:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case_noint (r0)) {
                            default: {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = ((object*) lenv) [2];
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = top[135];
                              r1[2] = r2;
                              r2 = ((object*) lenv) [3];
                              r1[3] = r2;
                              r2 = top[34];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L944; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                              L944:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = top[135];
                              r2[2] = r3;
                              r3 = ((object****) lenv) [1][1][1][3];
                              r2[3] = r3;
                              r3 = top[34];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L945; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
                              L945:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = (object*)UITAG(5);
                              r1[2] = r2;
                              r2 = ((object*) lenv) [2];
                              r1[3] = r2;
                              r2 = top[120];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L946; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                              L946:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              lenv = lenv[1];
                              r0[4] = r1;
                              r1 = top[124];
                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2ffix_500;
                            } break;
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_246;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_246;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_246;
                }
                PXLL_RETURN(0);
                goto fatbar_246_over;
                fatbar_246:
                r0 = (object *) constructed_631[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = top[132];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L947; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_bindings_512;
                          L947:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case_noint (r0)) {
                            default: {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = ((object*) lenv) [2];
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = top[135];
                              r1[2] = r2;
                              r2 = ((object*) lenv) [3];
                              r1[3] = r2;
                              r2 = top[34];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L948; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                              L948:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = top[135];
                              r2[2] = r3;
                              r3 = ((object****) lenv) [1][1][1][3];
                              r2[3] = r3;
                              r3 = top[34];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L949; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
                              L949:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = (object*)UITAG(5);
                              r1[2] = r2;
                              r2 = ((object*) lenv) [2];
                              r1[3] = r2;
                              r2 = top[120];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L950; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                              L950:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              lenv = lenv[1];
                              r0[4] = r1;
                              r1 = top[125];
                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2flet_501;
                            } break;
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_247;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_247;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_247;
                }
                PXLL_RETURN(0);
                goto fatbar_247_over;
                fatbar_247:
                r0 = (object *) constructed_723[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(0)): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = ((object***) lenv) [1][1][2];
                                  r2[2] = r3;
                                  r3 = top[131];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L951; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_get_formals_511;
                                  L951:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = top[135];
                                  r2[2] = r3;
                                  r3 = ((object*) lenv) [2];
                                  r2[3] = r3;
                                  r3 = top[34];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L952; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
                                  L952:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[3] = r2;
                                  r2 = top[134];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L953; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_sort_fix_inits_514;
                                  L953:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case_noint (r0)) {
                                    default: {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = allocate (TC_TUPLE, 4);
                                      r1 = ((object*) lenv) [2];
                                      r0[2] = r1;
                                      r1 = ((object*) lenv) [3];
                                      r0[3] = r1;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = top[135];
                                      r2[2] = r3;
                                      r3 = ((object****) lenv) [1][1][1][3];
                                      r2[3] = r3;
                                      r3 = top[34];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L954; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
                                      L954:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = (object*)UITAG(5);
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [2];
                                      r1[3] = r2;
                                      r2 = top[120];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L955; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                                      L955:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      lenv = lenv[1];
                                      r0[4] = r1;
                                      r1 = top[124];
                                      r0[1] = r1[2]; lenv = r0; goto FUN_node_2ffix_500;
                                    } break;
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_248;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_248;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_248;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_248;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_248;
                }
                PXLL_RETURN(0);
                goto fatbar_248_over;
                fatbar_248:
                r0 = (object *) constructed_627[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              switch (get_case (r0)) {
                                case (UOTAG(0)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = ((object**) lenv) [1][3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object***) lenv) [1][1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = allocate (TC_TUPLE, 5);
                                      r1 = ((object****) lenv) [1][1][1][2];
                                      r0[2] = r1;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r2 = ((object**) lenv) [1][2];
                                      r1[2] = r2;
                                      r2 = top[131];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L956; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_get_formals_511;
                                      L956:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[3] = r1;
                                      r1 = ((object*) lenv) [2];
                                      r0[4] = r1;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = top[135];
                                      r2[2] = r3;
                                      r3 = ((object**) lenv) [1][3];
                                      r2[3] = r3;
                                      r3 = top[34];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L957; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
                                      L957:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = (object*)UITAG(5);
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [2];
                                      r1[3] = r2;
                                      r2 = top[120];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L958; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                                      L958:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      lenv = lenv[1];
                                      r0[5] = r1;
                                      r1 = top[123];
                                      r0[1] = r1[2]; lenv = r0; goto FUN_node_2ffunction_496;
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_249;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_249;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_249;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_249;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_249;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_249;
                }
                PXLL_RETURN(0);
                goto fatbar_249_over;
                fatbar_249:
                r0 = (object *) constructed_639[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [2];
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r0 = ((object**) lenv) [1][3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object***) lenv) [1][1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object***) lenv) [1][1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [2];
                                          switch (get_case (r0)) {
                                            case (UOTAG(0)): {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r0 = ((object**) lenv) [1][3];
                                              switch (get_case (r0)) {
                                                case (TC_PAIR): {
                                                  r0 = allocate (TC_TUPLE, 3);
                                                  r0[1] = lenv; lenv = r0;
                                                  r1 = ((object***) lenv) [1][1][3];
                                                  r1 = UOBJ_GET(r1,0);
                                                  r0[2] = r1;
                                                  r1 = ((object***) lenv) [1][1][3];
                                                  r1 = UOBJ_GET(r1,1);
                                                  r0[3] = r1;
                                                  r0 = ((object*) lenv) [2];
                                                  switch (get_case (r0)) {
                                                    case (UOTAG(0)): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = ((object**) lenv) [1][2];
                                                      r1 = UOBJ_GET(r1,0);
                                                      r0[2] = r1;
                                                      r0 = ((object**) lenv) [1][3];
                                                      switch (get_case (r0)) {
                                                        case (TC_PAIR): {
                                                          r0 = allocate (TC_TUPLE, 3);
                                                          r0[1] = lenv; lenv = r0;
                                                          r1 = ((object***) lenv) [1][1][3];
                                                          r1 = UOBJ_GET(r1,0);
                                                          r0[2] = r1;
                                                          r1 = ((object***) lenv) [1][1][3];
                                                          r1 = UOBJ_GET(r1,1);
                                                          r0[3] = r1;
                                                          r0 = ((object*) lenv) [3];
                                                          switch (get_case (r0)) {
                                                            case (TC_NIL): {
                                                              r0 = allocate (TC_TUPLE, 7);
                                                              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                                                              r0[2] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = top[88];
                                                              r1[2] = r2;
                                                              r2 = ((object******) lenv) [1][1][1][1][1][2];
                                                              r1[3] = r2;
                                                              r2 = top[34];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L959; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                                                              L959:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[3] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = top[89];
                                                              r1[2] = r2;
                                                              r2 = ((object****) lenv) [1][1][1][2];
                                                              r1[3] = r2;
                                                              r2 = top[34];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L960; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                                                              L960:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[4] = r1;
                                                              r1 = allocate (TC_TUPLE, 2);
                                                              r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                              r1[2] = r2;
                                                              r2 = top[135];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L961; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                                              L961:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[5] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = top[135];
                                                              r1[2] = r2;
                                                              r2 = ((object**) lenv) [1][2];
                                                              r1[3] = r2;
                                                              r2 = top[34];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L962; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                                                              L962:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[6] = r1;
                                                              r1 = allocate (TC_TUPLE, 2);
                                                              r2 = ((object*) lenv) [2];
                                                              r1[2] = r2;
                                                              r2 = top[135];
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L963; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                                              L963:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[7] = r1;
                                                              r1 = top[126];
                                                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2fnvcase_502;
                                                            } break;
                                                            default: {
                                                              lenv = ((object **********)lenv)[1][1][1][1][1][1][1][1][1][1];
                                                              goto fatbar_250;
                                                            }
                                                          }
                                                          PXLL_RETURN(0);
                                                        } break;
                                                        default: {
                                                          lenv = ((object *********)lenv)[1][1][1][1][1][1][1][1][1];
                                                          goto fatbar_250;
                                                        }
                                                      }
                                                      PXLL_RETURN(0);
                                                    } break;
                                                    default: {
                                                      lenv = ((object ********)lenv)[1][1][1][1][1][1][1][1];
                                                      goto fatbar_250;
                                                    }
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                  goto fatbar_250;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_250;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_250;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_250;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_250;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_250;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_250;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_250;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_250;
                }
                PXLL_RETURN(0);
                goto fatbar_250_over;
                fatbar_250:
                r0 = (object *) constructed_641[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object***) lenv) [1][1][2];
                              r1[2] = r2;
                              r2 = top[133];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L964; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_parse_cexp_sig_513;
                              L964:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case_noint (r0)) {
                                default: {
                                  r0 = allocate (TC_TUPLE, 4);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = top[135];
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r1[3] = r2;
                                  r2 = top[34];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L965; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                                  L965:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object*) lenv) [3];
                                  r2 = ((object**) lenv) [1][2];
                                  r3 = ((object*) lenv) [2];
                                  t = alloc_no_clear (UOTAG(3),3);
                                  t[1] = r3;
                                  t[2] = r1;
                                  t[3] = r2;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [4];
                                  r0[3] = r1;
                                  r1 = top[120];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                                } break;
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_251;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_251;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_251;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_251;
                }
                PXLL_RETURN(0);
                goto fatbar_251_over;
                fatbar_251:
                r0 = (object *) constructed_621[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object***) lenv) [1][1][2];
                                  r1[2] = r2;
                                  r2 = top[135];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L966; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L966:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[135];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L967; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L967:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = top[135];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L968; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L968:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = top[122];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_node_2fif_495;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_252;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_252;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_252;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_252;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_252;
                }
                PXLL_RETURN(0);
                goto fatbar_252_over;
                fatbar_252:
                r0 = (object *) constructed_903[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[137];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L969; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
                          L969:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(2),1);
                          t[1] = r1;
                          r1 = t;
                          r0[2] = r1;
                          r1 = (object *) constructed_846[0];
                          r0[3] = r1;
                          r1 = top[120];
                          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_253;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_253;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_253;
                }
                PXLL_RETURN(0);
                goto fatbar_253_over;
                fatbar_253:
                r0 = (object *) constructed_905[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = ((object**) lenv) [1][2];
                          r1[2] = r2;
                          r2 = top[137];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L970; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
                          L970:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = ((object*) lenv) [2];
                          t = alloc_no_clear (UOTAG(2),1);
                          t[1] = r1;
                          r1 = t;
                          r0[2] = r1;
                          r1 = (object *) constructed_846[0];
                          r0[3] = r1;
                          r1 = top[120];
                          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_254;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_254;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_254;
                }
                PXLL_RETURN(0);
                goto fatbar_254_over;
                fatbar_254:
                r0 = (object *) constructed_623[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object***) lenv) [1][1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = top[135];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L971; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L971:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object***) lenv) [1][1][2];
                                  t = alloc_no_clear (UOTAG(1),1);
                                  t[1] = r1;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = (object*)TC_NIL;
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  r2 = ((object**) lenv) [1][2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  lenv = lenv[1];
                                  r0[3] = r1;
                                  r1 = top[120];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_255;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_255;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_255;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_255;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_255;
                }
                PXLL_RETURN(0);
                goto fatbar_255_over;
                fatbar_255:
                r0 = (object *) constructed_625[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[135];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L972; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L972:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(5);
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[3] = r1;
                  r1 = top[120];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_244;
                }
                PXLL_RETURN(0);
                fatbar_255_over: ;
                PXLL_RETURN(0);
                fatbar_254_over: ;
                PXLL_RETURN(0);
                fatbar_253_over: ;
                PXLL_RETURN(0);
                fatbar_252_over: ;
                PXLL_RETURN(0);
                fatbar_251_over: ;
                PXLL_RETURN(0);
                fatbar_250_over: ;
                PXLL_RETURN(0);
                fatbar_249_over: ;
                PXLL_RETURN(0);
                fatbar_248_over: ;
                PXLL_RETURN(0);
                fatbar_247_over: ;
                PXLL_RETURN(0);
                fatbar_246_over: ;
                PXLL_RETURN(0);
                fatbar_245_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_244;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_244_over;
            fatbar_244:
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object***) lenv) [1][1][2];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                lenv = lenv[1];
                r0[2] = r1;
                r1 = (object *) 1;
                r2 = ((object*) lenv) [2];
                range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
                r1 = (object *) 1;
                r2 = ((object*) lenv) [2];
                r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
                r0[3] = r1;
                r0 = (object *) 9474;
                r1 = ((object*) lenv) [3];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                if PXLL_IS_TRUE(r0) {
                  r0 = ((object**) lenv) [1][3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object***) lenv) [1][1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = top[135];
                      r1[2] = r2;
                      r2 = ((object*) lenv) [3];
                      r1[3] = r2;
                      r2 = top[34];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L973; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                      L973:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = ((object*) lenv) [2];
                      r2 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (UOTAG(12),2);
                      t[1] = r2;
                      t[2] = r1;
                      r1 = t;
                      r0[2] = r1;
                      r1 = ((object*) lenv) [4];
                      r0[3] = r1;
                      r1 = top[120];
                      r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                    } break;
                    default: {
                      goto fatbar_257;
                    }
                  }
                  PXLL_RETURN(0);
                  goto fatbar_257_over;
                  fatbar_257:
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*) &constructed_906;
                  r0[2] = r1;
                  r1 = ((object***) lenv) [1][1][2];
                  r0[3] = r1;
                  r1 = top[15];
                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                  fatbar_257_over: ;
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***) lenv) [1][1][2];
                  r1[2] = r2;
                  r2 = top[135];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L974; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                  L974:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[135];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L975; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L975:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  r2 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(8);
                  r0[2] = r1;
                  r1 = ((object*) lenv) [4];
                  r0[3] = r1;
                  r1 = top[120];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                }
                PXLL_RETURN(0);
              } break;
              case (UOTAG(9)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_49[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 9);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***) lenv) [1][1][3];
                  r1[2] = r2;
                  r2 = top[24];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L976; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                  L976:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  t = alloc_no_clear (UOTAG(5),1);
                  t[1] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r1 = (object*)TC_NIL;
                  r0[5] = r1;
                  r1 = ((object*) lenv) [5];
                  r2 = ((object*) lenv) [4];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[6] = r1;
                  r1 = ((object*) lenv) [6];
                  r2 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[7] = r1;
                  r1 = ((object*) lenv) [7];
                  t = alloc_no_clear (UOTAG(0),1);
                  t[1] = r1;
                  r1 = t;
                  r0[8] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[135];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L977; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L977:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[9] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [8];
                  r2 = (object *) constructed_505[0];
                  t = alloc_no_clear (UOTAG(12),2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [9];
                  r0[3] = r1;
                  r1 = top[120];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***) lenv) [1][1][2];
                  r1[2] = r2;
                  r2 = top[135];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L978; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                  L978:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[135];
                  r1[2] = r2;
                  r2 = ((object***) lenv) [1][1][3];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L979; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L979:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = ((object*) lenv) [3];
                  r2 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(8);
                  r0[2] = r1;
                  r1 = ((object*) lenv) [4];
                  r0[3] = r1;
                  r1 = top[120];
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_256;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_256_over;
            fatbar_256:
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[135];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L980; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
            L980:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = top[135];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = top[34];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L981; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
            L981:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object*) lenv) [3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*)UITAG(8);
            r0[2] = r1;
            r1 = ((object*) lenv) [4];
            r0[3] = r1;
            r1 = top[120];
            r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
            fatbar_256_over: ;
            PXLL_RETURN(0);
            fatbar_244_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_243;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_243_over;
        fatbar_243:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_907;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
        fatbar_243_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_242_over;
    fatbar_242:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_908;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_242_over: ;
    PXLL_RETURN(0);
  L934:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_walk_515; r1[2] = lenv;
  r0[135] = r1;
  // def build-list-literal_516
  goto L982;
  FUN_build_list_literal_516:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = top[137];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = top[34];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L983; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
            L983:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [4];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(5),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_241;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_241_over;
        fatbar_241:
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = top[137];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L984; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
        L984:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][3];
        r1[2] = r2;
        r2 = top[136];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L985; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_list_literal_516;
        L985:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = (object*)TC_NIL;
        r0[4] = r1;
        r1 = ((object*) lenv) [4];
        r2 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r0 = (object *) constructed_61[0];
        r1 = ((object*) lenv) [6];
        r2 = (object *) constructed_51[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_241_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) constructed_49[0];
        r1 = (object *) constructed_894[0];
        r2 = (object *) constructed_51[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L982:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_list_literal_516; r1[2] = lenv;
  r0[136] = r1;
  // def build-literal_517
  goto L986;
  FUN_build_literal_517:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = (object*)UITAG(3);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[136];
        r0[1] = r1[2]; lenv = r0; goto FUN_build_list_literal_516;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = top[137];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L987; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L987:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(6),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_240;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_240_over;
    fatbar_240:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_893;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_240_over: ;
    PXLL_RETURN(0);
  L986:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_literal_517; r1[2] = lenv;
  r0[137] = r1;
  // def make-vardef_519
  goto L988;
  FUN_make_vardef_519:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 6);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][2];
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = ((object****) lenv) [1][1][1][2];
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = ((object*) lenv) [2];
    lenv = lenv[1];
    r3[2] = r4;
    r4 = allocate (TC_TUPLE, 2);
    r5 = ((object***) lenv) [1][1][3];
    r4[2] = r5;
    r5 = top[58];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L989; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
    L989:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[3] = r4;
    r4 = (object*)TC_NIL;
    r3[4] = r4;
    r4 = ((object*) lenv) [4];
    r5 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[5] = r4;
    r4 = ((object*) lenv) [5];
    r5 = (object*) &constructed_892;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[6] = r4;
    r3 = ((object*) lenv) [6];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    lenv = lenv[1];
    r2[2] = r3;
    r3 = top[49];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L990; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
    L990:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = top[82];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L991; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
    L991:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (UOTAG(19), 5);
    r1 = (object *) constructed_891[0];
    r0[1] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = (object *) constructed_890[0];
    r0[4] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[5] = r1;
    PXLL_RETURN(0);
  L988:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_vardef_519; r1[2] = lenv;
  r0[138] = r1;
  // def k/free_525
  goto L992;
  FUN_k_2ffree_525:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_889;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_889;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L992:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_k_2ffree_525; r1[2] = lenv;
  r0[139] = r1;
  // def k/target_526
  goto L993;
  FUN_k_2ftarget_526:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_888;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_888;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L993:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_k_2ftarget_526; r1[2] = lenv;
  r0[140] = r1;
  // def print-insn_529
  goto L994;
  FUN_print_insn_529:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def mprint-insn_3114
    goto L995;
    FUN_mprint_insn_3114:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = top[141];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
        } break;
        default: {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L995:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_mprint_insn_3114; r1[2] = lenv;
    r0[2] = r1;
    // def print-line_3115
    goto L996;
    FUN_print_line_3115:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = top[161];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L997; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L997:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r1 = top[94];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L998; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
          L998:
          ; lenv = k[2]; k = k[1];
          r0 = (object *) -1;
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object*) &constructed_886;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_886;
            r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          } else {
            r0 = ((object*) lenv) [2];
            r0 = dump_object (r0, 0);
          }
          r0 = (object*) &constructed_885;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_885;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object**) lenv) [1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L999; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L999:
          ; lenv = k[2]; k = k[1];
          r0 = ((object****) lenv) [1][1][1][3];
          r1 = ((object*) lenv) [4];
          lenv = ((object ***)lenv)[1][1][1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_print_insn_529;
        } break;
        default: {
          r0 = top[161];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1000; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L1000:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object***) lenv) [1][1][3];
          r0[2] = r1;
          r1 = top[94];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1001; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
          L1001:
          ; lenv = k[2]; k = k[1];
          r0 = (object*) &constructed_887;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_887;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          lenv = r0[2]; goto *r0[1];
        } break;
      }
      PXLL_RETURN(0);
    L996:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_print_line_3115; r1[2] = lenv;
    r0[3] = r1;
    r0 = ((object**) lenv) [1][2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = top[161];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1002; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L1002:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object***) lenv) [1][1][3];
        r0[2] = r1;
        r1 = top[94];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1003; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
        L1003:
        ; lenv = k[2]; k = k[1];
        r0 = (object*) &constructed_860;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_860;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_859;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_859;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = ((object*) lenv) [2];
        r0 = dump_object (r0, 0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(14)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19848
        goto L1004;
        FUN_lambda_19848:
          r0 = (object*) &constructed_862;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_862;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1004:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19848; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(15)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19878
        goto L1005;
        FUN_lambda_19878:
          r0 = (object*) &constructed_863;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_863;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1005:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19878; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19902
        goto L1006;
        FUN_lambda_19902:
          check_heap (0);
          r0 = (object*) &constructed_864;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_864;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[128];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1007; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_literal__3estring_507;
          L1007:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1006:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19902; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19927
        goto L1008;
        FUN_lambda_19927:
          r0 = (object*) &constructed_865;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_865;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1008:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19927; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_19967
        goto L1009;
        FUN_lambda_19967:
          check_heap (0);
          r0 = (object*) &constructed_866;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_866;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[109];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1010; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
          L1010:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[109];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1011; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
          L1011:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [5];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1009:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_19967; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [6];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20008
        goto L1012;
        FUN_lambda_20008:
          check_heap (0);
          r0 = (object*) &constructed_867;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_867;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[141];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1013; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
          L1013:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[141];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
        L1012:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20008; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(6)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20030
        goto L1014;
        FUN_lambda_20030:
          r0 = (object*) &constructed_868;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_868;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          r0 = dump_object (r0, 0);
          PXLL_RETURN(0);
        L1014:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20030; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20060
        goto L1015;
        FUN_lambda_20060:
          check_heap (0);
          r0 = (object*) &constructed_869;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_869;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[141];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
        L1015:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20060; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20086
        goto L1016;
        FUN_lambda_20086:
          r0 = (object*) &constructed_870;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_870;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1016:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20086; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20117
        goto L1017;
        FUN_lambda_20117:
          r0 = (object*) &constructed_871;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_871;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1017:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20117; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20154
        goto L1018;
        FUN_lambda_20154:
          r0 = (object*) &constructed_872;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_872;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [5];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1018:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20154; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [6];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(13)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20187
        goto L1019;
        FUN_lambda_20187:
          r0 = (object*) &constructed_873;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_873;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1019:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20187; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20214
        goto L1020;
        FUN_lambda_20214:
          r0 = (object*) &constructed_874;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_874;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1020:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20214; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(11)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20240
        goto L1021;
        FUN_lambda_20240:
          r0 = (object*) &constructed_875;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_875;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1021:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20240; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(16)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20261
        goto L1022;
        FUN_lambda_20261:
          r0 = (object*) &constructed_876;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_876;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1022:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20261; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(17)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20281
        goto L1023;
        FUN_lambda_20281:
          r0 = (object*) &constructed_877;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_877;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1023:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20281; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(18)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20320
        goto L1024;
        FUN_lambda_20320:
          check_heap (0);
          r0 = (object*) &constructed_878;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_878;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[93];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1025; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
          L1025:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = top[109];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1026; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
          L1026:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = ((object*) lenv) [5];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1024:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20320; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [6];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(19)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20348
        goto L1027;
        FUN_lambda_20348:
          r0 = (object*) &constructed_879;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_879;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1027:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20348; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(20)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20387
        goto L1028;
        FUN_lambda_20387:
          check_heap (0);
          r0 = (object*) &constructed_880;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_880;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[141];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1029; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
          L1029:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [4];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[141];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
        L1028:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20387; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [5];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(21)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20412
        goto L1030;
        FUN_lambda_20412:
          r0 = (object*) &constructed_881;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_881;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L1030:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20412; r1[2] = lenv;
        r0[2] = r1;
        r1 = (object*)UITAG(1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,5);
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20463
        goto L1031;
        FUN_lambda_20463:
          check_heap (0);
          r0 = (object*) &constructed_882;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_882;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[109];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1032; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
          L1032:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = ((object*) lenv) [2];
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [5];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[141];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1033; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
          L1033:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [6];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = top[141];
          r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
        L1031:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20463; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      case (UOTAG(22)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,5);
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20520
        goto L1034;
        FUN_lambda_20520:
          check_heap (0);
          r0 = (object*) &constructed_883;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_883;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_20508
          goto L1035;
          FUN_lambda_20508:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = (object *) 3;
            r2 = ((object****) lenv) [1][1][1][3];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r0[3] = r1;
            r1 = top[141];
            r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
          L1035:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_20508; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [5];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1036; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L1036:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [6];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_mprint_insn_3114;
        L1034:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20520; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,4);
        r0[6] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = UOBJ_GET(r1,5);
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_20577
        goto L1037;
        FUN_lambda_20577:
          check_heap (0);
          r0 = (object*) &constructed_884;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_884;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_859;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_859;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [2];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [3];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = ((object*) lenv) [4];
          dump_object (r0, 0);
          r0 = (object*) &constructed_861;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_861;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_20565
          goto L1038;
          FUN_lambda_20565:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = (object *) 3;
            r2 = ((object****) lenv) [1][1][1][3];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r0[3] = r1;
            r1 = top[141];
            r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
          L1038:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_20565; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [5];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1039; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L1039:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [6];
          r0[2] = r1;
          r1 = (object *) 3;
          r2 = ((object***) lenv) [1][1][3];
          r1 = box((pxll_int)unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_mprint_insn_3114;
        L1037:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_20577; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [7];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_print_line_3115;
      } break;
    }
    PXLL_RETURN(0);
  L994:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_print_insn_529; r1[2] = lenv;
  r0[141] = r1;
  // def unify_533
  goto L1040;
  FUN_unify_533:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def type-error_3276
    goto L1041;
    FUN_type_error_3276:
      check_heap (0);
      r0 = top[161];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1042; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L1042:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object***) lenv) [1][1][2];
      r0[2] = r1;
      r1 = top[130];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1043; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_pp_node_510;
      L1043:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[143];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1044; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_534;
      L1044:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = top[143];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1045; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_534;
      L1045:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][2];
      r3[2] = r4;
      r4 = top[109];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1046; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
      L1046:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][3];
      r3[2] = r4;
      r4 = top[109];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1047; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
      L1047:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_858;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_857;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_856;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1048; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L1048:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      lenv = lenv[1];
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_855;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_855;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
    L1041:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_type_error_3276; r1[2] = lenv;
    r0[2] = r1;
    // def U_3277
    goto L1049;
    FUN__55_3277:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_21227
      goto L1050;
      FUN_lambda_21227:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        // def lambda_21041
        goto L1051;
        FUN_lambda_21041:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[18];
          r0[1] = r1[2]; lenv = r0; goto FUN_throw_299;
        L1051:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_21041; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = top[111];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1052; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
        L1052:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r1[2] = r2;
        r2 = top[111];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1053; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
        L1053:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r2 = ((object**) lenv) [1][3];
        r1 = PXLL_TEST(r2==r1);
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = (object *) 14;
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object**) lenv) [1][4];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = (object *) 14;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object***) lenv) [1][1][4];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object***) lenv) [1][1][4];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = (object *) constructed_854[0];
                  r1 = ((object**) lenv) [1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = (object *) constructed_854[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = (object *) 14;
                    } else {
                      goto fatbar_234;
                    }
                    goto fatbar_234_over;
                    fatbar_234:
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = ((object**) lenv) [1][3];
                    r2[2] = r3;
                    r3 = top[21];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1054; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
                    L1054:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][4];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1055; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_3277;
                    L1055:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1056; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1056:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    fatbar_234_over: ;
                  } else {
                    goto fatbar_233;
                  }
                  goto fatbar_233_over;
                  fatbar_233:
                  r0 = (object *) constructed_854[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = ((object*) lenv) [3];
                    r2[2] = r3;
                    r3 = top[21];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1057; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
                    L1057:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][3];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1058; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_3277;
                    L1058:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1059; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1059:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    goto fatbar_235;
                  }
                  goto fatbar_235_over;
                  fatbar_235:
                  r0 = (object *) constructed_528[0];
                  r1 = ((object**) lenv) [1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][3];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][4];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1060; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3279;
                    L1060:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1061; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1061:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    goto fatbar_236;
                  }
                  goto fatbar_236_over;
                  fatbar_236:
                  r0 = (object *) constructed_528[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][4];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][3];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1062; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3279;
                    L1062:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1063; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1063:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    goto fatbar_237;
                  }
                  goto fatbar_237_over;
                  fatbar_237:
                  r0 = (object *) constructed_583[0];
                  r1 = ((object**) lenv) [1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][3];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][4];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1064; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3279;
                    L1064:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1065; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1065:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    goto fatbar_238;
                  }
                  goto fatbar_238_over;
                  fatbar_238:
                  r0 = (object *) constructed_583[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object***) lenv) [1][1][4];
                    r1[2] = r2;
                    r2 = ((object***) lenv) [1][1][3];
                    r1[3] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][4];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1066; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3279;
                    L1066:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object***) lenv) [1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1067; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1067:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    goto fatbar_239;
                  }
                  goto fatbar_239_over;
                  fatbar_239:
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r2 = ((object***) lenv) [1][1][2];
                  r1 = PXLL_TEST(r2==r1);
                  r0[2] = r1;
                  r0 = (object *) 6;
                  r1 = ((object*) lenv) [2];
                  r0 = PXLL_TEST(r1==r0);
                  lenv = lenv[1];
                  if PXLL_IS_TRUE(r0) {
                    r0 = (object *) 262;
                  } else {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object***) lenv) [1][1][3];
                    r1[2] = r2;
                    r2 = top[24];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1068; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                    L1068:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][3];
                    r1[2] = r2;
                    r2 = top[24];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1069; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                    L1069:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = ((object*) lenv) [3];
                    r2 = ((object*) lenv) [2];
                    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                    r0[4] = r1;
                    r0 = (object *) 6;
                    r1 = ((object*) lenv) [4];
                    r0 = PXLL_TEST(r1==r0);
                    lenv = lenv[1];
                  }
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = ((object*****) lenv) [1][1][1][1][2];
                    r0[2] = r1;
                    r1 = ((object*****) lenv) [1][1][1][1][3];
                    r0[3] = r1;
                    r1 = ((object******) lenv) [1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1070; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_type_error_3276;
                    L1070:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    r0 = (object *) 14;
                  }
                  fatbar_239_over: ;
                  fatbar_238_over: ;
                  fatbar_237_over: ;
                  fatbar_236_over: ;
                  fatbar_235_over: ;
                  fatbar_233_over: ;
                  lenv = lenv[1];
                } break;
              }
              lenv = lenv[1];
            } break;
          }
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r0[3] = r1;
          r1 = top[112];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1071; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_type_union_468;
          L1071:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[2] = r1;
              r0 = ((object**) lenv) [1][4];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object***) lenv) [1][1][4];
                  r1 = UOBJ_GET(r1,1);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r0[3] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[4] = r1;
                  r1 = top[38];
                  r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_332;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_232;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_232;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_232_over;
          fatbar_232:
          r0 = (object *) 14;
          PXLL_RETURN(0);
          fatbar_232_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L1050:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_21227; r1[2] = lenv;
      r0[2] = r1;
      r1 = top[17];
      r0[1] = r1[2]; lenv = r0; goto FUN_callcc_298;
    L1049:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__55_3277; r1[2] = lenv;
    r0[3] = r1;
    // def U-row_3279
    goto L1072;
    FUN__55_row_3279:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_583[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = ((object***) lenv) [1][1][3];
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object****) lenv) [1][1][1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object****) lenv) [1][1][1][3];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = (object *) constructed_583[0];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object***) lenv) [1][1][2];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_229;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_229;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_229;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_229_over;
                        fatbar_229:
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object**) lenv) [1][3];
                        r1[2] = r2;
                        r2 = top[24];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1073; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                        L1073:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        // def $loop_3313
                        goto L1074;
                        FUN__24loop_3313:
                          check_heap (0);
                          r0 = ((object***) lenv) [1][1][3];
                          r1 = ((object*) lenv) [2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = ((object*) lenv) [3];
                            r0[2] = r1;
                            r1 = (object *) constructed_36[0];
                            r0[3] = r1;
                            r1 = top[23];
                            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
                          } else {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = top[107];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1075; t[4] = r0; k = t;
                            lenv = r1[2]; goto FUN_new_tvar_455;
                            L1075:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r0 = ((object**) lenv) [1][3];
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            lenv = lenv[1];
                            r1 = (object *) 3;
                            r2 = ((object*) lenv) [2];
                            r1 = box((pxll_int)unbox(r2)+unbox(r1));
                            lenv[2] = r1;
                            lenv[3] = r0;
                            goto FUN__24loop_3313;
                          }
                          PXLL_RETURN(0);
                        L1074:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN__24loop_3313; r2[2] = lenv;
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object *) 1;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1076; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3313;
                        L1076:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        lenv = lenv[1];
                        r0[4] = r1;
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object***) lenv) [1][1][2];
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object**) lenv) [1][2];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [4];
                        r1[3] = r2;
                        r2 = top[106];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1077; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                        L1077:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = ((object******) lenv) [1][1][1][1][1][3];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1078; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                        L1078:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        // def $loop_3318
                        goto L1079;
                        FUN__24loop_3318:
                          check_heap (0);
                          r0 = ((object***) lenv) [1][1][2];
                          r1 = ((object*) lenv) [2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = (object *) 14;
                            PXLL_RETURN(0);
                          } else {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object*****) lenv) [1][1][1][1][3];
                            r1[2] = r2;
                            r2 = ((object*) lenv) [2];
                            r1[3] = r2;
                            r2 = top[29];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1080; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                            L1080:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = allocate (TC_TUPLE, 3);
                            r3 = ((object*****) lenv) [1][1][1][1][4];
                            r2[2] = r3;
                            r3 = ((object**) lenv) [1][2];
                            r2[3] = r3;
                            r3 = top[29];
                            t = allocate (TC_SAVE, 5);
                            t[1] = k; t[2] = lenv; t[3] = &&L1081; t[4] = r0; t[5] = r1; k = t;
                            r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                            L1081:
                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                            r2 = result;
                            r1[2] = r2;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = (object *) constructed_583[0];
                            r1[2] = r2;
                            r2 = allocate (TC_TUPLE, 2);
                            r2[1] = lenv; lenv = r2;
                            r3 = (object*)TC_NIL;
                            r2[2] = r3;
                            r2 = ((object*) lenv) [2];
                            r3 = ((object**) lenv) [1][2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r3;
                            t[2] = r2;
                            r2 = t;
                            lenv = lenv[1];
                            r1[3] = r2;
                            r2 = top[106];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1082; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                            L1082:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            lenv = lenv[1];
                            r0[3] = r1;
                            r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L1083; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                            L1083:
                            ; lenv = k[2]; k = k[1];
                            r0 = (object *) 3;
                            r1 = ((object*) lenv) [2];
                            r0 = box((pxll_int)unbox(r1)+unbox(r0));
                            lenv[2] = r0;
                            goto FUN__24loop_3318;
                          }
                          PXLL_RETURN(0);
                        L1079:
                        r1 = allocate (TC_CLOSURE, 2);
                        r1[1] = &&FUN__24loop_3318; r1[2] = lenv;
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = (object *) 1;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3318;
                        fatbar_229_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_228;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_228;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_228;
              }
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_228;
          }
          PXLL_RETURN(0);
          goto fatbar_228_over;
          fatbar_228:
          r0 = (object *) constructed_528[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][3];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = ((object*****) lenv) [1][1][1][1][3];
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object******) lenv) [1][1][1][1][1][3];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = ((object******) lenv) [1][1][1][1][1][3];
                                r1 = UOBJ_GET(r1,1);
                                r0[3] = r1;
                                r0 = (object *) constructed_528[0];
                                r1 = ((object*) lenv) [2];
                                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [3];
                                          switch (get_case (r0)) {
                                            case (TC_PAIR): {
                                              r0 = allocate (TC_TUPLE, 3);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][3];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r1 = ((object**) lenv) [1][3];
                                              r1 = UOBJ_GET(r1,1);
                                              r0[3] = r1;
                                              r0 = ((object*) lenv) [3];
                                              switch (get_case (r0)) {
                                                case (TC_NIL): {
                                                  r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                  switch (get_case (r0)) {
                                                    case (UOTAG(1)): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                      r1 = UOBJ_GET(r1,0);
                                                      r0[2] = r1;
                                                      r0 = ((object****) lenv) [1][1][1][2];
                                                      switch (get_case (r0)) {
                                                        case (UOTAG(1)): {
                                                          r0 = allocate (TC_TUPLE, 2);
                                                          r0[1] = lenv; lenv = r0;
                                                          r1 = ((object*****) lenv) [1][1][1][1][2];
                                                          r1 = UOBJ_GET(r1,0);
                                                          r0[2] = r1;
                                                          r0 = ((object*) lenv) [2];
                                                          r1 = ((object**) lenv) [1][2];
                                                          r0 = PXLL_TEST(r1==r0);
                                                          lenv = lenv[1];
                                                        } break;
                                                        default: {
                                                          lenv = ((object *)lenv)[1];
                                                          goto fatbar_231;
                                                        }
                                                      }
                                                      lenv = lenv[1];
                                                    } break;
                                                    default: {
                                                      goto fatbar_231;
                                                    }
                                                  }
                                                  goto fatbar_231_over;
                                                  fatbar_231:
                                                  r0 = (object *) 6;
                                                  fatbar_231_over: ;
                                                  if PXLL_IS_TRUE(r0) {
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object******) lenv) [1][1][1][1][1][2];
                                                    r0[2] = r1;
                                                    r1 = ((object**) lenv) [1][2];
                                                    r0[3] = r1;
                                                    r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                                                    t = allocate (TC_SAVE, 3);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1084; ; k = t;
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                                    L1084:
                                                    ; lenv = k[2]; k = k[1];
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object*****) lenv) [1][1][1][1][2];
                                                    r0[2] = r1;
                                                    r1 = ((object*) lenv) [2];
                                                    r0[3] = r1;
                                                    r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                                  } else {
                                                    r0 = allocate (TC_TUPLE, 2);
                                                    r0[1] = lenv; lenv = r0;
                                                    r1 = top[107];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1085; t[4] = r0; k = t;
                                                    lenv = r1[2]; goto FUN_new_tvar_455;
                                                    L1085:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[2] = r1;
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object******) lenv) [1][1][1][1][1][2];
                                                    r0[2] = r1;
                                                    r1 = allocate (TC_TUPLE, 4);
                                                    r2 = ((object****) lenv) [1][1][1][2];
                                                    r1[2] = r2;
                                                    r2 = ((object***) lenv) [1][1][2];
                                                    r1[3] = r2;
                                                    r2 = ((object*) lenv) [2];
                                                    r1[4] = r2;
                                                    r2 = top[108];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1086; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_460;
                                                    L1086:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[3] = r1;
                                                    r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                                                    t = allocate (TC_SAVE, 3);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1087; ; k = t;
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                                    L1087:
                                                    ; lenv = k[2]; k = k[1];
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = ((object**) lenv) [1][2];
                                                    r0[2] = r1;
                                                    r1 = allocate (TC_TUPLE, 4);
                                                    r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                    r1[2] = r2;
                                                    r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                    r1[3] = r2;
                                                    r2 = ((object*) lenv) [2];
                                                    r1[4] = r2;
                                                    r2 = top[108];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1088; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_460;
                                                    L1088:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[3] = r1;
                                                    r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object ***)lenv)[1][1][1];
                                                  goto fatbar_230;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_230;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_230;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      goto fatbar_230;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } else {
                                  goto fatbar_230;
                                }
                                PXLL_RETURN(0);
                                goto fatbar_230_over;
                                fatbar_230:
                                r0 = (object *) constructed_583[0];
                                r1 = ((object*) lenv) [2];
                                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = top[21];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1089; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
                                  L1089:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object***) lenv) [1][1][2];
                                  r0[3] = r1;
                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1090; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                  L1090:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][2];
                                  r0[3] = r1;
                                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                } else {
                                  r0 = allocate (TC_TUPLE, 6);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object**) lenv) [1][3];
                                  r1[2] = r2;
                                  r2 = top[24];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1091; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                                  L1091:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  // def $loop_3337
                                  goto L1092;
                                  FUN__24loop_3337:
                                    check_heap (0);
                                    r0 = ((object***) lenv) [1][1][3];
                                    r1 = ((object*) lenv) [2];
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = ((object*) lenv) [3];
                                      r0[2] = r1;
                                      r1 = (object *) constructed_36[0];
                                      r0[3] = r1;
                                      r1 = top[23];
                                      r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = top[107];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1093; t[4] = r0; k = t;
                                      lenv = r1[2]; goto FUN_new_tvar_455;
                                      L1093:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r0 = ((object**) lenv) [1][3];
                                      r1 = ((object*) lenv) [2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r1;
                                      t[2] = r0;
                                      r0 = t;
                                      lenv = lenv[1];
                                      r1 = (object *) 3;
                                      r2 = ((object*) lenv) [2];
                                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN__24loop_3337;
                                    }
                                    PXLL_RETURN(0);
                                  L1092:
                                  r2 = allocate (TC_CLOSURE, 2);
                                  r2[1] = &&FUN__24loop_3337; r2[2] = lenv;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object *) 1;
                                  r1[2] = r2;
                                  r2 = (object*)TC_NIL;
                                  r1[3] = r2;
                                  r2 = ((object*) lenv) [2];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1094; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3337;
                                  L1094:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  lenv = lenv[1];
                                  r0[4] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[5] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  // def $loop_3342
                                  goto L1095;
                                  FUN__24loop_3342:
                                    check_heap (0);
                                    r0 = ((object***) lenv) [1][1][5];
                                    r1 = ((object*) lenv) [2];
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = ((object*) lenv) [3];
                                      r0[2] = r1;
                                      r1 = (object *) constructed_36[0];
                                      r0[3] = r1;
                                      r1 = top[23];
                                      r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = top[107];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1096; t[4] = r0; k = t;
                                      lenv = r1[2]; goto FUN_new_tvar_455;
                                      L1096:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r0 = ((object**) lenv) [1][3];
                                      r1 = ((object*) lenv) [2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r1;
                                      t[2] = r0;
                                      r0 = t;
                                      lenv = lenv[1];
                                      r1 = (object *) 3;
                                      r2 = ((object*) lenv) [2];
                                      r1 = box((pxll_int)unbox(r2)+unbox(r1));
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN__24loop_3342;
                                    }
                                    PXLL_RETURN(0);
                                  L1095:
                                  r2 = allocate (TC_CLOSURE, 2);
                                  r2[1] = &&FUN__24loop_3342; r2[2] = lenv;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object *) 1;
                                  r1[2] = r2;
                                  r2 = (object*)TC_NIL;
                                  r1[3] = r2;
                                  r2 = ((object*) lenv) [2];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1097; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3342;
                                  L1097:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  lenv = lenv[1];
                                  r0[6] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [4];
                                  r1[3] = r2;
                                  r2 = top[106];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1098; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1098:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object****) lenv) [1][1][1][2];
                                  r0[3] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1099; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                  L1099:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [6];
                                  r1[3] = r2;
                                  r2 = top[106];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1100; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1100:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = ((object***) lenv) [1][1][2];
                                  r0[3] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1101; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                  L1101:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object**) lenv) [1][2];
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  // def $loop_3347
                                  goto L1102;
                                  FUN__24loop_3347:
                                    check_heap (0);
                                    r0 = ((object***) lenv) [1][1][2];
                                    r1 = ((object*) lenv) [2];
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = (object *) 14;
                                      PXLL_RETURN(0);
                                    } else {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = ((object*****) lenv) [1][1][1][1][3];
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [2];
                                      r1[3] = r2;
                                      r2 = top[29];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1103; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                                      L1103:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = allocate (TC_TUPLE, 4);
                                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                      r1[2] = r2;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = ((object****) lenv) [1][1][1][4];
                                      r2[2] = r3;
                                      r3 = ((object*) lenv) [2];
                                      r2[3] = r3;
                                      r3 = top[29];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1104; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                                      L1104:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[3] = r2;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = ((object****) lenv) [1][1][1][6];
                                      r2[2] = r3;
                                      r3 = ((object*) lenv) [2];
                                      r2[3] = r3;
                                      r3 = top[29];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1105; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                                      L1105:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[4] = r2;
                                      r2 = top[108];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1106; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_460;
                                      L1106:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[3] = r1;
                                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1107; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
                                      L1107:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = (object *) 3;
                                      r1 = ((object*) lenv) [2];
                                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                                      lenv[2] = r0;
                                      goto FUN__24loop_3347;
                                    }
                                    PXLL_RETURN(0);
                                  L1102:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN__24loop_3347; r1[2] = lenv;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = (object *) 1;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3347;
                                }
                                PXLL_RETURN(0);
                                fatbar_230_over: ;
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                lenv = ((object ****)lenv)[1][1][1][1];
                                goto fatbar_227;
                              }
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object ****)lenv)[1][1][1][1];
                            goto fatbar_227;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_227;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_227;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_227;
              }
            }
            PXLL_RETURN(0);
          } else {
            lenv = ((object *)lenv)[1];
            goto fatbar_227;
          }
          PXLL_RETURN(0);
          fatbar_228_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_227;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_227_over;
      fatbar_227:
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r0[1] = r1[2]; lenv = r0; goto FUN_type_error_3276;
      fatbar_227_over: ;
      PXLL_RETURN(0);
    L1072:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__55_row_3279; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][3];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][4];
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r0[1] = r1[2]; lenv = r0; goto FUN__55_3277;
  L1040:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unify_533; r1[2] = lenv;
  r0[142] = r1;
  // def apply-subst_534
  goto L1108;
  FUN_apply_subst_534:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def p_3350
    goto L1109;
    FUN_p_3350:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = top[111];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1110; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
      L1110:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[110];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1111; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type__3etrec_466;
      L1111:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r0 = ((pxll_vector*)r0)->val[2];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = top[107];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1112; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_new_tvar_455;
        L1112:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        r1 = ((object**) lenv) [1][3];
        ((pxll_vector*)r1)->val[0] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } else {
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_854[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            } else {
              goto fatbar_226;
            }
            PXLL_RETURN(0);
            goto fatbar_226_over;
            fatbar_226:
            r0 = (object *) 262;
            r1 = ((object**) lenv) [1][3];
            ((pxll_vector*)r1)->val[2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*****) lenv) [1][1][1][1][2];
            r2[2] = r3;
            r3 = ((object**) lenv) [1][3];
            r2[3] = r3;
            r3 = top[34];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1113; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
            L1113:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = top[106];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1114; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
            L1114:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object***) lenv) [1][1][3];
            ((pxll_vector*)r1)->val[2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r1 = ((pxll_vector*)r1)->val[0];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object *) constructed_854[0];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r1[1] = lenv; lenv = r1;
                r2 = (object*)TC_NIL;
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r3 = ((object****) lenv) [1][1][1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[3] = r2;
                r1 = ((object*) lenv) [3];
                r2 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r0[3] = r1;
                r1 = top[106];
                r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
              } break;
              default: {
                r0 = ((object**) lenv) [1][2];
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
            fatbar_226_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1109:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_p_3350; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_p_3350;
  L1108:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_apply_subst_534; r1[2] = lenv;
  r0[143] = r1;
  // def symbol-set-maker_541
  goto L1115;
  FUN_symbol_set_maker_541:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = top[202];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1116; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L1116:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_25307
    goto L1117;
    FUN_lambda_25307:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1117:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_25307; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[37];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1118; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L1118:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L1115:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_set_maker_541; r1[2] = lenv;
  r0[144] = r1;
  // def build-dependency-graph_542
  goto L1119;
  FUN_build_dependency_graph_542:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = top[84];
    r1[2] = r2;
    r2 = top[201];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1120; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1120:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def search_3865
    goto L1121;
    FUN_search_3865:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,10)];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,10)];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1122; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1122:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1123; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
          L1123:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_search_3865;
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1124; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L1124:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def $loop_3873
          goto L1125;
          FUN__24loop_3873:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*****) lenv) [1][1][1][1][2];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[29];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1126; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
              L1126:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[29];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1127; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
              L1127:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = (object *) constructed_852[0];
              r1[2] = r2;
              r2 = top[144];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1128; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_541;
              L1128:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object*) lenv) [4];
              r0[4] = r1;
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              r1 = ((pxll_vector*)r1)->val[1];
              r1 = ((pxll_vector*)r1)->val[0];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1129; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1129:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = ((object*) lenv) [4];
              r0[3] = r1;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1130; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_search_3865;
              L1130:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_3873;
            }
            PXLL_RETURN(0);
          L1125:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN__24loop_3873; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1131; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3873;
          L1131:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[24];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1132; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
          L1132:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1133; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L1133:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_search_3865;
        } break;
        default: {
          goto fatbar_225;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_225_over;
      fatbar_225:
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_25427
      goto L1134;
      FUN_lambda_25427:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_search_3865;
      L1134:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_25427; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[37];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
      fatbar_225_over: ;
      PXLL_RETURN(0);
    L1121:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_search_3865; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_851[0];
    r1[2] = r2;
    r2 = top[144];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1135; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_541;
    L1135:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = (object *) constructed_518[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1136; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1136:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object****) lenv) [1][1][1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1137; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_search_3865;
    L1137:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = ((object**) lenv) [1][2];
    r1 = ((object***) lenv) [1][1][3];
    ((pxll_vector*)r1)->val[3] = r0;
    PXLL_RETURN(0);
  L1119:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_dependency_graph_542; r1[2] = lenv;
  r0[145] = r1;
  // def symbol-add-suffix_551
  goto L1138;
  FUN_symbol_add_suffix_551:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = ((object**) lenv) [1][2];
    r3 = allocate (TC_TUPLE, 2);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][2];
    r4 = UOBJ_GET(r4,0);
    r3[2] = r4;
    r3 = ((object*) lenv) [2];
    lenv = lenv[1];
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1139; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L1139:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = top[82];
    r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_421;
  L1138:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_add_suffix_551; r1[2] = lenv;
  r0[146] = r1;
  // def do-simple-optimizations_554
  goto L1140;
  FUN_do_simple_optimizations_554:
    check_heap (0);
    r0 = (object *) 1;
    top[204] = r0;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4142
    goto L1141;
    FUN_loop_4142:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 5);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = top[204];
      r3[2] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1142; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
      L1142:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = (object*)TC_NIL;
      r2[3] = r3;
      r3 = ((object*) lenv) [3];
      r4 = (object*) &constructed_850;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r2 = ((object*) lenv) [5];
      r3 = (object*) &constructed_849;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1143; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L1143:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[204];
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)>unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 1;
        top[204] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[148];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1144; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_simpleopt_555;
        L1144:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv[2] = r0;
        goto FUN_loop_4142;
      } else {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1141:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4142; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[148];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1145; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
    L1145:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4142;
  L1140:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_do_simple_optimizations_554; r1[2] = lenv;
  r0[147] = r1;
  // def simpleopt_555
  goto L1146;
  FUN_simpleopt_555:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_28050
    goto L1147;
    FUN_lambda_28050:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def lambda_27568
      goto L1148;
      FUN_lambda_27568:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[18];
        r0[1] = r1[2]; lenv = r0; goto FUN_throw_299;
      L1148:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_27568; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[204];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      top[204] = r0;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = ((object******) lenv) [1][1][1][1][1][2];
              r3 = ((pxll_vector*)r3)->val[3];
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object*) lenv) [2];
              r2[2] = r3;
              r3 = top[21];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1149; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
              L1149:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[2] = r2;
              r2 = top[148];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1150; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
              L1150:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1151; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1151:
              ; lenv = k[2]; k = k[1];
              r0 = result;
            } break;
            default: {
              goto fatbar_218;
            }
          }
          goto fatbar_218_over;
          fatbar_218:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[127];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1152; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
          L1152:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            case (UOTAG(4)): {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[3];
              r0[5] = r1;
              r0 = ((object*) lenv) [4];
              switch (get_case (r0)) {
                case (UOTAG(10)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][5];
                  r1[2] = r2;
                  r2 = top[127];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1153; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
                  L1153:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case_noint (r0)) {
                    default: {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object*****) lenv) [1][1][1][1][2];
                      r4[2] = r5;
                      r5 = (object *) constructed_36[0];
                      r4[3] = r5;
                      r5 = top[23];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1154; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                      L1154:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object**) lenv) [1][2];
                      r3[3] = r4;
                      r4 = top[23];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1155; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                      L1155:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object***) lenv) [1][1][3];
                      r4[2] = r5;
                      r5 = (object *) constructed_36[0];
                      r4[3] = r5;
                      r5 = top[23];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1156; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                      L1156:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object*) lenv) [3];
                      r3[3] = r4;
                      r4 = top[23];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1157; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                      L1157:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = ((object*) lenv) [2];
                      r2[4] = r3;
                      r3 = top[124];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L1158; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_node_2ffix_500;
                      L1158:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = top[148];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1159; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
                      L1159:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1160; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L1160:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                    } break;
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_219;
                }
              }
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_219;
            };
          }
          goto fatbar_219_over;
          fatbar_219:
          r0 = (object *) 14;
          fatbar_219_over: ;
          lenv = lenv[1];
          fatbar_218_over: ;
          lenv = lenv[1];
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = ((object******) lenv) [1][1][1][1][1][2];
              r3 = ((pxll_vector*)r3)->val[3];
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object*) lenv) [2];
              r2[2] = r3;
              r3 = top[21];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1161; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
              L1161:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[2] = r2;
              r2 = top[148];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1162; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
              L1162:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1163; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1163:
              ; lenv = k[2]; k = k[1];
              r0 = result;
            } break;
            default: {
              goto fatbar_220;
            }
          }
          goto fatbar_220_over;
          fatbar_220:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[127];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1164; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
          L1164:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[3];
              r0[5] = r1;
              r0 = ((object*) lenv) [4];
              switch (get_case (r0)) {
                case (UOTAG(9)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][5];
                  r1[2] = r2;
                  r2 = top[127];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1165; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
                  L1165:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case_noint (r0)) {
                    default: {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object*****) lenv) [1][1][1][1][2];
                      r4[2] = r5;
                      r5 = (object *) constructed_36[0];
                      r4[3] = r5;
                      r5 = top[23];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1166; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                      L1166:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object**) lenv) [1][2];
                      r3[3] = r4;
                      r4 = top[23];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1167; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                      L1167:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = ((object***) lenv) [1][1][3];
                      r4[2] = r5;
                      r5 = (object *) constructed_36[0];
                      r4[3] = r5;
                      r5 = top[23];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1168; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                      L1168:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = ((object*) lenv) [3];
                      r3[3] = r4;
                      r4 = top[23];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1169; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                      L1169:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = ((object*) lenv) [2];
                      r2[4] = r3;
                      r3 = top[125];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L1170; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_node_2flet_501;
                      L1170:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = top[148];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1171; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
                      L1171:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1172; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L1172:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                    } break;
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_221;
                }
              }
              goto fatbar_221_over;
              fatbar_221:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = top[24];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1173; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
              L1173:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def $loop_4171
              goto L1174;
              FUN__24loop_4171:
                check_heap (0);
                r0 = ((object***) lenv) [1][1][2];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = (object *) 14;
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object******) lenv) [1][1][1][1][1][3];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[29];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1175; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                  L1175:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[3] = r1;
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[3];
                  r0[4] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (UOTAG(9)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][4];
                      r1[2] = r2;
                      r2 = top[127];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1176; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
                      L1176:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case_noint (r0)) {
                        default: {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 4);
                          r3 = allocate (TC_TUPLE, 4);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                          r4[2] = r5;
                          r5 = (object *) 1;
                          r4[3] = r5;
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[31];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1177; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_325;
                          L1177:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = allocate (TC_TUPLE, 3);
                          r6 = ((object*) lenv) [2];
                          r5[2] = r6;
                          r6 = (object *) constructed_36[0];
                          r5[3] = r6;
                          r6 = top[23];
                          t = allocate (TC_SAVE, 8);
                          t[1] = k; t[2] = lenv; t[3] = &&L1178; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                          r5[1] = r6[2]; lenv = r5; goto FUN_reverse_onto_313;
                          L1178:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                          r5 = result;
                          r4[2] = r5;
                          r5 = ((object***) lenv) [1][1][2];
                          r4[3] = r5;
                          r5 = top[23];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1179; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                          L1179:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                          r4[2] = r5;
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[3] = r5;
                          r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[31];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1180; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_325;
                          L1180:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r3 = allocate (TC_TUPLE, 3);
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = ((object*) lenv) [3];
                          r4[2] = r5;
                          r5 = (object *) constructed_36[0];
                          r4[3] = r5;
                          r5 = top[23];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1181; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                          L1181:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = ((object*) lenv) [4];
                          r3[3] = r4;
                          r4 = top[23];
                          t = allocate (TC_SAVE, 6);
                          t[1] = k; t[2] = lenv; t[3] = &&L1182; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                          L1182:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                          r3 = result;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r4[2] = r5;
                          r5 = (object *) 1;
                          r4[3] = r5;
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[31];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1183; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_325;
                          L1183:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = allocate (TC_TUPLE, 3);
                          r6 = ((object*) lenv) [2];
                          r5[2] = r6;
                          r6 = (object *) constructed_36[0];
                          r5[3] = r6;
                          r6 = top[23];
                          t = allocate (TC_SAVE, 8);
                          t[1] = k; t[2] = lenv; t[3] = &&L1184; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                          r5[1] = r6[2]; lenv = r5; goto FUN_reverse_onto_313;
                          L1184:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                          r5 = result;
                          r4[2] = r5;
                          r5 = ((object**) lenv) [1][3];
                          r4[3] = r5;
                          r5 = top[23];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1185; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                          L1185:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r4[2] = r5;
                          r5 = (object *) 3;
                          r6 = ((object*****) lenv) [1][1][1][1][2];
                          r5 = box((pxll_int)unbox(r6)+unbox(r5));
                          r4[3] = r5;
                          r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                          r4[4] = r5;
                          r5 = top[31];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1186; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_325;
                          L1186:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = ((object**) lenv) [1][2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = allocate (TC_TUPLE, 3);
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = ((object*) lenv) [3];
                          r4[2] = r5;
                          r5 = (object *) constructed_36[0];
                          r4[3] = r5;
                          r5 = top[23];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1187; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                          L1187:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = ((object*) lenv) [5];
                          r3[3] = r4;
                          r4 = top[23];
                          t = allocate (TC_SAVE, 6);
                          t[1] = k; t[2] = lenv; t[3] = &&L1188; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                          L1188:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                          r3 = result;
                          lenv = lenv[1];
                          r2[3] = r3;
                          r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                          r2[4] = r3;
                          r3 = top[125];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L1189; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_node_2flet_501;
                          L1189:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = top[148];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1190; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
                          L1190:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1191; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          L1191:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                        } break;
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      goto fatbar_222;
                    }
                  }
                  goto fatbar_222_over;
                  fatbar_222:
                  r0 = (object *) 14;
                  fatbar_222_over: ;
                  lenv = lenv[1];
                  r0 = (object *) 3;
                  r1 = ((object*) lenv) [2];
                  r0 = box((pxll_int)unbox(r1)+unbox(r0));
                  lenv[2] = r0;
                  goto FUN__24loop_4171;
                }
                PXLL_RETURN(0);
              L1174:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN__24loop_4171; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r1 = (object *) 1;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1192; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4171;
              L1192:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              lenv = lenv[1];
              r0 = (object *) 14;
              lenv = lenv[1];
              fatbar_221_over: ;
              lenv = lenv[1];
            } break;
          }
          lenv = lenv[1];
          fatbar_220_over: ;
          lenv = lenv[1];
        } break;
        case (UITAG(6)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              switch (get_case (r0)) {
                case (UOTAG(2)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(5)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = (object *) constructed_46[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object***) lenv) [1][1][3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object****) lenv) [1][1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object****) lenv) [1][1][1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [3];
                            switch (get_case (r0)) {
                              case (TC_PAIR): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][3];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = ((object**) lenv) [1][3];
                                r1 = UOBJ_GET(r1,1);
                                r0[3] = r1;
                                r0 = ((object*) lenv) [3];
                                switch (get_case (r0)) {
                                  case (TC_NIL): {
                                    r0 = (object *) constructed_44[0];
                                    r1 = ((object***) lenv) [1][1][3];
                                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r1 = allocate (TC_TUPLE, 2);
                                      r2 = ((object**) lenv) [1][2];
                                      r1[2] = r2;
                                      r2 = top[148];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1193; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
                                      L1193:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1194; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                      L1194:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = result;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r1 = allocate (TC_TUPLE, 2);
                                      r2 = ((object*) lenv) [2];
                                      r1[2] = r2;
                                      r2 = top[148];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1195; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
                                      L1195:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1196; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                      L1196:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = result;
                                    }
                                  } break;
                                  default: {
                                    lenv = ((object *****)lenv)[1][1][1][1][1];
                                    goto fatbar_223;
                                  }
                                }
                                lenv = lenv[1];
                              } break;
                              default: {
                                lenv = ((object ****)lenv)[1][1][1][1];
                                goto fatbar_223;
                              }
                            }
                            lenv = lenv[1];
                          } break;
                          default: {
                            lenv = ((object ***)lenv)[1][1][1];
                            goto fatbar_223;
                          }
                        }
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_223;
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_223;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_223;
                }
              }
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_223;
            }
          }
          goto fatbar_223_over;
          fatbar_223:
          r0 = (object *) 14;
          fatbar_223_over: ;
          lenv = lenv[1];
        } break;
        case (UITAG(5)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1197; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L1197:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = (object *) 3;
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object****) lenv) [1][1][1][2];
            r3 = ((pxll_vector*)r3)->val[3];
            r2[2] = r3;
            r3 = (object *) 1;
            r2[3] = r3;
            r3 = top[29];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1198; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
            L1198:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[148];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1199; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
            L1199:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1200; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L1200:
            ; lenv = k[2]; k = k[1];
            r0 = result;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r1 = ((pxll_vector*)r1)->val[3];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1201; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L1201:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_4194
            goto L1202;
            FUN__24loop_4194:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][2];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1203; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1203:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[4];
                r0[3] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[3];
                r0[4] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (UITAG(5)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = allocate (TC_TUPLE, 5);
                    r2[1] = lenv; lenv = r2;
                    r3 = allocate (TC_TUPLE, 4);
                    r4 = ((object******) lenv) [1][1][1][1][1][2];
                    r3[2] = r4;
                    r4 = (object *) 1;
                    r3[3] = r4;
                    r4 = ((object***) lenv) [1][1][2];
                    r3[4] = r4;
                    r4 = top[31];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1204; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_slice_325;
                    L1204:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[2] = r3;
                    r3 = allocate (TC_TUPLE, 3);
                    r4 = allocate (TC_TUPLE, 3);
                    r5 = ((object*) lenv) [2];
                    r4[2] = r5;
                    r5 = (object *) constructed_36[0];
                    r4[3] = r5;
                    r5 = top[23];
                    t = allocate (TC_SAVE, 7);
                    t[1] = k; t[2] = lenv; t[3] = &&L1205; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                    r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                    L1205:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                    r4 = result;
                    r3[2] = r4;
                    r4 = ((object**) lenv) [1][4];
                    r3[3] = r4;
                    r4 = top[23];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1206; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                    L1206:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[3] = r3;
                    r3 = allocate (TC_TUPLE, 4);
                    r4 = ((object******) lenv) [1][1][1][1][1][2];
                    r3[2] = r4;
                    r4 = ((object***) lenv) [1][1][2];
                    r5 = (object *) 3;
                    r4 = box((pxll_int)unbox(r5)+unbox(r4));
                    r3[3] = r4;
                    r4 = ((object******) lenv) [1][1][1][1][1][3];
                    r3[4] = r4;
                    r4 = top[31];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1207; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_slice_325;
                    L1207:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[4] = r3;
                    r3 = allocate (TC_TUPLE, 3);
                    r4 = allocate (TC_TUPLE, 3);
                    r5 = ((object*) lenv) [3];
                    r4[2] = r5;
                    r5 = (object *) constructed_36[0];
                    r4[3] = r5;
                    r5 = top[23];
                    t = allocate (TC_SAVE, 7);
                    t[1] = k; t[2] = lenv; t[3] = &&L1208; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                    r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
                    L1208:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                    r4 = result;
                    r3[2] = r4;
                    r4 = ((object*) lenv) [4];
                    r3[3] = r4;
                    r4 = top[23];
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1209; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                    L1209:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[5] = r3;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = (object*)UITAG(5);
                    r2[2] = r3;
                    r3 = ((object*) lenv) [5];
                    r2[3] = r3;
                    r3 = top[120];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1210; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_make_node_488;
                    L1210:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    lenv = lenv[1];
                    r1[2] = r2;
                    r2 = top[148];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1211; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_555;
                    L1211:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1212; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1212:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } break;
                  default: {
                    goto fatbar_224;
                  }
                }
                goto fatbar_224_over;
                fatbar_224:
                r0 = (object *) 14;
                fatbar_224_over: ;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4194;
              }
              PXLL_RETURN(0);
            L1202:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_4194; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1213; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4194;
            L1213:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            lenv = lenv[1];
            r0 = (object *) 14;
            lenv = lenv[1];
          }
        } break;
        default: {
          goto fatbar_217;
        }
      }
      goto fatbar_217_over;
      fatbar_217:
      r0 = (object *) 14;
      fatbar_217_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[204];
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)-unbox(r0));
      lenv = lenv[1];
      top[204] = r0;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[148];
      r1[2] = r2;
      r2 = ((object****) lenv) [1][1][1][2];
      r2 = ((pxll_vector*)r2)->val[3];
      r1[3] = r2;
      r2 = top[34];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1214; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
      L1214:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object****) lenv) [1][1][1][2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = ((object****) lenv) [1][1][1][2];
      PXLL_RETURN(0);
    L1147:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_28050; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[17];
    r0[1] = r1[2]; lenv = r0; goto FUN_callcc_298;
  L1146:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_simpleopt_555; r1[2] = lenv;
  r0[148] = r1;
  // def do-one-round_558
  goto L1215;
  FUN_do_one_round_558:
    check_heap (0);
    r0 = top[168];
    r1 = ((object*) lenv) [3];
    ((pxll_vector*)r1)->val[17] = r0;
    r0 = top[168];
    r1 = ((object*) lenv) [3];
    ((pxll_vector*)r1)->val[5] = r0;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[8];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1216; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_252;
    L1216:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_518[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[7];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1217; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_add_var_251;
    L1217:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def walk_3943_i3178_i3181
    goto L1218;
    FUN_walk_3943_i3178_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(8)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1219; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L1219:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object******) lenv) [1][1][1][1][1][3];
              r1[2] = r2;
              r2 = ((object*) lenv) [2];
              r1[3] = r2;
              r2 = top[5];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1220; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
              L1220:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = ((object****) lenv) [1][1][1][3];
              r0[3] = r1;
              r1 = top[27];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1221; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_321;
              L1221:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = ((pxll_vector*)r1)->val[1];
                r0[2] = r1;
                r0 = top[156];
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
                lenv = lenv[1];
                r1 = ((object*) lenv) [3];
                ((pxll_vector*)r1)->val[1] = r0;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = top[196];
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
                lenv = lenv[1];
                r1 = ((object****) lenv) [1][1][1][2];
                ((pxll_vector*)r1)->val[0] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = ((pxll_vector*)r1)->val[0];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = (object *) 3;
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv = lenv[1];
              r1 = ((object*) lenv) [3];
              ((pxll_vector*)r1)->val[0] = r0;
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_216;
            }
          }
          goto fatbar_216_over;
          fatbar_216:
          r0 = (object *) 14;
          fatbar_216_over: ;
          lenv = lenv[1];
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object***) lenv) [1][1][3] = r0;
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[2] = r1;
          r1 = top[84];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[5] = r1;
          r1 = top[74];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1222; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_409;
          L1222:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          ((pxll_vector*)r1)->val[5] = r0;
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[158];
          r0[4] = r1;
          r1 = top[6];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1223; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
          L1223:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
        } break;
        case (UOTAG(12)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = (object *) constructed_214[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 262;
          } else {
            r0 = (object *) constructed_210[0];
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
          }
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object*****) lenv) [1][1][1][1][3];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object***) lenv) [1][1][3];
            r1[2] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1224; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
            L1224:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = top[160];
            r0[4] = r1;
            r1 = top[6];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1225; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
            L1225:
            ; lenv = k[2]; k = k[1];
            r0 = result;
          } else {
            r0 = (object *) 14;
          }
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_215;
        }
      }
      goto fatbar_215_over;
      fatbar_215:
      r0 = (object *) 14;
      fatbar_215_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_26128_i3178_i3181
      goto L1226;
      FUN_lambda_26128_i3178_i3181:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_walk_3943_i3178_i3181;
      L1226:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_26128_i3178_i3181; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[37];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L1218:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3943_i3178_i3181; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) constructed_848[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1227; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3943_i3178_i3181;
    L1227:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def add-ref_3961_i3179_i3181
    goto L1228;
    FUN_add_ref_3961_i3179_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][3];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1229; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
      L1229:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,72)];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,72)] = r0;
      PXLL_RETURN(0);
    L1228:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_ref_3961_i3179_i3181; r1[2] = lenv;
    r0[2] = r1;
    // def add-set_3962_i3179_i3181
    goto L1230;
    FUN_add_set_3962_i3179_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][3];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[5];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1231; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
      L1231:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = (object *) 3;
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[4] = r0;
      PXLL_RETURN(0);
    L1230:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_set_3962_i3179_i3181; r1[2] = lenv;
    r0[3] = r1;
    // def walk_3963_i3179_i3181
    goto L1232;
    FUN_walk_3963_i3179_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1233; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
          L1233:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,72)];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = (object *) 3;
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r1 = ((object*) lenv) [3];
          ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,72)] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1234; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
          L1234:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = (object *) 3;
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r1 = ((object*) lenv) [3];
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_214;
        }
      }
      goto fatbar_214_over;
      fatbar_214:
      r0 = (object *) 14;
      fatbar_214_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object**) lenv) [1][4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[37];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L1232:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3963_i3179_i3181; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1235; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3963_i3179_i3181;
    L1235:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_847[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def find-escaping-functions_4114_i3180_i3181
    goto L1236;
    FUN_find_escaping_functions_4114_i3180_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(10)): {
              r0 = (object *) 14;
            } break;
            default: {
              goto fatbar_212;
            }
          }
          goto fatbar_212_over;
          fatbar_212:
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[157];
          r0[4] = r1;
          r1 = top[6];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1237; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
          L1237:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object*****) lenv) [1][1][1][1][2] = r0;
          fatbar_212_over: ;
          lenv = lenv[1];
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[5];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1238; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
          L1238:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,74)];
          r0[3] = r1;
          r0 = top[158];
          r1 = ((object*) lenv) [3];
          r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r1 = ((pxll_vector*)r1)->val[4];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UITAG(8)): {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][3];
                r1 = ((pxll_vector*)r1)->val[3];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = top[21];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1239; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
                L1239:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r2 = ((object*) lenv) [3];
                r1 = PXLL_TEST(r2==r1);
                r0[4] = r1;
                r0 = (object *) 6;
                r1 = ((object*) lenv) [4];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r0[3] = r1;
                  r1 = top[157];
                  r0[4] = r1;
                  r1 = top[6];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1240; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
                  L1240:
                  ; lenv = k[2]; k = k[1];
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object***) lenv) [1][1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  ((object******) lenv) [1][1][1][1][1][2] = r0;
                } else {
                  r0 = (object *) 14;
                }
              } break;
              default: {
                goto fatbar_213;
              }
            }
            goto fatbar_213_over;
            fatbar_213:
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = top[157];
            r0[4] = r1;
            r1 = top[6];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1241; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
            L1241:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object******) lenv) [1][1][1][1][1][2] = r0;
            fatbar_213_over: ;
            lenv = lenv[1];
          } else {
            r0 = (object *) 14;
          }
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_211;
        }
      }
      goto fatbar_211_over;
      fatbar_211:
      r0 = (object *) 14;
      fatbar_211_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_27376_i3180_i3181
      goto L1242;
      FUN_lambda_27376_i3180_i3181:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_functions_4114_i3180_i3181;
      L1242:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_27376_i3180_i3181; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[37];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L1236:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_escaping_functions_4114_i3180_i3181; r1[2] = lenv;
    r0[2] = r1;
    // def maybe-var-escapes_4115_i3180_i3181
    goto L1243;
    FUN_maybe_var_escapes_4115_i3180_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = top[27];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1244; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_321;
      L1244:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 6;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object****) lenv) [1][1][1][3];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[157];
        r0[4] = r1;
        r1 = top[6];
        r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
      } else {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1243:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_maybe_var_escapes_4115_i3180_i3181; r1[2] = lenv;
    r0[3] = r1;
    // def find-escaping-variables_4116_i3180_i3181
    goto L1245;
    FUN_find_escaping_variables_4116_i3180_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1246; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1246:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[23];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1247; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
          L1247:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          ((object***) lenv) [1][1][3] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1248; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1248:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[23];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1249; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
          L1249:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          ((object***) lenv) [1][1][3] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1250; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1250:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[23];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1251; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
          L1251:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          ((object***) lenv) [1][1][3] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1252; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_maybe_var_escapes_4115_i3180_i3181;
          L1252:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1253; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_maybe_var_escapes_4115_i3180_i3181;
          L1253:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_210;
        }
      }
      goto fatbar_210_over;
      fatbar_210:
      r0 = (object *) 14;
      fatbar_210_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_27461_i3180_i3181
      goto L1254;
      FUN_lambda_27461_i3180_i3181:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_variables_4116_i3180_i3181;
      L1254:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_27461_i3180_i3181; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[37];
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L1245:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_escaping_variables_4116_i3180_i3181; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = (object *) 1;
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r2;
    r2 = t;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(2),1);
    t[1] = r2;
    r2 = t;
    r1[2] = r2;
    r2 = (object *) constructed_846[0];
    r1[3] = r2;
    r2 = top[120];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1255; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
    L1255:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1256; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_functions_4114_i3180_i3181;
    L1256:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_27505_i3180_i3181
    goto L1257;
    FUN_lambda_27505_i3180_i3181:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 4);
      r2 = ((object*****) lenv) [1][1][1][1][3];
      r2 = ((pxll_vector*)r2)->val[5];
      r1[2] = r2;
      r2 = top[84];
      r1[3] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[4] = r2;
      r2 = top[75];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1258; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
      L1258:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (UOTAG(0)): {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_845;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1259; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L1259:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
        } break;
      }
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = (object *) constructed_844[0];
      r0[3] = r1;
      r1 = ((object***) lenv) [1][1][4];
      r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_variables_4116_i3180_i3181;
    L1257:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_27505_i3180_i3181; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[37];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1260; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L1260:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = top[145];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1261; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_build_dependency_graph_542;
    L1261:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 3);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][3];
    r4 = ((pxll_vector*)r4)->val[3];
    r3[2] = r4;
    r4 = allocate (TC_TUPLE, 2);
    r5 = (object *) constructed_843[0];
    r4[2] = r5;
    r5 = top[144];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L1262; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    r4[1] = r5[2]; lenv = r4; goto FUN_symbol_set_maker_541;
    L1262:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[3] = r4;
    r3 = allocate (TC_TUPLE, 3);
    r3[1] = lenv; lenv = r3;
    // def walk_4204_i3183
    goto L1263;
    FUN_walk_4204_i3183:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][2];
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,11)];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1264; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1264:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
          r1 = ((pxll_vector*)r1)->val[0];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1265; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1265:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_28091_i3183
          goto L1266;
          FUN_lambda_28091_i3183:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
            r2 = ((pxll_vector*)r2)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1267; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L1267:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[1] = r1[2]; lenv = r0; goto FUN_walk_4204_i3183;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          L1266:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_28091_i3183; r1[2] = lenv;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,11)];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1268; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1268:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = top[37];
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
        } break;
      }
      PXLL_RETURN(0);
    L1263:
    r4 = allocate (TC_CLOSURE, 2);
    r4[1] = &&FUN_walk_4204_i3183; r4[2] = lenv;
    r3[2] = r4;
    // def trim_4205_i3183
    goto L1269;
    FUN_trim_4205_i3183:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (UOTAG(10)): {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][2];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[24];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1270; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
          L1270:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[3];
          r1[4] = r2;
          r2 = (object *) constructed_842[0];
          r1[5] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def $loop_4217_i3183
          goto L1271;
          FUN__24loop_4217_i3183:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object*****) lenv) [1][1][1][1][2];
              r2[2] = r3;
              r3 = ((object**) lenv) [1][2];
              r2[3] = r3;
              r3 = top[29];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1272; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
              L1272:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
              r2 = ((pxll_vector*)r2)->val[2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1273; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L1273:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][5];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object****) lenv) [1][1][1][5] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_4217_i3183;
            }
            PXLL_RETURN(0);
          L1271:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN__24loop_4217_i3183; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1274; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4217_i3183;
          L1274:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          switch (get_case (r1)) {
            case (TC_NIL): {
              r1 = (object *) 262;
            } break;
            default: {
              goto fatbar_209;
            }
          }
          goto fatbar_209_over;
          fatbar_209:
          r1 = (object *) 6;
          fatbar_209_over: ;
          lenv = lenv[1];
          if PXLL_IS_TRUE(r1) {
            r1 = ((object***) lenv) [1][1][2];
          } else {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_841[0];
            r1[2] = r2;
            r2 = (object *) constructed_840[0];
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 3);
            // def lambda_28172_i3183
            goto L1275;
            FUN_lambda_28172_i3183:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object***) lenv) [1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[29];
              r0[1] = r1[2]; lenv = r0; goto FUN_nth_323;
            L1275:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN_lambda_28172_i3183; r3[2] = lenv;
            r2[2] = r3;
            r3 = ((object**) lenv) [1][5];
            r2[3] = r3;
            r3 = top[34];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1276; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
            L1276:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][3];
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4224_i3183
            goto L1277;
            FUN__24loop_4224_i3183:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object******) lenv) [1][1][1][1][1][5];
                r1[3] = r2;
                r2 = top[27];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1278; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_321;
                L1278:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = (object *) 6;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object******) lenv) [1][1][1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[29];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1279; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                  L1279:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*****) lenv) [1][1][1][1][2];
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  ((object****) lenv) [1][1][1][2] = r0;
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object******) lenv) [1][1][1][1][1][4];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[29];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1280; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                  L1280:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = ((object*****) lenv) [1][1][1][1][3];
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  ((object****) lenv) [1][1][1][3] = r0;
                } else {
                  r0 = (object *) 14;
                }
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4224_i3183;
              }
              PXLL_RETURN(0);
            L1277:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4224_i3183; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1281; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4224_i3183;
            L1281:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 4);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1282; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L1282:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1283; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L1283:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[25];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1284; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_last_319;
            L1284:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r2 = top[124];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1285; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_node_2ffix_500;
            L1285:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
          }
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_208;
        }
      }
      goto fatbar_208_over;
      fatbar_208:
      r1 = ((object**) lenv) [1][2];
      fatbar_208_over: ;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object***) lenv) [1][1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[34];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1286; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_map_328;
      L1286:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = ((object*) lenv) [3];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = ((object*) lenv) [3];
      PXLL_RETURN(0);
    L1269:
    r4 = allocate (TC_CLOSURE, 2);
    r4[1] = &&FUN_trim_4205_i3183; r4[2] = lenv;
    r3[3] = r4;
    r3 = allocate (TC_TUPLE, 2);
    r4 = (object *) constructed_518[0];
    r3[2] = r4;
    r4 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1287; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_walk_4204_i3183;
    L1287:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object****) lenv) [1][1][1][2];
    r3[2] = r4;
    r4 = ((object*) lenv) [3];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1288; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_trim_4205_i3183;
    L1288:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    lenv = lenv[1];
    lenv = lenv[1];
    r2[2] = r3;
    r3 = top[147];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1289; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_do_simple_optimizations_554;
    L1289:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = (object *) 1;
    r2[2] = r3;
    r3 = top[115];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1290; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
    L1290:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = (object *) 1;
    r2[2] = r3;
    r3 = top[115];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1291; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
    L1291:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[4] = r2;
    r2 = (object*)UITAG(0);
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 7);
    r1[1] = lenv; lenv = r1;
    // def set-multiplier_3979_i3182
    goto L1292;
    FUN_set_multiplier_3979_i3182:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object*****) lenv) [1][1][1][1][3];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object*) lenv) [2];
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,11)];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1293; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1293:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          // def lambda_26310_i3182
          goto L1294;
          FUN_lambda_26310_i3182:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][5];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[67];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1295; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
            L1295:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                r0[2] = r1;
                r0 = ((object******) lenv) [1][1][1][1][1][3];
                r1 = ((object*) lenv) [2];
                r2 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                ((object*******) lenv) [1][1][1][1][1][1][5] = r0;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L1294:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_26310_i3182; r1[2] = lenv;
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,25)];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1292:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_set_multiplier_3979_i3182; r2[2] = lenv;
    r1[2] = r2;
    // def follow-aliases_3980_i3182
    goto L1296;
    FUN_follow_aliases_3980_i3182:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = top[67];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1297; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
      L1297:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object****) lenv) [1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_follow_aliases_3980_i3182;
            } break;
            default: {
              goto fatbar_207;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_207_over;
          fatbar_207:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(1), 2);
          r2 = ((object****) lenv) [1][1][1][3];
          r1[1] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
          fatbar_207_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1296:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_follow_aliases_3980_i3182; r2[2] = lenv;
    r1[3] = r2;
    // def get-fun-calls_3981_i3182
    goto L1298;
    FUN_get_fun_calls_3981_i3182:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][5];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = top[67];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1299; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
      L1299:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][3];
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)*unbox(r0));
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1298:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_get_fun_calls_3981_i3182; r2[2] = lenv;
    r1[4] = r2;
    // def inline_3982_i3182
    goto L1300;
    FUN_inline_3982_i3182:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_26651_i3182
      goto L1301;
      FUN_lambda_26651_i3182:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def lambda_26391_i3182
        goto L1302;
        FUN_lambda_26391_i3182:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[18];
          r0[1] = r1[2]; lenv = r0; goto FUN_throw_299;
        L1302:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_26391_i3182; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1303; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L1303:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_4012_i3182
            goto L1304;
            FUN__24loop_4012_i3182:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][3];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object****) lenv) [1][1][1][2];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1305; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1305:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                r2 = ((pxll_vector*)r2)->val[3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1306; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1306:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                r0[4] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [4];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                ((object*******) lenv) [1][1][1][1][1][1][3] = r0;
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4012_i3182;
              }
              PXLL_RETURN(0);
            L1304:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_4012_i3182; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1307; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4012_i3182;
            L1307:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            lenv = lenv[1];
          } break;
          case (UITAG(8)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r1 = ((pxll_vector*)r1)->val[3];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = (object*) &constructed_68;
                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_68;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_67;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_67;
                PXLL_UNDEFINED; result=r0; goto Lreturn;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r1 = ((object*) lenv) [2];
                r1 = ((pxll_vector*)r1)->val[4];
                r0[4] = r1;
                r0 = ((object*) lenv) [4];
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][4];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                    r1[2] = r2;
                    r2 = ((object*) lenv) [2];
                    r1[3] = r2;
                    r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1308; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_follow_aliases_3980_i3182;
                    L1308:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (UITAG(1)): {
                        r0 = (object *) 14;
                      } break;
                      default: {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        switch (get_case_noint (r0)) {
                          default: {
                            r0 = allocate (TC_TUPLE, 11);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
                            r1[2] = r2;
                            r2 = ((object*) lenv) [2];
                            r1[3] = r2;
                            r2 = top[5];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1309; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
                            L1309:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[4] = r1;
                            r1 = ((object*) lenv) [4];
                            r1 = ((pxll_vector*)r1)->val[1];
                            r0[5] = r1;
                            r1 = top[157];
                            r2 = ((object*) lenv) [5];
                            r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                            r0[6] = r1;
                            r1 = ((object*) lenv) [4];
                            r1 = ((pxll_vector*)r1)->val[1];
                            r0[7] = r1;
                            r1 = top[156];
                            r2 = ((object*) lenv) [7];
                            r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                            r0[8] = r1;
                            r1 = ((object*) lenv) [4];
                            r1 = ((pxll_vector*)r1)->val[1];
                            r0[9] = r1;
                            r1 = top[160];
                            r2 = ((object*) lenv) [9];
                            r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                            r0[10] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object*) lenv) [2];
                            r1[2] = r2;
                            r2 = ((object*) lenv) [4];
                            r2 = ((pxll_vector*)r2)->val[0];
                            r1[3] = r2;
                            r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1310; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_get_fun_calls_3981_i3182;
                            L1310:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[11] = r1;
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][3];
                            r1 = ((pxll_vector*)r1)->val[4];
                            r0[2] = r1;
                            r0 = ((object*) lenv) [2];
                            switch (get_case (r0)) {
                              case (UOTAG(7)): {
                                r0 = (object *) 262;
                              } break;
                              default: {
                                goto fatbar_206;
                              }
                            }
                            goto fatbar_206_over;
                            fatbar_206:
                            r0 = (object *) 6;
                            fatbar_206_over: ;
                            lenv = lenv[1];
                            if PXLL_IS_TRUE(r0) {
                              r0 = allocate (TC_TUPLE, 4);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object***) lenv) [1][1][2];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = ((object*) lenv) [2];
                              lenv = lenv[1];
                              r0[2] = r1;
                              r1 = (object *) 1;
                              r2 = ((object*) lenv) [2];
                              range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
                              r1 = (object *) 1;
                              r2 = ((object*) lenv) [2];
                              r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
                              r0[3] = r1;
                              r1 = (object *) 24066;
                              r2 = ((object*) lenv) [3];
                              r1 = PXLL_TEST(r2==r1);
                              r0[4] = r1;
                              r0 = (object *) 6;
                              r1 = ((object*) lenv) [4];
                              r0 = PXLL_TEST(r1==r0);
                              lenv = lenv[1];
                              if PXLL_IS_TRUE(r0) {
                                r0 = (object *) 6;
                                r1 = ((object*) lenv) [10];
                                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                  r0 = (object *) 1;
                                  r1 = ((object*) lenv) [11];
                                  if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                    r0 = allocate (TC_TUPLE, 2);
                                    r0[1] = lenv; lenv = r0;
                                    r1 = ((object**) lenv) [1][3];
                                    r1 = ((pxll_vector*)r1)->val[2];
                                    r0[2] = r1;
                                    r0 = top[203];
                                    r1 = ((object*) lenv) [2];
                                    r0 = PXLL_TEST(unbox(r1)<=unbox(r0));
                                    lenv = lenv[1];
                                    if PXLL_IS_TRUE(r0) {
                                      r0 = (object *) 262;
                                    } else {
                                      r0 = (object *) 3;
                                      r1 = ((object*) lenv) [11];
                                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                        r0 = (object *) 6;
                                        r1 = ((object*) lenv) [6];
                                        r0 = PXLL_TEST(r1==r0);
                                      } else {
                                        r0 = (object *) 6;
                                      }
                                    }
                                    if PXLL_IS_TRUE(r0) {
                                      r0 = (object *) 6;
                                      r1 = ((object*) lenv) [8];
                                      r0 = PXLL_TEST(r1==r0);
                                    } else {
                                      r0 = (object *) 6;
                                    }
                                  } else {
                                    r0 = (object *) 6;
                                  }
                                } else {
                                  r0 = (object *) 6;
                                }
                              } else {
                                r0 = (object *) 6;
                              }
                            } else {
                              r0 = (object *) 6;
                            }
                            if PXLL_IS_TRUE(r0) {
                              r0 = (object *) 3;
                              r1 = ((object*) lenv) [11];
                              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                r0 = allocate (TC_TUPLE, 3);
                                r1 = ((object*) lenv) [2];
                                r0[2] = r1;
                                r1 = ((object*) lenv) [11];
                                r0[3] = r1;
                                r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L1311; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_set_multiplier_3979_i3182;
                                L1311:
                                ; lenv = k[2]; k = k[1];
                                r0 = result;
                              } else {
                                r0 = (object *) 14;
                              }
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = ((object**) lenv) [1][3];
                              r1[2] = r2;
                              r2 = ((object*****) lenv) [1][1][1][1][3];
                              r1[3] = r2;
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][6];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1312; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_inline_application_3985_i3182;
                              L1312:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r0 = allocate (TC_TUPLE, 3);
                              r1 = ((object*) lenv) [2];
                              r0[2] = r1;
                              r1 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][3];
                              r0[3] = r1;
                              r1 = top[8];
                              t = allocate (TC_SAVE, 3);
                              t[1] = k; t[2] = lenv; t[3] = &&L1313; ; k = t;
                              r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_252;
                              L1313:
                              ; lenv = k[2]; k = k[1];
                              r0 = allocate (TC_TUPLE, 2);
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = ((object*) lenv) [2];
                              r1[2] = r2;
                              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                              r1[3] = r2;
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][5];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1314; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_inline_3982_i3182;
                              L1314:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                              t = allocate (TC_SAVE, 3);
                              t[1] = k; t[2] = lenv; t[3] = &&L1315; ; k = t;
                              r0[1] = r1[2]; lenv = r0; goto *r1[1];
                              L1315:
                              ; lenv = k[2]; k = k[1];
                              r0 = result;
                              lenv = lenv[1];
                            } else {
                              r0 = (object *) 14;
                            }
                            lenv = lenv[1];
                          } break;
                        }
                        lenv = lenv[1];
                      } break;
                    }
                    lenv = lenv[1];
                  } break;
                  case (UOTAG(7)): {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][4];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][4];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = ((object*******) lenv) [1][1][1][1][1][1][2];
                    r3 = ((pxll_vector*)r3)->val[3];
                    r2[2] = r3;
                    r3 = top[21];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1316; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
                    L1316:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = ((object**) lenv) [1][3];
                    r1[3] = r2;
                    r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1317; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_inline_application_3985_i3182;
                    L1317:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = ((object*) lenv) [4];
                    r0[2] = r1;
                    r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                    r0[3] = r1;
                    r1 = top[8];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1318; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_252;
                    L1318:
                    ; lenv = k[2]; k = k[1];
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*) lenv) [4];
                    r1[2] = r2;
                    r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                    r1[3] = r2;
                    r2 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1319; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_inline_3982_i3182;
                    L1319:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object*****) lenv) [1][1][1][1][2];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1320; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1320:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    lenv = lenv[1];
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_205;
                  }
                }
                lenv = lenv[1];
              } break;
            }
            goto fatbar_205_over;
            fatbar_205:
            r0 = (object *) 14;
            fatbar_205_over: ;
            lenv = lenv[1];
          } break;
          default: {
            goto fatbar_204;
          }
        }
        goto fatbar_204_over;
        fatbar_204:
        r0 = (object *) 14;
        fatbar_204_over: ;
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_26641_i3182
        goto L1321;
        FUN_lambda_26641_i3182:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][5];
          r0[1] = r1[2]; lenv = r0; goto FUN_inline_3982_i3182;
        L1321:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_26641_i3182; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r1 = top[34];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1322; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_map_328;
        L1322:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object***) lenv) [1][1][2];
        ((pxll_vector*)r1)->val[3] = r0;
        r0 = ((object***) lenv) [1][1][2];
        PXLL_RETURN(0);
      L1301:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_26651_i3182; r1[2] = lenv;
      r0[2] = r1;
      r1 = top[17];
      r0[1] = r1[2]; lenv = r0; goto FUN_callcc_298;
    L1300:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_inline_3982_i3182; r2[2] = lenv;
    r1[5] = r2;
    // def inline-application_3985_i3182
    goto L1323;
    FUN_inline_application_3985_i3182:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_839[0];
      r0[2] = r1;
      r1 = (object *) constructed_838[0];
      r0[3] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object**) lenv) [1][3];
      r1[2] = r2;
      r2 = top[24];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1324; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
      L1324:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[4] = r1;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[5] = r1;
      r0 = ((object*) lenv) [5];
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1325; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L1325:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r2 = ((object***) lenv) [1][1][4];
          r1 = PXLL_TEST(unbox(r2)==unbox(r1));
          r0[3] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [3];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_828;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[15];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object***) lenv) [1][1][4];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_4073_i3182
            goto L1326;
            FUN__24loop_4073_i3182:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1327; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1327:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[5];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1328; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
                L1328:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1329; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1329:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = ((pxll_vector*)r1)->val[4];
                r0[2] = r1;
                r0 = (object *) 1;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(unbox(r1)>unbox(r0));
                lenv = lenv[1];
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object***) lenv) [1][1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  ((object******) lenv) [1][1][1][1][1][3] = r0;
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][4];
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(2)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object****) lenv) [1][1][1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      lenv = lenv[1];
                      ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
                    } break;
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
                      r1[2] = r2;
                      r2 = ((object*) lenv) [2];
                      r1[3] = r2;
                      r2 = top[5];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1330; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
                      L1330:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = ((pxll_vector*)r1)->val[4];
                      r0[2] = r1;
                      r0 = (object *) 1;
                      r1 = ((object*) lenv) [2];
                      r0 = PXLL_TEST(unbox(r1)>unbox(r0));
                      lenv = lenv[1];
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        ((object********) lenv) [1][1][1][1][1][1][1][3] = r0;
                      } else {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        ((object********) lenv) [1][1][1][1][1][1][1][2] = r0;
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      goto fatbar_202;
                    }
                  }
                  goto fatbar_202_over;
                  fatbar_202:
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object***) lenv) [1][1][3];
                  r1 = ((pxll_vector*)r1)->val[3];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = (object *) 3;
                  r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                  lenv = lenv[1];
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r1 = ((pxll_vector*)r1)->val[4];
                        r0[3] = r1;
                        r1 = ((object*) lenv) [2];
                        r1 = ((pxll_vector*)r1)->val[3];
                        r0[4] = r1;
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (UOTAG(12)): {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r0 = (object *) constructed_314[0];
                            r1 = ((object*) lenv) [2];
                            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                              r0 = ((object**) lenv) [1][4];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r1 = ((pxll_vector*)r1)->val[4];
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 4);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = ((object***************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][3];
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [2];
                                      r1[3] = r2;
                                      r2 = top[5];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1331; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
                                      L1331:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[3] = r1;
                                      r1 = ((object*) lenv) [3];
                                      r1 = ((pxll_vector*)r1)->val[4];
                                      r0[4] = r1;
                                      r0 = ((object*) lenv) [4];
                                      r1 = (object *) 1;
                                      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                                      lenv = lenv[1];
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_203;
                                    }
                                  }
                                  lenv = lenv[1];
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_203;
                                }
                              }
                            } else {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_203;
                            }
                            lenv = lenv[1];
                          } break;
                          default: {
                            lenv = ((object *)lenv)[1];
                            goto fatbar_203;
                          }
                        }
                        lenv = lenv[1];
                      } break;
                      default: {
                        goto fatbar_203;
                      }
                    }
                    goto fatbar_203_over;
                    fatbar_203:
                    r0 = (object *) 6;
                    fatbar_203_over: ;
                  } else {
                    r0 = (object *) 6;
                  }
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    ((object*******) lenv) [1][1][1][1][1][1][2] = r0;
                  } else {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    r1 = ((object****) lenv) [1][1][1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    ((object*******) lenv) [1][1][1][1][1][1][3] = r0;
                  }
                  fatbar_202_over: ;
                  lenv = lenv[1];
                }
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4073_i3182;
              }
              PXLL_RETURN(0);
            L1326:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_4073_i3182; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1332; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4073_i3182;
            L1332:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_836[0];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = allocate (TC_TUPLE, 2);
            r4 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r4 = ((pxll_vector*)r4)->val[1];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L1333; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            lenv = r4[2]; goto *r4[1];
            L1333:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = top[58];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L1334; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
            L1334:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [3];
            r4 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[4] = r3;
            r2 = ((object*) lenv) [4];
            r3 = (object*) &constructed_835;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r1[2] = r2;
            r2 = top[49];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1335; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
            L1335:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][2];
            r2 = ((pxll_vector*)r2)->val[3];
            r1[2] = r2;
            r2 = (object *) 1;
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1336; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1336:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            // def append-suffix_4037_i3097_i3182
            goto L1337;
            FUN_append_suffix_4037_i3097_i3182:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = ((object**) lenv) [1][2];
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = ((object***) lenv) [1][1][2];
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              lenv = lenv[1];
              r2[2] = r3;
              r3 = (object*)TC_NIL;
              r2[3] = r3;
              r3 = ((object*) lenv) [3];
              r4 = ((object****) lenv) [1][1][1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = ((object*) lenv) [4];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[2] = r2;
              r2 = top[49];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1338; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
              L1338:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = top[82];
              r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_421;
            L1337:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_append_suffix_4037_i3097_i3182; r2[2] = lenv;
            r1[2] = r2;
            // def rename_4038_i3097_i3182
            goto L1339;
            FUN_rename_4038_i3097_i3182:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def get-new-name_4042_i3097_i3182
              goto L1340;
              FUN_get_new_name_4042_i3097_i3182:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1341; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_4037_i3097_i3182;
                L1341:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object******) lenv) [1][1][1][1][1][2] = r0;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*****) lenv) [1][1][1][1][3];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object***) lenv) [1][1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object****) lenv) [1][1][1][3] = r0;
                r0 = ((object*) lenv) [2];
                PXLL_RETURN(0);
              L1340:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_get_new_name_4042_i3097_i3182; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (UOTAG(2)): {
                  r0 = ((object*) lenv) [2];
                } break;
                default: {
                  goto fatbar_201;
                }
              }
              goto fatbar_201_over;
              fatbar_201:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][2];
              r2 = ((pxll_vector*)r2)->val[4];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              r1[3] = r2;
              r2 = top[120];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1342; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
              L1342:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object**) lenv) [1][2];
              r0 = ((pxll_vector*)r0)->val[0];
              r1 = ((object*) lenv) [2];
              ((pxll_vector*)r1)->val[0] = r0;
              r0 = ((object**) lenv) [1][2];
              r0 = ((pxll_vector*)r0)->val[5];
              r1 = ((object*) lenv) [2];
              ((pxll_vector*)r1)->val[5] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              fatbar_201_over: ;
              lenv = lenv[1];
              ((object**) lenv) [1][2] = r0;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(9)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1343; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L1343:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(9),1);
                  t[1] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r1 = ((object****) lenv) [1][1][1][2];
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                } break;
                case (UOTAG(10)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1344; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L1344:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(10),1);
                  t[1] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r1 = ((object****) lenv) [1][1][1][2];
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                } break;
                case (UOTAG(7)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][2];
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1345; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_get_new_name_4042_i3097_i3182;
                  L1345:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object****) lenv) [1][1][1][2];
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][3];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1346; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L1346:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(7),2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r1 = ((object****) lenv) [1][1][1][2];
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                } break;
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [2];
                  r0[2] = r1;
                  r1 = ((object****) lenv) [1][1][1][3];
                  r0[3] = r1;
                  r1 = top[27];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1347; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_321;
                  L1347:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1348; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_4037_i3097_i3182;
                    L1348:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r1 = ((object****) lenv) [1][1][1][2];
                    ((pxll_vector*)r1)->val[4] = r0;
                  } else {
                    r0 = (object *) 14;
                  }
                  lenv = lenv[1];
                } break;
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [2];
                  r0[2] = r1;
                  r1 = ((object****) lenv) [1][1][1][3];
                  r0[3] = r1;
                  r1 = top[27];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1349; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_321;
                  L1349:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][2];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1350; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_4037_i3097_i3182;
                    L1350:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r1 = ((object****) lenv) [1][1][1][2];
                    ((pxll_vector*)r1)->val[4] = r0;
                  } else {
                    r0 = (object *) 14;
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_200;
                }
              }
              goto fatbar_200_over;
              fatbar_200:
              r0 = (object *) 14;
              fatbar_200_over: ;
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_26814_i3097_i3182
              goto L1351;
              FUN_lambda_26814_i3097_i3182:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [2];
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][3];
                r0[3] = r1;
                r1 = ((object****) lenv) [1][1][1][3];
                r0[1] = r1[2]; lenv = r0; goto FUN_rename_4038_i3097_i3182;
              L1351:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_26814_i3097_i3182; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[3];
              r0[3] = r1;
              r1 = top[34];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1352; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_map_328;
              L1352:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r1 = ((object**) lenv) [1][2];
              ((pxll_vector*)r1)->val[3] = r0;
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            L1339:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_rename_4038_i3097_i3182; r2[2] = lenv;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = (object *) constructed_834[0];
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1353; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_rename_4038_i3097_i3182;
            L1353:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            switch (get_case (r2)) {
              case (TC_NIL): {
                r2 = (object *) 262;
              } break;
              default: {
                goto fatbar_199;
              }
            }
            goto fatbar_199_over;
            fatbar_199:
            r2 = (object *) 6;
            fatbar_199_over: ;
            r1[3] = r2;
            r1 = (object *) 6;
            r2 = ((object*) lenv) [3];
            r1 = PXLL_TEST(r2==r1);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 3);
              // def lambda_27047_i3182
              goto L1354;
              FUN_lambda_27047_i3182:
                check_heap (0);
                r0 = allocate (UOTAG(1), 2);
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object***) lenv) [1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1355; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1355:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[1] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*****) lenv) [1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1356; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1356:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                PXLL_RETURN(0);
              L1354:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_27047_i3182; r2[2] = lenv;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[34];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1357; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
              L1357:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) constructed_833[0];
            }
            r0[6] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r0[2] = r1;
            r1 = (object*)TC_NIL;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [5];
              r0[2] = r1;
              r1 = ((object*) lenv) [6];
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][7];
              r0[1] = r1[2]; lenv = r0; goto FUN_substitute_3986_i3182;
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_832[0];
              r0[2] = r1;
              r1 = (object *) constructed_831[0];
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object****) lenv) [1][1][1][3];
              r1[2] = r2;
              r2 = top[24];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1358; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
              L1358:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_27116_i3182
              goto L1359;
              FUN_lambda_27116_i3182:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object*****) lenv) [1][1][1][1][3];
                r2[2] = r3;
                r3 = ((object**) lenv) [1][2];
                r2[3] = r3;
                r3 = top[29];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1360; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                L1360:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 4);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                r5 = ((pxll_vector*)r5)->val[1];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L1361; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                lenv = r5[2]; goto *r5[1];
                L1361:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L1362; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L1362:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_830;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1363; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L1363:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = top[146];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1364; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_symbol_add_suffix_551;
                L1364:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object****) lenv) [1][1][1][2];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object***) lenv) [1][1][2] = r0;
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object***) lenv) [1][1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1365; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1365:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object****) lenv) [1][1][1][3];
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object***) lenv) [1][1][3] = r0;
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (UOTAG(1), 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object******) lenv) [1][1][1][1][1][3];
                r2[2] = r3;
                r3 = ((object***) lenv) [1][1][2];
                r2[3] = r3;
                r3 = top[29];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1366; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                L1366:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[1] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r3;
                r3 = t;
                r2[2] = r3;
                r3 = (object *) constructed_829[0];
                r2[3] = r3;
                r3 = top[120];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1367; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_make_node_488;
                L1367:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r0[2] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][6];
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object****) lenv) [1][1][1][6] = r0;
                PXLL_RETURN(0);
              L1359:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_27116_i3182; r1[2] = lenv;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object*****) lenv) [1][1][1][1][3];
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_36[0];
              r1[3] = r2;
              r2 = top[23];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1368; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
              L1368:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r0[3] = r1;
              r1 = top[37];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1369; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
              L1369:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object***) lenv) [1][1][5];
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][6];
              r1[3] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][7];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1370; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_substitute_3986_i3182;
              L1370:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][2];
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_36[0];
              r1[3] = r2;
              r2 = top[23];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1371; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
              L1371:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) constructed_36[0];
              r1[3] = r2;
              r2 = top[23];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1372; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
              L1372:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r0[4] = r1;
              r1 = top[125];
              r0[1] = r1[2]; lenv = r0; goto FUN_node_2flet_501;
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_198;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_198_over;
      fatbar_198:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_837;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      fatbar_198_over: ;
      PXLL_RETURN(0);
    L1323:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_inline_application_3985_i3182; r2[2] = lenv;
    r1[6] = r2;
    // def substitute_3986_i3182
    goto L1373;
    FUN_substitute_3986_i3182:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      // def lookup_4092_i3182
      goto L1374;
      FUN_lookup_4092_i3182:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_4095_i3182
        goto L1375;
        FUN_loop_4095_i3182:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*)UITAG(1);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case_noint (r0)) {
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object*****) lenv) [1][1][1][1][2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object*) lenv) [3];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object**) lenv) [1][3];
                    lenv = ((object **)lenv)[1][1];
                    lenv[2] = r0;
                    goto FUN_loop_4095_i3182;
                  }
                  PXLL_RETURN(0);
                } break;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L1375:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_4095_i3182; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object****) lenv) [1][1][1][3];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_4095_i3182;
      L1374:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lookup_4092_i3182; r1[2] = lenv;
      r0[2] = r1;
      // def walk_4093_i3182
      goto L1376;
      FUN_walk_4093_i3182:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1377; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_lookup_4092_i3182;
            L1377:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                lenv = lenv[1];
              } break;
              default: {
                r1 = ((object***) lenv) [1][1][2];
              } break;
            }
            lenv = lenv[1];
          } break;
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1378; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_lookup_4092_i3182;
            L1378:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = allocate (TC_TUPLE, 4);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object*) lenv) [2];
                r3 = ((pxll_vector*)r3)->val[lookup_field((GET_TYPECODE(*r3)-TC_USEROBJ)>>2,53)];
                r2[2] = r3;
                r3 = top[121];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1379; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_varref__3ename_491;
                L1379:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object****) lenv) [1][1][1][2];
                r3 = ((pxll_vector*)r3)->val[3];
                r2[2] = r3;
                r3 = top[21];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1380; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
                L1380:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[4] = r2;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r2;
                r2 = t;
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = (object*)TC_NIL;
                r2[2] = r3;
                r2 = ((object*) lenv) [2];
                r3 = ((object**) lenv) [1][4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r1[3] = r2;
                r2 = top[120];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1381; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                L1381:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
              } break;
              default: {
                r1 = ((object***) lenv) [1][1][2];
              } break;
            }
            lenv = lenv[1];
          } break;
          default: {
            goto fatbar_197;
          }
        }
        goto fatbar_197_over;
        fatbar_197:
        r1 = ((object**) lenv) [1][2];
        fatbar_197_over: ;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object***) lenv) [1][1][3];
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r1 = top[34];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1382; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_map_328;
        L1382:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object*) lenv) [3];
        ((pxll_vector*)r1)->val[3] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      L1376:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_walk_4093_i3182; r1[2] = lenv;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r0[1] = r1[2]; lenv = r0; goto FUN_walk_4093_i3182;
    L1373:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_substitute_3986_i3182; r2[2] = lenv;
    r1[7] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object*)UITAG(0);
    r1[3] = r2;
    r2 = ((object*) lenv) [5];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1383; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_inline_3982_i3182;
    L1383:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    lenv = lenv[1];
    r0[2] = r1;
    r1 = top[147];
    r0[1] = r1[2]; lenv = r0; goto FUN_do_simple_optimizations_554;
  L1215:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_do_one_round_558; r1[2] = lenv;
  r0[149] = r1;
  // def encode-immediate_561
  goto L1384;
  FUN_encode_immediate_561:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)<<unbox(r1));
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = (object *) 3;
        r0 = box((pxll_int)unbox(r1)|unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r1 = box((pxll_int)GET_CHAR(r1));
        r0[3] = r1;
        r1 = (object *) 17;
        r2 = ((object*) lenv) [3];
        r1 = box((pxll_int)unbox(r2)<<unbox(r1));
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        r1 = (object *) 5;
        r0 = box((pxll_int)unbox(r1)|unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UITAG(3)): {
        r0 = (object *) 29;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_46[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_41[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 13;
            PXLL_RETURN(0);
          } else {
            goto fatbar_196;
          }
          PXLL_RETURN(0);
          goto fatbar_196_over;
          fatbar_196:
          r0 = (object *) constructed_44[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 525;
            PXLL_RETURN(0);
          } else {
            lenv = ((object *)lenv)[1];
            goto fatbar_195;
          }
          PXLL_RETURN(0);
          fatbar_196_over: ;
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_195;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_195;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_195_over;
    fatbar_195:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_827;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_195_over: ;
    PXLL_RETURN(0);
  L1384:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_encode_immediate_561; r1[2] = lenv;
  r0[150] = r1;
  // def wrap-in_562
  goto L1385;
  FUN_wrap_in_562:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_533[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_86[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = (object*)TC_NIL;
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        r3 = (object*) &constructed_814;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object*****) lenv) [1][1][1][1][3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = ((object*) lenv) [4];
                        r2 = (object*) &constructed_813;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r0[2] = r1;
                        r1 = top[49];
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_184;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_184;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_184;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_184;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_184_over;
          fatbar_184:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_815;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = top[15];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          fatbar_184_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_183;
        }
        PXLL_RETURN(0);
        goto fatbar_183_over;
        fatbar_183:
        r0 = (object *) constructed_566[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_185;
        }
        PXLL_RETURN(0);
        goto fatbar_185_over;
        fatbar_185:
        r0 = (object *) constructed_771[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_186;
        }
        PXLL_RETURN(0);
        goto fatbar_186_over;
        fatbar_186:
        r0 = (object *) constructed_58[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_187;
        }
        PXLL_RETURN(0);
        goto fatbar_187_over;
        fatbar_187:
        r0 = (object *) constructed_477[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_188;
        }
        PXLL_RETURN(0);
        goto fatbar_188_over;
        fatbar_188:
        r0 = (object *) constructed_97[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_189;
        }
        PXLL_RETURN(0);
        goto fatbar_189_over;
        fatbar_189:
        r0 = (object *) constructed_797[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        } else {
          goto fatbar_190;
        }
        PXLL_RETURN(0);
        goto fatbar_190_over;
        fatbar_190:
        r0 = (object *) constructed_490[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 7);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object***) lenv) [1][1][2];
          r2[2] = r3;
          r3 = top[152];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1386; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_irken_type__3ec_type_563;
          L1386:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = (object*)TC_NIL;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = (object*) &constructed_818;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r2 = ((object*) lenv) [4];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[5] = r2;
          r2 = ((object*) lenv) [5];
          r3 = (object*) &constructed_817;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[6] = r2;
          r2 = ((object*) lenv) [6];
          r3 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[7] = r2;
          r1 = ((object*) lenv) [7];
          r2 = (object*) &constructed_816;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_191;
        }
        PXLL_RETURN(0);
        goto fatbar_191_over;
        fatbar_191:
        r0 = (object *) constructed_800[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          r2 = (object*) &constructed_819;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_192;
        }
        PXLL_RETURN(0);
        goto fatbar_192_over;
        fatbar_192:
        r0 = (object *) constructed_86[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_821;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_820;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_193;
        }
        PXLL_RETURN(0);
        goto fatbar_193_over;
        fatbar_193:
        r0 = (object *) constructed_226[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_823;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_822;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_194;
        }
        PXLL_RETURN(0);
        goto fatbar_194_over;
        fatbar_194:
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[206];
        r0[3] = r1;
        r1 = top[27];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1387; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_321;
        L1387:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_825;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_824;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_826;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = top[15];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
        }
        PXLL_RETURN(0);
        fatbar_194_over: ;
        PXLL_RETURN(0);
        fatbar_193_over: ;
        PXLL_RETURN(0);
        fatbar_192_over: ;
        PXLL_RETURN(0);
        fatbar_191_over: ;
        PXLL_RETURN(0);
        fatbar_190_over: ;
        PXLL_RETURN(0);
        fatbar_189_over: ;
        PXLL_RETURN(0);
        fatbar_188_over: ;
        PXLL_RETURN(0);
        fatbar_187_over: ;
        PXLL_RETURN(0);
        fatbar_186_over: ;
        PXLL_RETURN(0);
        fatbar_185_over: ;
        PXLL_RETURN(0);
        fatbar_183_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1385:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_wrap_in_562; r1[2] = lenv;
  r0[151] = r1;
  // def irken-type->c-type_563
  goto L1388;
  FUN_irken_type__3ec_type_563:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_809[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = allocate (TC_TUPLE, 4);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object**) lenv) [1][2];
                  r2[2] = r3;
                  r3 = top[152];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L1389; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_irken_type__3ec_type_563;
                  L1389:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = (object*)TC_NIL;
                  r1[3] = r2;
                  r2 = ((object*) lenv) [3];
                  r3 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  r1[4] = r2;
                  r1 = ((object*) lenv) [4];
                  r2 = (object*) &constructed_807;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  lenv = lenv[1];
                  r0[2] = r1;
                  r1 = top[49];
                  r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_181;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_181;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_181;
        }
        PXLL_RETURN(0);
        goto fatbar_181_over;
        fatbar_181:
        r0 = (object *) constructed_490[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = allocate (TC_TUPLE, 5);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object**) lenv) [1][2];
                  r2[2] = r3;
                  r3 = top[152];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L1390; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_irken_type__3ec_type_563;
                  L1390:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = (object*)TC_NIL;
                  r1[3] = r2;
                  r2 = ((object*) lenv) [3];
                  r3 = (object*) &constructed_811;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  r1[4] = r2;
                  r2 = ((object*) lenv) [4];
                  r3 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  r1[5] = r2;
                  r1 = ((object*) lenv) [5];
                  r2 = (object*) &constructed_810;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  lenv = lenv[1];
                  r0[2] = r1;
                  r1 = top[49];
                  r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_182;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_182;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_182;
        }
        PXLL_RETURN(0);
        goto fatbar_182_over;
        fatbar_182:
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = ((object*) lenv) [2];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_180;
          }
        }
        PXLL_RETURN(0);
        fatbar_182_over: ;
        PXLL_RETURN(0);
        fatbar_181_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_180;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_180_over;
    fatbar_180:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_812;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[109];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1391; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
    L1391:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_180_over: ;
    PXLL_RETURN(0);
  L1388:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_irken_type__3ec_type_563; r1[2] = lenv;
  r0[152] = r1;
  // def wrap-out_564
  goto L1392;
  FUN_wrap_out_564:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = (object *) constructed_797[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          r2 = (object*) &constructed_795;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_176;
        }
        PXLL_RETURN(0);
        goto fatbar_176_over;
        fatbar_176:
        r0 = (object *) constructed_800[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          r2 = (object*) &constructed_798;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_177;
        }
        PXLL_RETURN(0);
        goto fatbar_177_over;
        fatbar_177:
        r0 = (object *) constructed_46[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_802;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_801;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_178;
        }
        PXLL_RETURN(0);
        goto fatbar_178_over;
        fatbar_178:
        r0 = (object *) constructed_226[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_804;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_803;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          goto fatbar_179;
        }
        PXLL_RETURN(0);
        goto fatbar_179_over;
        fatbar_179:
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = top[206];
        r0[3] = r1;
        r1 = top[27];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1393; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_321;
        L1393:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = (object*) &constructed_806;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          r2 = (object*) &constructed_805;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } else {
          r0 = ((object**) lenv) [1][3];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
        fatbar_179_over: ;
        PXLL_RETURN(0);
        fatbar_178_over: ;
        PXLL_RETURN(0);
        fatbar_177_over: ;
        PXLL_RETURN(0);
        fatbar_176_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_175;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_175_over;
    fatbar_175:
    r0 = ((object*) lenv) [3];
    PXLL_RETURN(0);
    fatbar_175_over: ;
    PXLL_RETURN(0);
  L1392:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_wrap_out_564; r1[2] = lenv;
  r0[153] = r1;
  // def cexp-subst_565
  goto L1394;
  FUN_cexp_subst_565:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = (object *) 9474;
    r1[3] = r2;
    r2 = top[51];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1395; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_split_356;
    L1395:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4281
    goto L1396;
    FUN_loop_4281:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1397; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1397:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = top[49];
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object*) &constructed_793;
          r1[3] = r2;
          r2 = top[52];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1398; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
          L1398:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_791;
                r0[2] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r0[3] = r1;
                r1 = top[15];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object****) lenv) [1][1][1][2];
                r2 = (object*) &constructed_792;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r1 = ((object*) lenv) [3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_4281;
              } break;
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_174;
          }
          PXLL_RETURN(0);
          goto fatbar_174_over;
          fatbar_174:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[172];
          r1[2] = r2;
          r2 = (object *) 1;
          r3 = ((object**) lenv) [1][2];
          range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
          r2 = (object *) 1;
          r3 = ((object**) lenv) [1][2];
          r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
          r1[3] = r2;
          r2 = top[67];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1399; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
          L1399:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UITAG(1)): {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_794;
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][2];
              r0[3] = r1;
              r1 = top[15];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 4);
              r2 = ((object****) lenv) [1][1][1][2];
              r1[2] = r2;
              r2 = (object *) 3;
              r1[3] = r2;
              r2 = ((object****) lenv) [1][1][1][2];
              r2 = box((pxll_int)((pxll_string*)(r2))->len);
              r1[4] = r2;
              r2 = top[47];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1400; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_substring_347;
              L1400:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[29];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1401; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
              L1401:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r2 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r1 = ((object***) lenv) [1][1][3];
              lenv = ((object ***)lenv)[1][1][1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_4281;
            } break;
          }
          PXLL_RETURN(0);
          fatbar_174_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1396:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4281; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = allocate (TC_TUPLE, 3);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object***) lenv) [1][1][2];
    r2[2] = r3;
    r3 = top[21];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1402; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
    L1402:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1403; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
    L1403:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4281;
  L1394:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cexp_subst_565; r1[2] = lenv;
  r0[154] = r1;
  // def getenv-or_575
  goto L1404;
  FUN_getenv_or_575:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[55];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1405; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_362;
    L1405:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1 = (object*)getenv (((pxll_string*)(r1))->data);
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST((char*)r1==NULL)) {
      r1 = (object*) &constructed_790;
    } else {
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[61];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1406; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_copy_cstring_374;
      L1406:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
    }
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = (object *) 1;
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = ((object**) lenv) [1][3];
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [3];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1404:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_getenv_or_575; r1[2] = lenv;
  r0[155] = r1;
  r1 = (object *) 1;
  r0[156] = r1;
  r1 = (object *) 3;
  r0[157] = r1;
  r1 = (object *) 5;
  r0[158] = r1;
  r1 = (object *) 7;
  r0[159] = r1;
  r1 = (object *) 11;
  r0[160] = r1;
  r1 = top[10];
  r0[161] = r1;
  r1 = (object *) constructed_789[0];
  r0[162] = r1;
  r1 = box((pxll_int)O_RDONLY);
  r0[163] = r1;
  r1 = box((pxll_int)O_WRONLY);
  r0[164] = r1;
  r1 = box((pxll_int)O_CREAT);
  r0[165] = r1;
  r1 = box((pxll_int)O_TRUNC);
  r0[166] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = box((pxll_int)argc);
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  ensure_heap (2, unbox(r2));
  r2 = (object*) &constructed_788;
  r3 = ((object*) lenv) [2];
  if (unbox(r3) == 0) { r2 = (object *) TC_EMPTY_VECTOR; } else {
    t = alloc_no_clear (TC_VECTOR, unbox(r3));
    for (i=0; i<unbox(r3); i++) { t[i+1] = r2; }
    r2 = t;
  }
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  // def loop_4835
  goto L1407;
  FUN_loop_4835:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r0)==0)) {
      r0 = ((object***) lenv) [1][1][3];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 3;
      r2 = ((object**) lenv) [1][2];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r1 = (object*)argv[unbox(r1)];
      r0[2] = r1;
      r1 = top[61];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1408; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_copy_cstring_374;
      L1408:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r1 = (object *) 3;
      r2 = ((object*) lenv) [2];
      r1 = box((pxll_int)unbox(r2)-unbox(r1));
      r2 = ((object***) lenv) [1][1][3];
      range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
      ((pxll_vector*)r2)->val[unbox(r1)] = r0;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)-unbox(r0));
      lenv[2] = r0;
      goto FUN_loop_4835;
    }
    PXLL_RETURN(0);
  L1407:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_loop_4835; r3[2] = lenv;
  r2[2] = r3;
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object**) lenv) [1][2];
  r2[2] = r3;
  r3 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1409; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_loop_4835;
  L1409:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  lenv = lenv[1];
  r1[4] = r2;
  r1 = allocate (UOTAG(18), 2);
  r2 = ((object*) lenv) [2];
  r1[1] = r2;
  r2 = ((object*) lenv) [4];
  r1[2] = r2;
  lenv = lenv[1];
  r0[167] = r1;
  r1 = allocate (TC_TUPLE, 5);
  r1[1] = lenv; lenv = r1;
  r2 = (object *) 14;
  r2 = r2;
  r1[2] = r2;
  r2 = (object *) 14;
  r2 = r2;
  r1[3] = r2;
  r2 = (object *) 14;
  r2 = r2;
  r1[4] = r2;
  r2 = (object *) 14;
  r2 = r2;
  r1[5] = r2;
  r1 = allocate (UOTAG(17), 5);
  r2 = ((object*) lenv) [2];
  r1[1] = r2;
  r2 = ((object*) lenv) [4];
  r1[2] = r2;
  r2 = (object *) 1;
  r1[3] = r2;
  r2 = ((object*) lenv) [5];
  r1[4] = r2;
  r2 = ((object*) lenv) [3];
  r1[5] = r2;
  lenv = lenv[1];
  r0[168] = r1;
  r1 = (object *) 1;
  r0[169] = r1;
  r1 = top[168];
  r0[170] = r1;
  r1 = (object *) constructed_787[0];
  r0[171] = r1;
  r1 = (object *) constructed_786[0];
  r0[172] = r1;
  r1 = (object *) constructed_785[0];
  r0[173] = r1;
  r1 = (object *) constructed_784[0];
  r0[174] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_783;
  r1[2] = r2;
  r2 = top[57];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1410; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_364;
  L1410:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[175] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_782;
  r1[2] = r2;
  r2 = top[57];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1411; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_364;
  L1411:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[176] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = allocate (TC_TUPLE, 3);
  r3 = top[174];
  r2[2] = r3;
  r3 = (object *) constructed_36[0];
  r2[3] = r3;
  r3 = top[23];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1412; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
  L1412:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = top[175];
  r1[3] = r2;
  r2 = top[23];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1413; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
  L1413:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[177] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_781;
  r1[2] = r2;
  r2 = top[57];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1414; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_364;
  L1414:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[178] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) constructed_780[0];
  r1[2] = r2;
  r2 = top[85];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1415; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1415:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[179] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = top[177];
  r1[2] = r2;
  r2 = top[85];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1416; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1416:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[180] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = top[178];
  r1[2] = r2;
  r2 = top[85];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1417; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1417:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[181] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  r3 = allocate (TC_TUPLE, 3);
  r4 = allocate (TC_TUPLE, 3);
  r5 = top[176];
  r4[2] = r5;
  r5 = (object *) constructed_36[0];
  r4[3] = r5;
  r5 = top[23];
  t = allocate (TC_SAVE, 7);
  t[1] = k; t[2] = lenv; t[3] = &&L1418; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
  r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_313;
  L1418:
  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
  r4 = result;
  r3[2] = r4;
  r4 = top[178];
  r3[3] = r4;
  r4 = top[23];
  t = allocate (TC_SAVE, 6);
  t[1] = k; t[2] = lenv; t[3] = &&L1419; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
  r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
  L1419:
  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
  r3 = result;
  r2[2] = r3;
  r2 = ((object*) lenv) [2];
  r3 = (object *) 11522;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r1[2] = r2;
  r2 = top[85];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1420; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1420:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[182] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[115];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1421; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1421:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[183] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_226[0];
  r1[2] = r2;
  r2 = (object *) constructed_779[0];
  r1[3] = r2;
  r2 = top[106];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1422; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1422:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[184] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_771[0];
  r1[2] = r2;
  r2 = (object *) constructed_778[0];
  r1[3] = r2;
  r2 = top[106];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1423; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1423:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[185] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_86[0];
  r1[2] = r2;
  r2 = (object *) constructed_777[0];
  r1[3] = r2;
  r2 = top[106];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1424; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1424:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[186] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_773[0];
  r1[2] = r2;
  r2 = (object *) constructed_776[0];
  r1[3] = r2;
  r2 = top[106];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1425; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1425:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[187] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_46[0];
  r1[2] = r2;
  r2 = (object *) constructed_775[0];
  r1[3] = r2;
  r2 = top[106];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1426; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1426:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[188] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_58[0];
  r1[2] = r2;
  r2 = (object *) constructed_774[0];
  r1[3] = r2;
  r2 = top[106];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1427; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1427:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[189] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = top[189];
  r3 = ((object*) lenv) [2];
  r4 = (object *) constructed_58[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[3] = r2;
  r2 = top[187];
  r3 = ((object*) lenv) [3];
  r4 = (object *) constructed_773[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[4] = r2;
  r2 = top[186];
  r3 = ((object*) lenv) [4];
  r4 = (object *) constructed_86[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[5] = r2;
  r2 = top[185];
  r3 = ((object*) lenv) [5];
  r4 = (object *) constructed_771[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[6] = r2;
  r1 = top[184];
  r2 = ((object*) lenv) [6];
  r3 = (object *) constructed_226[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r3;
  t[2] = r1;
  t[3] = r2;
  r1 = t;
  lenv = lenv[1];
  r0[190] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object *) constructed_512[0];
  t = alloc_no_clear (UOTAG(1),1);
  t[1] = r2;
  r2 = t;
  r1[2] = r2;
  r2 = (object *) 6;
  t = alloc_no_clear (UOTAG(4),1);
  t[1] = r2;
  r2 = t;
  r1[3] = r2;
  r2 = (object*)TC_NIL;
  r1[4] = r2;
  r2 = ((object*) lenv) [4];
  r3 = ((object*) lenv) [3];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[5] = r2;
  r2 = ((object*) lenv) [5];
  r3 = ((object*) lenv) [2];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[6] = r2;
  r1 = ((object*) lenv) [6];
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  lenv = lenv[1];
  r0[191] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object *) constructed_510[0];
  t = alloc_no_clear (UOTAG(1),1);
  t[1] = r2;
  r2 = t;
  r1[2] = r2;
  r2 = (object *) 6;
  t = alloc_no_clear (UOTAG(4),1);
  t[1] = r2;
  r2 = t;
  r1[3] = r2;
  r2 = (object*)TC_NIL;
  r1[4] = r2;
  r2 = ((object*) lenv) [4];
  r3 = ((object*) lenv) [3];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[5] = r2;
  r2 = ((object*) lenv) [5];
  r3 = ((object*) lenv) [2];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[6] = r2;
  r1 = ((object*) lenv) [6];
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  lenv = lenv[1];
  r0[192] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[115];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1428; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1428:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[193] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[115];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1429; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1429:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[194] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_543[0];
  r1[2] = r2;
  r2 = (object *) constructed_769[0];
  r1[3] = r2;
  r2 = top[106];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1430; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1430:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[195] = r1;
  r1 = (object *) 1;
  r0[196] = r1;
  r1 = (object *) 5;
  r0[197] = r1;
  r1 = (object *) 7;
  r0[198] = r1;
  r1 = allocate (TC_TUPLE, 5);
  r1[1] = lenv; lenv = r1;
  // def in_3730_i4845
  goto L1431;
  FUN_in_3730_i4845:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3736_i4845
    goto L1432;
    FUN_loop_3736_i4845:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object****) lenv) [1][1][1][3];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } else {
            r0 = ((object*) lenv) [3];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_loop_3736_i4845;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1432:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3736_i4845; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3736_i4845;
  L1431:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_in_3730_i4845; r2[2] = lenv;
  r1[2] = r2;
  // def add_3731_i4845
  goto L1433;
  FUN_add_3731_i4845:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1434; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1434:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[0] = r0;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1433:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3731_i4845; r2[2] = lenv;
  r1[3] = r2;
  // def get_3732_i4845
  goto L1435;
  FUN_get_3732_i4845:
    r0 = ((object*) lenv) [2];
    r0 = ((pxll_vector*)r0)->val[0];
    PXLL_RETURN(0);
  L1435:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_3732_i4845; r2[2] = lenv;
  r1[4] = r2;
  // def iterate_3733_i4845
  goto L1436;
  FUN_iterate_3733_i4845:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3745_i4845
    goto L1437;
    FUN_loop_3745_i4845:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1438; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1438:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_3745_i4845;
        } break;
      }
      PXLL_RETURN(0);
    L1437:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3745_i4845; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3745_i4845;
  L1436:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3733_i4845; r2[2] = lenv;
  r1[5] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(12), 4);
  r3 = ((object**) lenv) [1][3];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][2];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def new_3750_i4845
  goto L1439;
  FUN_new_3750_i4845:
    r0 = allocate (UOTAG(16), 2);
    r1 = ((object*) lenv) [2];
    r0[1] = r1;
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1439:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_new_3750_i4845; r2[2] = lenv;
  r1[2] = r2;
  r1 = ((object*) lenv) [2];
  lenv = lenv[1];
  lenv = lenv[1];
  lenv = lenv[1];
  r0[199] = r1;
  r1 = allocate (TC_TUPLE, 9);
  r1[1] = lenv; lenv = r1;
  // def add_3752_i4846
  goto L1440;
  FUN_add_3752_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r0 = ((object**) lenv) [1][4];
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][3];
    t = alloc_no_clear (UOTAG(1),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    lenv = lenv[1];
    r1 = ((object*) lenv) [2];
    ((pxll_vector*)r1)->val[0] = r0;
    PXLL_RETURN(0);
  L1440:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3752_i4846; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_3753_i4846
  goto L1441;
  FUN_lookup_3753_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3765_i4846
    goto L1442;
    FUN_loop_3765_i4846:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object****) lenv) [1][1][1][3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = ((object*) lenv) [4];
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_loop_3765_i4846;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1442:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3765_i4846; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3765_i4846;
  L1441:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_3753_i4846; r2[2] = lenv;
  r1[3] = r2;
  // def lookup*_3754_i4846
  goto L1443;
  FUN_lookup_splat_3754_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = ((object***) lenv) [1][1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1444; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_lookup_3753_i4846;
    L1444:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = ((object**) lenv) [1][4];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1443:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_splat_3754_i4846; r2[2] = lenv;
  r1[4] = r2;
  // def get-error_3755_i4846
  goto L1445;
  FUN_get_error_3755_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[3] = r2;
    r2 = ((object***) lenv) [1][1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1446; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_lookup_3753_i4846;
    L1446:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1445:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_error_3755_i4846; r2[2] = lenv;
  r1[5] = r2;
  // def iterate_3756_i4846
  goto L1447;
  FUN_iterate_3756_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3782_i4846
    goto L1448;
    FUN_loop_3782_i4846:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1449; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1449:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [4];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_3782_i4846;
        } break;
      }
      PXLL_RETURN(0);
    L1448:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3782_i4846; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3782_i4846;
  L1447:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3756_i4846; r2[2] = lenv;
  r1[6] = r2;
  // def map_3757_i4846
  goto L1450;
  FUN_map_3757_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3789_i4846
    goto L1451;
    FUN_loop_3789_i4846:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = (object *) constructed_36[0];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1452; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1452:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = ((object*) lenv) [4];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3789_i4846;
        } break;
      }
      PXLL_RETURN(0);
    L1451:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3789_i4846; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_768[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3789_i4846;
  L1450:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_map_3757_i4846; r2[2] = lenv;
  r1[7] = r2;
  // def keys_3758_i4846
  goto L1453;
  FUN_keys_3758_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3796_i4846
    goto L1454;
    FUN_loop_3796_i4846:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = (object *) constructed_36[0];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3796_i4846;
        } break;
      }
      PXLL_RETURN(0);
    L1454:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3796_i4846; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_767[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3796_i4846;
  L1453:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_keys_3758_i4846; r2[2] = lenv;
  r1[8] = r2;
  // def values_3759_i4846
  goto L1455;
  FUN_values_3759_i4846:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3802_i4846
    goto L1456;
    FUN_loop_3802_i4846:
      check_heap (0);
      r0 = ((object*) lenv) [3];
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = (object *) constructed_36[0];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r1 = UOBJ_GET(r1,2);
          r0[3] = r1;
          r0 = ((object**) lenv) [1][2];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3802_i4846;
        } break;
      }
      PXLL_RETURN(0);
    L1456:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3802_i4846; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_766[0];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3802_i4846;
  L1455:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_values_3759_i4846; r2[2] = lenv;
  r1[9] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(14), 8);
  r3 = ((object**) lenv) [1][2];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][3];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r3 = ((object**) lenv) [1][6];
  r2[5] = r3;
  r3 = ((object**) lenv) [1][8];
  r2[6] = r3;
  r3 = ((object**) lenv) [1][7];
  r2[7] = r3;
  r3 = ((object**) lenv) [1][9];
  r2[8] = r3;
  r1[2] = r2;
  // def lambda_25050_i4846
  goto L1457;
  FUN_lambda_25050_i4846:
    r0 = allocate (UOTAG(15), 2);
    r1 = (object*)UITAG(0);
    r0[1] = r1;
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1457:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_25050_i4846; r1[2] = lenv;
  lenv = lenv[1];
  lenv = lenv[1];
  r0[200] = r1;
  r1 = allocate (TC_TUPLE, 9);
  r1[1] = lenv; lenv = r1;
  // def add_3808_i4847
  goto L1458;
  FUN_add_3808_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[0];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1459; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L1459:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_765;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[5] = r1;
        r1 = top[74];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1460; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_409;
        L1460:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[2] = r0;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1458:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3808_i4847; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_3809_i4847
  goto L1461;
  FUN_lookup_3809_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r0[4] = r1;
    r1 = top[75];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fmember_411;
  L1461:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_3809_i4847; r2[2] = lenv;
  r1[3] = r2;
  // def lookup*_3810_i4847
  goto L1462;
  FUN_lookup_splat_3810_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[0];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1463; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L1463:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = ((object**) lenv) [1][4];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1462:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_splat_3810_i4847; r2[2] = lenv;
  r1[4] = r2;
  // def get-error_3811_i4847
  goto L1464;
  FUN_get_error_3811_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[0];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1465; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L1465:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      } break;
    }
    PXLL_RETURN(0);
  L1464:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_error_3811_i4847; r2[2] = lenv;
  r1[5] = r2;
  // def iterate_3812_i4847
  goto L1466;
  FUN_iterate_3812_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [3];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r0[3] = r1;
    r1 = top[76];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_412;
  L1466:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3812_i4847; r2[2] = lenv;
  r1[6] = r2;
  // def map_3813_i4847
  goto L1467;
  FUN_map_3813_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_764[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_25159_i4847
    goto L1468;
    FUN_lambda_25159_i4847:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][3];
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][3];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1469; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1469:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      ((object**) lenv) [1][2] = r0;
      PXLL_RETURN(0);
    L1468:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_25159_i4847; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r0[3] = r1;
    r1 = top[77];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1470; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2freverse_413;
    L1470:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L1467:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_map_3813_i4847; r2[2] = lenv;
  r1[7] = r2;
  // def keys_3814_i4847
  goto L1471;
  FUN_keys_3814_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r0[2] = r1;
    r1 = top[78];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fkeys_414;
  L1471:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_keys_3814_i4847; r2[2] = lenv;
  r1[8] = r2;
  // def values_3815_i4847
  goto L1472;
  FUN_values_3815_i4847:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r0[2] = r1;
    r1 = top[79];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fvalues_415;
  L1472:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_values_3815_i4847; r2[2] = lenv;
  r1[9] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(14), 8);
  r3 = ((object**) lenv) [1][2];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][3];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r3 = ((object**) lenv) [1][6];
  r2[5] = r3;
  r3 = ((object**) lenv) [1][8];
  r2[6] = r3;
  r3 = ((object**) lenv) [1][7];
  r2[7] = r3;
  r3 = ((object**) lenv) [1][9];
  r2[8] = r3;
  r1[2] = r2;
  // def lambda_25207_i4847
  goto L1473;
  FUN_lambda_25207_i4847:
    r0 = allocate (UOTAG(13), 3);
    r1 = ((object*) lenv) [2];
    r0[1] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = top[168];
    r0[3] = r1;
    PXLL_RETURN(0);
  L1473:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_25207_i4847; r1[2] = lenv;
  lenv = lenv[1];
  lenv = lenv[1];
  r0[201] = r1;
  r1 = allocate (TC_TUPLE, 5);
  r1[1] = lenv; lenv = r1;
  // def in_3843_i4848
  goto L1474;
  FUN_in_3843_i4848:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object**) lenv) [1][2];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,53)];
    r1[2] = r2;
    r2 = top[12];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = ((object***) lenv) [1][1][3];
    r3 = UOBJ_GET(r3,1);
    r2[2] = r3;
    r2 = ((object*) lenv) [2];
    lenv = lenv[1];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1475; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L1475:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1474:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_in_3843_i4848; r2[2] = lenv;
  r1[2] = r2;
  // def add_3844_i4848
  goto L1476;
  FUN_add_3844_i4848:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1477; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_in_3843_i4848;
    L1477:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 5);
      r1 = ((object*) lenv) [2];
      r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
      r0[2] = r1;
      r1 = top[12];
      r0[3] = r1;
      r1 = ((object*) lenv) [3];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = ((object**) lenv) [1][3];
      r2 = UOBJ_GET(r2,1);
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      lenv = lenv[1];
      r0[4] = r1;
      r1 = ((object*) lenv) [3];
      r0[5] = r1;
      r1 = top[74];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1478; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_409;
      L1478:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = ((object*) lenv) [2];
      ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)] = r0;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1476:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3844_i4848; r2[2] = lenv;
  r1[3] = r2;
  // def get_3845_i4848
  goto L1479;
  FUN_get_3845_i4848:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r0[2] = r1;
    r1 = top[79];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fvalues_415;
  L1479:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_3845_i4848; r2[2] = lenv;
  r1[4] = r2;
  // def iterate_3846_i4848
  goto L1480;
  FUN_iterate_3846_i4848:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_25263_i4848
    goto L1481;
    FUN_lambda_25263_i4848:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][3];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1481:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_25263_i4848; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,53)];
    r0[3] = r1;
    r1 = top[76];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_412;
  L1480:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3846_i4848; r2[2] = lenv;
  r1[5] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(12), 4);
  r3 = ((object**) lenv) [1][3];
  r2[1] = r3;
  r3 = ((object**) lenv) [1][4];
  r2[2] = r3;
  r3 = ((object**) lenv) [1][2];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][5];
  r2[4] = r3;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def new_3858_i4848
  goto L1482;
  FUN_new_3858_i4848:
    r0 = allocate (UOTAG(11), 2);
    r1 = ((object**) lenv) [1][2];
    r0[1] = r1;
    r1 = top[168];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1482:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_new_3858_i4848; r2[2] = lenv;
  r1[2] = r2;
  r1 = ((object*) lenv) [2];
  lenv = lenv[1];
  lenv = lenv[1];
  lenv = lenv[1];
  r0[202] = r1;
  r1 = (object *) 27;
  r0[203] = r1;
  r1 = (object *) 1;
  r0[204] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) 1;
  r2[2] = r3;
  r3 = top[115];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1483; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
  L1483:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  // def lambda_28530
  goto L1484;
  FUN_lambda_28530:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 4);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = ((object**) lenv) [1][2];
    r3 = ((pxll_vector*)r3)->val[1];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1485; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    lenv = r3[2]; goto *r3[1];
    L1485:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = top[58];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1486; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
    L1486:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = ((object*) lenv) [3];
    r3 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[4] = r2;
    r1 = ((object*) lenv) [4];
    r2 = (object*) &constructed_763;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r0[2] = r1;
    r1 = top[49];
    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
  L1484:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_28530; r1[2] = lenv;
  lenv = lenv[1];
  r0[205] = r1;
  r1 = (object *) constructed_762[0];
  r0[206] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object*) &constructed_745;
  r2[2] = r3;
  r3 = top[57];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1487; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_string__3elist_364;
  L1487:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = top[85];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1488; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1488:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[207] = r1;
  r1 = (object*) &constructed_744;
  r0[208] = r1;
  r1 = (object*) &constructed_743;
  r0[209] = r1;
  r1 = (object*) &constructed_742;
  r0[210] = r1;
  r1 = (object*) &constructed_741;
  r0[211] = r1;
  r0 = top[168];
  r1 = top[168];
  ((pxll_vector*)r1)->val[1] = r0;
  r0 = top[168];
  r1 = top[168];
  ((pxll_vector*)r1)->val[3] = r0;
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = (object *) pxll_internal_symbols;
  r0[2] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  // def loop_1252_i4852
  goto L1489;
  FUN_loop_1252_i4852:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = box((pxll_int)(r1 == (object*) TC_EMPTY_VECTOR) ? 0 : GET_TUPLE_LENGTH(*r1));
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object**) lenv) [1][2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r2 = ((object***) lenv) [1][1][2];
      range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
      r1 = ((pxll_vector*)r2)->val[unbox(r1)];
      r0[2] = r1;
      r1 = top[81];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1490; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_intern_symbol_420;
      L1490:
      ; lenv = k[2]; k = k[1];
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv[2] = r0;
      goto FUN_loop_1252_i4852;
    }
    PXLL_RETURN(0);
  L1489:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_loop_1252_i4852; r1[2] = lenv;
  r0[2] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r1 = (object *) 1;
  r0[2] = r1;
  r1 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L1491; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_loop_1252_i4852;
  L1491:
  ; lenv = k[2]; k = k[1];
  r0 = result;
  lenv = lenv[1];
  lenv = lenv[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = top[167];
  r1 = ((pxll_vector*)r1)->val[0];
  r0[2] = r1;
  r0 = (object *) 5;
  r1 = ((object*) lenv) [2];
  r0 = PXLL_TEST(unbox(r1)<unbox(r0));
  lenv = lenv[1];
  if PXLL_IS_TRUE(r0) {
    r0 = (object*) &constructed_68;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_68;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_740;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_740;
    PXLL_UNDEFINED; result=r0; goto Lreturn;
  } else {
    r0 = (object *) 14;
  }
  r0 = allocate (TC_TUPLE, 56);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (UOTAG(8), 18);
  r2 = (object *) constructed_739[0];
  r1[1] = r2;
  r2 = (object *) constructed_738[0];
  r1[2] = r2;
  r2 = (object*)UITAG(0);
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = top[84];
  r2[2] = r3;
  r3 = top[201];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1492; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1492:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = (object*)UITAG(0);
  r1[5] = r2;
  r2 = top[168];
  r1[6] = r2;
  r2 = (object *) constructed_737[0];
  r1[7] = r2;
  r2 = top[168];
  r1[8] = r2;
  r2 = (object *) constructed_736[0];
  r1[9] = r2;
  r2 = (object*)UITAG(0);
  r1[10] = r2;
  r2 = allocate (UOTAG(10), 6);
  r3 = (object *) 6;
  r2[1] = r3;
  r3 = (object*) &constructed_735;
  r2[2] = r3;
  r3 = (object *) 6;
  r2[3] = r3;
  r3 = (object *) 6;
  r2[4] = r3;
  r3 = (object *) 6;
  r2[5] = r3;
  r3 = (object *) 6;
  r2[6] = r3;
  r1[11] = r2;
  r2 = (object *) constructed_734[0];
  r1[12] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  r3 = (object *) -1;
  r2[2] = r3;
  r2 = allocate (TC_TUPLE, 3);
  r2[1] = lenv; lenv = r2;
  // def allocate_2648_i5_i4734_i4853
  goto L1493;
  FUN_allocate_2648_i5_i4734_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2651_i5_i4734_i4853
    goto L1494;
    FUN_loop_2651_i5_i4734_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[11];
      r0[4] = r1;
      r1 = top[26];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1495; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_member_question_320;
      L1495:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        lenv[2] = r0;
        goto FUN_loop_2651_i5_i4734_i4853;
      } else {
        r0 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
          r0 = ((object*) lenv) [2];
        } else {
          r0 = ((object*****) lenv) [1][1][1][1][2];
        }
        ((object*****) lenv) [1][1][1][1][2] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1494:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2651_i5_i4734_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2651_i5_i4734_i4853;
  L1493:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_allocate_2648_i5_i4734_i4853; r3[2] = lenv;
  r2[2] = r3;
  // def get-max_2649_i5_i4734_i4853
  goto L1496;
  FUN_get_max_2649_i5_i4734_i4853:
    r0 = ((object**) lenv) [1][2];
    PXLL_RETURN(0);
  L1496:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_get_max_2649_i5_i4734_i4853; r3[2] = lenv;
  r2[3] = r3;
  r2 = allocate (UOTAG(9), 2);
  r3 = ((object*) lenv) [2];
  r2[1] = r3;
  r3 = ((object*) lenv) [3];
  r2[2] = r3;
  lenv = lenv[1];
  lenv = lenv[1];
  r1[13] = r2;
  r2 = (object *) constructed_733[0];
  r1[14] = r2;
  r2 = (object*) &constructed_732;
  r1[15] = r2;
  r2 = (object*)UITAG(0);
  r1[16] = r2;
  r2 = (object*)UITAG(0);
  r1[17] = r2;
  r2 = top[168];
  r1[18] = r2;
  r0[2] = r1;
  r1 = top[167];
  r1 = ((pxll_vector*)r1)->val[1];
  r0[3] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[10];
  r0[4] = r1;
  r1 = ((object*) lenv) [3];
  r1 = box((pxll_int)(r1 == (object*) TC_EMPTY_VECTOR) ? 0 : GET_TUPLE_LENGTH(*r1));
  r0[5] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def $loop_4778_i4735_i4853
  goto L1497;
  FUN__24loop_4778_i4735_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r0 = ((object****) lenv) [1][1][1][5];
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = top[167];
      r1 = ((pxll_vector*)r1)->val[1];
      r2 = ((object**) lenv) [1][2];
      range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r2));
      r1 = ((pxll_vector*)r1)->val[unbox(r2)];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_726;
      r1[3] = r2;
      r2 = top[52];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1498; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
      L1498:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[3] = r0;
      } else {
        goto fatbar_168;
      }
      goto fatbar_168_over;
      fatbar_168:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_727;
      r1[3] = r2;
      r2 = top[52];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1499; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
      L1499:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[0] = r0;
      } else {
        goto fatbar_169;
      }
      goto fatbar_169_over;
      fatbar_169:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_728;
      r1[3] = r2;
      r2 = top[52];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1500; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
      L1500:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)+unbox(r0));
        lenv = lenv[1];
        ((object**) lenv) [1][2] = r0;
        r0 = ((object**) lenv) [1][2];
        r1 = ((object****) lenv) [1][1][1][3];
        range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r0));
        r0 = ((pxll_vector*)r1)->val[unbox(r0)];
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[1] = r0;
      } else {
        goto fatbar_170;
      }
      goto fatbar_170_over;
      fatbar_170:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_729;
      r1[3] = r2;
      r2 = top[52];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1501; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
      L1501:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[4] = r0;
      } else {
        goto fatbar_171;
      }
      goto fatbar_171_over;
      fatbar_171:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_730;
      r1[3] = r2;
      r2 = top[52];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1502; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
      L1502:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[5] = r0;
      } else {
        goto fatbar_172;
      }
      goto fatbar_172_over;
      fatbar_172:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object**) lenv) [1][2];
      r1[2] = r2;
      r2 = (object*) &constructed_731;
      r1[3] = r2;
      r2 = top[52];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1503; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
      L1503:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 262;
        r1 = ((object****) lenv) [1][1][1][4];
        ((pxll_vector*)r1)->val[2] = r0;
      } else {
        goto fatbar_173;
      }
      goto fatbar_173_over;
      fatbar_173:
      r0 = (object *) 14;
      fatbar_173_over: ;
      fatbar_172_over: ;
      fatbar_171_over: ;
      fatbar_170_over: ;
      fatbar_169_over: ;
      fatbar_168_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = ((object*) lenv) [2];
      r0 = box((pxll_int)unbox(r1)+unbox(r0));
      lenv = lenv[1];
      lenv[2] = r0;
      goto FUN__24loop_4778_i4735_i4853;
    }
    PXLL_RETURN(0);
  L1497:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN__24loop_4778_i4735_i4853; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1504; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4778_i4735_i4853;
  L1504:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[6] = r1;
  r1 = allocate (TC_TUPLE, 29);
  r1[1] = lenv; lenv = r1;
  // def go_1966_i4736_i4853
  goto L1505;
  FUN_go_1966_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    switch (get_case (r1)) {
      case (UOTAG(0)): {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object***) lenv) [1][1][2];
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        switch (get_case (r1)) {
          case (TC_NIL): {
            r1 = (object *) constructed_724[0];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (TC_NIL): {
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1506; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                L1506:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_167;
              }
            }
            lenv = lenv[1];
          } break;
        }
        goto fatbar_167_over;
        fatbar_167:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][5];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1507; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_find_declarations_1971_i4736_i4853;
        L1507:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][4];
        r1[3] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1508; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_1972_i4736_i4853;
        L1508:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        fatbar_167_over: ;
        lenv = lenv[1];
      } break;
      default: {
        goto fatbar_166;
      }
    }
    goto fatbar_166_over;
    fatbar_166:
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_725;
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[15];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1509; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
    L1509:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    fatbar_166_over: ;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object***) lenv) [1][1][20];
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_with_constructors_1989_i4736_i4853;
  L1505:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_go_1966_i4736_i4853; r2[2] = lenv;
  r1[2] = r2;
  // def wrap-fix_1967_i4736_i4853
  goto L1510;
  FUN_wrap_fix_1967_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1511; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L1511:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)>unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 9);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_723[0];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[3] = r1;
      r1 = ((object**) lenv) [1][3];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[4] = r1;
      r1 = (object*)TC_NIL;
      r0[5] = r1;
      r1 = ((object*) lenv) [5];
      r2 = ((object**) lenv) [1][4];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[6] = r1;
      r1 = ((object*) lenv) [6];
      r2 = ((object*) lenv) [4];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[7] = r1;
      r1 = ((object*) lenv) [7];
      r2 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[8] = r1;
      r1 = ((object*) lenv) [8];
      r2 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[9] = r1;
      r0 = ((object*) lenv) [9];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r0;
      r0 = t;
      PXLL_RETURN(0);
    } else {
      r0 = ((object*) lenv) [4];
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1510:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_fix_1967_i4736_i4853; r2[2] = lenv;
  r1[3] = r2;
  // def wrap-definitions_1969_i4736_i4853
  goto L1512;
  FUN_wrap_definitions_1969_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_721[0];
    r0[2] = r1;
    r1 = (object *) constructed_720[0];
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_11388_i4736_i4853
    goto L1513;
    FUN_lambda_11388_i4736_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object***) lenv) [1][1][2] = r0;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][3];
          r1[2] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][8];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1514; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
          L1514:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object***) lenv) [1][1][3] = r0;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1513:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_11388_i4736_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[37];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1515; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L1515:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 4);
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = (object *) constructed_36[0];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1516; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L1516:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = (object *) constructed_36[0];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1517; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L1517:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 3);
    r2[1] = lenv; lenv = r2;
    r3 = (object *) constructed_625[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r3;
    r3 = t;
    r2[2] = r3;
    r3 = ((object***) lenv) [1][1][3];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r2 = ((object*) lenv) [3];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][8];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1518; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
    L1518:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][3];
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_fix_1967_i4736_i4853;
  L1512:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_definitions_1969_i4736_i4853; r2[2] = lenv;
  r1[4] = r2;
  // def find-declarations_1971_i4736_i4853
  goto L1519;
  FUN_find_declarations_1971_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_2022_i4736_i4853
    goto L1520;
    FUN_recur_2022_i4736_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [3];
          r0[2] = r1;
          r1 = (object *) constructed_36[0];
          r0[3] = r1;
          r1 = top[23];
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_713[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [2];
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 4);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                // def loop_2179_i1165_i4736_i4853
                                goto L1521;
                                FUN_loop_2179_i1165_i4736_i4853:
                                  check_heap (0);
                                  r0 = ((object*) lenv) [2];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = (object *) constructed_709[0];
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [2];
                                          switch (get_case (r0)) {
                                            case (UOTAG(1)): {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r0 = (object *) constructed_691[0];
                                              r1 = ((object*) lenv) [2];
                                              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                                r0 = ((object**) lenv) [1][3];
                                                switch (get_case (r0)) {
                                                  case (TC_PAIR): {
                                                    r0 = allocate (TC_TUPLE, 5);
                                                    r0[1] = lenv; lenv = r0;
                                                    r1 = ((object***) lenv) [1][1][3];
                                                    r1 = UOBJ_GET(r1,0);
                                                    r0[2] = r1;
                                                    r1 = ((object***) lenv) [1][1][3];
                                                    r1 = UOBJ_GET(r1,1);
                                                    r0[3] = r1;
                                                    r1 = allocate (UOTAG(1), 2);
                                                    r2 = ((object****) lenv) [1][1][1][2];
                                                    r1[1] = r2;
                                                    r2 = ((object*) lenv) [2];
                                                    r1[2] = r2;
                                                    r0[4] = r1;
                                                    r1 = allocate (TC_TUPLE, 2);
                                                    r2 = ((object*) lenv) [3];
                                                    r1[2] = r2;
                                                    r2 = ((object******) lenv) [1][1][1][1][1][2];
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1522; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_loop_2179_i1165_i4736_i4853;
                                                    L1522:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[5] = r1;
                                                    r0 = ((object*) lenv) [5];
                                                    r1 = ((object*) lenv) [4];
                                                    t = alloc_no_clear (TC_PAIR,2);
                                                    t[1] = r1;
                                                    t[2] = r0;
                                                    r0 = t;
                                                    PXLL_RETURN(0);
                                                  } break;
                                                  default: {
                                                    lenv = ((object ***)lenv)[1][1][1];
                                                    goto fatbar_163;
                                                  }
                                                }
                                                PXLL_RETURN(0);
                                              } else {
                                                lenv = ((object ***)lenv)[1][1][1];
                                                goto fatbar_163;
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_163;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_163;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                  }
                                  PXLL_RETURN(0);
                                  goto fatbar_163_over;
                                  fatbar_163:
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = (object*) &constructed_710;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = top[15];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                                  fatbar_163_over: ;
                                  PXLL_RETURN(0);
                                L1521:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_loop_2179_i1165_i4736_i4853; r2[2] = lenv;
                                r1[2] = r2;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = ((object***) lenv) [1][1][3];
                                r1[2] = r2;
                                r2 = ((object*) lenv) [2];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1523; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_loop_2179_i1165_i4736_i4853;
                                L1523:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                lenv = lenv[1];
                                r0[3] = r1;
                                r1 = allocate (TC_TUPLE, 3);
                                r1[1] = lenv; lenv = r1;
                                // def apply_1564_i1166_i4736_i4853
                                goto L1524;
                                FUN_apply_1564_i1166_i4736_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  // def loop_1568_i1166_i4736_i4853
                                  goto L1525;
                                  FUN_loop_1568_i1166_i4736_i4853:
                                    check_heap (0);
                                    r0 = ((object*) lenv) [2];
                                    switch (get_case (r0)) {
                                      case (TC_PAIR): {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r0[1] = lenv; lenv = r0;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,0);
                                        r0[2] = r1;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,1);
                                        r0[3] = r1;
                                        r0 = ((object*) lenv) [2];
                                        switch (get_case_noint (r0)) {
                                          default: {
                                            r0 = allocate (TC_TUPLE, 3);
                                            r0[1] = lenv; lenv = r0;
                                            r1 = ((object**) lenv) [1][2];
                                            r1 = UOBJ_GET(r1,0);
                                            r0[2] = r1;
                                            r1 = ((object**) lenv) [1][2];
                                            r1 = UOBJ_GET(r1,1);
                                            r0[3] = r1;
                                            r0 = allocate (TC_TUPLE, 3);
                                            r1 = ((object*) lenv) [2];
                                            r0[2] = r1;
                                            r1 = ((object*****) lenv) [1][1][1][1][2];
                                            r0[3] = r1;
                                            r1 = top[99];
                                            t = allocate (TC_SAVE, 3);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1526; ; k = t;
                                            r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_443;
                                            L1526:
                                            ; lenv = k[2]; k = k[1];
                                            r0 = result;
                                            if PXLL_IS_TRUE(r0) {
                                              r0 = ((object*****) lenv) [1][1][1][1][3];
                                              if PXLL_IS_TRUE(r0) {
                                                r0 = allocate (TC_TUPLE, 2);
                                                r0[1] = lenv; lenv = r0;
                                                r1 = allocate (TC_TUPLE, 2);
                                                r2 = allocate (TC_TUPLE, 8);
                                                r2[1] = lenv; lenv = r2;
                                                r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                                                r3 = allocate (TC_TUPLE, 2);
                                                r3[1] = lenv; lenv = r3;
                                                r4 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                                r4 = UOBJ_GET(r4,0);
                                                r3[2] = r4;
                                                r3 = ((object*) lenv) [2];
                                                lenv = lenv[1];
                                                r2[2] = r3;
                                                r3 = allocate (TC_TUPLE, 2);
                                                r4 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                r3[2] = r4;
                                                r4 = top[93];
                                                t = allocate (TC_SAVE, 6);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1527; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                                r3[1] = r4[2]; lenv = r3; goto FUN_repr_435;
                                                L1527:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                                r3 = result;
                                                r2[3] = r3;
                                                r3 = (object*)TC_NIL;
                                                r2[4] = r3;
                                                r3 = ((object*) lenv) [4];
                                                r4 = (object*) &constructed_707;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[5] = r3;
                                                r3 = ((object*) lenv) [5];
                                                r4 = ((object*) lenv) [3];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[6] = r3;
                                                r3 = ((object*) lenv) [6];
                                                r4 = (object*) &constructed_706;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[7] = r3;
                                                r3 = ((object*) lenv) [7];
                                                r4 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[8] = r3;
                                                r2 = ((object*) lenv) [8];
                                                r3 = (object*) &constructed_705;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r3;
                                                t[2] = r2;
                                                r2 = t;
                                                lenv = lenv[1];
                                                r1[2] = r2;
                                                r2 = top[49];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1528; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                                                L1528:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                r0[2] = r1;
                                                r0 = ((object*) lenv) [2];
                                                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                                r1 = ((object*) lenv) [2];
                                                r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                                lenv = lenv[1];
                                              } else {
                                                r0 = (object *) 14;
                                              }
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = allocate (TC_TUPLE, 3);
                                              r2 = ((object**) lenv) [1][3];
                                              r1[2] = r2;
                                              r2 = allocate (TC_TUPLE, 3);
                                              r3 = ((object**) lenv) [1][2];
                                              r2[2] = r3;
                                              r3 = ((object******) lenv) [1][1][1][1][1][2];
                                              r2[3] = r3;
                                              r3 = top[103];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1529; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_get_bindings_447;
                                              L1529:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[3] = r2;
                                              r2 = top[104];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1530; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_pattern_449;
                                              L1530:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[2] = r1;
                                              r0 = ((object******) lenv) [1][1][1][1][1][3];
                                              if PXLL_IS_TRUE(r0) {
                                                r0 = allocate (TC_TUPLE, 2);
                                                r0[1] = lenv; lenv = r0;
                                                r1 = allocate (TC_TUPLE, 2);
                                                r2 = allocate (TC_TUPLE, 5);
                                                r2[1] = lenv; lenv = r2;
                                                r3 = allocate (TC_TUPLE, 2);
                                                r4 = ((object***) lenv) [1][1][2];
                                                r3[2] = r4;
                                                r4 = top[93];
                                                t = allocate (TC_SAVE, 6);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1531; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                                r3[1] = r4[2]; lenv = r3; goto FUN_repr_435;
                                                L1531:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                                r3 = result;
                                                r2[2] = r3;
                                                r3 = (object*)TC_NIL;
                                                r2[3] = r3;
                                                r3 = ((object*) lenv) [3];
                                                r4 = (object*) &constructed_704;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[4] = r3;
                                                r3 = ((object*) lenv) [4];
                                                r4 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[5] = r3;
                                                r2 = ((object*) lenv) [5];
                                                r3 = (object*) &constructed_703;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r3;
                                                t[2] = r2;
                                                r2 = t;
                                                lenv = lenv[1];
                                                r1[2] = r2;
                                                r2 = top[49];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1532; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                                                L1532:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                r0[2] = r1;
                                                r0 = ((object*) lenv) [2];
                                                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                                r1 = ((object*) lenv) [2];
                                                r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                                lenv = lenv[1];
                                              } else {
                                                r0 = (object *) 14;
                                              }
                                              r0 = ((object*) lenv) [2];
                                              PXLL_RETURN(0);
                                            } else {
                                              r0 = ((object**) lenv) [1][3];
                                              lenv = ((object **)lenv)[1][1];
                                              lenv[2] = r0;
                                              goto FUN_loop_1568_i1166_i4736_i4853;
                                            }
                                            PXLL_RETURN(0);
                                          } break;
                                        }
                                        PXLL_RETURN(0);
                                      } break;
                                      default: {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object*) &constructed_708;
                                        r0[2] = r1;
                                        r1 = allocate (TC_TUPLE, 2);
                                        r2 = ((object***) lenv) [1][1][2];
                                        r1[2] = r2;
                                        r2 = top[93];
                                        t = allocate (TC_SAVE, 4);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1533; t[4] = r0; k = t;
                                        r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
                                        L1533:
                                        r0 = k[4]; lenv = k[2]; k = k[1];
                                        r1 = result;
                                        r0[3] = r1;
                                        r1 = top[15];
                                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                                      } break;
                                    }
                                    PXLL_RETURN(0);
                                  L1525:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN_loop_1568_i1166_i4736_i4853; r1[2] = lenv;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = ((object****) lenv) [1][1][1][3];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_loop_1568_i1166_i4736_i4853;
                                L1524:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_apply_1564_i1166_i4736_i4853; r2[2] = lenv;
                                r1[2] = r2;
                                // def unread-macro_1565_i1166_i4736_i4853
                                goto L1534;
                                FUN_unread_macro_1565_i1166_i4736_i4853:
                                  check_heap (0);
                                  r0 = (object*) &constructed_702;
                                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_702;
                                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  r0 = ((object**) lenv) [1][2];
                                  dump_object (r0, 0);
                                  r0 = (object*) &constructed_701;
                                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_701;
                                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  r0 = allocate (TC_TUPLE, 3);
                                  // def lambda_8157_i1166_i4736_i4853
                                  goto L1535;
                                  FUN_lambda_8157_i1166_i4736_i4853:
                                    check_heap (0);
                                    r0 = ((object*) lenv) [2];
                                    switch (get_case_noint (r0)) {
                                      default: {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r0[1] = lenv; lenv = r0;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,0);
                                        r0[2] = r1;
                                        r1 = ((object**) lenv) [1][2];
                                        r1 = UOBJ_GET(r1,1);
                                        r0[3] = r1;
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object *) 1;
                                        r0[2] = r1;
                                        r1 = ((object*) lenv) [2];
                                        r0[3] = r1;
                                        r1 = top[97];
                                        t = allocate (TC_SAVE, 3);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1536; ; k = t;
                                        r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
                                        L1536:
                                        ; lenv = k[2]; k = k[1];
                                        r0 = (object*) &constructed_700;
                                        r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                        r1 = (object*) &constructed_700;
                                        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object *) 1;
                                        r0[2] = r1;
                                        r1 = ((object*) lenv) [3];
                                        r0[3] = r1;
                                        r1 = top[97];
                                        t = allocate (TC_SAVE, 3);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1537; ; k = t;
                                        r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
                                        L1537:
                                        ; lenv = k[2]; k = k[1];
                                        r0 = (object*) &constructed_699;
                                        r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                        r1 = (object*) &constructed_699;
                                        r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                        PXLL_RETURN(0);
                                      } break;
                                    }
                                    PXLL_RETURN(0);
                                  L1535:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN_lambda_8157_i1166_i4736_i4853; r1[2] = lenv;
                                  r0[2] = r1;
                                  r1 = ((object**) lenv) [1][3];
                                  r0[3] = r1;
                                  r1 = top[37];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1538; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
                                  L1538:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = (object*) &constructed_698;
                                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_698;
                                  r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  PXLL_RETURN(0);
                                L1534:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_unread_macro_1565_i1166_i4736_i4853; r2[2] = lenv;
                                r1[3] = r2;
                                r1 = allocate (UOTAG(6), 4);
                                r2 = ((object*) lenv) [2];
                                r1[1] = r2;
                                r2 = ((object**) lenv) [1][2];
                                r1[2] = r2;
                                r2 = ((object**) lenv) [1][3];
                                r1[3] = r2;
                                r2 = ((object*) lenv) [3];
                                r1[4] = r2;
                                lenv = lenv[1];
                                r0[4] = r1;
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                                r1 = ((pxll_vector*)r1)->val[9];
                                r0[2] = r1;
                                r0 = ((object**) lenv) [1][4];
                                r1 = ((object*) lenv) [2];
                                r2 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                lenv = lenv[1];
                                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                                ((pxll_vector*)r1)->val[9] = r0;
                                lenv = lenv[1];
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_162;
                              }
                            }
                            lenv = lenv[1];
                          } break;
                          default: {
                            goto fatbar_162;
                          }
                        }
                        goto fatbar_162_over;
                        fatbar_162:
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_711;
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][3];
                        r0[3] = r1;
                        r1 = top[15];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1539; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                        L1539:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        fatbar_162_over: ;
                        r0 = ((object*****) lenv) [1][1][1][1][3];
                        r1 = ((object****) lenv) [1][1][1][3];
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r1;
                        lenv[3] = r0;
                        goto FUN_recur_2022_i4736_i4853;
                      } else {
                        goto fatbar_161;
                      }
                      PXLL_RETURN(0);
                      goto fatbar_161_over;
                      fatbar_161:
                      r0 = (object *) constructed_719[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [2];
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 6);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = top[200];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1540; t[4] = r0; k = t;
                                lenv = r1[2]; goto *r1[1];
                                L1540:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r1 = top[200];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1541; t[4] = r0; k = t;
                                lenv = r1[2]; goto *r1[1];
                                L1541:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[4] = r1;
                                r1 = (object *) 1;
                                r0[5] = r1;
                                r1 = allocate (TC_TUPLE, 8);
                                r1[1] = lenv; lenv = r1;
                                // def get_2193_i1172_i4736_i4853
                                goto L1542;
                                FUN_get_2193_i1172_i4736_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = ((object***) lenv) [1][1][4];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = (object*) &constructed_716;
                                  r0[4] = r1;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[3];
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L1542:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_2193_i1172_i4736_i4853; r2[2] = lenv;
                                r1[2] = r2;
                                // def add_2194_i1172_i4736_i4853
                                goto L1543;
                                FUN_add_2194_i1172_i4736_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = ((object***) lenv) [1][1][4];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r1 = ((pxll_vector*)r1)->val[2];
                                  r0[3] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[4] = r1;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[0];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1544; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                  L1544:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = ((object***) lenv) [1][1][5];
                                  r1 = ((object*) lenv) [2];
                                  ((pxll_vector*)r1)->val[1] = r0;
                                  r0 = ((object***) lenv) [1][1][5];
                                  r1 = (object *) 3;
                                  r0 = box((pxll_int)unbox(r1)+unbox(r0));
                                  ((object***) lenv) [1][1][5] = r0;
                                  PXLL_RETURN(0);
                                L1543:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_add_2194_i1172_i4736_i4853; r2[2] = lenv;
                                r1[3] = r2;
                                // def iterate_2195_i1172_i4736_i4853
                                goto L1545;
                                FUN_iterate_2195_i1172_i4736_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object***) lenv) [1][1][4];
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = ((object***) lenv) [1][1][4];
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[4];
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L1545:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_iterate_2195_i1172_i4736_i4853; r2[2] = lenv;
                                r1[4] = r2;
                                // def get-nalts_2196_i1172_i4736_i4853
                                goto L1546;
                                FUN_get_nalts_2196_i1172_i4736_i4853:
                                  r0 = ((object**) lenv) [1][5];
                                  PXLL_RETURN(0);
                                L1546:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_nalts_2196_i1172_i4736_i4853; r2[2] = lenv;
                                r1[5] = r2;
                                // def get-scheme_2197_i1172_i4736_i4853
                                goto L1547;
                                FUN_get_scheme_2197_i1172_i4736_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object***) lenv) [1][1][3];
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1548; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1548:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [2];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_36[0];
                                  r1[3] = r2;
                                  r2 = top[23];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1549; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                                  L1549:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (UOTAG(2), 2);
                                  r1 = ((object*) lenv) [3];
                                  r0[1] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object***) lenv) [1][1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [3];
                                  r1[3] = r2;
                                  r2 = top[106];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1550; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1550:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  PXLL_RETURN(0);
                                L1547:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_scheme_2197_i1172_i4736_i4853; r2[2] = lenv;
                                r1[6] = r2;
                                // def get-tvars_2198_i1172_i4736_i4853
                                goto L1551;
                                FUN_get_tvars_2198_i1172_i4736_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object***) lenv) [1][1][3];
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1552; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1552:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = ((object*) lenv) [2];
                                  r0[2] = r1;
                                  r1 = (object *) constructed_36[0];
                                  r0[3] = r1;
                                  r1 = top[23];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
                                L1551:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_tvars_2198_i1172_i4736_i4853; r2[2] = lenv;
                                r1[7] = r2;
                                // def get-alt-scheme_2199_i1172_i4736_i4853
                                goto L1553;
                                FUN_get_alt_scheme_2199_i1172_i4736_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 6);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 4);
                                  r2 = ((object****) lenv) [1][1][1][4];
                                  r1[2] = r2;
                                  r2 = ((object**) lenv) [1][2];
                                  r1[3] = r2;
                                  r2 = (object*) &constructed_715;
                                  r1[4] = r2;
                                  r2 = ((object****) lenv) [1][1][1][4];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[3];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1554; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1554:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = ((object****) lenv) [1][1][1][3];
                                  r1[2] = r2;
                                  r2 = ((object****) lenv) [1][1][1][3];
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1555; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1555:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object*) lenv) [3];
                                  r1[2] = r2;
                                  r2 = (object *) constructed_36[0];
                                  r1[3] = r2;
                                  r2 = top[23];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1556; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                                  L1556:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = ((object****) lenv) [1][1][1][2];
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [4];
                                  r1[3] = r2;
                                  r2 = top[106];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1557; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1557:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[5] = r1;
                                  r1 = allocate (UOTAG(2), 2);
                                  r2 = ((object*) lenv) [4];
                                  r1[1] = r2;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r2[1] = lenv; lenv = r2;
                                  r3 = ((object**) lenv) [1][2];
                                  r3 = ((pxll_vector*)r3)->val[3];
                                  r2[2] = r3;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = (object *) constructed_97[0];
                                  r2[2] = r3;
                                  r3 = ((object*) lenv) [2];
                                  r4 = ((object**) lenv) [1][5];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r4;
                                  t[2] = r3;
                                  r3 = t;
                                  r2[3] = r3;
                                  r3 = top[106];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1558; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                  L1558:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  lenv = lenv[1];
                                  r1[2] = r2;
                                  r0[6] = r1;
                                  r0 = ((object*) lenv) [6];
                                  PXLL_RETURN(0);
                                L1553:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_alt_scheme_2199_i1172_i4736_i4853; r2[2] = lenv;
                                r1[8] = r2;
                                r1 = allocate (UOTAG(7), 8);
                                r2 = ((object*) lenv) [3];
                                r1[1] = r2;
                                r2 = ((object*) lenv) [2];
                                r1[2] = r2;
                                r2 = ((object*) lenv) [8];
                                r1[3] = r2;
                                r2 = ((object*) lenv) [5];
                                r1[4] = r2;
                                r2 = ((object*) lenv) [6];
                                r1[5] = r2;
                                r2 = ((object*) lenv) [7];
                                r1[6] = r2;
                                r2 = ((object*) lenv) [4];
                                r1[7] = r2;
                                r2 = ((object**) lenv) [1][2];
                                r1[8] = r2;
                                lenv = lenv[1];
                                r0[6] = r1;
                                r0 = allocate (TC_TUPLE, 3);
                                // def lambda_13222_i1171_i4736_i4853
                                goto L1559;
                                FUN_lambda_13222_i1171_i4736_i4853:
                                  check_heap (0);
                                  r0 = ((object*) lenv) [2];
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][2];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r0 = ((object*) lenv) [2];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][2];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [2];
                                          switch (get_case (r0)) {
                                            case (UOTAG(9)): {
                                              r0 = allocate (TC_TUPLE, 3);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r1 = ((object**) lenv) [1][2];
                                              r1 = UOBJ_GET(r1,1);
                                              r0[3] = r1;
                                              r0 = (object *) constructed_49[0];
                                              r1 = ((object*) lenv) [2];
                                              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                                r0 = allocate (TC_TUPLE, 2);
                                                r1 = allocate (TC_TUPLE, 4);
                                                r2 = ((object*****) lenv) [1][1][1][1][3];
                                                r1[2] = r2;
                                                r2 = ((object*) lenv) [3];
                                                r1[3] = r2;
                                                r2 = ((object**) lenv) [1][3];
                                                r1[4] = r2;
                                                r2 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][22];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1560; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_make_alt_1991_i4736_i4853;
                                                L1560:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                r0[2] = r1;
                                                r1 = ((object*****) lenv) [1][1][1][1][6];
                                                r1 = ((pxll_vector*)r1)->val[0];
                                                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                              } else {
                                                lenv = ((object ***)lenv)[1][1][1];
                                                goto fatbar_165;
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_165;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_165;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      goto fatbar_165;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                  goto fatbar_165_over;
                                  fatbar_165:
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = (object*) &constructed_714;
                                  r0[2] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[3] = r1;
                                  r1 = top[15];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                                  fatbar_165_over: ;
                                  PXLL_RETURN(0);
                                L1559:
                                r1 = allocate (TC_CLOSURE, 2);
                                r1[1] = &&FUN_lambda_13222_i1171_i4736_i4853; r1[2] = lenv;
                                r0[2] = r1;
                                r1 = ((object**) lenv) [1][3];
                                r0[3] = r1;
                                r1 = top[37];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L1561; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
                                L1561:
                                ; lenv = k[2]; k = k[1];
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                                r1 = ((pxll_vector*)r1)->val[2];
                                r0[2] = r1;
                                r0 = ((object**) lenv) [1][6];
                                r1 = ((object*) lenv) [2];
                                r2 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                lenv = lenv[1];
                                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                                ((pxll_vector*)r1)->val[2] = r0;
                                lenv = lenv[1];
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_164;
                              }
                            }
                            lenv = lenv[1];
                          } break;
                          default: {
                            goto fatbar_164;
                          }
                        }
                        goto fatbar_164_over;
                        fatbar_164:
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_717;
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][3];
                        r0[3] = r1;
                        r1 = top[15];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1562; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                        L1562:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        fatbar_164_over: ;
                        r0 = ((object*****) lenv) [1][1][1][1][3];
                        r1 = ((object****) lenv) [1][1][1][3];
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r1;
                        lenv[3] = r0;
                        goto FUN_recur_2022_i4736_i4853;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_160;
                      }
                      PXLL_RETURN(0);
                      fatbar_161_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_160;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_160;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_160;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_160_over;
          fatbar_160:
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_recur_2022_i4736_i4853;
          fatbar_160_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1520:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_2022_i4736_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = (object *) constructed_697[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_2022_i4736_i4853;
  L1519:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_find_declarations_1971_i4736_i4853; r2[2] = lenv;
  r1[5] = r2;
  // def find-definitions_1972_i4736_i4853
  goto L1563;
  FUN_find_definitions_1972_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_2033_i4736_i4853
    goto L1564;
    FUN_recur_2033_i4736_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1565; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1565:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1566; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1566:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_696[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object***) lenv) [1][1][3];
                        switch (get_case (r1)) {
                          case (TC_PAIR): {
                            r1 = allocate (TC_TUPLE, 3);
                            r1[1] = lenv; lenv = r1;
                            r2 = ((object****) lenv) [1][1][1][3];
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r2 = ((object****) lenv) [1][1][1][3];
                            r2 = UOBJ_GET(r2,1);
                            r1[3] = r2;
                            r1 = ((object*) lenv) [2];
                            switch (get_case (r1)) {
                              case (UOTAG(1)): {
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                r2 = ((object**) lenv) [1][2];
                                r2 = UOBJ_GET(r2,0);
                                r1[2] = r2;
                                r1 = allocate (TC_TUPLE, 4);
                                r2 = (object *) constructed_691[0];
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r2;
                                r2 = t;
                                r1[2] = r2;
                                r2 = ((object**) lenv) [1][3];
                                r1[3] = r2;
                                r2 = top[91];
                                r1[4] = r2;
                                r2 = top[26];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1567; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_member_question_320;
                                L1567:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                if PXLL_IS_TRUE(r1) {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 5);
                                  r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                                  r2[2] = r3;
                                  r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][8];
                                  r2[3] = r3;
                                  r3 = (object *) constructed_688[0];
                                  r2[4] = r3;
                                  r3 = ((object***) lenv) [1][1][3];
                                  r2[5] = r3;
                                  r3 = top[118];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1568; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_compile_pattern_480;
                                  L1568:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case_noint (r1)) {
                                    default: {
                                      r1 = allocate (TC_TUPLE, 3);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = ((object**) lenv) [1][2];
                                      r2 = UOBJ_GET(r2,0);
                                      r1[2] = r2;
                                      r2 = ((object**) lenv) [1][2];
                                      r2 = UOBJ_GET(r2,1);
                                      r1[3] = r2;
                                      r1 = allocate (UOTAG(1), 2);
                                      r2 = ((object***) lenv) [1][1][2];
                                      r1[1] = r2;
                                      r2 = allocate (TC_TUPLE, 13);
                                      r2[1] = lenv; lenv = r2;
                                      r3 = (object *) constructed_627[0];
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[2] = r3;
                                      r3 = ((object****) lenv) [1][1][1][2];
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[3] = r3;
                                      r3 = allocate (TC_TUPLE, 3);
                                      r4 = top[3];
                                      r3[2] = r4;
                                      r4 = ((object**) lenv) [1][2];
                                      r3[3] = r4;
                                      r4 = top[34];
                                      t = allocate (TC_SAVE, 6);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1569; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                      r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
                                      L1569:
                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                      r3 = result;
                                      r2[4] = r3;
                                      r3 = ((object*) lenv) [4];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[5] = r3;
                                      r3 = (object *) 6;
                                      t = alloc_no_clear (UOTAG(4),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[6] = r3;
                                      r3 = allocate (TC_TUPLE, 2);
                                      r4 = ((object**) lenv) [1][3];
                                      r3[2] = r4;
                                      r4 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][8];
                                      t = allocate (TC_SAVE, 6);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1570; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                      r3[1] = r4[2]; lenv = r3; goto FUN_expand_1974_i4736_i4853;
                                      L1570:
                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                      r3 = result;
                                      r2[7] = r3;
                                      r3 = (object*)TC_NIL;
                                      r2[8] = r3;
                                      r3 = ((object*) lenv) [8];
                                      r4 = ((object*) lenv) [7];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[9] = r3;
                                      r3 = ((object*) lenv) [9];
                                      r4 = ((object*) lenv) [6];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[10] = r3;
                                      r3 = ((object*) lenv) [10];
                                      r4 = ((object*) lenv) [5];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[11] = r3;
                                      r3 = ((object*) lenv) [11];
                                      r4 = ((object*) lenv) [3];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[12] = r3;
                                      r3 = ((object*) lenv) [12];
                                      r4 = ((object*) lenv) [2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[13] = r3;
                                      r2 = ((object*) lenv) [13];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r2;
                                      r2 = t;
                                      lenv = lenv[1];
                                      r1[2] = r2;
                                      lenv = lenv[1];
                                    } break;
                                  }
                                  lenv = lenv[1];
                                } else {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = ((object***) lenv) [1][1][3];
                                  r2[2] = r3;
                                  r3 = top[24];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1571; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
                                  L1571:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = ((object*) lenv) [2];
                                  r3 = (object *) 3;
                                  r2 = PXLL_TEST(unbox(r3)==unbox(r2));
                                  r1[3] = r2;
                                  r1 = (object *) 6;
                                  r2 = ((object*) lenv) [3];
                                  r1 = PXLL_TEST(r2==r1);
                                  lenv = lenv[1];
                                  if PXLL_IS_TRUE(r1) {
                                    r1 = allocate (TC_TUPLE, 3);
                                    r2 = (object*) &constructed_689;
                                    r1[2] = r2;
                                    r2 = ((object*) lenv) [2];
                                    r1[3] = r2;
                                    r2 = top[15];
                                    t = allocate (TC_SAVE, 4);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1572; t[4] = r0; k = t;
                                    r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                                    L1572:
                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                    r1 = result;
                                  } else {
                                    r1 = allocate (UOTAG(1), 2);
                                    r2 = ((object*) lenv) [2];
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 2);
                                    r3 = ((object**) lenv) [1][3];
                                    r2[2] = r3;
                                    r3 = top[21];
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1573; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
                                    L1573:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    r1[2] = r2;
                                  }
                                }
                                lenv = lenv[1];
                              } break;
                              case (UOTAG(0)): {
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                r2 = ((object**) lenv) [1][2];
                                r2 = UOBJ_GET(r2,0);
                                r1[2] = r2;
                                r1 = ((object*) lenv) [2];
                                switch (get_case (r1)) {
                                  case (TC_PAIR): {
                                    r1 = allocate (TC_TUPLE, 3);
                                    r1[1] = lenv; lenv = r1;
                                    r2 = ((object**) lenv) [1][2];
                                    r2 = UOBJ_GET(r2,0);
                                    r1[2] = r2;
                                    r2 = ((object**) lenv) [1][2];
                                    r2 = UOBJ_GET(r2,1);
                                    r1[3] = r2;
                                    r1 = ((object*) lenv) [2];
                                    switch (get_case (r1)) {
                                      case (UOTAG(1)): {
                                        r1 = allocate (TC_TUPLE, 2);
                                        r1[1] = lenv; lenv = r1;
                                        r2 = ((object**) lenv) [1][2];
                                        r2 = UOBJ_GET(r2,0);
                                        r1[2] = r2;
                                        r1 = (object *) constructed_693[0];
                                        r2 = ((object*) lenv) [2];
                                        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                          r1 = ((object**) lenv) [1][3];
                                          switch (get_case (r1)) {
                                            case (TC_PAIR): {
                                              r1 = allocate (TC_TUPLE, 3);
                                              r1[1] = lenv; lenv = r1;
                                              r2 = ((object***) lenv) [1][1][3];
                                              r2 = UOBJ_GET(r2,0);
                                              r1[2] = r2;
                                              r2 = ((object***) lenv) [1][1][3];
                                              r2 = UOBJ_GET(r2,1);
                                              r1[3] = r2;
                                              r1 = ((object*) lenv) [2];
                                              switch (get_case (r1)) {
                                                case (UOTAG(0)): {
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r1[1] = lenv; lenv = r1;
                                                  r2 = ((object**) lenv) [1][2];
                                                  r2 = UOBJ_GET(r2,0);
                                                  r1[2] = r2;
                                                  r1 = ((object*) lenv) [2];
                                                  switch (get_case (r1)) {
                                                    case (TC_PAIR): {
                                                      r1 = allocate (TC_TUPLE, 3);
                                                      r1[1] = lenv; lenv = r1;
                                                      r2 = ((object**) lenv) [1][2];
                                                      r2 = UOBJ_GET(r2,0);
                                                      r1[2] = r2;
                                                      r2 = ((object**) lenv) [1][2];
                                                      r2 = UOBJ_GET(r2,1);
                                                      r1[3] = r2;
                                                      r1 = ((object*) lenv) [2];
                                                      switch (get_case (r1)) {
                                                        case (UOTAG(1)): {
                                                          r1 = allocate (TC_TUPLE, 2);
                                                          r1[1] = lenv; lenv = r1;
                                                          r2 = ((object**) lenv) [1][2];
                                                          r2 = UOBJ_GET(r2,0);
                                                          r1[2] = r2;
                                                          r1 = ((object****) lenv) [1][1][1][3];
                                                          switch (get_case (r1)) {
                                                            case (TC_PAIR): {
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r1[1] = lenv; lenv = r1;
                                                              r2 = ((object*****) lenv) [1][1][1][1][3];
                                                              r2 = UOBJ_GET(r2,0);
                                                              r1[2] = r2;
                                                              r2 = ((object*****) lenv) [1][1][1][1][3];
                                                              r2 = UOBJ_GET(r2,1);
                                                              r1[3] = r2;
                                                              r1 = ((object*) lenv) [3];
                                                              switch (get_case (r1)) {
                                                                case (TC_NIL): {
                                                                  r1 = allocate (TC_TUPLE, 5);
                                                                  r2 = ((object**) lenv) [1][2];
                                                                  r1[2] = r2;
                                                                  r2 = ((object***) lenv) [1][1][3];
                                                                  r1[3] = r2;
                                                                  r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                                                                  r1[4] = r2;
                                                                  r2 = ((object*) lenv) [2];
                                                                  r1[5] = r2;
                                                                  r2 = ((object******************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][23];
                                                                  t = allocate (TC_SAVE, 4);
                                                                  t[1] = k; t[2] = lenv; t[3] = &&L1574; t[4] = r0; k = t;
                                                                  r1[1] = r2[2]; lenv = r1; goto FUN_parse_normal_definition_1996_i4736_i4853;
                                                                  L1574:
                                                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                                                  r1 = result;
                                                                } break;
                                                                default: {
                                                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                                                  goto fatbar_159;
                                                                }
                                                              }
                                                              lenv = lenv[1];
                                                            } break;
                                                            default: {
                                                              lenv = ((object ****)lenv)[1][1][1][1];
                                                              goto fatbar_159;
                                                            }
                                                          }
                                                          lenv = lenv[1];
                                                        } break;
                                                        default: {
                                                          lenv = ((object ***)lenv)[1][1][1];
                                                          goto fatbar_159;
                                                        }
                                                      }
                                                      lenv = lenv[1];
                                                    } break;
                                                    default: {
                                                      lenv = ((object **)lenv)[1][1];
                                                      goto fatbar_159;
                                                    }
                                                  }
                                                  lenv = lenv[1];
                                                } break;
                                                default: {
                                                  lenv = ((object *)lenv)[1];
                                                  goto fatbar_159;
                                                }
                                              }
                                              lenv = lenv[1];
                                            } break;
                                            default: {
                                              goto fatbar_159;
                                            }
                                          }
                                        } else {
                                          goto fatbar_159;
                                        }
                                        goto fatbar_159_over;
                                        fatbar_159:
                                        r1 = allocate (TC_TUPLE, 5);
                                        r2 = ((object*) lenv) [2];
                                        r1[2] = r2;
                                        r2 = ((object**) lenv) [1][3];
                                        r1[3] = r2;
                                        r2 = ((object****) lenv) [1][1][1][3];
                                        r1[4] = r2;
                                        r2 = (object *) 6;
                                        t = alloc_no_clear (UOTAG(4),1);
                                        t[1] = r2;
                                        r2 = t;
                                        r1[5] = r2;
                                        r2 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][23];
                                        t = allocate (TC_SAVE, 4);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1575; t[4] = r0; k = t;
                                        r1[1] = r2[2]; lenv = r1; goto FUN_parse_normal_definition_1996_i4736_i4853;
                                        L1575:
                                        r0 = k[4]; lenv = k[2]; k = k[1];
                                        r1 = result;
                                        fatbar_159_over: ;
                                        lenv = lenv[1];
                                      } break;
                                      default: {
                                        lenv = ((object ***)lenv)[1][1][1];
                                        goto fatbar_158;
                                      }
                                    }
                                    lenv = lenv[1];
                                  } break;
                                  default: {
                                    lenv = ((object **)lenv)[1][1];
                                    goto fatbar_158;
                                  }
                                }
                                lenv = lenv[1];
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_158;
                              }
                            }
                            lenv = lenv[1];
                          } break;
                          default: {
                            goto fatbar_158;
                          }
                        }
                        goto fatbar_158_over;
                        fatbar_158:
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object*) &constructed_694;
                        r1[2] = r2;
                        r2 = ((object***) lenv) [1][1][3];
                        r1[3] = r2;
                        r2 = top[15];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1576; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                        L1576:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        fatbar_158_over: ;
                        r0[2] = r1;
                        r0 = ((object******) lenv) [1][1][1][1][1][2];
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r1 = ((object*****) lenv) [1][1][1][1][3];
                        r2 = ((object****) lenv) [1][1][1][3];
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r0;
                        lenv[3] = r1;
                        lenv[4] = r2;
                        goto FUN_recur_2033_i4736_i4853;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_157;
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_157;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_157;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_157;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_157_over;
          fatbar_157:
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_recur_2033_i4736_i4853;
          fatbar_157_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1564:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_2033_i4736_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) constructed_687[0];
    r0[2] = r1;
    r1 = (object *) constructed_686[0];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_2033_i4736_i4853;
  L1563:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_find_definitions_1972_i4736_i4853; r2[2] = lenv;
  r1[6] = r2;
  // def expand-field_1973_i4736_i4853
  goto L1577;
  FUN_expand_field_1973_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [3];
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][8];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1578; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
    L1578:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = ((object*) lenv) [4];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L1577:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_field_1973_i4736_i4853; r2[2] = lenv;
  r1[7] = r2;
  // def expand_1974_i4736_i4853
  goto L1579;
  FUN_expand_1974_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][9];
        r0[1] = r1[2]; lenv = r0; goto FUN_maybe_expand_1975_i4736_i4853;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][8];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1580; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1580:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(7),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object***) lenv) [1][1][7];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1581; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1581:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        t = alloc_no_clear (UOTAG(8),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][8];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1582; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
        L1582:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [4];
        t = alloc_no_clear (UOTAG(10),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1579:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_1974_i4736_i4853; r2[2] = lenv;
  r1[8] = r2;
  // def maybe-expand_1975_i4736_i4853
  goto L1583;
  FUN_maybe_expand_1975_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_681[0];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][29];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[67];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1584; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
            L1584:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object***) lenv) [1][1][3];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][2];
                r2 = ((pxll_vector*)r2)->val[9];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[67];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1585; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
                L1585:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*****) lenv) [1][1][1][1][2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r2;
                    r2 = t;
                    r1[2] = r2;
                    r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                    r2 = ((pxll_vector*)r2)->val[10];
                    r2 = ((pxll_vector*)r2)->val[0];
                    r1[3] = r2;
                    r2 = ((object*) lenv) [2];
                    r2 = ((pxll_vector*)r2)->val[0];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1586; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L1586:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object******) lenv) [1][1][1][1][1][8];
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_1974_i4736_i4853;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    r1[2] = r2;
                    r2 = ((object****) lenv) [1][1][1][3];
                    r1[3] = r2;
                    r2 = top[34];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1587; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                    L1587:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = ((object*) lenv) [2];
                    r2 = ((object****) lenv) [1][1][1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_685[0];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(1)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = ((object**) lenv) [1][3];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = allocate (TC_TUPLE, 8);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = (object *) constructed_683[0];
                                      r2 = ((object**) lenv) [1][2];
                                      t = alloc_no_clear (UOTAG(10),2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[2] = r1;
                                      r1 = ((object***) lenv) [1][1][2];
                                      r2 = ((object*) lenv) [2];
                                      t = alloc_no_clear (UOTAG(10),2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[3] = r1;
                                      r1 = (object*)TC_NIL;
                                      r0[4] = r1;
                                      r1 = ((object*) lenv) [4];
                                      r2 = ((object**) lenv) [1][2];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[5] = r1;
                                      r1 = ((object*) lenv) [5];
                                      r2 = ((object*) lenv) [3];
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[6] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][8];
                                      r1[2] = r2;
                                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                      r1[3] = r2;
                                      r2 = top[34];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1588; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                                      L1588:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[7] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = ((object*) lenv) [6];
                                      r2[2] = r3;
                                      r3 = (object *) constructed_36[0];
                                      r2[3] = r3;
                                      r3 = top[23];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1589; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
                                      L1589:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r2 = ((object*) lenv) [7];
                                      r1[3] = r2;
                                      r2 = top[23];
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1590; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                                      L1590:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[8] = r1;
                                      r0 = ((object*) lenv) [8];
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r0;
                                      r0 = t;
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                      goto fatbar_156;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_156;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_156;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_156;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_156;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_156;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_156;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_156;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_156_over;
        fatbar_156:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object****) lenv) [1][1][1][8];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1591; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1591:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_156_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1583:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_maybe_expand_1975_i4736_i4853; r2[2] = lenv;
  r1[9] = r2;
  // def expand-if_1976_i4736_i4853
  goto L1592;
  FUN_expand_if_1976_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 10);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object***) lenv) [1][1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1593; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                L1593:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1594; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                L1594:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = (object*)UITAG(6);
                r0[4] = r1;
                r1 = (object*)TC_NIL;
                r0[5] = r1;
                r1 = ((object*) lenv) [5];
                r2 = ((object*) lenv) [4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[6] = r1;
                r1 = ((object*) lenv) [6];
                r2 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[7] = r1;
                r1 = ((object*) lenv) [7];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[8] = r1;
                r1 = (object *) constructed_621[0];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                r0[9] = r1;
                r1 = ((object*) lenv) [8];
                r2 = ((object*) lenv) [9];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[10] = r1;
                r0 = ((object*) lenv) [10];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 10);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object****) lenv) [1][1][1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1595; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                    L1595:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object***) lenv) [1][1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1596; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                    L1596:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = ((object******) lenv) [1][1][1][1][1][8];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1597; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                    L1597:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r1 = (object*)TC_NIL;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [4];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object*) lenv) [6];
                    r2 = ((object*) lenv) [3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = ((object*) lenv) [7];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r1 = (object *) constructed_621[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[9] = r1;
                    r1 = ((object*) lenv) [8];
                    r2 = ((object*) lenv) [9];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[10] = r1;
                    r0 = ((object*) lenv) [10];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_155;
                  }
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_155;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_155;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_155_over;
    fatbar_155:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_680;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_155_over: ;
    PXLL_RETURN(0);
  L1592:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_if_1976_i4736_i4853; r2[2] = lenv;
  r1[10] = r2;
  // def expand-set!_1977_i4736_i4853
  goto L1598;
  FUN_expand_set_bang_1977_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object***) lenv) [1][1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1599; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                L1599:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][8];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1600; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                L1600:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(10)): {
                    r0 = allocate (TC_TUPLE, 10);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = ((object*) lenv) [3];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[4] = r1;
                    r1 = (object*)TC_NIL;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object**) lenv) [1][3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object*) lenv) [6];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = ((object*) lenv) [7];
                    r2 = ((object*) lenv) [4];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r1 = (object *) constructed_492[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[9] = r1;
                    r1 = ((object*) lenv) [8];
                    r2 = ((object*) lenv) [9];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[10] = r1;
                    r0 = ((object*) lenv) [10];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [2];
                        switch (get_case (r0)) {
                          case (UOTAG(1)): {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r0 = (object *) constructed_295[0];
                            r1 = ((object*) lenv) [2];
                            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                              r0 = ((object**) lenv) [1][3];
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = ((object*) lenv) [3];
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = ((object**) lenv) [1][3];
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = ((object*) lenv) [3];
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = ((object**) lenv) [1][3];
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = ((object*) lenv) [3];
                                          switch (get_case (r0)) {
                                            case (TC_NIL): {
                                              r0 = allocate (TC_TUPLE, 8);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = (object*)TC_NIL;
                                              r0[2] = r1;
                                              r1 = ((object*) lenv) [2];
                                              r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[3] = r1;
                                              r1 = ((object*) lenv) [3];
                                              r2 = ((object**) lenv) [1][2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[4] = r1;
                                              r1 = ((object*) lenv) [4];
                                              r2 = ((object***) lenv) [1][1][2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[5] = r1;
                                              r1 = ((object*) lenv) [5];
                                              r2 = ((object****) lenv) [1][1][1][2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[6] = r1;
                                              r1 = (object *) constructed_286[0];
                                              t = alloc_no_clear (UOTAG(1),1);
                                              t[1] = r1;
                                              r1 = t;
                                              r0[7] = r1;
                                              r1 = ((object*) lenv) [6];
                                              r2 = ((object*) lenv) [7];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[8] = r1;
                                              r0 = ((object*) lenv) [8];
                                              t = alloc_no_clear (UOTAG(0),1);
                                              t[1] = r0;
                                              r0 = t;
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_154;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_154;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_154;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_154;
                                }
                              }
                              PXLL_RETURN(0);
                            } else {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_154;
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object **)lenv)[1][1];
                            goto fatbar_154;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_154;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 8);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[3] = r1;
                    r1 = (object*)TC_NIL;
                    r0[4] = r1;
                    r1 = ((object*) lenv) [4];
                    r2 = ((object**) lenv) [1][3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[5] = r1;
                    r1 = ((object*) lenv) [5];
                    r2 = ((object*) lenv) [3];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = (object *) constructed_623[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = ((object*) lenv) [6];
                    r2 = ((object*) lenv) [7];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r0 = ((object*) lenv) [8];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_154;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_154_over;
                fatbar_154:
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_678;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = top[15];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                fatbar_154_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_153;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_153;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_153;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_153_over;
    fatbar_153:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_679;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_153_over: ;
    PXLL_RETURN(0);
  L1598:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_set_bang_1977_i4736_i4853; r2[2] = lenv;
  r1[11] = r2;
  // def expand-begin_1978_i4736_i4853
  goto L1601;
  FUN_expand_begin_1978_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_677;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_677;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][8];
            r0[1] = r1[2]; lenv = r0; goto FUN_expand_1974_i4736_i4853;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_152;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_152_over;
    fatbar_152:
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object***) lenv) [1][1][8];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[34];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1602; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
    L1602:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = (object *) constructed_625[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r0 = ((object*) lenv) [4];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_152_over: ;
    PXLL_RETURN(0);
  L1601:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_begin_1978_i4736_i4853; r2[2] = lenv;
  r1[12] = r2;
  // def expand-let-splat_1979_i4736_i4853
  goto L1603;
  FUN_expand_let_splat_1979_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_12158_i4736_i4853
            goto L1604;
            FUN_lambda_12158_i4736_i4853:
              check_heap (0);
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = allocate (TC_TUPLE, 5);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object**) lenv) [1][2];
                              r1[2] = r2;
                              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][8];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1605; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                              L1605:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = (object*)TC_NIL;
                              r0[3] = r1;
                              r1 = ((object*) lenv) [3];
                              r2 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r0[4] = r1;
                              r1 = ((object*) lenv) [4];
                              r2 = ((object***) lenv) [1][1][2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r0[5] = r1;
                              r0 = ((object*) lenv) [5];
                              t = alloc_no_clear (UOTAG(0),1);
                              t[1] = r0;
                              r0 = t;
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_151;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_151;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_151;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_151;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_151_over;
              fatbar_151:
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_675;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[15];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
              fatbar_151_over: ;
              PXLL_RETURN(0);
            L1604:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_12158_i4736_i4853; r2[2] = lenv;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[34];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1606; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
            L1606:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][3];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][4];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1607; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_1972_i4736_i4853;
            L1607:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = (object*)TC_NIL;
            r0[6] = r1;
            r1 = ((object*) lenv) [6];
            r2 = ((object*) lenv) [5];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = (object *) constructed_631[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = ((object*) lenv) [8];
            r2 = ((object*) lenv) [9];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[10] = r1;
            r0 = ((object*) lenv) [10];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_150;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_150;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_150_over;
    fatbar_150:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_676;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_150_over: ;
    PXLL_RETURN(0);
  L1603:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_let_splat_1979_i4736_i4853; r2[2] = lenv;
  r1[13] = r2;
  // def expand-lambda_1980_i4736_i4853
  goto L1608;
  FUN_expand_lambda_1980_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) constructed_611[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][4];
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1609; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_1972_i4736_i4853;
        L1609:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][16];
        r0[1] = r1[2]; lenv = r0; goto FUN_exp_function_1982_i4736_i4853;
      } break;
      default: {
        goto fatbar_149;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_149_over;
    fatbar_149:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_674;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_149_over: ;
    PXLL_RETURN(0);
  L1608:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_lambda_1980_i4736_i4853; r2[2] = lenv;
  r1[14] = r2;
  // def expand-function_1981_i4736_i4853
  goto L1610;
  FUN_expand_function_1981_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = allocate (TC_TUPLE, 5);
                r1 = ((object***) lenv) [1][1][2];
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r0[3] = r1;
                r1 = ((object*) lenv) [2];
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*) lenv) [3];
                r1[2] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][4];
                r1[3] = r2;
                r2 = ((object*****) lenv) [1][1][1][1][6];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1611; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_1972_i4736_i4853;
                L1611:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][16];
                r0[1] = r1[2]; lenv = r0; goto FUN_exp_function_1982_i4736_i4853;
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_148;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_148;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_148;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_148_over;
    fatbar_148:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_673;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_148_over: ;
    PXLL_RETURN(0);
  L1610:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_function_1981_i4736_i4853; r2[2] = lenv;
  r1[15] = r2;
  // def exp-function_1982_i4736_i4853
  goto L1612;
  FUN_exp_function_1982_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 8);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r2 = ((object**) lenv) [1][5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = ((object*) lenv) [4];
    r2 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[5] = r1;
    r1 = ((object*) lenv) [5];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[6] = r1;
    r1 = (object *) constructed_627[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[7] = r1;
    r1 = ((object*) lenv) [6];
    r2 = ((object*) lenv) [7];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[8] = r1;
    r0 = ((object*) lenv) [8];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1612:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_exp_function_1982_i4736_i4853; r2[2] = lenv;
  r1[16] = r2;
  // def make-nvget_1984_i4736_i4853
  goto L1613;
  FUN_make_nvget_1984_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 15);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_314[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(9),2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = ((object**) lenv) [1][4];
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = ((object**) lenv) [1][5];
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r1;
    r1 = t;
    r0[5] = r1;
    r1 = (object*)TC_NIL;
    r0[6] = r1;
    r1 = ((object*) lenv) [6];
    r2 = ((object*) lenv) [5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[7] = r1;
    r1 = ((object*) lenv) [7];
    r2 = ((object*) lenv) [4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[8] = r1;
    r1 = ((object*) lenv) [8];
    r2 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[9] = r1;
    r1 = ((object*) lenv) [9];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[10] = r1;
    r1 = ((object**) lenv) [1][6];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[11] = r1;
    r1 = (object*)TC_NIL;
    r0[12] = r1;
    r1 = ((object*) lenv) [12];
    r2 = ((object*) lenv) [11];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[13] = r1;
    r1 = ((object*) lenv) [13];
    r2 = ((object*) lenv) [10];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[14] = r1;
    r1 = ((object*) lenv) [14];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[15] = r1;
    r0 = ((object*) lenv) [15];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1613:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_nvget_1984_i4736_i4853; r2[2] = lenv;
  r1[17] = r2;
  // def expand-vcase_1985_i4736_i4853
  goto L1614;
  FUN_expand_vcase_1985_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    r1 = ((object***) lenv) [1][1][2];
                    r0[2] = r1;
                    r1 = ((object*) lenv) [2];
                    r0[3] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r0[4] = r1;
                    r1 = ((object******) lenv) [1][1][1][1][1][19];
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_vcase_splat_1986_i4736_i4853;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_147;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_147;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_147_over;
            fatbar_147:
            r0 = allocate (TC_TUPLE, 4);
            r1 = (object *) constructed_49[0];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object**) lenv) [1][3];
            r0[4] = r1;
            r1 = ((object****) lenv) [1][1][1][19];
            r0[1] = r1[2]; lenv = r0; goto FUN_expand_vcase_splat_1986_i4736_i4853;
            fatbar_147_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_146;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_146;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_146_over;
    fatbar_146:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_672;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_146_over: ;
    PXLL_RETURN(0);
  L1614:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_vcase_1985_i4736_i4853; r2[2] = lenv;
  r1[18] = r2;
  // def expand-vcase*_1986_i4736_i4853
  goto L1615;
  FUN_expand_vcase_splat_1986_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def lambda_12741_i4736_i4853
    goto L1616;
    FUN_lambda_12741_i4736_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_671[0];
      r0[2] = r1;
      r1 = (object *) constructed_670[0];
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][4];
      r1[2] = r2;
      r2 = top[24];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1617; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
      L1617:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_2163_i4736_i4853
      goto L1618;
      FUN__24loop_2163_i4736_i4853:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1619; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L1619:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1620; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L1620:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1621; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L1621:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def loop_2168_i4736_i4853
          goto L1622;
          FUN_loop_2168_i4736_i4853:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][3];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*) lenv) [3];
              r0[2] = r1;
              r1 = (object *) constructed_36[0];
              r0[3] = r1;
              r1 = top[23];
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object****) lenv) [1][1][1][2];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[29];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1623; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
              L1623:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_669[0];
                  r1 = ((object*) lenv) [2];
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = (object *) 3;
                    r1 = ((object***) lenv) [1][1][2];
                    r0 = box((pxll_int)unbox(r1)+unbox(r0));
                    r1 = ((object***) lenv) [1][1][3];
                    lenv = ((object **)lenv)[1][1];
                    lenv[2] = r0;
                    lenv[3] = r1;
                    goto FUN_loop_2168_i4736_i4853;
                  } else {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_145;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_145;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_145_over;
              fatbar_145:
              r0 = allocate (TC_TUPLE, 6);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 6);
              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
              r1[2] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][4];
              r1[3] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[4] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][3];
              r1[5] = r2;
              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
              r1[6] = r2;
              r2 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][17];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1624; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_make_nvget_1984_i4736_i4853;
              L1624:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = (object*)TC_NIL;
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = ((object*) lenv) [5];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              r0[6] = r1;
              r0 = ((object***) lenv) [1][1][3];
              r1 = ((object*) lenv) [6];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r1 = (object *) 3;
              r2 = ((object**) lenv) [1][2];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              lenv = ((object *)lenv)[1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_2168_i4736_i4853;
              fatbar_145_over: ;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          L1622:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_loop_2168_i4736_i4853; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = (object *) constructed_667[0];
          r1[3] = r2;
          r2 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1625; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_loop_2168_i4736_i4853;
          L1625:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object*****) lenv) [1][1][1][1][2] = r0;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][5];
          switch (get_case (r1)) {
            case (TC_NIL): {
              r1 = (object *) 262;
            } break;
            default: {
              goto fatbar_144;
            }
          }
          goto fatbar_144_over;
          fatbar_144:
          r1 = (object *) 6;
          fatbar_144_over: ;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 12);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_648[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][5];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = (object*)TC_NIL;
            r0[4] = r1;
            r1 = ((object*) lenv) [4];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1626; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1626:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r1 = (object*)TC_NIL;
            r0[8] = r1;
            r1 = ((object*) lenv) [8];
            r2 = ((object*) lenv) [7];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [6];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1627; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L1627:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [9];
            r1[3] = r2;
            r2 = top[23];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1628; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
            L1628:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[10] = r1;
            r1 = ((object*) lenv) [10];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[11] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r0[12] = r1;
            r0 = ((object*) lenv) [12];
            r1 = ((object*) lenv) [11];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object*****) lenv) [1][1][1][1][3] = r0;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1629; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1629:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object*****) lenv) [1][1][1][1][3] = r0;
          }
          lenv = lenv[1];
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_2163_i4736_i4853;
        }
        PXLL_RETURN(0);
      L1618:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_2163_i4736_i4853; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1630; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2163_i4736_i4853;
      L1630:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 19);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_639[0];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[2] = r1;
      r1 = ((object*****) lenv) [1][1][1][1][2];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[3] = r1;
      r1 = ((object*****) lenv) [1][1][1][1][3];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[4] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[3];
      r1[2] = r2;
      r2 = ((object***) lenv) [1][1][2];
      r1[3] = r2;
      r2 = top[34];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1631; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
      L1631:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[5] = r1;
      r1 = ((object*) lenv) [5];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[6] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = top[4];
      r1[2] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object***) lenv) [1][1][2];
      r2[2] = r3;
      r2 = allocate (TC_TUPLE, 3);
      r3 = ((object*) lenv) [2];
      r2[2] = r3;
      r3 = (object *) constructed_36[0];
      r2[3] = r3;
      r3 = top[23];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L1632; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
      L1632:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      lenv = lenv[1];
      r1[3] = r2;
      r2 = top[34];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1633; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
      L1633:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[7] = r1;
      r1 = ((object*) lenv) [7];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[8] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object******) lenv) [1][1][1][1][1][8];
      r1[2] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = ((object***) lenv) [1][1][3];
      r2[2] = r3;
      r2 = allocate (TC_TUPLE, 3);
      r3 = ((object*) lenv) [2];
      r2[2] = r3;
      r3 = (object *) constructed_36[0];
      r2[3] = r3;
      r3 = top[23];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L1634; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
      L1634:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      lenv = lenv[1];
      r1[3] = r2;
      r2 = top[34];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1635; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
      L1635:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[9] = r1;
      r1 = ((object*) lenv) [9];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[10] = r1;
      r1 = ((object***) lenv) [1][1][5];
      switch (get_case (r1)) {
        case (UITAG(1)): {
          r1 = top[191];
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object****) lenv) [1][1][1][5];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][8];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1636; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
          L1636:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
        } break;
      }
      r0[11] = r1;
      r1 = (object*)TC_NIL;
      r0[12] = r1;
      r1 = ((object*) lenv) [12];
      r2 = ((object*) lenv) [11];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[13] = r1;
      r1 = ((object*) lenv) [13];
      r2 = ((object*) lenv) [10];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[14] = r1;
      r1 = ((object*) lenv) [14];
      r2 = ((object*) lenv) [8];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[15] = r1;
      r1 = ((object*) lenv) [15];
      r2 = ((object*) lenv) [6];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[16] = r1;
      r1 = ((object*) lenv) [16];
      r2 = ((object*) lenv) [4];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[17] = r1;
      r1 = ((object*) lenv) [17];
      r2 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[18] = r1;
      r1 = ((object*) lenv) [18];
      r2 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[19] = r1;
      r0 = ((object*) lenv) [19];
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L1616:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_12741_i4736_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2126_i1294_i4736_i4853
    goto L1637;
    FUN_loop_2126_i1294_i4736_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [5];
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object*) lenv) [4];
          r0[4] = r1;
          r1 = (object*)UITAG(1);
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][2];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (UOTAG(9)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][2];
                              r1 = UOBJ_GET(r1,1);
                              r0[2] = r1;
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 3);
                              r2[1] = lenv; lenv = r2;
                              r3 = (object *) constructed_625[0];
                              t = alloc_no_clear (UOTAG(1),1);
                              t[1] = r3;
                              r3 = t;
                              r2[2] = r3;
                              r3 = ((object******) lenv) [1][1][1][1][1][3];
                              r4 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              r2[3] = r3;
                              r2 = ((object*) lenv) [3];
                              t = alloc_no_clear (UOTAG(0),1);
                              t[1] = r2;
                              r2 = t;
                              lenv = lenv[1];
                              r1[2] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][8];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1638; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_1974_i4736_i4853;
                              L1638:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r0 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                              r1 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r1;
                              t[2] = r0;
                              r0 = t;
                              lenv = lenv[1];
                              r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                              r2 = ((object**) lenv) [1][3];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                              r3 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r3;
                              t[2] = r2;
                              r2 = t;
                              r3 = ((object******) lenv) [1][1][1][1][1][3];
                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                              lenv[2] = r2;
                              lenv[3] = r1;
                              lenv[4] = r0;
                              lenv[5] = r3;
                              goto FUN_loop_2126_i1294_i4736_i4853;
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_143;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_143;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_665[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object****) lenv) [1][1][1][3];
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 5);
                            r1 = ((object*****) lenv) [1][1][1][1][2];
                            r0[2] = r1;
                            r1 = ((object*****) lenv) [1][1][1][1][3];
                            r0[3] = r1;
                            r1 = ((object*****) lenv) [1][1][1][1][4];
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = allocate (TC_TUPLE, 2);
                            r3 = allocate (TC_TUPLE, 3);
                            r3[1] = lenv; lenv = r3;
                            r4 = (object *) constructed_625[0];
                            t = alloc_no_clear (UOTAG(1),1);
                            t[1] = r4;
                            r4 = t;
                            r3[2] = r4;
                            r4 = ((object****) lenv) [1][1][1][3];
                            r5 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r5;
                            t[2] = r4;
                            r4 = t;
                            r3[3] = r4;
                            r3 = ((object*) lenv) [3];
                            t = alloc_no_clear (UOTAG(0),1);
                            t[1] = r3;
                            r3 = t;
                            lenv = lenv[1];
                            r2[2] = r3;
                            r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][8];
                            t = allocate (TC_SAVE, 5);
                            t[1] = k; t[2] = lenv; t[3] = &&L1639; t[4] = r0; t[5] = r1; k = t;
                            r2[1] = r3[2]; lenv = r2; goto FUN_expand_1974_i4736_i4853;
                            L1639:
                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                            r2 = result;
                            r1[2] = r2;
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (UOTAG(0),1);
                            t[1] = r1;
                            r1 = t;
                            lenv = lenv[1];
                            r0[5] = r1;
                            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                            r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          } break;
                          default: {
                            lenv = ((object ****)lenv)[1][1][1][1];
                            goto fatbar_143;
                          }
                        }
                        PXLL_RETURN(0);
                      } else {
                        lenv = ((object ****)lenv)[1][1][1][1];
                        goto fatbar_143;
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_143;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_143;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_143;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_143_over;
      fatbar_143:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [5];
      r1[2] = r2;
      r2 = top[21];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1640; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
      L1640:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = top[97];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1641; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
      L1641:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_666;
      r0[2] = r1;
      r1 = ((object*) lenv) [5];
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      fatbar_143_over: ;
      PXLL_RETURN(0);
    L1637:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2126_i1294_i4736_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r1 = (object *) constructed_663[0];
    r0[2] = r1;
    r1 = (object *) constructed_662[0];
    r0[3] = r1;
    r1 = (object *) constructed_661[0];
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][4];
    r0[5] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2126_i1294_i4736_i4853;
  L1615:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_vcase_splat_1986_i4736_i4853; r2[2] = lenv;
  r1[19] = r2;
  // def wrap-with-constructors_1989_i4736_i4853
  goto L1642;
  FUN_wrap_with_constructors_1989_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_660[0];
    r0[2] = r1;
    r1 = (object *) constructed_659[0];
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_13006_i4736_i4853
    goto L1643;
    FUN_lambda_13006_i4736_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_13003_i4736_i4853
      goto L1644;
      FUN_lambda_13003_i4736_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 7);
        r3[1] = lenv; lenv = r3;
        r4 = ((object****) lenv) [1][1][1][3];
        r4 = ((pxll_vector*)r4)->val[7];
        r3[2] = r4;
        r4 = ((object*) lenv) [2];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object**) lenv) [1][2];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r3[3] = r4;
        r4 = ((object***) lenv) [1][1][2];
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = ((object****) lenv) [1][1][1][2];
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = ((object*) lenv) [2];
        lenv = lenv[1];
        r3[4] = r4;
        r4 = (object*)TC_NIL;
        r3[5] = r4;
        r4 = ((object*) lenv) [5];
        r5 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[6] = r4;
        r4 = ((object*) lenv) [6];
        r5 = (object*) &constructed_658;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[7] = r4;
        r3 = ((object*) lenv) [7];
        r4 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r2[2] = r3;
        r3 = top[49];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1645; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
        L1645:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = top[82];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1646; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
        L1646:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object****) lenv) [1][1][1][2];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        ((object***) lenv) [1][1][2] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object***) lenv) [1][1][3];
        r2 = ((pxll_vector*)r2)->val[7];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][3];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[4] = r2;
        r2 = ((object******) lenv) [1][1][1][1][1][21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1647; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_make_constructor_1990_i4736_i4853;
        L1647:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object****) lenv) [1][1][1][3];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        ((object***) lenv) [1][1][3] = r0;
        PXLL_RETURN(0);
      L1644:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_13003_i4736_i4853; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object*) lenv) [3];
      r1 = ((pxll_vector*)r1)->val[6];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1643:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_13006_i4736_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[3] = r1;
    r1 = top[69];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1648; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
    L1648:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 4);
    r1 = allocate (TC_TUPLE, 3);
    r2 = top[3];
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r1[3] = r2;
    r2 = top[34];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1649; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
    L1649:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object*) lenv) [3];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object***) lenv) [1][1][3];
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_fix_1967_i4736_i4853;
  L1642:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_with_constructors_1989_i4736_i4853; r2[2] = lenv;
  r1[20] = r2;
  // def make-constructor_1990_i4736_i4853
  goto L1650;
  FUN_make_constructor_1990_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 21);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][4];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def $loop_2220_i4736_i4853
    goto L1651;
    FUN__24loop_2220_i4736_i4853:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) constructed_36[0];
        r0[3] = r1;
        r1 = top[23];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
      } else {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 4);
        r3[1] = lenv; lenv = r3;
        r4 = allocate (TC_TUPLE, 2);
        r5 = ((object***) lenv) [1][1][2];
        r4[2] = r5;
        r5 = top[58];
        t = allocate (TC_SAVE, 7);
        t[1] = k; t[2] = lenv; t[3] = &&L1652; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
        L1652:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
        r4 = result;
        r3[2] = r4;
        r4 = (object*)TC_NIL;
        r3[3] = r4;
        r4 = ((object*) lenv) [3];
        r5 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[4] = r4;
        r3 = ((object*) lenv) [4];
        r4 = (object*) &constructed_657;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r2[2] = r3;
        r3 = top[49];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1653; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
        L1653:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = top[82];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1654; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
        L1654:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN__24loop_2220_i4736_i4853;
      }
      PXLL_RETURN(0);
    L1651:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN__24loop_2220_i4736_i4853; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1655; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2220_i4736_i4853;
    L1655:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[3] = r1;
    r1 = (object *) constructed_627[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 6);
    r3[1] = lenv; lenv = r3;
    r4 = ((object***) lenv) [1][1][2];
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = ((object****) lenv) [1][1][1][2];
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = ((object*) lenv) [2];
    lenv = lenv[1];
    r3[2] = r4;
    r4 = ((object***) lenv) [1][1][3];
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = ((object****) lenv) [1][1][1][3];
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = ((object*) lenv) [2];
    lenv = lenv[1];
    r3[3] = r4;
    r4 = (object*)TC_NIL;
    r3[4] = r4;
    r4 = ((object*) lenv) [4];
    r5 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[5] = r4;
    r4 = ((object*) lenv) [5];
    r5 = (object*) &constructed_656;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[6] = r4;
    r3 = ((object*) lenv) [6];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    lenv = lenv[1];
    r2[2] = r3;
    r3 = top[49];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1656; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
    L1656:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = top[82];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1657; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
    L1657:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = ((object*) lenv) [5];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[6] = r1;
    r1 = ((object*) lenv) [3];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[7] = r1;
    r1 = (object *) 6;
    t = alloc_no_clear (UOTAG(4),1);
    t[1] = r1;
    r1 = t;
    r0[8] = r1;
    r1 = (object *) constructed_328[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[9] = r1;
    r1 = ((object**) lenv) [1][3];
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(9),2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[10] = r1;
    r1 = (object*)TC_NIL;
    r0[11] = r1;
    r1 = ((object*) lenv) [11];
    r2 = ((object*) lenv) [10];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[12] = r1;
    r1 = ((object*) lenv) [12];
    r2 = ((object*) lenv) [9];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[13] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [13];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1658; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L1658:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1659; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L1659:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[14] = r1;
    r1 = ((object*) lenv) [14];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[15] = r1;
    r1 = (object*)TC_NIL;
    r0[16] = r1;
    r1 = ((object*) lenv) [16];
    r2 = ((object*) lenv) [15];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[17] = r1;
    r1 = ((object*) lenv) [17];
    r2 = ((object*) lenv) [8];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[18] = r1;
    r1 = ((object*) lenv) [18];
    r2 = ((object*) lenv) [7];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[19] = r1;
    r1 = ((object*) lenv) [19];
    r2 = ((object*) lenv) [6];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[20] = r1;
    r1 = ((object*) lenv) [20];
    r2 = ((object*) lenv) [4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[21] = r1;
    r0 = ((object*) lenv) [21];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1650:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_constructor_1990_i4736_i4853; r2[2] = lenv;
  r1[21] = r2;
  // def make-alt_1991_i4736_i4853
  goto L1660;
  FUN_make_alt_1991_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    // def lambda_13140_i4736_i4853
    goto L1661;
    FUN_lambda_13140_i4736_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[113];
      r0[1] = r1[2]; lenv = r0; goto FUN_parse_type_splat_469;
    L1661:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_13140_i4736_i4853; r2[2] = lenv;
    r1[2] = r2;
    r2 = ((object**) lenv) [1][4];
    r1[3] = r2;
    r2 = top[34];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1662; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
    L1662:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1663; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L1663:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = allocate (UOTAG(5), 4);
    r1 = ((object*) lenv) [3];
    r0[1] = r1;
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[4] = r1;
    PXLL_RETURN(0);
  L1660:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_alt_1991_i4736_i4853; r2[2] = lenv;
  r1[22] = r2;
  // def parse-normal-definition_1996_i4736_i4853
  goto L1664;
  FUN_parse_normal_definition_1996_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [5];
    switch (get_case (r0)) {
      case (UOTAG(4)): {
        r0 = (object *) 14;
      } break;
      default: {
        goto fatbar_142;
      }
    }
    goto fatbar_142_over;
    fatbar_142:
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 5);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object***) lenv) [1][1][5];
    r3[2] = r4;
    r4 = top[93];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1665; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_repr_435;
    L1665:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = (object*) &constructed_655;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r2 = ((object*) lenv) [5];
    r3 = (object*) &constructed_654;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1666; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L1666:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 5);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = allocate (TC_TUPLE, 3);
    r5 = ((object***) lenv) [1][1][5];
    r4[2] = r5;
    r5 = top[200];
    t = allocate (TC_SAVE, 8);
    t[1] = k; t[2] = lenv; t[3] = &&L1667; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
    lenv = r5[2]; goto *r5[1];
    L1667:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
    r5 = result;
    r4[3] = r5;
    r5 = top[113];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L1668; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    r4[1] = r5[2]; lenv = r4; goto FUN_parse_type_splat_469;
    L1668:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[2] = r4;
    r4 = top[109];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1669; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
    L1669:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = (object*) &constructed_653;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r2 = ((object*) lenv) [5];
    r3 = (object*) &constructed_652;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1670; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L1670:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    lenv = lenv[1];
    fatbar_142_over: ;
    r0 = allocate (UOTAG(1), 2);
    r1 = ((object*) lenv) [2];
    r0[1] = r1;
    r1 = allocate (TC_TUPLE, 11);
    r1[1] = lenv; lenv = r1;
    r2 = (object *) constructed_627[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r2;
    r2 = t;
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r2;
    r2 = t;
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r2;
    r2 = t;
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object**) lenv) [1][4];
    r2[2] = r3;
    r3 = ((object***) lenv) [1][1][4];
    r2[3] = r3;
    r3 = ((object***) lenv) [1][1][6];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1671; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_find_definitions_1972_i4736_i4853;
    L1671:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r2 = (object*)TC_NIL;
    r1[6] = r2;
    r2 = ((object*) lenv) [6];
    r3 = ((object*) lenv) [5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[7] = r2;
    r2 = ((object*) lenv) [7];
    r3 = ((object**) lenv) [1][5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[8] = r2;
    r2 = ((object*) lenv) [8];
    r3 = ((object*) lenv) [4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[9] = r2;
    r2 = ((object*) lenv) [9];
    r3 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[10] = r2;
    r2 = ((object*) lenv) [10];
    r3 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[11] = r2;
    r1 = ((object*) lenv) [11];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    lenv = lenv[1];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1664:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_parse_normal_definition_1996_i4736_i4853; r2[2] = lenv;
  r1[23] = r2;
  // def expand-match_1997_i4736_i4853
  goto L1672;
  FUN_expand_match_1997_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2270_i4736_i4853
    goto L1673;
    FUN_loop_2270_i4736_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [4];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][4];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_650[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 5);
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                r1[2] = r2;
                r2 = ((object*******) lenv) [1][1][1][1][1][1][8];
                r1[3] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object****) lenv) [1][1][1][2];
                r2[2] = r3;
                r3 = (object *) constructed_36[0];
                r2[3] = r3;
                r3 = top[23];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1674; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
                L1674:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[4] = r2;
                r2 = ((object***) lenv) [1][1][3];
                r1[5] = r2;
                r2 = top[118];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1675; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_compile_pattern_480;
                L1675:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case_noint (r0)) {
                  default: {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,1);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = ((object*****) lenv) [1][1][1][1][3];
                    switch (get_case (r1)) {
                      case (TC_NIL): {
                        r1 = (object *) 262;
                      } break;
                      default: {
                        goto fatbar_141;
                      }
                    }
                    goto fatbar_141_over;
                    fatbar_141:
                    r1 = (object *) 6;
                    fatbar_141_over: ;
                    if PXLL_IS_TRUE(r1) {
                      r1 = ((object*) lenv) [2];
                    } else {
                      r1 = allocate (TC_TUPLE, 7);
                      r1[1] = lenv; lenv = r1;
                      r2 = (object *) constructed_648[0];
                      t = alloc_no_clear (UOTAG(1),1);
                      t[1] = r2;
                      r2 = t;
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][3];
                      t = alloc_no_clear (UOTAG(0),1);
                      t[1] = r2;
                      r2 = t;
                      r1[3] = r2;
                      r2 = (object*)TC_NIL;
                      r1[4] = r2;
                      r2 = ((object*) lenv) [4];
                      r3 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[5] = r2;
                      r2 = ((object*) lenv) [5];
                      r3 = ((object*) lenv) [3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[6] = r2;
                      r2 = ((object*) lenv) [6];
                      r3 = ((object*) lenv) [2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[7] = r2;
                      r1 = ((object*) lenv) [7];
                      t = alloc_no_clear (UOTAG(0),1);
                      t[1] = r1;
                      r1 = t;
                      lenv = lenv[1];
                    }
                    r0[2] = r1;
                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][8];
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_1974_i4736_i4853;
                  } break;
                }
                PXLL_RETURN(0);
              } else {
                goto fatbar_140;
              }
              PXLL_RETURN(0);
              goto fatbar_140_over;
              fatbar_140:
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              r1 = ((object***) lenv) [1][1][3];
              r2 = ((object**) lenv) [1][3];
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              lenv[3] = r1;
              lenv[4] = r2;
              goto FUN_loop_2270_i4736_i4853;
              fatbar_140_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_139;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_139_over;
          fatbar_139:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = top[116];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1676; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_match_var_478;
          L1676:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r2 = ((object***) lenv) [1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = ((object****) lenv) [1][1][1][3];
          r1 = ((object*) lenv) [6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = ((object***) lenv) [1][1][2];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r2 = ((object**) lenv) [1][3];
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r1;
          lenv[3] = r0;
          lenv[4] = r2;
          goto FUN_loop_2270_i4736_i4853;
          fatbar_139_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_138;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_138_over;
      fatbar_138:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_651;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      fatbar_138_over: ;
      PXLL_RETURN(0);
    L1673:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2270_i4736_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) constructed_646[0];
    r0[2] = r1;
    r1 = (object *) constructed_645[0];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2270_i4736_i4853;
  L1672:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_match_1997_i4736_i4853; r2[2] = lenv;
  r1[24] = r2;
  // def expand-cinclude_1998_i4736_i4853
  goto L1677;
  FUN_expand_cinclude_1998_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(2)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object******) lenv) [1][1][1][1][1][2];
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r1 = ((object*****) lenv) [1][1][1][1][2];
                ((pxll_vector*)r1)->val[0] = r0;
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = (object *) constructed_625[0];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                r0[2] = r1;
                r1 = (object*)TC_NIL;
                r0[3] = r1;
                r1 = ((object*) lenv) [3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[4] = r1;
                r0 = ((object*) lenv) [4];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_137;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_137;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_137;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_137_over;
    fatbar_137:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_644;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_137_over: ;
    PXLL_RETURN(0);
  L1677:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_cinclude_1998_i4736_i4853; r2[2] = lenv;
  r1[25] = r2;
  // def expand-cverbatim_1999_i4736_i4853
  goto L1678;
  FUN_expand_cverbatim_1999_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(2)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object******) lenv) [1][1][1][1][1][2];
                r1 = ((pxll_vector*)r1)->val[1];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r1 = ((object*****) lenv) [1][1][1][1][2];
                ((pxll_vector*)r1)->val[1] = r0;
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = (object *) constructed_625[0];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                r0[2] = r1;
                r1 = (object*)TC_NIL;
                r0[3] = r1;
                r1 = ((object*) lenv) [3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[4] = r1;
                r0 = ((object*) lenv) [4];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_136;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_136;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_136;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_136_over;
    fatbar_136:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_643;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_136_over: ;
    PXLL_RETURN(0);
  L1678:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_cverbatim_1999_i4736_i4853; r2[2] = lenv;
  r1[26] = r2;
  // def expand-%nvcase_2000_i4736_i4853
  goto L1679;
  FUN_expand__percentnvcase_2000_i4736_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_639[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1679:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand__percentnvcase_2000_i4736_i4853; r2[2] = lenv;
  r1[27] = r2;
  // def expand-%%cexp_2001_i4736_i4853
  goto L1680;
  FUN_expand__percent_percentcexp_2001_i4736_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = (object *) constructed_641[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = (object*)TC_NIL;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = ((object*) lenv) [6];
            r2 = ((object**) lenv) [1][2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = ((object*) lenv) [7];
            r2 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][8];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = top[34];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1681; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
            L1681:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[9] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [8];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1682; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L1682:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [9];
            r1[3] = r2;
            r2 = top[23];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1683; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
            L1683:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[10] = r1;
            r0 = ((object*) lenv) [10];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_135;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_135;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_135_over;
    fatbar_135:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_642;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_135_over: ;
    PXLL_RETURN(0);
  L1680:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand__percent_percentcexp_2001_i4736_i4853; r2[2] = lenv;
  r1[28] = r2;
  r2 = allocate (TC_TUPLE, 13);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)UITAG(0);
  r2[2] = r3;
  r3 = ((object**) lenv) [1][28];
  r4 = ((object*) lenv) [2];
  r5 = (object *) constructed_641[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[3] = r3;
  r3 = ((object**) lenv) [1][27];
  r4 = ((object*) lenv) [3];
  r5 = (object *) constructed_639[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[4] = r3;
  r3 = ((object**) lenv) [1][26];
  r4 = ((object*) lenv) [4];
  r5 = (object *) constructed_637[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[5] = r3;
  r3 = ((object**) lenv) [1][25];
  r4 = ((object*) lenv) [5];
  r5 = (object *) constructed_635[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[6] = r3;
  r3 = ((object**) lenv) [1][24];
  r4 = ((object*) lenv) [6];
  r5 = (object *) constructed_633[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[7] = r3;
  r3 = ((object**) lenv) [1][13];
  r4 = ((object*) lenv) [7];
  r5 = (object *) constructed_631[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[8] = r3;
  r3 = ((object**) lenv) [1][18];
  r4 = ((object*) lenv) [8];
  r5 = (object *) constructed_629[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[9] = r3;
  r3 = ((object**) lenv) [1][15];
  r4 = ((object*) lenv) [9];
  r5 = (object *) constructed_627[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[10] = r3;
  r3 = ((object**) lenv) [1][14];
  r4 = ((object*) lenv) [10];
  r5 = (object *) constructed_611[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[11] = r3;
  r3 = ((object**) lenv) [1][12];
  r4 = ((object*) lenv) [11];
  r5 = (object *) constructed_625[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[12] = r3;
  r3 = ((object**) lenv) [1][11];
  r4 = ((object*) lenv) [12];
  r5 = (object *) constructed_623[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[13] = r3;
  r2 = ((object**) lenv) [1][10];
  r3 = ((object*) lenv) [13];
  r4 = (object *) constructed_621[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  lenv = lenv[1];
  r1[29] = r2;
  r1 = ((object*) lenv) [2];
  lenv = lenv[1];
  r0[7] = r1;
  r1 = top[167];
  r1 = ((pxll_vector*)r1)->val[1];
  r2 = (object *) 3;
  range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r2));
  r1 = ((pxll_vector*)r1)->val[unbox(r2)];
  r0[8] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [8];
  r1[2] = r2;
  r2 = (object *) 11778;
  r1[3] = r2;
  r2 = top[51];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1684; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_split_356;
  L1684:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[9] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [9];
  r1[2] = r2;
  r2 = (object *) constructed_36[0];
  r1[3] = r2;
  r2 = top[23];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1685; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
  L1685:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[10] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object**) lenv) [1][10];
  r2[2] = r3;
  r3 = top[21];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1686; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
  L1686:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object*) lenv) [2];
  r2[2] = r3;
  r3 = (object*) &constructed_619;
  r2[3] = r3;
  r3 = top[52];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1687; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_357;
  L1687:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = (object *) 1;
  r3 = ((object*) lenv) [3];
  r2 = PXLL_TEST(unbox(r3)==unbox(r2));
  r1[4] = r2;
  r1 = (object *) 6;
  r2 = ((object*) lenv) [4];
  r1 = PXLL_TEST(r2==r1);
  lenv = lenv[1];
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_617;
    r1[2] = r2;
    r2 = ((object*) lenv) [8];
    r1[3] = r2;
    r2 = top[15];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1688; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
    L1688:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
  } else {
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object**) lenv) [1][10];
    r3[2] = r4;
    r4 = top[22];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1689; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_cdr_312;
    L1689:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r2 = allocate (TC_TUPLE, 3);
    r3 = ((object*) lenv) [2];
    r2[2] = r3;
    r3 = (object *) constructed_36[0];
    r2[3] = r3;
    r3 = top[23];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1690; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
    L1690:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = (object*) &constructed_618;
    r1[3] = r2;
    r2 = top[50];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1691; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_join_355;
    L1691:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
  }
  r0[11] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 3);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)TC_NIL;
  r2[2] = r3;
  r3 = ((object*) lenv) [2];
  r4 = (object*) &constructed_616;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[3] = r3;
  r2 = ((object*) lenv) [3];
  r3 = ((object**) lenv) [1][11];
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r1[2] = r2;
  r2 = top[49];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1692; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
  L1692:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[12] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object*) lenv) [8];
  r1[2] = r2;
  r2 = top[87];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1693; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_427;
  L1693:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[13] = r1;
  r1 = ((object*) lenv) [13];
  r0[14] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r2 = top[2];
  r1[2] = r2;
  r2 = ((object*) lenv) [14];
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object*) lenv) [2];
  r3 = ((pxll_vector*)r3)->val[14];
  r2[2] = r3;
  r3 = top[87];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1694; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_read_file_427;
  L1694:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = top[40];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1695; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_foldr_334;
  L1695:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[15] = r1;
  r1 = ((object*) lenv) [15];
  r0[16] = r1;
  r1 = ((object*) lenv) [16];
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  r0[17] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[10];
  r1 = ((pxll_vector*)r1)->val[5];
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = ((object*) lenv) [17];
    r1[3] = r2;
    r2 = top[97];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1696; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_439;
    L1696:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = top[161];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1697; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L1697:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = (object *) 14;
  } else {
    r1 = (object *) 14;
  }
  r0[18] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object*) lenv) [17];
  r1[2] = r2;
  r2 = ((object*) lenv) [7];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1698; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto *r2[1];
  L1698:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[19] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[10];
  r1 = ((pxll_vector*)r1)->val[5];
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = ((object*) lenv) [19];
    r1[3] = r2;
    r2 = top[97];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1699; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_439;
    L1699:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = top[161];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1700; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L1700:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = (object *) 14;
  } else {
    r1 = (object *) 14;
  }
  r0[20] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object*) lenv) [19];
  r1[2] = r2;
  r2 = top[135];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1701; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
  L1701:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[21] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  // def shadow_2621_i4743_i4853
  goto L1702;
  FUN_shadow_2621_i4743_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*)TC_NIL;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r1[3] = r2;
        r2 = top[27];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1703; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_321;
        L1703:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][3];
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1704; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_shadow_2621_i4743_i4853;
          L1704:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2621_i4743_i4853;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1702:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_shadow_2621_i4743_i4853; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_2622_i4743_i4853
  goto L1705;
  FUN_lookup_2622_i4743_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object***) lenv) [1][1][2];
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = ((object*) lenv) [2];
          r0 = ((pxll_vector*)r0)->val[1];
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object**) lenv) [1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_lookup_2622_i4743_i4853;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1705:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_2622_i4743_i4853; r2[2] = lenv;
  r1[3] = r2;
  // def walk_2623_i4743_i4853
  goto L1706;
  FUN_walk_2623_i4743_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_16919_i4743_i4853
    goto L1707;
    FUN_lambda_16919_i4743_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def lambda_16806_i4743_i4853
      goto L1708;
      FUN_lambda_16806_i4743_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[18];
        r0[1] = r1[2]; lenv = r0; goto FUN_throw_299;
      L1708:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_16806_i4743_i4853; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[3] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1709; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2621_i4743_i4853;
          L1709:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*****) lenv) [1][1][1][1][3] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[3] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1710; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2621_i4743_i4853;
          L1710:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*****) lenv) [1][1][1][1][3] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r0[3] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1711; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2621_i4743_i4853;
          L1711:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          ((object*****) lenv) [1][1][1][1][3] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(11)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(4), 2);
          r2 = ((object**) lenv) [1][2];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][3];
          r2[2] = r3;
          r3 = ((object******) lenv) [1][1][1][1][1][3];
          r2[3] = r3;
          r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1712; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_lookup_2622_i4743_i4853;
          L1712:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r0[2] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object*****) lenv) [1][1][1][1][3] = r0;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*****) lenv) [1][1][1][1][2];
          r3 = ((pxll_vector*)r3)->val[3];
          r2[2] = r3;
          r3 = top[21];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1713; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
          L1713:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1714; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_2623_i4743_i4853;
          L1714:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1715; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1715:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1716; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2622_i4743_i4853;
          L1716:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = ((object*****) lenv) [1][1][1][1][2];
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1717; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2622_i4743_i4853;
          L1717:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = ((object*****) lenv) [1][1][1][1][2];
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_134;
        }
      }
      goto fatbar_134_over;
      fatbar_134:
      r0 = (object *) 14;
      fatbar_134_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_16909_i4743_i4853
      goto L1718;
      FUN_lambda_16909_i4743_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object****) lenv) [1][1][1][3];
        r0[3] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][4];
        r0[1] = r1[2]; lenv = r0; goto FUN_walk_2623_i4743_i4853;
      L1718:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_16909_i4743_i4853; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][2];
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = top[34];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1719; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_map_328;
      L1719:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = ((object***) lenv) [1][1][2];
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = ((object***) lenv) [1][1][2];
      PXLL_RETURN(0);
    L1707:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_16919_i4743_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[17];
    r0[1] = r1[2]; lenv = r0; goto FUN_callcc_298;
  L1706:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_walk_2623_i4743_i4853; r2[2] = lenv;
  r1[4] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][21];
  r1[2] = r2;
  r2 = (object *) constructed_615[0];
  r1[3] = r2;
  r2 = ((object*) lenv) [4];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1720; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_walk_2623_i4743_i4853;
  L1720:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[22] = r1;
  r1 = (object *) 1;
  t = alloc_no_clear (UOTAG(5),1);
  t[1] = r1;
  r1 = t;
  ((object*) lenv) [17] = r1;
  r0[23] = r1;
  r1 = (object *) 1;
  t = alloc_no_clear (UOTAG(5),1);
  t[1] = r1;
  r1 = t;
  ((object*) lenv) [19] = r1;
  r0[24] = r1;
  r1 = (object *) constructed_614[0];
  ((object*) lenv) [13] = r1;
  r0[25] = r1;
  r1 = (object *) constructed_613[0];
  ((object*) lenv) [15] = r1;
  r0[26] = r1;
  r1 = top[168];
  r0[27] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = top[115];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1721; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1721:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[28] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  // def add_2568_i1796_i4746_i4853
  goto L1722;
  FUN_add_2568_i1796_i4746_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object****) lenv) [1][1][1][28];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1723; t[4] = r0; t[5] = r1; k = t;
    lenv = r2[2]; goto *r2[1];
    L1723:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = top[138];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1724; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_make_vardef_519;
    L1724:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r1 = ((object****) lenv) [1][1][1][27];
    r0[2] = r1;
    r1 = top[84];
    r0[3] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[4] = r1;
    r1 = ((object*) lenv) [2];
    r0[5] = r1;
    r1 = top[74];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1725; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_409;
    L1725:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    ((object****) lenv) [1][1][1][27] = r0;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L1722:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_2568_i1796_i4746_i4853; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_2569_i1796_i4746_i4853
  goto L1726;
  FUN_lookup_2569_i1796_i4746_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object***) lenv) [1][1][27];
    r0[2] = r1;
    r1 = top[84];
    r0[3] = r1;
    r1 = ((object*) lenv) [2];
    r0[4] = r1;
    r1 = top[75];
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fmember_411;
  L1726:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_2569_i1796_i4746_i4853; r2[2] = lenv;
  r1[3] = r2;
  // def get_2570_i1796_i4746_i4853
  goto L1727;
  FUN_get_2570_i1796_i4746_i4853:
    r0 = ((object**) lenv) [1][27];
    PXLL_RETURN(0);
  L1727:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_2570_i1796_i4746_i4853; r2[2] = lenv;
  r1[4] = r2;
  r1 = allocate (UOTAG(3), 3);
  r2 = ((object*) lenv) [2];
  r1[1] = r2;
  r2 = ((object*) lenv) [4];
  r1[2] = r2;
  r2 = ((object*) lenv) [3];
  r1[3] = r2;
  lenv = lenv[1];
  r0[29] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def rename_2577_i4746_i4853
  goto L1728;
  FUN_rename_2577_i4746_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def lookup_2583_i4746_i4853
    goto L1729;
    FUN_lookup_2583_i4746_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop0_2585_i4746_i4853
      goto L1730;
      FUN_loop0_2585_i4746_i4853:
        check_heap (0);
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object*)UITAG(1);
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop1_2589_i4746_i4853
            goto L1731;
            FUN_loop1_2589_i4746_i4853:
              check_heap (0);
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = ((object***) lenv) [1][1][3];
                  lenv = ((object ***)lenv)[1][1][1];
                  lenv[2] = r0;
                  goto FUN_loop0_2585_i4746_i4853;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,16)];
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                  r0 = PXLL_TEST(r1==r0);
                  lenv = lenv[1];
                  if PXLL_IS_TRUE(r0) {
                    r0 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } else {
                    r0 = ((object*) lenv) [3];
                    lenv = ((object *)lenv)[1];
                    lenv[2] = r0;
                    goto FUN_loop1_2589_i4746_i4853;
                  }
                  PXLL_RETURN(0);
                } break;
              }
              PXLL_RETURN(0);
            L1731:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop1_2589_i4746_i4853; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[1] = r1[2]; lenv = r0; goto FUN_loop1_2589_i4746_i4853;
          } break;
        }
        PXLL_RETURN(0);
      L1730:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop0_2585_i4746_i4853; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object****) lenv) [1][1][1][3];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r0[1] = r1[2]; lenv = r0; goto FUN_loop0_2585_i4746_i4853;
    L1729:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lookup_2583_i4746_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][2];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][29];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1732; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1732:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1733; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2583_i4746_i4853;
        L1733:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        switch (get_case (r1)) {
          case (UITAG(1)): {
            r1 = (object *) constructed_611[0];
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 4);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object*****) lenv) [1][1][1][1][2];
              r5 = ((pxll_vector*)r5)->val[1];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1734; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L1734:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r3 = ((object*) lenv) [4];
              r4 = (object*) &constructed_609;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1735; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L1735:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = top[82];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1736; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_421;
              L1736:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = ((object*) lenv) [2];
            }
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = ((object*) lenv) [2];
            r1 = ((pxll_vector*)r1)->val[2];
            lenv = lenv[1];
          } break;
        }
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_16511_i4746_i4853
        goto L1737;
        FUN_lambda_16511_i4746_i4853:
          r0 = ((object*) lenv) [2];
          r0 = ((pxll_vector*)r0)->val[2];
          PXLL_RETURN(0);
        L1737:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_16511_i4746_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][4];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1738; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1738:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][6];
        t = alloc_no_clear (UOTAG(7),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r1 = ((object****) lenv) [1][1][1][2];
        ((pxll_vector*)r1)->val[4] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        r2 = ((object**) lenv) [1][4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16396_i1805_i4746_i4853
        goto L1739;
        FUN_lambda_16396_i1805_i4746_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2577_i4746_i4853;
        L1739:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16396_i1805_i4746_i4853; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[37];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][29];
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1740; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1740:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_16544_i4746_i4853
        goto L1741;
        FUN_lambda_16544_i4746_i4853:
          r0 = ((object*) lenv) [2];
          r0 = ((pxll_vector*)r0)->val[2];
          PXLL_RETURN(0);
        L1741:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_16544_i4746_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1742; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1742:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(10),1);
        t[1] = r0;
        r0 = t;
        lenv = lenv[1];
        r1 = ((object****) lenv) [1][1][1][2];
        ((pxll_vector*)r1)->val[4] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][3];
        r2 = ((object**) lenv) [1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16396_i1808_i4746_i4853
        goto L1743;
        FUN_lambda_16396_i1808_i4746_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][3];
          r0[3] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2577_i4746_i4853;
        L1743:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16396_i1808_i4746_i4853; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[37];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object****) lenv) [1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[127];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1744; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
        L1744:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = (object *) constructed_612[0];
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1745; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L1745:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][5];
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_2611_i4746_i4853
            goto L1746;
            FUN__24loop_2611_i4746_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 3);
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object****) lenv) [1][1][1][3];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1747; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L1747:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object*****) lenv) [1][1][1][1][4];
                r1[2] = r2;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r0[3] = r1;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L1748; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_rename_2577_i4746_i4853;
                L1748:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = ((object******) lenv) [1][1][1][1][1][2];
                r2[2] = r3;
                r3 = ((object**) lenv) [1][2];
                r2[3] = r3;
                r3 = top[29];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1749; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                L1749:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][29];
                r2 = ((pxll_vector*)r2)->val[0];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1750; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L1750:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object*****) lenv) [1][1][1][1][4];
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object****) lenv) [1][1][1][4] = r0;
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_2611_i4746_i4853;
              }
              PXLL_RETURN(0);
            L1746:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_2611_i4746_i4853; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1751; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2611_i4746_i4853;
            L1751:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_16628_i4746_i4853
            goto L1752;
            FUN_lambda_16628_i4746_i4853:
              r0 = ((object*) lenv) [2];
              r0 = ((pxll_vector*)r0)->val[2];
              PXLL_RETURN(0);
            L1752:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_16628_i4746_i4853; r2[2] = lenv;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object***) lenv) [1][1][4];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = (object *) constructed_36[0];
            r2[3] = r3;
            r3 = top[23];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1753; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
            L1753:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r1[3] = r2;
            r2 = top[34];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1754; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
            L1754:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(9),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r1 = ((object*****) lenv) [1][1][1][1][2];
            ((pxll_vector*)r1)->val[4] = r0;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r0[3] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_rename_2577_i4746_i4853;
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1755; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2583_i4746_i4853;
        L1755:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = ((pxll_vector*)r1)->val[2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r1 = ((object*****) lenv) [1][1][1][1][2];
            ((pxll_vector*)r1)->val[4] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1756; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2583_i4746_i4853;
        L1756:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = (object *) 14;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = ((pxll_vector*)r1)->val[2];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r1 = ((object******) lenv) [1][1][1][1][1][2];
            ((pxll_vector*)r1)->val[4] = r0;
            lenv = lenv[1];
          } break;
        }
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16396_i1819_i4746_i4853
        goto L1757;
        FUN_lambda_16396_i1819_i4746_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          r0[3] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2577_i4746_i4853;
        L1757:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16396_i1819_i4746_i4853; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[37];
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
      } break;
      default: {
        goto fatbar_133;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_133_over;
    fatbar_133:
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_16396_i1820_i4746_i4853
    goto L1758;
    FUN_lambda_16396_i1820_i4746_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object*****) lenv) [1][1][1][1][3];
      r0[3] = r1;
      r1 = ((object******) lenv) [1][1][1][1][1][2];
      r0[1] = r1[2]; lenv = r0; goto FUN_rename_2577_i4746_i4853;
    L1758:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_16396_i1820_i4746_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = top[37];
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    fatbar_133_over: ;
    PXLL_RETURN(0);
  L1728:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_rename_2577_i4746_i4853; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][22];
  r1[2] = r2;
  r2 = (object *) constructed_608[0];
  r1[3] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1759; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_rename_2577_i4746_i4853;
  L1759:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[30] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [22];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = top[149];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1760; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_do_one_round_558;
  L1760:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[31] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [31];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = top[149];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1761; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_do_one_round_558;
  L1761:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[32] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object*)UITAG(5);
  r1[2] = r2;
  r2 = (object *) constructed_607[0];
  r1[3] = r2;
  r2 = top[120];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1762; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
  L1762:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  ((object*) lenv) [31] = r1;
  r0[33] = r1;
  r1 = ((object*) lenv) [32];
  r0[34] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def search_3955_i4748_i4853
  goto L1763;
  FUN_search_3955_i4748_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[3] = r1;
    r1 = top[42];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1764; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_every_question_336;
    L1764:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][2];
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (UITAG(8)): {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = ((object***) lenv) [1][1][2];
          r2 = ((pxll_vector*)r2)->val[0];
          r1[2] = r2;
          r1 = top[196];
          r2 = ((object*) lenv) [2];
          r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
          lenv = lenv[1];
        } break;
        default: {
          goto fatbar_132;
        }
      }
      goto fatbar_132_over;
      fatbar_132:
      r1 = (object *) 262;
      fatbar_132_over: ;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = top[197];
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)|(1<<unbox(r0)));
        lenv = lenv[1];
        r1 = ((object**) lenv) [1][2];
        ((pxll_vector*)r1)->val[0] = r0;
      } else {
        r0 = (object *) 14;
      }
      r0 = ((object*) lenv) [3];
      PXLL_RETURN(0);
    } else {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1763:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_search_3955_i4748_i4853; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object**) lenv) [1][34];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1765; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_search_3955_i4748_i4853;
  L1765:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[35] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[10];
  r1 = ((pxll_vector*)r1)->val[5];
  if PXLL_IS_TRUE(r1) {
    r1 = (object*) &constructed_606;
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r2 = (object*) &constructed_606;
    (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [32];
    r1[2] = r2;
    r2 = top[130];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1766; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_node_510;
    L1766:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = (object *) 14;
  } else {
    r1 = (object *) 14;
  }
  r0[36] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [32];
  r1[2] = r2;
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = top[145];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1767; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_build_dependency_graph_542;
  L1767:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[37] = r1;
  r1 = (object*) &constructed_605;
  r1 = box((pxll_int)((pxll_string*)(r1))->len);
  r2 = (object*) &constructed_605;
  r1 = (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
  r0[38] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[3];
  r0[39] = r1;
  r1 = (object *) constructed_604[0];
  r0[40] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) constructed_603[0];
  r1[2] = r2;
  r2 = top[144];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1768; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_541;
  L1768:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[41] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def visit0_3895_i4751_i4853
  goto L1769;
  FUN_visit0_3895_i4751_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][41];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][41];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1770; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1770:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][39];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][39];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1771; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1771:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = (object *) 14;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        // def lambda_25610_i4751_i4853
        goto L1772;
        FUN_lambda_25610_i4751_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][41];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][41];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
          r2 = ((pxll_vector*)r2)->val[2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1773; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1773:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_visit0_3895_i4751_i4853;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L1772:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_25610_i4751_i4853; r1[2] = lenv;
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,25)];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1774; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L1774:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
      } break;
    }
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][40];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    lenv = lenv[1];
    ((object***) lenv) [1][1][40] = r0;
    PXLL_RETURN(0);
  L1769:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_visit0_3895_i4751_i4853; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][39];
  r1[2] = r2;
  // def lambda_25645_i4751_i4853
  goto L1775;
  FUN_lambda_25645_i4751_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][41];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][41];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
    r2 = ((pxll_vector*)r2)->val[2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1776; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1776:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 6;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object**) lenv) [1][2];
      r0[1] = r1[2]; lenv = r0; goto FUN_visit0_3895_i4751_i4853;
    } else {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1775:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lambda_25645_i4751_i4853; r2[2] = lenv;
  r1[3] = r2;
  r2 = ((object**) lenv) [1][39];
  r2 = ((pxll_vector*)r2)->val[1];
  r2 = ((pxll_vector*)r2)->val[4];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1777; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto *r2[1];
  L1777:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = top[84];
  r2[2] = r3;
  r3 = top[201];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1778; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1778:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object***) lenv) [1][1][39];
  r2[2] = r3;
  // def lambda_25480_i2997_i4751_i4853
  goto L1779;
  FUN_lambda_25480_i2997_i4751_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_602[0];
    r1[2] = r2;
    r2 = top[144];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1780; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_541;
    L1780:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L1779:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_lambda_25480_i2997_i4751_i4853; r3[2] = lenv;
  r2[3] = r3;
  r3 = ((object***) lenv) [1][1][39];
  r3 = ((pxll_vector*)r3)->val[1];
  r3 = ((pxll_vector*)r3)->val[4];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1781; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1781:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object***) lenv) [1][1][39];
  r2[2] = r3;
  // def lambda_25531_i2997_i4751_i4853
  goto L1782;
  FUN_lambda_25531_i2997_i4751_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_25523_i2997_i4751_i4853
    goto L1783;
    FUN_lambda_25523_i2997_i4751_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object****) lenv) [1][1][1][2];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][2];
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[1];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1784; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1784:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object****) lenv) [1][1][1][2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object****) lenv) [1][1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[144];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1785; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_symbol_set_maker_541;
          L1785:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[1];
          r1 = ((pxll_vector*)r1)->val[0];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,10)];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
      }
      PXLL_RETURN(0);
    L1783:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_25523_i2997_i4751_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [3];
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,11)];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1786; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1786:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[37];
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
  L1782:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_lambda_25531_i2997_i4751_i4853; r3[2] = lenv;
  r2[3] = r3;
  r3 = ((object***) lenv) [1][1][39];
  r3 = ((pxll_vector*)r3)->val[1];
  r3 = ((pxll_vector*)r3)->val[4];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1787; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1787:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = ((object*) lenv) [2];
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) constructed_601[0];
  r2[2] = r3;
  r3 = top[144];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1788; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_symbol_set_maker_541;
  L1788:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = (object *) constructed_600[0];
  r1[5] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) constructed_599[0];
  r2[2] = r3;
  r3 = top[144];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1789; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_symbol_set_maker_541;
  L1789:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[6] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def visit1_3906_i4751_i4853
  goto L1790;
  FUN_visit1_3906_i4751_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][4];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][4];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1791; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1791:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][3];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][3];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1792; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1792:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = (object *) 14;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        // def lambda_25691_i4751_i4853
        goto L1793;
        FUN_lambda_25691_i4751_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
          r2 = ((pxll_vector*)r2)->val[2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1794; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1794:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_visit1_3906_i4751_i4853;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L1793:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_25691_i4751_i4853; r1[2] = lenv;
        r0[3] = r1;
        r1 = ((object*) lenv) [2];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,25)];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1795; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L1795:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
      } break;
    }
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object***) lenv) [1][1][6];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[3] = r1;
    r1 = ((object***) lenv) [1][1][6];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,52)];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,10)];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L1790:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_visit1_3906_i4751_i4853; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def $loop_3911_i4751_i4853
  goto L1796;
  FUN__24loop_3911_i4751_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object******) lenv) [1][1][1][1][1][40];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    switch (get_case (r1)) {
      case (TC_NIL): {
        r1 = (object *) 262;
      } break;
      default: {
        goto fatbar_131;
      }
    }
    goto fatbar_131_over;
    fatbar_131:
    r1 = (object *) 6;
    fatbar_131_over: ;
    r0[3] = r1;
    r0 = (object *) 6;
    r1 = ((object*) lenv) [3];
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object******) lenv) [1][1][1][1][1][40];
      switch (get_case (r1)) {
        case (TC_NIL): {
          r1 = (object*) &constructed_68;
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_598;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_598;
          PXLL_UNDEFINED; result=r1; goto Lreturn;
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][40];
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = ((object*******) lenv) [1][1][1][1][1][1][40];
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r1 = ((object*) lenv) [3];
          ((object*******) lenv) [1][1][1][1][1][1][40] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
        } break;
      }
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r1[2] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[3] = r2;
      r2 = ((object*****) lenv) [1][1][1][1][4];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
      r2 = ((pxll_vector*)r2)->val[2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1797; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1797:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 6;
      r1 = ((object*) lenv) [2];
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) constructed_597[0];
        r0[2] = r1;
        r1 = top[144];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1798; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_symbol_set_maker_541;
        L1798:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        ((object****) lenv) [1][1][1][6] = r0;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1799; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_visit1_3906_i4751_i4853;
        L1799:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*****) lenv) [1][1][1][1][6];
        r1[2] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][6];
        r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,52)];
        r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,11)];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1800; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L1800:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][5];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        ((object****) lenv) [1][1][1][5] = r0;
      } else {
        r0 = (object *) 14;
      }
      lenv = lenv[1];
      goto FUN__24loop_3911_i4751_i4853;
    } else {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1796:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN__24loop_3911_i4751_i4853; r2[2] = lenv;
  r1[2] = r2;
  r1 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1801; t[4] = r0; k = t;
  lenv = r1[2]; goto FUN__24loop_3911_i4751_i4853;
  L1801:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = ((object**) lenv) [1][5];
  lenv = lenv[1];
  lenv = lenv[1];
  lenv = lenv[1];
  r0[42] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[10];
  r1 = ((pxll_vector*)r1)->val[5];
  if PXLL_IS_TRUE(r1) {
    r1 = ((object*) lenv) [42];
    dump_object (r1, 0); fprintf (stdout, "\n");
    r1 = (object *) 14;
  } else {
    r1 = (object *) 14;
  }
  r0[43] = r1;
  r1 = ((object*) lenv) [42];
  r2 = ((object*) lenv) [2];
  ((pxll_vector*)r2)->val[13] = r1;
  r0[44] = r1;
  r1 = (object*) &constructed_596;
  r1 = box((pxll_int)((pxll_string*)(r1))->len);
  r2 = (object*) &constructed_596;
  r1 = (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
  r0[45] = r1;
  r1 = ((object*) lenv) [32];
  r0[46] = r1;
  r1 = allocate (TC_TUPLE, 15);
  r1[1] = lenv; lenv = r1;
  // def instantiate-type-scheme_3365_i4754_i4853
  goto L1802;
  FUN_instantiate_type_scheme_3365_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    // def lambda_21829_i4754_i4853
    goto L1803;
    FUN_lambda_21829_i4754_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = top[107];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1804; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_455;
          L1804:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object**) lenv) [1][3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(1),3);
          t[1] = r2;
          t[2] = r0;
          t[3] = r1;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_130;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_130_over;
      fatbar_130:
      r0 = (object*) &constructed_68;
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_68;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_595;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_595;
      PXLL_UNDEFINED; result=r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_130_over: ;
      PXLL_RETURN(0);
    L1803:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_21829_i4754_i4853; r2[2] = lenv;
    r1[2] = r2;
    r2 = (object*)UITAG(0);
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[4] = r2;
    r2 = top[40];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1805; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_foldr_334;
    L1805:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def walk_3406_i4754_i4853
    goto L1806;
    FUN_walk_3406_i4754_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object*) lenv) [2];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][2];
          r1[2] = r2;
          r2 = ((object*) lenv) [3];
          r1[3] = r2;
          r2 = top[34];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1807; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
          L1807:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = top[106];
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = top[67];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1808; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
          L1808:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = ((object**) lenv) [1][2];
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1806:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3406_i4754_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object***) lenv) [1][1][3];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3406_i4754_i4853;
  L1802:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_instantiate_type_scheme_3365_i4754_i4853; r2[2] = lenv;
  r1[2] = r2;
  // def occurs-in-type_3366_i4754_i4853
  goto L1809;
  FUN_occurs_in_type_3366_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_21925_i4754_i4853
    goto L1810;
    FUN_lambda_21925_i4754_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def lambda_21890_i4754_i4853
      goto L1811;
      FUN_lambda_21890_i4754_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[18];
        r0[1] = r1[2]; lenv = r0; goto FUN_throw_299;
      L1811:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_21890_i4754_i4853; r1[2] = lenv;
      r0[2] = r1;
      r0 = ((object***) lenv) [1][1][3];
      r1 = ((object***) lenv) [1][1][2];
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } else {
        r0 = ((object***) lenv) [1][1][3];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = (object *) 6;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object****) lenv) [1][1][1][3];
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_21911_i4754_i4853
            goto L1812;
            FUN_lambda_21911_i4754_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1813; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_occurs_in_type_3366_i4754_i4853;
              L1813:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 262;
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            L1812:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_21911_i4754_i4853; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = top[37];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1814; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
            L1814:
            ; lenv = k[2]; k = k[1];
            r0 = (object *) 6;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1810:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_21925_i4754_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[17];
    r0[1] = r1[2]; lenv = r0; goto FUN_callcc_298;
  L1809:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_occurs_in_type_3366_i4754_i4853; r2[2] = lenv;
  r1[3] = r2;
  // def occurs-free-in-tenv_3367_i4754_i4853
  goto L1815;
  FUN_occurs_free_in_tenv_3367_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_21974_i4754_i4853
    goto L1816;
    FUN_lambda_21974_i4754_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def lambda_21935_i4754_i4853
      goto L1817;
      FUN_lambda_21935_i4754_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[18];
        r0[1] = r1[2]; lenv = r0; goto FUN_throw_299;
      L1817:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_21935_i4754_i4853; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_21966_i4754_i4853
      goto L1818;
      FUN_lambda_21966_i4754_i4853:
        check_heap (0);
        r0 = ((object*) lenv) [3];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[27];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1819; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_321;
            L1819:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = ((object*****) lenv) [1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [3];
              r0[3] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][3];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1820; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_occurs_in_type_3366_i4754_i4853;
              L1820:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 262;
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L1818:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_21966_i4754_i4853; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][3];
      r0[3] = r1;
      r1 = top[69];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1821; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
      L1821:
      ; lenv = k[2]; k = k[1];
      r0 = (object *) 6;
      PXLL_RETURN(0);
    L1816:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_21974_i4754_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = top[17];
    r0[1] = r1[2]; lenv = r0; goto FUN_callcc_298;
  L1815:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_occurs_free_in_tenv_3367_i4754_i4853; r2[2] = lenv;
  r1[4] = r2;
  // def build-type-scheme_3368_i4754_i4853
  goto L1822;
  FUN_build_type_scheme_3368_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_594[0];
    r1[2] = r2;
    r2 = top[199];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1823; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1823:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def find-generic-tvars_3432_i4754_i4853
    goto L1824;
    FUN_find_generic_tvars_3432_i4754_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1825; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_occurs_free_in_tenv_3367_i4754_i4853;
          L1825:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object***) lenv) [1][1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object***) lenv) [1][1][2];
            r1 = ((pxll_vector*)r1)->val[1];
            r1 = ((pxll_vector*)r1)->val[0];
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[37];
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
        } break;
      }
      PXLL_RETURN(0);
    L1824:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_generic_tvars_3432_i4754_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object****) lenv) [1][1][1][2];
    r1[2] = r2;
    r2 = top[143];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1826; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_534;
    L1826:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1827; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_find_generic_tvars_3432_i4754_i4853;
    L1827:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (UOTAG(2), 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object***) lenv) [1][1][2];
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][2];
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1828; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1828:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[1] = r1;
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    PXLL_RETURN(0);
  L1822:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_build_type_scheme_3368_i4754_i4853; r2[2] = lenv;
  r1[5] = r2;
  // def type-of*_3369_i4754_i4853
  goto L1829;
  FUN_type_of_splat_3369_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*) lenv) [2];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[4] = r1;
        r1 = ((object****) lenv) [1][1][1][7];
        r0[1] = r1[2]; lenv = r0; goto FUN_type_of_literal_3371_i4754_i4853;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object*) lenv) [3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1830; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3365_i4754_i4853;
        L1830:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_97[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][3];
              r1[2] = r2;
              r2 = top[24];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1831; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
              L1831:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = (object *) 3;
              r2 = ((object*) lenv) [2];
              r1 = box((pxll_int)unbox(r2)-unbox(r1));
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*****) lenv) [1][1][1][1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              r1[2] = r2;
              r2 = top[24];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1832; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
              L1832:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = ((object*) lenv) [4];
              r2 = ((object*) lenv) [3];
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              r0[5] = r1;
              r0 = (object *) 6;
              r1 = ((object*) lenv) [5];
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_536;
                r0[2] = r1;
                r1 = ((object****) lenv) [1][1][1][2];
                r0[3] = r1;
                r1 = top[15];
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
              } else {
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = (object*) &constructed_537;
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r0[3] = r1;
                    r1 = top[15];
                    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    // def lambda_22430_i2357_i4754_i4853
                    goto L1833;
                    FUN_lambda_22430_i2357_i4754_i4853:
                      check_heap (0);
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                      r1[3] = r2;
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1834; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
                      L1834:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r1 = ((object**) lenv) [1][2];
                      ((pxll_vector*)r1)->val[5] = r0;
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    L1833:
                    r2 = allocate (TC_CLOSURE, 2);
                    r2[1] = &&FUN_lambda_22430_i2357_i4754_i4853; r2[2] = lenv;
                    r1[2] = r2;
                    r2 = ((object*****) lenv) [1][1][1][1][2];
                    r2 = ((pxll_vector*)r2)->val[3];
                    r1[3] = r2;
                    r2 = top[34];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1835; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                    L1835:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    // def lambda_22443_i2357_i4754_i4853
                    goto L1836;
                    FUN_lambda_22443_i2357_i4754_i4853:
                      check_heap (0);
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = ((object******) lenv) [1][1][1][1][1][2];
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [2];
                      r1[2] = r2;
                      r2 = ((object*******) lenv) [1][1][1][1][1][1][8];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1837; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_unraw_3372_i4754_i4853;
                      L1837:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = ((object*) lenv) [3];
                      r0[4] = r1;
                      r1 = top[142];
                      r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                    L1836:
                    r1 = allocate (TC_CLOSURE, 2);
                    r1[1] = &&FUN_lambda_22443_i2357_i4754_i4853; r1[2] = lenv;
                    r0[2] = r1;
                    r1 = ((object*) lenv) [3];
                    r0[3] = r1;
                    r1 = ((object*) lenv) [4];
                    r0[4] = r1;
                    r1 = top[38];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1838; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_332;
                    L1838:
                    ; lenv = k[2]; k = k[1];
                    r0 = ((object*) lenv) [2];
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_87;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_87;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_87_over;
        fatbar_87:
        r0 = ((object*) lenv) [4];
        PXLL_RETURN(0);
        fatbar_87_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_22477_i2363_i4754_i4853
        goto L1839;
        FUN_lambda_22477_i2363_i4754_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][6];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1840; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
          L1840:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          ((pxll_vector*)r1)->val[5] = r0;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        L1839:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_22477_i2363_i4754_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1841; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1841:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r1 = ((object******) lenv) [1][1][1][1][1][2];
                        r0[2] = r1;
                        r1 = ((object***) lenv) [1][1][2];
                        r0[3] = r1;
                        r1 = top[188];
                        r0[4] = r1;
                        r1 = top[142];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1842; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                        L1842:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 4);
                        r1 = ((object******) lenv) [1][1][1][1][1][2];
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r0[3] = r1;
                        r1 = ((object*) lenv) [2];
                        r0[4] = r1;
                        r1 = top[142];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1843; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                        L1843:
                        ; lenv = k[2]; k = k[1];
                        r0 = ((object*) lenv) [2];
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_88;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_88;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_88;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_88;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_88_over;
        fatbar_88:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_538;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
        fatbar_88_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_3508_i2365_i4754_i4853
        goto L1844;
        FUN_loop_3508_i2365_i4754_i4853:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*) &constructed_68;
              r0 = box((pxll_int)((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_68;
              (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              r0 = (object*) &constructed_539;
              dump_object (r0, 0); fprintf (stdout, "\n");
              r0 = (object*) &constructed_539;
              PXLL_UNDEFINED; result=r0; goto Lreturn;
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object**) lenv) [1][2];
                  r1[2] = r2;
                  r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r1[3] = r2;
                  r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1845; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
                  L1845:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  r1 = ((object**) lenv) [1][2];
                  ((pxll_vector*)r1)->val[5] = r0;
                  r0 = ((object*) lenv) [2];
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_89;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_89_over;
              fatbar_89:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
              r1[3] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1846; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
              L1846:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = ((object**) lenv) [1][2];
              ((pxll_vector*)r1)->val[5] = r0;
              r0 = ((object*) lenv) [2];
              lenv = lenv[1];
              r0 = ((object*) lenv) [3];
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_loop_3508_i2365_i4754_i4853;
              fatbar_89_over: ;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L1844:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_3508_i2365_i4754_i4853; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_3508_i2365_i4754_i4853;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1847; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L1847:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[5];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[5] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_543[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = (object *) 262;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_90;
                }
              }
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_90;
            }
            lenv = lenv[1];
          } break;
          default: {
            goto fatbar_90;
          }
        }
        goto fatbar_90_over;
        fatbar_90:
        r0 = (object *) 6;
        fatbar_90_over: ;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_541[0];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_22605_i2369_i4754_i4853
          goto L1848;
          FUN_lambda_22605_i2369_i4754_i4853:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = top[107];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1849; t[4] = r0; k = t;
            lenv = r1[2]; goto FUN_new_tvar_455;
            L1849:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            ((object***) lenv) [1][1][2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (UOTAG(2), 2);
            r2 = (object *) constructed_540[0];
            r1[1] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object*****) lenv) [1][1][1][1][5];
            r2 = ((object***) lenv) [1][1][2];
            t = alloc_no_clear (UOTAG(1),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            lenv = lenv[1];
            ((object****) lenv) [1][1][1][5] = r0;
            PXLL_RETURN(0);
          L1848:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_22605_i2369_i4754_i4853; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1850; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L1850:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object***) lenv) [1][1][3];
          r1[2] = r2;
          r2 = ((object***) lenv) [1][1][5];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][6];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1851; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
          L1851:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r2 = ((object***) lenv) [1][1][3];
          ((pxll_vector*)r2)->val[5] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1852; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1852:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) constructed_97[0];
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r2 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[3] = r1;
          r1 = top[106];
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
        } else {
          r0 = ((object*) lenv) [4];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][9];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1853; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_apply_tenv_3378_i4754_i4853;
        L1853:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1854; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L1854:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][9];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1855; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_apply_tenv_3378_i4754_i4853;
        L1855:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][3];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1856; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
        L1856:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        r2 = ((object*) lenv) [3];
        ((pxll_vector*)r2)->val[5] = r1;
        r1 = ((object*) lenv) [5];
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [4];
        r0[3] = r1;
        r1 = ((object*) lenv) [6];
        r0[4] = r1;
        r1 = top[142];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1857; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
        L1857:
        ; lenv = k[2]; k = k[1];
        r0 = top[187];
        PXLL_RETURN(0);
      } break;
      case (UITAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_22696_i2380_i4754_i4853
        goto L1858;
        FUN_lambda_22696_i2380_i4754_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][6];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1859; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
          L1859:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          ((pxll_vector*)r1)->val[5] = r0;
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        L1858:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_22696_i2380_i4754_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object***) lenv) [1][1][2];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1860; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L1860:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = top[107];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1861; t[4] = r0; k = t;
            lenv = r1[2]; goto FUN_new_tvar_455;
            L1861:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object****) lenv) [1][1][1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = (object *) constructed_97[0];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r3 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[3] = r2;
            r2 = top[106];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1862; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
            L1862:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = top[142];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1863; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
            L1863:
            ; lenv = k[2]; k = k[1];
            r0 = ((object*) lenv) [4];
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_68;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_68;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_544;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_544;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 17);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[13];
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[24];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1864; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
        L1864:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[6] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = top[84];
        r1[2] = r2;
        r2 = top[201];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1865; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L1865:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[7] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [6];
        r1[2] = r2;
        r2 = top[32];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1866; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_range_326;
        L1866:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[8] = r1;
        r1 = (object *) constructed_552[0];
        r0[9] = r1;
        r1 = (object *) constructed_551[0];
        r0[10] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = ((object**) lenv) [1][6];
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_3923_i2386_i4754_i4853
        goto L1867;
        FUN__24loop_3923_i2386_i4754_i4853:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object****) lenv) [1][1][1][7];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1868; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1868:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (UOTAG(2), 2);
            r2 = (object *) 6;
            r1[1] = r2;
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r0[4] = r1;
            r1 = ((object****) lenv) [1][1][1][7];
            r1 = ((pxll_vector*)r1)->val[1];
            r1 = ((pxll_vector*)r1)->val[0];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1869; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L1869:
            ; lenv = k[2]; k = k[1];
            r0 = (object *) 3;
            r1 = ((object*) lenv) [2];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            lenv[2] = r0;
            goto FUN__24loop_3923_i2386_i4754_i4853;
          }
          PXLL_RETURN(0);
        L1867:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_3923_i2386_i4754_i4853; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1870; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3923_i2386_i4754_i4853;
        L1870:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_25896_i2386_i4754_i4853
        goto L1871;
        FUN_lambda_25896_i2386_i4754_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object***) lenv) [1][1][10];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1872; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L1872:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)>unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = ((object**) lenv) [1][9];
            r1 = ((object**) lenv) [1][10];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            ((object**) lenv) [1][9] = r0;
            r0 = (object *) constructed_550[0];
            ((object**) lenv) [1][10] = r0;
          } else {
            r0 = (object *) 14;
          }
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_25891_i2386_i4754_i4853
          goto L1873;
          FUN_lambda_25891_i2386_i4754_i4853:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][7];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][7];
            r2 = ((pxll_vector*)r2)->val[1];
            r2 = ((pxll_vector*)r2)->val[1];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1874; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L1874:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = (object *) 6;
                r1 = ((object*) lenv) [2];
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = ((pxll_vector*)r1)->val[1];
                  r0[2] = r1;
                  r0 = ((object******) lenv) [1][1][1][1][1][10];
                  r1 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  ((object*****) lenv) [1][1][1][1][10] = r0;
                  r0 = (object *) 262;
                  r1 = ((object*) lenv) [2];
                  ((pxll_vector*)r1)->val[0] = r0;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[1];
                  r0[2] = r1;
                  r1 = ((object*****) lenv) [1][1][1][1][8];
                  r0[3] = r1;
                  r1 = top[28];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1875; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_remove_eq_322;
                  L1875:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  ((object*****) lenv) [1][1][1][1][8] = r0;
                  PXLL_RETURN(0);
                } else {
                  r0 = (object *) 14;
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L1873:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_25891_i2386_i4754_i4853; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = top[37];
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
        L1871:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_25896_i2386_i4754_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object*) lenv) [5];
        r1[3] = r2;
        r2 = top[37];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1876; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_for_each_331;
        L1876:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][10];
        r2[2] = r3;
        r3 = top[24];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1877; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
        L1877:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(unbox(r2)>unbox(r1));
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*) lenv) [9];
          r2 = ((object*) lenv) [10];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          ((object*) lenv) [9] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][8];
        r2[2] = r3;
        r3 = top[24];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1878; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
        L1878:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 1;
        r2 = ((object*) lenv) [2];
        r1 = PXLL_TEST(unbox(r2)>unbox(r1));
        lenv = lenv[1];
        if PXLL_IS_TRUE(r1) {
          r1 = ((object*) lenv) [9];
          r2 = ((object*) lenv) [8];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          ((object*) lenv) [9] = r1;
        } else {
          r1 = (object *) 14;
        }
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [9];
        r1[2] = r2;
        r2 = (object *) constructed_36[0];
        r1[3] = r2;
        r2 = top[23];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1879; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
        L1879:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[11] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[24];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1880; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
        L1880:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[12] = r1;
        r1 = (object *) constructed_549[0];
        r0[13] = r1;
        r1 = (object *) constructed_548[0];
        r0[14] = r1;
        r1 = (object *) constructed_547[0];
        r0[15] = r1;
        r1 = (object *) 1;
        r0[16] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_25989_i2385_i4754_i4853
        goto L1881;
        FUN_lambda_25989_i2385_i4754_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_546[0];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_25975_i2385_i4754_i4853
          goto L1882;
          FUN_lambda_25975_i2385_i4754_i4853:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1883; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1883:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*****) lenv) [1][1][1][1][13];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object****) lenv) [1][1][1][13] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][4];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1884; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1884:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*****) lenv) [1][1][1][1][14];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object****) lenv) [1][1][1][14] = r0;
            r0 = ((object**) lenv) [1][2];
            r1 = ((object****) lenv) [1][1][1][16];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            ((object**) lenv) [1][2] = r0;
            r0 = (object *) 3;
            r1 = ((object****) lenv) [1][1][1][16];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            ((object****) lenv) [1][1][1][16] = r0;
            PXLL_RETURN(0);
          L1882:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_25975_i2385_i4754_i4853; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1885; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L1885:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1886; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L1886:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object****) lenv) [1][1][1][15];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          ((object***) lenv) [1][1][15] = r0;
          PXLL_RETURN(0);
        L1881:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_25989_i2385_i4754_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object*) lenv) [11];
        r1[3] = r2;
        r2 = top[37];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1887; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_for_each_331;
        L1887:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (UOTAG(5), 4);
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [13];
        r2[2] = r3;
        r3 = (object *) constructed_36[0];
        r2[3] = r3;
        r3 = top[23];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1888; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
        L1888:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[1] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [14];
        r2[2] = r3;
        r3 = (object *) constructed_36[0];
        r2[3] = r3;
        r3 = top[23];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1889; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
        L1889:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [4];
        r2[2] = r3;
        r3 = ((object*) lenv) [12];
        r2[3] = r3;
        r3 = top[29];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1890; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
        L1890:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [15];
        r2[2] = r3;
        r3 = (object *) constructed_36[0];
        r2[3] = r3;
        r3 = top[23];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1891; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
        L1891:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r0[17] = r1;
        r0 = ((object*) lenv) [17];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r1 = ((object**) lenv) [1][17];
            r1 = UOBJ_GET(r1,3);
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1892; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L1892:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[45];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1893; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_341;
            L1893:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = top[45];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1894; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_341;
            L1894:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[8] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = ((object**) lenv) [1][6];
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_3555_i2384_i4754_i4853
            goto L1895;
            FUN__24loop_3555_i2384_i4754_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [3];
                r0[2] = r1;
                r1 = (object *) constructed_36[0];
                r0[3] = r1;
                r1 = top[23];
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = top[107];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1896; t[4] = r0; k = t;
                lenv = r1[2]; goto FUN_new_tvar_455;
                L1896:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object**) lenv) [1][3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_3555_i2384_i4754_i4853;
              }
              PXLL_RETURN(0);
            L1895:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_3555_i2384_i4754_i4853; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1897; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_3555_i2384_i4754_i4853;
            L1897:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            lenv = lenv[1];
            r1[2] = r2;
            r2 = top[45];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1898; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_341;
            L1898:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[9] = r1;
            r1 = ((object*) lenv) [6];
            ensure_heap (1, unbox(r1));
            r1 = top[195];
            r2 = ((object*) lenv) [6];
            if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
              t = alloc_no_clear (TC_VECTOR, unbox(r2));
              for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
              r1 = t;
            }
            r0[10] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_22868_i2384_i4754_i4853
            goto L1899;
            FUN_lambda_22868_i2384_i4754_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 4);
              // def lambda_22808_i2384_i4754_i4853
              goto L1900;
              FUN_lambda_22808_i2384_i4754_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object*****) lenv) [1][1][1][1][7];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r1 = allocate (UOTAG(2), 2);
                r2 = (object *) constructed_545[0];
                r1[1] = r2;
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][9];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object**) lenv) [1][3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                PXLL_RETURN(0);
              L1900:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_22808_i2384_i4754_i4853; r2[2] = lenv;
              r1[2] = r2;
              r2 = ((object****) lenv) [1][1][1][3];
              r1[3] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object**) lenv) [1][2];
              r2[2] = r3;
              r3 = (object *) constructed_36[0];
              r2[3] = r3;
              r3 = top[23];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1901; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
              L1901:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[4] = r2;
              r2 = top[40];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1902; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_foldr_334;
              L1902:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_22840_i2384_i4754_i4853
              goto L1903;
              FUN_lambda_22840_i2384_i4754_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 6);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object*****) lenv) [1][1][1][1][8];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = ((object***) lenv) [1][1][2];
                r1[3] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][6];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1904; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
                L1904:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = ((object*) lenv) [3];
                r2 = ((object*) lenv) [2];
                ((pxll_vector*)r2)->val[5] = r1;
                r1 = ((object*) lenv) [3];
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 4);
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][8];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r2 = ((object*) lenv) [4];
                r1[3] = r2;
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][9];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[4] = r2;
                r2 = top[142];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1905; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_unify_533;
                L1905:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*) lenv) [4];
                r1[2] = r2;
                r2 = top[143];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1906; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_534;
                L1906:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[6] = r1;
                r0 = ((object**) lenv) [1][2];
                r1 = ((object*) lenv) [6];
                r2 = ((object*****) lenv) [1][1][1][1][10];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
                ((pxll_vector*)r2)->val[unbox(r0)] = r1;
                PXLL_RETURN(0);
              L1903:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_22840_i2384_i4754_i4853; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[37];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1907; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
              L1907:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_22861_i2384_i4754_i4853
              goto L1908;
              FUN_lambda_22861_i2384_i4754_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**) lenv) [1][2];
                r3 = ((object*****) lenv) [1][1][1][1][10];
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r2 = ((object******) lenv) [1][1][1][1][1][3];
                r1[3] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1909; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_build_type_scheme_3368_i4754_i4853;
                L1909:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object***) lenv) [1][1][2];
                r2 = ((object******) lenv) [1][1][1][1][1][7];
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r0 = ((object**) lenv) [1][2];
                r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                ((object******) lenv) [1][1][1][1][1][3] = r0;
                PXLL_RETURN(0);
              L1908:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_22861_i2384_i4754_i4853; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[37];
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
            L1899:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_22868_i2384_i4754_i4853; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object*) lenv) [5];
            r0[3] = r1;
            r1 = top[37];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1910; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
            L1910:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            r1[3] = r2;
            r2 = ((object******) lenv) [1][1][1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1911; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
            L1911:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][4];
            ((pxll_vector*)r1)->val[5] = r0;
            r0 = ((object*) lenv) [2];
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[24];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1912; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
        L1912:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def $loop_3576_i2418_i4754_i4853
        goto L1913;
        FUN__24loop_3576_i2418_i4754_i4853:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][2];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][5];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1914; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1914:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*****) lenv) [1][1][1][1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1915; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L1915:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r1[3] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1916; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
            L1916:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = ((object*) lenv) [4];
            r2 = ((object*) lenv) [2];
            ((pxll_vector*)r2)->val[5] = r1;
            r1 = ((object*) lenv) [4];
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (UOTAG(2), 2);
            r2 = (object *) constructed_553[0];
            r1[1] = r2;
            r2 = ((object**) lenv) [1][5];
            r1[2] = r2;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object******) lenv) [1][1][1][1][1][3];
            r2 = ((object**) lenv) [1][3];
            t = alloc_no_clear (UOTAG(1),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            lenv = lenv[1];
            ((object*****) lenv) [1][1][1][1][3] = r0;
            lenv = lenv[1];
            r0 = (object *) 3;
            r1 = ((object*) lenv) [2];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            lenv[2] = r0;
            goto FUN__24loop_3576_i2418_i4754_i4853;
          }
          PXLL_RETURN(0);
        L1913:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN__24loop_3576_i2418_i4754_i4853; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) 1;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1917; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3576_i2418_i4754_i4853;
        L1917:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][5];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][4];
        r1[3] = r2;
        r2 = top[29];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1918; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
        L1918:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][3];
        r1[3] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][6];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1919; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
        L1919:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        ((pxll_vector*)r1)->val[5] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r0 = (object *) constructed_486[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [4];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][4];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][4];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][3];
                      r1[3] = r2;
                      r2 = ((object*******) lenv) [1][1][1][1][1][1][6];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1920; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
                      L1920:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = ((object*) lenv) [2];
                      r2 = ((object**) lenv) [1][2];
                      ((pxll_vector*)r2)->val[5] = r1;
                      r1 = ((object*) lenv) [2];
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 2);
                      r2[1] = lenv; lenv = r2;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = ((object****) lenv) [1][1][1][2];
                      r3[2] = r4;
                      r4 = ((object*******) lenv) [1][1][1][1][1][1][3];
                      r3[3] = r4;
                      r4 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1921; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_type_of_splat_3369_i4754_i4853;
                      L1921:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r2 = ((object*) lenv) [2];
                      r3 = ((object****) lenv) [1][1][1][2];
                      ((pxll_vector*)r3)->val[5] = r2;
                      r2 = ((object*) lenv) [2];
                      lenv = lenv[1];
                      r1[2] = r2;
                      r2 = top[143];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1922; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_534;
                      L1922:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 5);
                      r2[1] = lenv; lenv = r2;
                      r3 = allocate (TC_TUPLE, 2);
                      r4 = allocate (TC_TUPLE, 2);
                      r5 = ((object***) lenv) [1][1][4];
                      r4[2] = r5;
                      r5 = top[143];
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1923; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_apply_subst_534;
                      L1923:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = top[109];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1924; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
                      L1924:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r3 = (object*)TC_NIL;
                      r2[3] = r3;
                      r3 = ((object*) lenv) [3];
                      r4 = (object*) &constructed_558;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      r2[4] = r3;
                      r3 = ((object*) lenv) [4];
                      r4 = ((object*) lenv) [2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      r2[5] = r3;
                      r2 = ((object*) lenv) [5];
                      r3 = (object*) &constructed_557;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      lenv = lenv[1];
                      r1[2] = r2;
                      r2 = top[49];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1925; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                      L1925:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = ((object*) lenv) [2];
                      r0 = box((pxll_int)((pxll_string*)(r0))->len);
                      r1 = ((object*) lenv) [2];
                      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      lenv = lenv[1];
                      r0 = ((object*) lenv) [4];
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][4];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][4];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = (object *) constructed_555[0];
                          r1 = ((object*) lenv) [2];
                          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                            r0 = ((object*) lenv) [3];
                            switch (get_case (r0)) {
                              case (TC_PAIR): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][3];
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = ((object**) lenv) [1][3];
                                r1 = UOBJ_GET(r1,1);
                                r0[3] = r1;
                                r0 = ((object*) lenv) [3];
                                switch (get_case (r0)) {
                                  case (TC_NIL): {
                                    r0 = allocate (TC_TUPLE, 4);
                                    r1 = ((object****) lenv) [1][1][1][2];
                                    r0[2] = r1;
                                    r1 = ((object*) lenv) [2];
                                    r0[3] = r1;
                                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                                    r0[4] = r1;
                                    r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][11];
                                    t = allocate (TC_SAVE, 3);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1926; ; k = t;
                                    r0[1] = r1[2]; lenv = r0; goto FUN_unify_exception_types_3392_i4754_i4853;
                                    L1926:
                                    ; lenv = k[2]; k = k[1];
                                    r0 = ((object***) lenv) [1][1][3];
                                    PXLL_RETURN(0);
                                  } break;
                                  default: {
                                    lenv = ((object **)lenv)[1][1];
                                    goto fatbar_93;
                                  }
                                }
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_93;
                              }
                            }
                            PXLL_RETURN(0);
                          } else {
                            lenv = ((object *)lenv)[1];
                            goto fatbar_93;
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_93;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_93_over;
                      fatbar_93:
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_556;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [4];
                      r1[2] = r2;
                      r2 = top[109];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1927; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
                      L1927:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = top[15];
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                      fatbar_93_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_92;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_92;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_92;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_92_over;
          fatbar_92:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_559;
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r0[3] = r1;
          r1 = top[15];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          fatbar_92_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_91;
        }
        PXLL_RETURN(0);
        goto fatbar_91_over;
        fatbar_91:
        r0 = (object *) constructed_488[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [4];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][4];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][4];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 2);
                  r2[1] = lenv; lenv = r2;
                  r3 = allocate (TC_TUPLE, 3);
                  r4 = ((object***) lenv) [1][1][2];
                  r3[2] = r4;
                  r4 = ((object******) lenv) [1][1][1][1][1][3];
                  r3[3] = r4;
                  r4 = ((object*******) lenv) [1][1][1][1][1][1][6];
                  t = allocate (TC_SAVE, 6);
                  t[1] = k; t[2] = lenv; t[3] = &&L1928; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                  r3[1] = r4[2]; lenv = r3; goto FUN_type_of_splat_3369_i4754_i4853;
                  L1928:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                  r3 = result;
                  r2[2] = r3;
                  r2 = ((object*) lenv) [2];
                  r3 = ((object***) lenv) [1][1][2];
                  ((pxll_vector*)r3)->val[5] = r2;
                  r2 = ((object*) lenv) [2];
                  lenv = lenv[1];
                  r1[2] = r2;
                  r2 = top[143];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1929; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_534;
                  L1929:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = (object *) constructed_555[0];
                      r1 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [3];
                            switch (get_case (r0)) {
                              case (TC_NIL): {
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = ((object****) lenv) [1][1][1][2];
                                r0[2] = r1;
                                r1 = ((object*) lenv) [2];
                                r0[3] = r1;
                                r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                r0[4] = r1;
                                r1 = ((object********) lenv) [1][1][1][1][1][1][1][11];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L1930; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_unify_exception_types_3392_i4754_i4853;
                                L1930:
                                ; lenv = k[2]; k = k[1];
                                r0 = ((object***) lenv) [1][1][2];
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                lenv = ((object **)lenv)[1][1];
                                goto fatbar_96;
                              }
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object *)lenv)[1];
                            goto fatbar_96;
                          }
                        }
                        PXLL_RETURN(0);
                      } else {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_96;
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_96;
                    }
                  }
                  PXLL_RETURN(0);
                  goto fatbar_96_over;
                  fatbar_96:
                  r0 = (object*) &constructed_561;
                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                  r1 = (object*) &constructed_561;
                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = ((object**) lenv) [1][2];
                  r0[2] = r1;
                  r1 = top[130];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1931; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_pp_node_510;
                  L1931:
                  ; lenv = k[2]; k = k[1];
                  r0 = top[161];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1932; ; k = t;
                  lenv = r0[2]; goto *r0[1];
                  L1932:
                  ; lenv = k[2]; k = k[1];
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*) &constructed_560;
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r0[3] = r1;
                  r1 = top[15];
                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                  fatbar_96_over: ;
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_95;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_95;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_95_over;
          fatbar_95:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_562;
          r0[2] = r1;
          r1 = ((object*) lenv) [4];
          r0[3] = r1;
          r1 = top[15];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          fatbar_95_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_94;
        }
        PXLL_RETURN(0);
        goto fatbar_94_over;
        fatbar_94:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) constructed_210[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object******) lenv) [1][1][1][1][1][14];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_566[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object*******) lenv) [1][1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1933; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1933:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object******) lenv) [1][1][1][1][1][14];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1934; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1934:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_98;
        }
        goto fatbar_98_over;
        fatbar_98:
        r1 = (object *) constructed_214[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_566[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object*******) lenv) [1][1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1935; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1935:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1936; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1936:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_99;
        }
        goto fatbar_99_over;
        fatbar_99:
        r1 = (object *) constructed_230[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object******) lenv) [1][1][1][1][1][14];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_490[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object*******) lenv) [1][1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1937; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1937:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object******) lenv) [1][1][1][1][1][14];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = top[184];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [6];
          r4 = top[187];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1938; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1938:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_100;
        }
        goto fatbar_100_over;
        fatbar_100:
        r1 = (object *) constructed_239[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_490[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object*******) lenv) [1][1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1939; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1939:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[184];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1940; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1940:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_101;
        }
        goto fatbar_101_over;
        fatbar_101:
        r1 = (object *) constructed_243[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object******) lenv) [1][1][1][1][1][14];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = ((object*) lenv) [3];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object******) lenv) [1][1][1][1][1][14];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1941; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1941:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_102;
        }
        goto fatbar_102_over;
        fatbar_102:
        r1 = (object *) constructed_250[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object***) lenv) [1][1][3];
          r2[2] = r3;
          r3 = top[200];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1942; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          lenv = r3[2]; goto *r3[1];
          L1942:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = top[113];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1943; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_parse_type_splat_469;
          L1943:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_567[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_490[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object***) lenv) [1][1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1944; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1944:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[184];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1945; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1945:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
          lenv = lenv[1];
        } else {
          goto fatbar_103;
        }
        goto fatbar_103_over;
        fatbar_103:
        r1 = (object *) constructed_314[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object**) lenv) [1][3];
          switch (get_case (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (UOTAG(9)): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object**) lenv) [1][3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [2];
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object**) lenv) [1][2];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = ((object**) lenv) [1][3];
                              switch (get_case (r1)) {
                                case (TC_PAIR): {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = UOBJ_GET(r2,1);
                                  r1[3] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case (r1)) {
                                    case (UOTAG(5)): {
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = ((object**) lenv) [1][2];
                                      r2 = UOBJ_GET(r2,0);
                                      r1[2] = r2;
                                      r1 = ((object**) lenv) [1][3];
                                      switch (get_case (r1)) {
                                        case (TC_NIL): {
                                          r1 = (object *) constructed_49[0];
                                          r2 = ((object*****) lenv) [1][1][1][1][2];
                                          if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                            r1 = allocate (TC_TUPLE, 6);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = allocate (TC_TUPLE, 2);
                                            r3 = ((object**) lenv) [1][2];
                                            r2[2] = r3;
                                            r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][10];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1946; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_n_tvars_3388_i4754_i4853;
                                            L1946:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[2] = r2;
                                            r2 = top[107];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1947; t[4] = r0; t[5] = r1; k = t;
                                            lenv = r2[2]; goto FUN_new_tvar_455;
                                            L1947:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[3] = r2;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = ((object******) lenv) [1][1][1][1][1][3];
                                            r2[2] = r3;
                                            r3 = (object *) constructed_572[0];
                                            r2[3] = r3;
                                            r3 = top[106];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1948; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                            L1948:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[4] = r2;
                                            r2 = allocate (TC_TUPLE, 4);
                                            r3 = ((object*) lenv) [4];
                                            r2[2] = r3;
                                            r3 = allocate (TC_TUPLE, 2);
                                            r3[1] = lenv; lenv = r3;
                                            r4 = (object *) 3;
                                            r5 = ((object***) lenv) [1][1][2];
                                            if PXLL_IS_TRUE(PXLL_TEST(unbox(r5)>unbox(r4))) {
                                              r4 = allocate (TC_TUPLE, 3);
                                              r5 = (object *) constructed_571[0];
                                              r4[2] = r5;
                                              r5 = ((object**) lenv) [1][2];
                                              r4[3] = r5;
                                              r5 = top[106];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1949; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                              L1949:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                            } else {
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object**) lenv) [1][2];
                                              r4[2] = r5;
                                              r5 = top[21];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1950; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_car_311;
                                              L1950:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                            }
                                            r3[2] = r4;
                                            r3 = allocate (TC_TUPLE, 3);
                                            r4 = (object *) constructed_569[0];
                                            r3[2] = r4;
                                            r4 = allocate (TC_TUPLE, 2);
                                            r4[1] = lenv; lenv = r4;
                                            r5 = (object*)TC_NIL;
                                            r4[2] = r5;
                                            r4 = ((object*) lenv) [2];
                                            r5 = ((object**) lenv) [1][2];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r5;
                                            t[2] = r4;
                                            r4 = t;
                                            lenv = lenv[1];
                                            r3[3] = r4;
                                            r4 = top[106];
                                            t = allocate (TC_SAVE, 6);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1951; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                            r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                            L1951:
                                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                            r3 = result;
                                            lenv = lenv[1];
                                            r2[3] = r3;
                                            r3 = ((object*) lenv) [3];
                                            r2[4] = r3;
                                            r3 = top[108];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1952; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_rlabel_460;
                                            L1952:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[5] = r2;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = (object *) constructed_555[0];
                                            r2[2] = r3;
                                            r3 = allocate (TC_TUPLE, 2);
                                            r3[1] = lenv; lenv = r3;
                                            r4 = (object*)TC_NIL;
                                            r3[2] = r4;
                                            r3 = ((object*) lenv) [2];
                                            r4 = ((object**) lenv) [1][5];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            lenv = lenv[1];
                                            r2[3] = r3;
                                            r3 = top[106];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1953; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                            L1953:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[6] = r2;
                                            r1 = allocate (UOTAG(2), 2);
                                            r2 = ((object*) lenv) [2];
                                            r3 = ((object*) lenv) [3];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r3;
                                            t[2] = r2;
                                            r2 = t;
                                            r1[1] = r2;
                                            r2 = allocate (TC_TUPLE, 4);
                                            r2[1] = lenv; lenv = r2;
                                            r3 = allocate (TC_TUPLE, 3);
                                            r4 = ((object**) lenv) [1][2];
                                            r3[2] = r4;
                                            r4 = ((object*****) lenv) [1][1][1][1][2];
                                            r3[3] = r4;
                                            r4 = top[29];
                                            t = allocate (TC_SAVE, 6);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1954; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                            r3[1] = r4[2]; lenv = r3; goto FUN_nth_323;
                                            L1954:
                                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                            r3 = result;
                                            r2[2] = r3;
                                            r3 = (object*)TC_NIL;
                                            r2[3] = r3;
                                            r3 = ((object*) lenv) [3];
                                            r4 = ((object**) lenv) [1][6];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            r2[4] = r3;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = (object *) constructed_97[0];
                                            r2[2] = r3;
                                            r3 = ((object*) lenv) [4];
                                            r4 = ((object*) lenv) [2];
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            r2[3] = r3;
                                            r3 = top[106];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1955; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                            L1955:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            lenv = lenv[1];
                                            r1[2] = r2;
                                            lenv = lenv[1];
                                          } else {
                                            r1 = allocate (TC_TUPLE, 2);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                            r3 = ((pxll_vector*)r3)->val[2];
                                            r2[2] = r3;
                                            r3 = ((object******) lenv) [1][1][1][1][1][2];
                                            r2[3] = r3;
                                            r3 = top[67];
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1956; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_396;
                                            L1956:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[2] = r2;
                                            r1 = ((object*) lenv) [2];
                                            switch (get_case (r1)) {
                                              case (UITAG(1)): {
                                                r1 = allocate (TC_TUPLE, 3);
                                                r2 = (object*) &constructed_573;
                                                r1[2] = r2;
                                                r2 = ((object******) lenv) [1][1][1][1][1][2];
                                                r1[3] = r2;
                                                r2 = top[15];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1957; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                                                L1957:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                              } break;
                                              default: {
                                                r1 = allocate (TC_TUPLE, 5);
                                                r1[1] = lenv; lenv = r1;
                                                r2 = ((object**) lenv) [1][2];
                                                r2 = UOBJ_GET(r2,0);
                                                r1[2] = r2;
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                                r2[2] = r3;
                                                r3 = ((object*) lenv) [2];
                                                r3 = ((pxll_vector*)r3)->val[1];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1958; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto *r3[1];
                                                L1958:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[3] = r2;
                                                r2 = ((object*) lenv) [2];
                                                r2 = ((pxll_vector*)r2)->val[5];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1959; t[4] = r0; t[5] = r1; k = t;
                                                lenv = r2[2]; goto *r2[1];
                                                L1959:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[4] = r2;
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                r2[2] = r3;
                                                r3 = ((object*) lenv) [4];
                                                r2[3] = r3;
                                                r3 = top[106];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1960; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                                L1960:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[5] = r2;
                                                r1 = allocate (UOTAG(2), 2);
                                                r2 = ((object*) lenv) [4];
                                                r1[1] = r2;
                                                r2 = allocate (TC_TUPLE, 4);
                                                r2[1] = lenv; lenv = r2;
                                                r3 = allocate (TC_TUPLE, 3);
                                                r4 = ((object**) lenv) [1][3];
                                                r4 = ((pxll_vector*)r4)->val[3];
                                                r3[2] = r4;
                                                r4 = ((object******) lenv) [1][1][1][1][1][2];
                                                r3[3] = r4;
                                                r4 = top[29];
                                                t = allocate (TC_SAVE, 6);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1961; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                                r3[1] = r4[2]; lenv = r3; goto FUN_nth_323;
                                                L1961:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                                r3 = result;
                                                r2[2] = r3;
                                                r3 = (object*)TC_NIL;
                                                r2[3] = r3;
                                                r3 = ((object*) lenv) [3];
                                                r4 = ((object**) lenv) [1][5];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[4] = r3;
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = (object *) constructed_97[0];
                                                r2[2] = r3;
                                                r3 = ((object*) lenv) [4];
                                                r4 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[3] = r3;
                                                r3 = top[106];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1962; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                                L1962:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                lenv = lenv[1];
                                                r1[2] = r2;
                                                lenv = lenv[1];
                                              } break;
                                            }
                                            lenv = lenv[1];
                                          }
                                        } break;
                                        default: {
                                          lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                          goto fatbar_105;
                                        }
                                      }
                                      lenv = lenv[1];
                                    } break;
                                    default: {
                                      lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                      goto fatbar_105;
                                    }
                                  }
                                  lenv = lenv[1];
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_105;
                                }
                              }
                              lenv = lenv[1];
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_105;
                            }
                          }
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_105;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_105;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_105;
                }
              }
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_105;
            }
          }
          goto fatbar_105_over;
          fatbar_105:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_574;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1963; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L1963:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_105_over: ;
        } else {
          goto fatbar_104;
        }
        goto fatbar_104_over;
        fatbar_104:
        r1 = (object *) constructed_505[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object**) lenv) [1][3];
          switch (get_case (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (UOTAG(1)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = ((object**) lenv) [1][3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object***) lenv) [1][1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [2];
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object**) lenv) [1][2];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = ((object**) lenv) [1][3];
                              switch (get_case (r1)) {
                                case (TC_NIL): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = ((object****) lenv) [1][1][1][2];
                                  r2[2] = r3;
                                  r3 = (object *) constructed_572[0];
                                  r2[3] = r3;
                                  r3 = top[106];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1964; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                  L1964:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                                  r3 = ((pxll_vector*)r3)->val[16];
                                  r2[2] = r3;
                                  r3 = ((object*****) lenv) [1][1][1][1][2];
                                  r2[3] = r3;
                                  r3 = top[67];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1965; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_396;
                                  L1965:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case (r1)) {
                                    case (UOTAG(0)): {
                                      r1 = (object *) 14;
                                    } break;
                                    default: {
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = allocate (TC_TUPLE, 2);
                                      r3 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                      r3 = ((pxll_vector*)r3)->val[16];
                                      r2[2] = r3;
                                      r3 = top[71];
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1966; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flength_403;
                                      L1966:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = ((object***************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                      r2 = ((pxll_vector*)r2)->val[16];
                                      r1[2] = r2;
                                      r1 = ((object**) lenv) [1][2];
                                      r2 = ((object*) lenv) [2];
                                      r3 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                      t = alloc_no_clear (UOTAG(1),3);
                                      t[1] = r3;
                                      t[2] = r1;
                                      t[3] = r2;
                                      r1 = t;
                                      lenv = lenv[1];
                                      r2 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                      ((pxll_vector*)r2)->val[16] = r1;
                                      lenv = lenv[1];
                                    } break;
                                  }
                                  lenv = lenv[1];
                                  r1 = (object *) 3;
                                  r2 = ((object**) lenv) [1][2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = allocate (UOTAG(2), 2);
                                    r2 = allocate (TC_TUPLE, 3);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = (object*)TC_NIL;
                                    r2[2] = r3;
                                    r3 = ((object*) lenv) [2];
                                    r4 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][14];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r2 = ((object*) lenv) [3];
                                    r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][13];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r3;
                                    t[2] = r2;
                                    r2 = t;
                                    lenv = lenv[1];
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 5);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = allocate (TC_TUPLE, 4);
                                    r4 = ((object**) lenv) [1][2];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 3);
                                    r5 = (object *) constructed_569[0];
                                    r4[2] = r5;
                                    r5 = allocate (TC_TUPLE, 2);
                                    r5[1] = lenv; lenv = r5;
                                    r6 = (object*)TC_NIL;
                                    r5[2] = r6;
                                    r5 = ((object*) lenv) [2];
                                    r6 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][13];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r6;
                                    t[2] = r5;
                                    r5 = t;
                                    lenv = lenv[1];
                                    r4[3] = r5;
                                    r5 = top[106];
                                    t = allocate (TC_SAVE, 7);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1967; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                    r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                    L1967:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                    r4 = result;
                                    r3[3] = r4;
                                    r4 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][14];
                                    r3[4] = r4;
                                    r4 = top[108];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1968; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
                                    L1968:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[2] = r3;
                                    r3 = allocate (TC_TUPLE, 3);
                                    r4 = (object *) constructed_555[0];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = (object*)TC_NIL;
                                    r4[2] = r5;
                                    r4 = ((object*) lenv) [2];
                                    r5 = ((object**) lenv) [1][2];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r5;
                                    t[2] = r4;
                                    r4 = t;
                                    lenv = lenv[1];
                                    r3[3] = r4;
                                    r4 = top[106];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1969; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                    L1969:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[3] = r3;
                                    r3 = (object*)TC_NIL;
                                    r2[4] = r3;
                                    r3 = ((object*) lenv) [4];
                                    r4 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][13];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[5] = r3;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r3 = (object *) constructed_97[0];
                                    r2[2] = r3;
                                    r3 = ((object*) lenv) [5];
                                    r4 = ((object*) lenv) [3];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r3 = top[106];
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1970; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                    L1970:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    lenv = lenv[1];
                                    r1[2] = r2;
                                  } else {
                                    goto fatbar_108;
                                  }
                                  goto fatbar_108_over;
                                  fatbar_108:
                                  r1 = (object *) 1;
                                  r2 = ((object**) lenv) [1][2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = allocate (UOTAG(2), 2);
                                    r2 = allocate (TC_TUPLE, 2);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = (object*)TC_NIL;
                                    r2[2] = r3;
                                    r2 = ((object*) lenv) [2];
                                    r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][13];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r3;
                                    t[2] = r2;
                                    r2 = t;
                                    lenv = lenv[1];
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = allocate (TC_TUPLE, 4);
                                    r4 = ((object**) lenv) [1][2];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = allocate (TC_TUPLE, 3);
                                    r6 = (object *) constructed_571[0];
                                    r5[2] = r6;
                                    r6 = (object *) constructed_576[0];
                                    r5[3] = r6;
                                    r6 = top[106];
                                    t = allocate (TC_SAVE, 8);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1971; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                    r5[1] = r6[2]; lenv = r5; goto FUN_pred_453;
                                    L1971:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                    r5 = result;
                                    r4[2] = r5;
                                    r4 = allocate (TC_TUPLE, 3);
                                    r5 = (object *) constructed_569[0];
                                    r4[2] = r5;
                                    r5 = allocate (TC_TUPLE, 2);
                                    r5[1] = lenv; lenv = r5;
                                    r6 = (object*)TC_NIL;
                                    r5[2] = r6;
                                    r5 = ((object*) lenv) [2];
                                    r6 = ((object**) lenv) [1][2];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r6;
                                    t[2] = r5;
                                    r5 = t;
                                    lenv = lenv[1];
                                    r4[3] = r5;
                                    r5 = top[106];
                                    t = allocate (TC_SAVE, 7);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1972; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                    r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                    L1972:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                    r4 = result;
                                    lenv = lenv[1];
                                    r3[3] = r4;
                                    r4 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][13];
                                    r3[4] = r4;
                                    r4 = top[108];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1973; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
                                    L1973:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[2] = r3;
                                    r3 = allocate (TC_TUPLE, 3);
                                    r4 = (object *) constructed_555[0];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = (object*)TC_NIL;
                                    r4[2] = r5;
                                    r4 = ((object*) lenv) [2];
                                    r5 = ((object**) lenv) [1][2];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r5;
                                    t[2] = r4;
                                    r4 = t;
                                    lenv = lenv[1];
                                    r3[3] = r4;
                                    r4 = top[106];
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1974; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                    L1974:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[3] = r3;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r3 = (object *) constructed_97[0];
                                    r2[2] = r3;
                                    r3 = (object *) constructed_575[0];
                                    r4 = ((object*) lenv) [3];
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r3 = top[106];
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1975; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                    L1975:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    lenv = lenv[1];
                                    r1[2] = r2;
                                  } else {
                                    goto fatbar_109;
                                  }
                                  goto fatbar_109_over;
                                  fatbar_109:
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = top[107];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1976; t[4] = r0; t[5] = r1; k = t;
                                  lenv = r2[2]; goto FUN_new_tvar_455;
                                  L1976:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = ((object***) lenv) [1][1][2];
                                  r2[2] = r3;
                                  r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][10];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1977; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_n_tvars_3388_i4754_i4853;
                                  L1977:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[3] = r2;
                                  r1 = allocate (UOTAG(2), 2);
                                  r2 = ((object*) lenv) [3];
                                  r3 = ((object*) lenv) [2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r3;
                                  t[2] = r2;
                                  r2 = t;
                                  r1[1] = r2;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r2[1] = lenv; lenv = r2;
                                  r3 = allocate (TC_TUPLE, 4);
                                  r4 = ((object***) lenv) [1][1][2];
                                  r3[2] = r4;
                                  r4 = allocate (TC_TUPLE, 2);
                                  r4[1] = lenv; lenv = r4;
                                  r5 = allocate (TC_TUPLE, 3);
                                  r6 = (object *) constructed_571[0];
                                  r5[2] = r6;
                                  r6 = ((object***) lenv) [1][1][3];
                                  r5[3] = r6;
                                  r6 = top[106];
                                  t = allocate (TC_SAVE, 8);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1978; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                  r5[1] = r6[2]; lenv = r5; goto FUN_pred_453;
                                  L1978:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                  r5 = result;
                                  r4[2] = r5;
                                  r4 = allocate (TC_TUPLE, 3);
                                  r5 = (object *) constructed_569[0];
                                  r4[2] = r5;
                                  r5 = allocate (TC_TUPLE, 2);
                                  r5[1] = lenv; lenv = r5;
                                  r6 = (object*)TC_NIL;
                                  r5[2] = r6;
                                  r5 = ((object*) lenv) [2];
                                  r6 = ((object**) lenv) [1][2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r6;
                                  t[2] = r5;
                                  r5 = t;
                                  lenv = lenv[1];
                                  r4[3] = r5;
                                  r5 = top[106];
                                  t = allocate (TC_SAVE, 7);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1979; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                  r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                  L1979:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                  r4 = result;
                                  lenv = lenv[1];
                                  r3[3] = r4;
                                  r4 = ((object**) lenv) [1][2];
                                  r3[4] = r4;
                                  r4 = top[108];
                                  t = allocate (TC_SAVE, 6);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1980; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                  r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
                                  L1980:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                  r3 = result;
                                  r2[2] = r3;
                                  r3 = allocate (TC_TUPLE, 3);
                                  r4 = (object *) constructed_555[0];
                                  r3[2] = r4;
                                  r4 = allocate (TC_TUPLE, 2);
                                  r4[1] = lenv; lenv = r4;
                                  r5 = (object*)TC_NIL;
                                  r4[2] = r5;
                                  r4 = ((object*) lenv) [2];
                                  r5 = ((object**) lenv) [1][2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r5;
                                  t[2] = r4;
                                  r4 = t;
                                  lenv = lenv[1];
                                  r3[3] = r4;
                                  r4 = top[106];
                                  t = allocate (TC_SAVE, 6);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1981; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                  r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                  L1981:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                  r3 = result;
                                  r2[3] = r3;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = (object *) constructed_97[0];
                                  r2[2] = r3;
                                  r3 = ((object**) lenv) [1][3];
                                  r4 = ((object*) lenv) [3];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r4;
                                  t[2] = r3;
                                  r3 = t;
                                  r2[3] = r3;
                                  r3 = top[106];
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1982; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                  L1982:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  lenv = lenv[1];
                                  r1[2] = r2;
                                  lenv = lenv[1];
                                  fatbar_109_over: ;
                                  fatbar_108_over: ;
                                  lenv = lenv[1];
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_107;
                                }
                              }
                              lenv = lenv[1];
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_107;
                            }
                          }
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_107;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_107;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_107;
                }
              }
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_107;
            }
          }
          goto fatbar_107_over;
          fatbar_107:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_574;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1983; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L1983:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_107_over: ;
        } else {
          goto fatbar_106;
        }
        goto fatbar_106_over;
        fatbar_106:
        r1 = (object *) constructed_328[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object**) lenv) [1][3];
          switch (get_case (r1)) {
            case (UOTAG(9)): {
              r1 = allocate (TC_TUPLE, 4);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][3];
              r2 = UOBJ_GET(r2,1);
              r1[3] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r3 = ((pxll_vector*)r3)->val[2];
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r2[3] = r3;
              r3 = top[67];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1984; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_396;
              L1984:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[4] = r2;
              r1 = ((object*) lenv) [4];
              switch (get_case (r1)) {
                case (UITAG(1)): {
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object*) &constructed_577;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r1[3] = r2;
                  r2 = top[15];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1985; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                  L1985:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                } break;
                default: {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][4];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object**) lenv) [1][3];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r2 = ((pxll_vector*)r2)->val[2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1986; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L1986:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                } break;
              }
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_111;
            }
          }
          goto fatbar_111_over;
          fatbar_111:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_574;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1987; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L1987:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_111_over: ;
        } else {
          goto fatbar_110;
        }
        goto fatbar_110_over;
        fatbar_110:
        r1 = (object *) constructed_492[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object**) lenv) [1][3];
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 3);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r4 = ((object*******) lenv) [1][1][1][1][1][1][14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r2 = ((object*) lenv) [3];
              r3 = ((object*******) lenv) [1][1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 6);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = allocate (TC_TUPLE, 3);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = (object *) constructed_572[0];
              r4[3] = r5;
              r5 = top[106];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1988; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1988:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_569[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = ((object*) lenv) [2];
              r6 = ((object********) lenv) [1][1][1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r4[3] = r5;
              r5 = top[106];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1989; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1989:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object*******) lenv) [1][1][1][1][1][1][14];
              r3[4] = r4;
              r4 = top[108];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1990; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L1990:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_579[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r3[3] = r4;
              r4 = top[106];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1991; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L1991:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = ((object*) lenv) [4];
              r4 = ((object*******) lenv) [1][1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r3 = ((object*) lenv) [5];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[6] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_97[0];
              r2[2] = r3;
              r3 = ((object*) lenv) [6];
              r4 = top[187];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = top[106];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1992; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L1992:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[2] = r2;
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_113;
            }
          }
          goto fatbar_113_over;
          fatbar_113:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_574;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1993; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L1993:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_113_over: ;
        } else {
          goto fatbar_112;
        }
        goto fatbar_112_over;
        fatbar_112:
        r1 = (object *) constructed_494[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object**) lenv) [1][3];
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 3);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r4 = ((object*******) lenv) [1][1][1][1][1][1][14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r2 = ((object*) lenv) [3];
              r3 = ((object*******) lenv) [1][1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 5);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = allocate (TC_TUPLE, 3);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = (object *) constructed_572[0];
              r4[3] = r5;
              r5 = top[106];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1994; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1994:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_569[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = ((object*) lenv) [2];
              r6 = ((object********) lenv) [1][1][1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r4[3] = r5;
              r5 = top[106];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1995; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1995:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object*******) lenv) [1][1][1][1][1][1][14];
              r3[4] = r4;
              r4 = top[108];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1996; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L1996:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_579[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r3[3] = r4;
              r4 = top[106];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1997; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L1997:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = ((object*) lenv) [4];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_97[0];
              r2[2] = r3;
              r3 = ((object*) lenv) [5];
              r4 = ((object*******) lenv) [1][1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = top[106];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1998; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L1998:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[2] = r2;
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_115;
            }
          }
          goto fatbar_115_over;
          fatbar_115:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_574;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1999; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L1999:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_115_over: ;
        } else {
          goto fatbar_114;
        }
        goto fatbar_114_over;
        fatbar_114:
        r1 = (object *) constructed_500[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = ((object**) lenv) [1][3];
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][3];
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object*) lenv) [2];
              r2[2] = r3;
              r3 = (object *) constructed_572[0];
              r2[3] = r3;
              r3 = top[106];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2000; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L2000:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r4 = ((object*******) lenv) [1][1][1][1][1][1][15];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = ((object*) lenv) [3];
              r4 = ((object*******) lenv) [1][1][1][1][1][1][14];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = ((object*) lenv) [4];
              r3 = ((object*******) lenv) [1][1][1][1][1][1][13];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 8);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_569[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = ((object*) lenv) [2];
              r6 = ((object********) lenv) [1][1][1][1][1][1][1][15];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r4[3] = r5;
              r5 = top[106];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2001; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L2001:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object*******) lenv) [1][1][1][1][1][1][14];
              r3[4] = r4;
              r4 = top[108];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2002; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L2002:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_579[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r3[3] = r4;
              r4 = top[106];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2003; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L2003:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 4);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = ((object*******) lenv) [1][1][1][1][1][1][13];
              r3[3] = r4;
              r4 = ((object*******) lenv) [1][1][1][1][1][1][14];
              r3[4] = r4;
              r4 = top[108];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2004; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L2004:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_579[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = ((object*) lenv) [2];
              r5 = ((object**) lenv) [1][4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r3[3] = r4;
              r4 = top[106];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2005; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L2005:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = ((object*******) lenv) [1][1][1][1][1][1][15];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_97[0];
              r2[2] = r3;
              r3 = ((object*) lenv) [8];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = top[106];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2006; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L2006:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[2] = r2;
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_117;
            }
          }
          goto fatbar_117_over;
          fatbar_117:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_574;
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[15];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2007; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
          L2007:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          fatbar_117_over: ;
        } else {
          goto fatbar_116;
        }
        goto fatbar_116_over;
        fatbar_116:
        r1 = (object *) constructed_255[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_580[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = top[184];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[187];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2008; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2008:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_118;
        }
        goto fatbar_118_over;
        fatbar_118:
        r1 = (object *) constructed_497[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_587[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_586[0];
          r3[2] = r4;
          r4 = (object *) constructed_584[0];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2009; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L2009:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_583[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object**) lenv) [1][2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2010; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L2010:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_579[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object**) lenv) [1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2011; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L2011:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = (object *) constructed_581[0];
          r4 = ((object*) lenv) [4];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2012; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2012:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_119;
        }
        goto fatbar_119_over;
        fatbar_119:
        r1 = (object *) constructed_286[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_477[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object*******) lenv) [1][1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2013; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L2013:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = top[184];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [6];
          r4 = top[187];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2014; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2014:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_120;
        }
        goto fatbar_120_over;
        fatbar_120:
        r1 = (object *) constructed_295[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_477[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object*******) lenv) [1][1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2015; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L2015:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = top[184];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2016; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2016:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_121;
        }
        goto fatbar_121_over;
        fatbar_121:
        r1 = (object *) constructed_308[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_477[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = ((object*) lenv) [2];
          r5 = ((object*******) lenv) [1][1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r3[3] = r4;
          r4 = top[106];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2017; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L2017:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = top[184];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2018; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2018:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_122;
        }
        goto fatbar_122_over;
        fatbar_122:
        r1 = (object *) constructed_512[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = (object *) constructed_588[0];
          r4 = ((object*****) lenv) [1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2019; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2019:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
        } else {
          goto fatbar_123;
        }
        goto fatbar_123_over;
        fatbar_123:
        r1 = (object *) constructed_510[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = (object *) constructed_589[0];
          r4 = ((object*****) lenv) [1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2020; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2020:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
        } else {
          goto fatbar_124;
        }
        goto fatbar_124_over;
        fatbar_124:
        r1 = (object *) constructed_507[0];
        r2 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = ((object*) lenv) [2];
          r3 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = ((object*) lenv) [2];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_97[0];
          r2[2] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object******) lenv) [1][1][1][1][1][13];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = top[106];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2021; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L2021:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r1[2] = r2;
        } else {
          goto fatbar_125;
        }
        goto fatbar_125_over;
        fatbar_125:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_590;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[15];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2022; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
        L2022:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        fatbar_125_over: ;
        fatbar_124_over: ;
        fatbar_123_over: ;
        fatbar_122_over: ;
        fatbar_121_over: ;
        fatbar_120_over: ;
        fatbar_119_over: ;
        fatbar_118_over: ;
        fatbar_116_over: ;
        fatbar_114_over: ;
        fatbar_112_over: ;
        fatbar_110_over: ;
        fatbar_106_over: ;
        fatbar_104_over: ;
        fatbar_103_over: ;
        fatbar_102_over: ;
        fatbar_101_over: ;
        fatbar_100_over: ;
        fatbar_99_over: ;
        fatbar_98_over: ;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2023; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3365_i4754_i4853;
            L2023:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [4];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_97[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = top[24];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2024; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                      L2024:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object******) lenv) [1][1][1][1][1][4];
                      r1[2] = r2;
                      r2 = top[24];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2025; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                      L2025:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = ((object*) lenv) [3];
                      r2 = ((object*) lenv) [2];
                      r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                      r0[4] = r1;
                      r0 = (object *) 6;
                      r1 = ((object*) lenv) [4];
                      r0 = PXLL_TEST(r1==r0);
                      lenv = lenv[1];
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_563;
                        r0[2] = r1;
                        r1 = ((object*****) lenv) [1][1][1][1][4];
                        r0[3] = r1;
                        r1 = top[15];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2026; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                        L2026:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      } else {
                        r0 = (object *) 14;
                      }
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = top[24];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2027; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                      L2027:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      // def $loop_3723_i2424_i4754_i4853
                      goto L2028;
                      FUN__24loop_3723_i2424_i4754_i4853:
                        check_heap (0);
                        r0 = ((object***) lenv) [1][1][2];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = (object *) 14;
                          PXLL_RETURN(0);
                        } else {
                          r0 = allocate (TC_TUPLE, 5);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[29];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2029; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                          L2029:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                          r1[3] = r2;
                          r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][6];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2030; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
                          L2030:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r1 = ((object*) lenv) [3];
                          r2 = ((object*) lenv) [2];
                          ((pxll_vector*)r2)->val[5] = r1;
                          r1 = ((object*) lenv) [3];
                          r0[4] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*****) lenv) [1][1][1][1][3];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[29];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2031; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                          L2031:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[5] = r1;
                          r0 = allocate (TC_TUPLE, 4);
                          r1 = ((object*) lenv) [2];
                          r0[2] = r1;
                          r1 = ((object*) lenv) [4];
                          r0[3] = r1;
                          r1 = ((object*) lenv) [5];
                          r0[4] = r1;
                          r1 = top[142];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L2032; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                          L2032:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = (object *) 3;
                          r1 = ((object*) lenv) [2];
                          r0 = box((pxll_int)unbox(r1)+unbox(r0));
                          lenv[2] = r0;
                          goto FUN__24loop_3723_i2424_i4754_i4853;
                        }
                        PXLL_RETURN(0);
                      L2028:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN__24loop_3723_i2424_i4754_i4853; r1[2] = lenv;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object *) 1;
                      r0[2] = r1;
                      r1 = ((object*) lenv) [2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2033; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3723_i2424_i4754_i4853;
                      L2033:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      lenv = lenv[1];
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_97;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_97;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_97;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_97_over;
            fatbar_97:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_564;
            r0[2] = r1;
            r1 = ((object***) lenv) [1][1][2];
            r0[3] = r1;
            r1 = top[15];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
            fatbar_97_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
        fatbar_94_over: ;
        PXLL_RETURN(0);
        fatbar_91_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = (object *) constructed_49[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 7);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r1 = top[107];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2034; t[4] = r0; k = t;
                  lenv = r1[2]; goto FUN_new_tvar_455;
                  L2034:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[4] = r1;
                  r1 = ((object*) lenv) [2];
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[5] = r1;
                  r1 = ((object*) lenv) [5];
                  switch (get_case (r1)) {
                    case (UOTAG(12)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][5];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = (object *) constructed_512[0];
                      r2 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                        r1 = (object *) 6;
                      } else {
                        goto fatbar_128;
                      }
                      goto fatbar_128_over;
                      fatbar_128:
                      r1 = (object *) constructed_510[0];
                      r2 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                        r1 = (object *) 6;
                      } else {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_127;
                      }
                      fatbar_128_over: ;
                      lenv = lenv[1];
                    } break;
                    default: {
                      goto fatbar_127;
                    }
                  }
                  goto fatbar_127_over;
                  fatbar_127:
                  r1 = (object *) 262;
                  fatbar_127_over: ;
                  r0[6] = r1;
                  r1 = ((object*) lenv) [6];
                  if PXLL_IS_TRUE(r1) {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = (object *) constructed_586[0];
                    r2[2] = r3;
                    r3 = (object *) constructed_584[0];
                    r2[3] = r3;
                    r3 = top[106];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L2035; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                    L2035:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = (object *) constructed_583[0];
                    r1[2] = r2;
                    r2 = allocate (TC_TUPLE, 2);
                    r2[1] = lenv; lenv = r2;
                    r3 = (object*)TC_NIL;
                    r2[2] = r3;
                    r2 = ((object*) lenv) [2];
                    r3 = ((object**) lenv) [1][2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r3;
                    t[2] = r2;
                    r2 = t;
                    lenv = lenv[1];
                    r1[3] = r2;
                    r2 = top[106];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2036; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                    L2036:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    lenv = lenv[1];
                  } else {
                    r1 = top[107];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2037; t[4] = r0; k = t;
                    lenv = r1[2]; goto FUN_new_tvar_455;
                    L2037:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                  }
                  r0[7] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object*****) lenv) [1][1][1][1][3];
                  r1[2] = r2;
                  r2 = top[24];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2038; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                  L2038:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  // def $loop_3617_i2629_i4754_i4853
                  goto L2039;
                  FUN__24loop_3617_i2629_i4754_i4853:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                      r0 = (object *) 14;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 5);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object*****) lenv) [1][1][1][1][3];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[29];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2040; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                      L2040:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[29];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2041; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                      L2041:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[29];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2042; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                      L2042:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [4];
                      r1[2] = r2;
                      r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][10];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2043; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_n_tvars_3388_i4754_i4853;
                      L2043:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[5] = r1;
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object*) lenv) [3];
                      r1[2] = r2;
                      r2 = (object *) constructed_572[0];
                      r1[3] = r2;
                      r2 = top[106];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2044; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                      L2044:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = (object *) 3;
                      r3 = ((object**) lenv) [1][4];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = ((object**) lenv) [1][5];
                        r2[2] = r3;
                        r3 = top[21];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2045; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
                        L2045:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                      } else {
                        r2 = allocate (TC_TUPLE, 3);
                        r3 = (object *) constructed_571[0];
                        r2[2] = r3;
                        r3 = ((object**) lenv) [1][5];
                        r2[3] = r3;
                        r3 = top[106];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2046; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                        L2046:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                      }
                      r1[2] = r2;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object *) constructed_569[0];
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r2[1] = lenv; lenv = r2;
                      r3 = (object*)TC_NIL;
                      r2[2] = r3;
                      r2 = ((object*) lenv) [2];
                      r3 = ((object**) lenv) [1][2];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      lenv = lenv[1];
                      r1[3] = r2;
                      r2 = top[106];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2047; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                      L2047:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r0[3] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][7];
                      r0[4] = r1;
                      r1 = top[108];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2048; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_rlabel_460;
                      L2048:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      ((object*****) lenv) [1][1][1][1][7] = r0;
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = ((object*) lenv) [2];
                      r0[2] = r1;
                      r1 = ((object*****) lenv) [1][1][1][1][4];
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = ((object**) lenv) [1][2];
                      r2[2] = r3;
                      r3 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                      r2[3] = r3;
                      r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][6];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2049; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3369_i4754_i4853;
                      L2049:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r1 = ((object*) lenv) [2];
                      r2 = ((object**) lenv) [1][2];
                      ((pxll_vector*)r2)->val[5] = r1;
                      r1 = ((object*) lenv) [2];
                      lenv = lenv[1];
                      r0[4] = r1;
                      r1 = top[142];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2050; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                      L2050:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = (object *) 3;
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv[2] = r0;
                      goto FUN__24loop_3617_i2629_i4754_i4853;
                    }
                    PXLL_RETURN(0);
                  L2039:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN__24loop_3617_i2629_i4754_i4853; r1[2] = lenv;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = (object *) 1;
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L2051; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3617_i2629_i4754_i4853;
                  L2051:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  lenv = lenv[1];
                  lenv = lenv[1];
                  r0 = ((object*) lenv) [6];
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 4);
                    r1 = ((object*) lenv) [2];
                    r0[2] = r1;
                    r1 = ((object*) lenv) [4];
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = ((object**) lenv) [1][2];
                    r2[2] = r3;
                    r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
                    r2[3] = r3;
                    r3 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L2052; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3369_i4754_i4853;
                    L2052:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r1 = ((object*) lenv) [2];
                    r2 = ((object**) lenv) [1][2];
                    ((pxll_vector*)r2)->val[5] = r1;
                    r1 = ((object*) lenv) [2];
                    lenv = lenv[1];
                    r0[4] = r1;
                    r1 = top[142];
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L2053; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                    L2053:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    r0 = (object *) 14;
                  }
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = ((object**) lenv) [1][2];
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object *) constructed_555[0];
                  r1[2] = r2;
                  r2 = allocate (TC_TUPLE, 2);
                  r2[1] = lenv; lenv = r2;
                  r3 = (object*)TC_NIL;
                  r2[2] = r3;
                  r2 = ((object*) lenv) [2];
                  r3 = ((object**) lenv) [1][7];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  lenv = lenv[1];
                  r1[3] = r2;
                  r2 = top[106];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2054; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                  L2054:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object***) lenv) [1][1][2];
                  r2[2] = r3;
                  r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r2[3] = r3;
                  r3 = ((object********) lenv) [1][1][1][1][1][1][1][6];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2055; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3369_i4754_i4853;
                  L2055:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  r2 = ((object***) lenv) [1][1][2];
                  ((pxll_vector*)r2)->val[5] = r1;
                  r1 = ((object*) lenv) [2];
                  lenv = lenv[1];
                  r0[4] = r1;
                  r1 = top[142];
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L2056; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                  L2056:
                  ; lenv = k[2]; k = k[1];
                  r0 = ((object*) lenv) [4];
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_126;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_126;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_126_over;
          fatbar_126:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_591;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r0[3] = r1;
          r1 = top[15];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          fatbar_126_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 10);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[2];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = (object*) &constructed_592;
          r1[4] = r2;
          r2 = top[68];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2057; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_398;
          L2057:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2058; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2058:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) 3;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2059; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2059:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [3];
          r2[2] = r3;
          r3 = top[22];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2060; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cdr_312;
          L2060:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2061; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
          L2061:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [4];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          r1[3] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][6];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2062; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3369_i4754_i4853;
          L2062:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r1 = ((object*) lenv) [7];
          r2 = ((object*) lenv) [4];
          ((pxll_vector*)r2)->val[5] = r1;
          r1 = ((object*) lenv) [7];
          r0[8] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2063; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L2063:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[9] = r1;
          r1 = top[107];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2064; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_455;
          L2064:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[10] = r1;
          r0 = ((object*) lenv) [9];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][9];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][9];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = (object *) 262;
                } break;
                default: {
                  goto fatbar_129;
                }
              }
              goto fatbar_129_over;
              fatbar_129:
              r0 = (object *) 6;
              fatbar_129_over: ;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 4);
                r1 = ((object*****) lenv) [1][1][1][1][2];
                r0[2] = r1;
                r1 = ((object**) lenv) [1][8];
                r0[3] = r1;
                r1 = ((object*) lenv) [3];
                r0[4] = r1;
                r1 = top[142];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2065; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                L2065:
                ; lenv = k[2]; k = k[1];
                r0 = result;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r1[3] = r2;
                r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2066; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3365_i4754_i4853;
                L2066:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 4);
                r1 = ((object******) lenv) [1][1][1][1][1][2];
                r0[2] = r1;
                r1 = ((object***) lenv) [1][1][8];
                r0[3] = r1;
                r1 = ((object*) lenv) [2];
                r0[4] = r1;
                r1 = top[142];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2067; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                L2067:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                lenv = lenv[1];
              }
              lenv = lenv[1];
            } break;
          }
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_23042_i2643_i4754_i4853
          goto L2068;
          FUN_lambda_23042_i2643_i4754_i4853:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object**) lenv) [1][10];
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object******) lenv) [1][1][1][1][1][3];
            r2[3] = r3;
            r3 = ((object*******) lenv) [1][1][1][1][1][1][6];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2069; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3369_i4754_i4853;
            L2069:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = ((object*) lenv) [2];
            r2 = ((object**) lenv) [1][2];
            ((pxll_vector*)r2)->val[5] = r1;
            r1 = ((object*) lenv) [2];
            lenv = lenv[1];
            r0[4] = r1;
            r1 = top[142];
            r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
          L2068:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_23042_i2643_i4754_i4853; r1[2] = lenv;
          r0[2] = r1;
          r1 = ((object*) lenv) [6];
          r0[3] = r1;
          r1 = top[37];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2070; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
          L2070:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object*) lenv) [5];
          r0[2] = r1;
          r1 = ((object*) lenv) [10];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][5];
          r2[2] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][3];
          r2[3] = r3;
          r3 = ((object******) lenv) [1][1][1][1][1][6];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2071; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3369_i4754_i4853;
          L2071:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = ((object*) lenv) [2];
          r2 = ((object**) lenv) [1][5];
          ((pxll_vector*)r2)->val[5] = r1;
          r1 = ((object*) lenv) [2];
          lenv = lenv[1];
          r0[4] = r1;
          r1 = top[142];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2072; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
          L2072:
          ; lenv = k[2]; k = k[1];
          r0 = ((object*) lenv) [10];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_86;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_86_over;
    fatbar_86:
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][2];
    r0[2] = r1;
    r1 = top[130];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2073; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_pp_node_510;
    L2073:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_593;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][2];
    r0[3] = r1;
    r1 = top[15];
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
    fatbar_86_over: ;
    PXLL_RETURN(0);
  L1829:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_type_of_splat_3369_i4754_i4853; r2[2] = lenv;
  r1[6] = r2;
  // def type-of-literal_3371_i4754_i4853
  goto L2074;
  FUN_type_of_literal_3371_i4754_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = top[186];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = top[184];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = top[185];
        PXLL_RETURN(0);
      } break;
      case (UITAG(3)): {
        r0 = top[187];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = top[189];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object****) lenv) [1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[2];
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = (object*) &constructed_535;
        r1[4] = r2;
        r2 = top[68];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2075; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_398;
        L2075:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = ((object*) lenv) [5];
        r2 = ((pxll_vector*)r2)->val[2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2076; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L2076:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[6] = r1;
        r0 = ((object*) lenv) [6];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][6];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][6];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2077; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3365_i4754_i4853;
            L2077:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = ((object*) lenv) [4];
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][4];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_97[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][3];
                      r1[2] = r2;
                      r2 = top[24];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2078; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                      L2078:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      // def $loop_3471_i4754_i4853
                      goto L2079;
                      FUN__24loop_3471_i4754_i4853:
                        check_heap (0);
                        r0 = ((object***) lenv) [1][1][2];
                        r1 = ((object*) lenv) [2];
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = (object *) 14;
                          PXLL_RETURN(0);
                        } else {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 4);
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                          r2[2] = r3;
                          r3 = ((object**) lenv) [1][2];
                          r2[3] = r3;
                          r3 = top[29];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2080; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                          L2080:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                          r1[4] = r2;
                          r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][7];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2081; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_literal_3371_i4754_i4853;
                          L2081:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 4);
                          r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
                          r0[2] = r1;
                          r1 = ((object*) lenv) [2];
                          r0[3] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*****) lenv) [1][1][1][1][3];
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r1[3] = r2;
                          r2 = top[29];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2082; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                          L2082:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[4] = r1;
                          r1 = top[142];
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L2083; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                          L2083:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = (object *) 3;
                          r1 = ((object*) lenv) [2];
                          r0 = box((pxll_int)unbox(r1)+unbox(r0));
                          lenv[2] = r0;
                          goto FUN__24loop_3471_i4754_i4853;
                        }
                        PXLL_RETURN(0);
                      L2079:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN__24loop_3471_i4754_i4853; r1[2] = lenv;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object *) 1;
                      r0[2] = r1;
                      r1 = ((object*) lenv) [2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2084; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3471_i4754_i4853;
                      L2084:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      lenv = lenv[1];
                      r0 = ((object*) lenv) [2];
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_85;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_85;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_85;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_85_over;
            fatbar_85:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_534;
            r0[2] = r1;
            r1 = ((object*) lenv) [4];
            r0[3] = r1;
            r1 = top[15];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
            fatbar_85_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = top[107];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2085; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_new_tvar_455;
        L2085:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_22329_i4754_i4853
        goto L2086;
        FUN_lambda_22329_i4754_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = ((object****) lenv) [1][1][1][3];
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][4];
          r1[4] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][7];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2087; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_literal_3371_i4754_i4853;
          L2087:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 4);
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[4] = r1;
          r1 = top[142];
          r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
        L2086:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_22329_i4754_i4853; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[37];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2088; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
        L2088:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_477[0];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[3] = r1;
        r1 = top[106];
        r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
      } break;
    }
    PXLL_RETURN(0);
  L2074:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_type_of_literal_3371_i4754_i4853; r2[2] = lenv;
  r1[7] = r2;
  // def unraw_3372_i4754_i4853
  goto L2089;
  FUN_unraw_3372_i4754_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_533[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = ((object*) lenv) [2];
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_84;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_84;
            }
          }
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_84;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_84;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_84_over;
    fatbar_84:
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
    fatbar_84_over: ;
    PXLL_RETURN(0);
  L2089:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_unraw_3372_i4754_i4853; r2[2] = lenv;
  r1[8] = r2;
  // def apply-tenv_3378_i4754_i4853
  goto L2090;
  FUN_apply_tenv_3378_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[67];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2091; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
    L2091:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_531;
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[1] = r1[2]; lenv = r0; goto FUN_instantiate_type_scheme_3365_i4754_i4853;
          } break;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2090:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_apply_tenv_3378_i4754_i4853; r2[2] = lenv;
  r1[9] = r2;
  // def n-tvars_3388_i4754_i4853
  goto L2092;
  FUN_n_tvars_3388_i4754_i4853:
    check_heap (0);
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) constructed_530[0];
      PXLL_RETURN(0);
    } else {
      goto fatbar_83;
    }
    PXLL_RETURN(0);
    goto fatbar_83_over;
    fatbar_83:
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = top[107];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2093; t[4] = r0; k = t;
    lenv = r1[2]; goto FUN_new_tvar_455;
    L2093:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) 3;
    r3 = ((object**) lenv) [1][2];
    r2 = box((pxll_int)unbox(r3)-unbox(r2));
    r1[2] = r2;
    r2 = ((object***) lenv) [1][1][10];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2094; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_n_tvars_3388_i4754_i4853;
    L2094:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_83_over: ;
    PXLL_RETURN(0);
  L2092:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_n_tvars_3388_i4754_i4853; r2[2] = lenv;
  r1[10] = r2;
  // def unify-exception-types_3392_i4754_i4853
  goto L2095;
  FUN_unify_exception_types_3392_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3676_i4754_i4853
    goto L2096;
    FUN_loop_3676_i4754_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_528[0];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [2];
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][2];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = ((object**) lenv) [1][3];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object***) lenv) [1][1][3];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object***) lenv) [1][1][3];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][3];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = ((object*) lenv) [3];
                            switch (get_case (r0)) {
                              case (TC_NIL): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = allocate (TC_TUPLE, 3);
                                r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                                r2 = ((pxll_vector*)r2)->val[4];
                                r1[2] = r2;
                                r2 = ((object****) lenv) [1][1][1][2];
                                r1[3] = r2;
                                r2 = top[67];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2097; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
                                L2097:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[2] = r1;
                                r1 = ((object*) lenv) [2];
                                switch (get_case (r1)) {
                                  case (UOTAG(0)): {
                                    r1 = allocate (TC_TUPLE, 2);
                                    r1[1] = lenv; lenv = r1;
                                    r2 = ((object**) lenv) [1][2];
                                    r2 = UOBJ_GET(r2,0);
                                    r1[2] = r2;
                                    r1 = ((object*) lenv) [2];
                                    lenv = lenv[1];
                                  } break;
                                  default: {
                                    r1 = allocate (TC_TUPLE, 2);
                                    r1[1] = lenv; lenv = r1;
                                    r2 = top[107];
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L2098; t[4] = r0; t[5] = r1; k = t;
                                    lenv = r2[2]; goto FUN_new_tvar_455;
                                    L2098:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    r1[2] = r2;
                                    r1 = allocate (TC_TUPLE, 2);
                                    r1[1] = lenv; lenv = r1;
                                    r2 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                                    r2 = ((pxll_vector*)r2)->val[4];
                                    r1[2] = r2;
                                    r1 = ((object**) lenv) [1][2];
                                    r2 = ((object*) lenv) [2];
                                    r3 = ((object******) lenv) [1][1][1][1][1][2];
                                    t = alloc_no_clear (UOTAG(1),3);
                                    t[1] = r3;
                                    t[2] = r1;
                                    t[3] = r2;
                                    r1 = t;
                                    lenv = lenv[1];
                                    r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                                    ((pxll_vector*)r2)->val[4] = r1;
                                    r1 = ((object*) lenv) [2];
                                    lenv = lenv[1];
                                  } break;
                                }
                                r0[3] = r1;
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = allocate (TC_TUPLE, 8);
                                r2[1] = lenv; lenv = r2;
                                r3 = ((object******) lenv) [1][1][1][1][1][2];
                                r3 = allocate (TC_TUPLE, 2);
                                r3[1] = lenv; lenv = r3;
                                r4 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                r4 = UOBJ_GET(r4,0);
                                r3[2] = r4;
                                r3 = ((object*) lenv) [2];
                                lenv = lenv[1];
                                r2[2] = r3;
                                r3 = allocate (TC_TUPLE, 2);
                                r4 = ((object***) lenv) [1][1][3];
                                r3[2] = r4;
                                r4 = top[109];
                                t = allocate (TC_SAVE, 6);
                                t[1] = k; t[2] = lenv; t[3] = &&L2099; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
                                L2099:
                                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                r3 = result;
                                r2[3] = r3;
                                r3 = (object*)TC_NIL;
                                r2[4] = r3;
                                r3 = ((object*) lenv) [4];
                                r4 = (object*) &constructed_526;
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r4;
                                t[2] = r3;
                                r3 = t;
                                r2[5] = r3;
                                r3 = ((object*) lenv) [5];
                                r4 = ((object*) lenv) [3];
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r4;
                                t[2] = r3;
                                r3 = t;
                                r2[6] = r3;
                                r3 = ((object*) lenv) [6];
                                r4 = (object*) &constructed_525;
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r4;
                                t[2] = r3;
                                r3 = t;
                                r2[7] = r3;
                                r3 = ((object*) lenv) [7];
                                r4 = ((object*) lenv) [2];
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r4;
                                t[2] = r3;
                                r3 = t;
                                r2[8] = r3;
                                r2 = ((object*) lenv) [8];
                                r3 = (object*) &constructed_524;
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r3;
                                t[2] = r2;
                                r2 = t;
                                lenv = lenv[1];
                                r1[2] = r2;
                                r2 = top[49];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2100; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                                L2100:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[2] = r1;
                                r0 = ((object*) lenv) [2];
                                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                r1 = ((object*) lenv) [2];
                                r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                lenv = lenv[1];
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = allocate (TC_TUPLE, 5);
                                r2[1] = lenv; lenv = r2;
                                r3 = allocate (TC_TUPLE, 2);
                                r4 = ((object*****) lenv) [1][1][1][1][2];
                                r3[2] = r4;
                                r4 = top[109];
                                t = allocate (TC_SAVE, 6);
                                t[1] = k; t[2] = lenv; t[3] = &&L2101; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
                                L2101:
                                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                r3 = result;
                                r2[2] = r3;
                                r3 = (object*)TC_NIL;
                                r2[3] = r3;
                                r3 = ((object*) lenv) [3];
                                r4 = (object*) &constructed_523;
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r4;
                                t[2] = r3;
                                r3 = t;
                                r2[4] = r3;
                                r3 = ((object*) lenv) [4];
                                r4 = ((object*) lenv) [2];
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r4;
                                t[2] = r3;
                                r3 = t;
                                r2[5] = r3;
                                r2 = ((object*) lenv) [5];
                                r3 = (object*) &constructed_522;
                                t = alloc_no_clear (TC_PAIR,2);
                                t[1] = r3;
                                t[2] = r2;
                                r2 = t;
                                lenv = lenv[1];
                                r1[2] = r2;
                                r2 = top[49];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2102; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                                L2102:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[2] = r1;
                                r0 = ((object*) lenv) [2];
                                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                                r1 = ((object*) lenv) [2];
                                r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                lenv = lenv[1];
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                                r0[2] = r1;
                                r1 = ((object*) lenv) [3];
                                r0[3] = r1;
                                r1 = ((object***) lenv) [1][1][2];
                                r0[4] = r1;
                                r1 = top[142];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L2103; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_unify_533;
                                L2103:
                                ; lenv = k[2]; k = k[1];
                                r0 = ((object**) lenv) [1][2];
                                lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                lenv[2] = r0;
                                goto FUN_loop_3676_i4754_i4853;
                              } break;
                              default: {
                                lenv = ((object *****)lenv)[1][1][1][1][1];
                                goto fatbar_82;
                              }
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object ****)lenv)[1][1][1][1];
                            goto fatbar_82;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_82;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_82;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_82;
              }
            }
            PXLL_RETURN(0);
          } else {
            lenv = ((object *)lenv)[1];
            goto fatbar_82;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_82_over;
      fatbar_82:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_529;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = top[109];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2104; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
      L2104:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = top[15];
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      fatbar_82_over: ;
      PXLL_RETURN(0);
    L2096:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3676_i4754_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object**) lenv) [1][3];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3676_i4754_i4853;
  L2095:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_unify_exception_types_3392_i4754_i4853; r2[2] = lenv;
  r1[11] = r2;
  // def apply-subst-to-program_3396_i4754_i4853
  goto L2105;
  FUN_apply_subst_to_program_3396_i4754_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[5];
    r0[2] = r1;
    r1 = top[143];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2106; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_apply_subst_534;
    L2106:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    r1 = ((object*) lenv) [2];
    ((pxll_vector*)r1)->val[5] = r0;
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object**) lenv) [1][12];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[3];
    r0[3] = r1;
    r1 = top[37];
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
  L2105:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_apply_subst_to_program_3396_i4754_i4853; r2[2] = lenv;
  r1[12] = r2;
  r2 = top[107];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2107; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_455;
  L2107:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[13] = r2;
  r2 = top[107];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2108; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_455;
  L2108:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[14] = r2;
  r2 = top[107];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2109; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_455;
  L2109:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[15] = r2;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = ((object***) lenv) [1][1][46];
  r2[2] = r3;
  r3 = ((object*) lenv) [2];
  r2[3] = r3;
  r3 = ((object**) lenv) [1][6];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2110; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3369_i4754_i4853;
  L2110:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = ((object*) lenv) [3];
  r3 = ((object***) lenv) [1][1][46];
  ((pxll_vector*)r3)->val[5] = r2;
  r2 = ((object*) lenv) [3];
  r1[4] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object***) lenv) [1][1][46];
  r2 = ((pxll_vector*)r2)->val[5];
  r1[2] = r2;
  r2 = top[143];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2111; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_534;
  L2111:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r2 = ((object***) lenv) [1][1][46];
  ((pxll_vector*)r2)->val[5] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object**) lenv) [1][12];
  r1[2] = r2;
  r2 = ((object***) lenv) [1][1][46];
  r2 = ((pxll_vector*)r2)->val[3];
  r1[3] = r2;
  r2 = top[37];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2112; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_for_each_331;
  L2112:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = ((object*) lenv) [4];
  lenv = lenv[1];
  lenv = lenv[1];
  r0[47] = r1;
  r1 = ((object*) lenv) [2];
  r1 = ((pxll_vector*)r1)->val[10];
  r1 = ((pxll_vector*)r1)->val[5];
  if PXLL_IS_TRUE(r1) {
    r1 = (object*) &constructed_521;
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r2 = (object*) &constructed_521;
    (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [32];
    r1[2] = r2;
    r2 = top[130];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2113; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_node_510;
    L2113:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = top[161];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2114; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L2114:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = (object *) 14;
  } else {
    r1 = (object *) 14;
  }
  r0[48] = r1;
  r1 = (object*) &constructed_520;
  r1 = box((pxll_int)((pxll_string*)(r1))->len);
  r2 = (object*) &constructed_520;
  r1 = (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
  r0[49] = r1;
  r1 = ((object*) lenv) [32];
  r0[50] = r1;
  r1 = (object *) constructed_519[0];
  r0[51] = r1;
  r1 = allocate (TC_TUPLE, 22);
  r1[1] = lenv; lenv = r1;
  // def cont_2666_i4757_i4853
  goto L2115;
  FUN_cont_2666_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[12];
    r2 = ((pxll_vector*)r2)->val[0];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2116; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L2116:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2117; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L2117:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = ((object**) lenv) [1][2];
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L2115:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_cont_2666_i4757_i4853; r2[2] = lenv;
  r1[2] = r2;
  // def compile_2668_i4757_i4853
  goto L2118;
  FUN_compile_2668_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [5];
      r1[2] = r2;
      r2 = top[139];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2119; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
      L2119:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object**) lenv) [1][19];
      r0[3] = r1;
      r1 = ((object**) lenv) [1][2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2120; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_cont_2666_i4757_i4853;
      L2120:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      ((object*) lenv) [5] = r0;
    } else {
      r0 = (object *) 14;
    }
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][3];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[1];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[4] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][6];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2121; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_symbol_index_2671_i4757_i4853;
            L2121:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) constructed_58[0];
            r1 = ((object**) lenv) [1][4];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object**) lenv) [1][3];
            r1[3] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][5];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2122; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2670_i4757_i4853;
            L2122:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) constructed_86[0];
            r1 = ((object**) lenv) [1][4];
            r2 = ((object*) lenv) [3];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2123; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2672_i4757_i4853;
            L2123:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            r1[3] = r2;
            r2 = ((object******) lenv) [1][1][1][1][1][5];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2124; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2670_i4757_i4853;
            L2124:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) constructed_477[0];
            r1 = ((object***) lenv) [1][1][4];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r0 = (object *) constructed_46[0];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = ((object**) lenv) [1][4];
              r1 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(1),2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              goto fatbar_55;
            }
            PXLL_RETURN(0);
            goto fatbar_55_over;
            fatbar_55:
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [4];
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2125; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2672_i4757_i4853;
            L2125:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][2];
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][3];
            r1[3] = r2;
            r2 = ((object******) lenv) [1][1][1][1][1][5];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2126; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2670_i4757_i4853;
            L2126:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) constructed_479[0];
            r1 = ((object***) lenv) [1][1][4];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_55_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_54;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_54_over;
        fatbar_54:
        r0 = ((object*) lenv) [4];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(1),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_54_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(5)): {
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object**) lenv) [1][2];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[4] = r1;
        r1 = ((object**) lenv) [1][5];
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][8];
        r0[1] = r1[2]; lenv = r0; goto FUN_c_sequence_2674_i4757_i4853;
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][5];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[140];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2127; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_526;
        L2127:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[139];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2128; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
        L2128:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object****) lenv) [1][1][1][2];
                        r1 = ((pxll_vector*)r1)->val[4];
                        r0[2] = r1;
                        r0 = ((object*) lenv) [2];
                        switch (get_case (r0)) {
                          case (UOTAG(3)): {
                            r0 = allocate (TC_TUPLE, 5);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,1);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,2);
                            r0[3] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object******) lenv) [1][1][1][1][1][2];
                            r1[2] = r2;
                            r2 = top[139];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2129; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
                            L2129:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object******) lenv) [1][1][1][1][1][2];
                            r1[2] = r2;
                            r2 = top[140];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2130; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_526;
                            L2130:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[5] = r1;
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            // def finish_2799_i1846_i4757_i4853
                            goto L2131;
                            FUN_finish_2799_i1846_i4757_i4853:
                              check_heap (0);
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 5);
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                              r1[2] = r2;
                              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
                              r1[3] = r2;
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                              r1[4] = r2;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = ((object****) lenv) [1][1][1][4];
                              r2[2] = r3;
                              // def lambda_17697_i1846_i4757_i4853
                              goto L2132;
                              FUN_lambda_17697_i1846_i4757_i4853:
                                check_heap (0);
                                r0 = ((object*****) lenv) [1][1][1][1][5];
                                r1 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(6),2);
                                t[1] = r1;
                                t[2] = r0;
                                r0 = t;
                                PXLL_RETURN(0);
                              L2132:
                              r3 = allocate (TC_CLOSURE, 2);
                              r3[1] = &&FUN_lambda_17697_i1846_i4757_i4853; r3[2] = lenv;
                              r2[3] = r3;
                              r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2133; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
                              L2133:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[5] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2134; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
                              L2134:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 5);
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                              r1[2] = r2;
                              r2 = ((object******) lenv) [1][1][1][1][1][2];
                              r1[3] = r2;
                              r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][4];
                              r1[4] = r2;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = ((object****) lenv) [1][1][1][4];
                              r2[2] = r3;
                              // def lambda_17711_i1846_i4757_i4853
                              goto L2135;
                              FUN_lambda_17711_i1846_i4757_i4853:
                                check_heap (0);
                                r0 = ((object*****) lenv) [1][1][1][1][5];
                                r1 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(6),2);
                                t[1] = r1;
                                t[2] = r0;
                                r0 = t;
                                PXLL_RETURN(0);
                              L2135:
                              r3 = allocate (TC_CLOSURE, 2);
                              r3[1] = &&FUN_lambda_17711_i1846_i4757_i4853; r3[2] = lenv;
                              r2[3] = r3;
                              r3 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2136; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
                              L2136:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[5] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][3];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2137; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
                              L2137:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r0 = ((object*) lenv) [2];
                              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                              r2 = ((object****) lenv) [1][1][1][2];
                              r3 = ((object****) lenv) [1][1][1][3];
                              r4 = ((object*) lenv) [3];
                              r5 = ((object**) lenv) [1][2];
                              t = alloc_no_clear (UOTAG(5),6);
                              t[1] = r5;
                              t[2] = r2;
                              t[3] = r3;
                              t[4] = r0;
                              t[5] = r4;
                              t[6] = r1;
                              r0 = t;
                              PXLL_RETURN(0);
                            L2131:
                            r1 = allocate (TC_CLOSURE, 2);
                            r1[1] = &&FUN_finish_2799_i1846_i4757_i4853; r1[2] = lenv;
                            r0[2] = r1;
                            r0 = allocate (TC_TUPLE, 5);
                            r1 = ((object******) lenv) [1][1][1][1][1][2];
                            r1 = ((pxll_vector*)r1)->val[3];
                            r0[2] = r1;
                            r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                            r0[3] = r1;
                            r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                            r0[4] = r1;
                            r1 = ((object*) lenv) [2];
                            r0[5] = r1;
                            r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][12];
                            r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2685_i4757_i4853;
                          } break;
                          default: {
                            goto fatbar_57;
                          }
                        }
                        PXLL_RETURN(0);
                        goto fatbar_57_over;
                        fatbar_57:
                        r0 = allocate (TC_TUPLE, 5);
                        r1 = (object *) 6;
                        r0[2] = r1;
                        r1 = ((object****) lenv) [1][1][1][2];
                        r0[3] = r1;
                        r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                        r0[4] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = ((object*****) lenv) [1][1][1][1][4];
                        r1[2] = r2;
                        // def lambda_17642_i1845_i4757_i4853
                        goto L2138;
                        FUN_lambda_17642_i1845_i4757_i4853:
                          check_heap (0);
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 5);
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                          r1[2] = r2;
                          r2 = ((object*****) lenv) [1][1][1][1][2];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                          r1[4] = r2;
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r2[2] = r3;
                          // def lambda_17622_i1845_i4757_i4853
                          goto L2139;
                          FUN_lambda_17622_i1845_i4757_i4853:
                            check_heap (0);
                            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (UOTAG(6),2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            PXLL_RETURN(0);
                          L2139:
                          r3 = allocate (TC_CLOSURE, 2);
                          r3[1] = &&FUN_lambda_17622_i1845_i4757_i4853; r3[2] = lenv;
                          r2[3] = r3;
                          r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2140; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
                          L2140:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[5] = r2;
                          r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2141; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
                          L2141:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 5);
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                          r1[2] = r2;
                          r2 = ((object****) lenv) [1][1][1][2];
                          r1[3] = r2;
                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                          r1[4] = r2;
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r2[2] = r3;
                          // def lambda_17636_i1845_i4757_i4853
                          goto L2142;
                          FUN_lambda_17636_i1845_i4757_i4853:
                            check_heap (0);
                            r0 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                            r1 = ((object*) lenv) [2];
                            t = alloc_no_clear (UOTAG(6),2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            PXLL_RETURN(0);
                          L2142:
                          r3 = allocate (TC_CLOSURE, 2);
                          r3[1] = &&FUN_lambda_17636_i1845_i4757_i4853; r3[2] = lenv;
                          r2[3] = r3;
                          r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2143; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
                          L2143:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[5] = r2;
                          r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2144; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
                          L2144:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = ((object*******) lenv) [1][1][1][1][1][1][2];
                          r1 = ((object*) lenv) [2];
                          r2 = ((object*) lenv) [3];
                          r3 = ((object**) lenv) [1][2];
                          t = alloc_no_clear (UOTAG(4),4);
                          t[1] = r3;
                          t[2] = r1;
                          t[3] = r2;
                          t[4] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        L2138:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN_lambda_17642_i1845_i4757_i4853; r2[2] = lenv;
                        r1[3] = r2;
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2145; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
                        L2145:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[5] = r1;
                        r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
                        fatbar_57_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_56;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_56;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_56;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_56;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_56_over;
        fatbar_56:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_480;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
        fatbar_56_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[1];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2146; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L2146:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*****) lenv) [1][1][1][1][51];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2147; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L2147:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = top[159];
        r0[4] = r1;
        r1 = top[6];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2148; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
        L2148:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][51];
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        ((object*****) lenv) [1][1][1][1][51] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 5);
        r2 = (object *) 262;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][5];
        r1[3] = r2;
        r2 = ((object**) lenv) [1][3];
        switch (get_case (r2)) {
          case (TC_NIL): {
            r2 = ((object****) lenv) [1][1][1][4];
          } break;
          default: {
            goto fatbar_58;
          }
        }
        goto fatbar_58_over;
        fatbar_58:
        r2 = ((object****) lenv) [1][1][1][4];
        r3 = ((object**) lenv) [1][3];
        t = alloc_no_clear (UOTAG(1),2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        fatbar_58_over: ;
        r1[4] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = (object *) constructed_482[0];
        r2[2] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][19];
        r2[3] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][2];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2149; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
        L2149:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[5] = r2;
        r2 = ((object*****) lenv) [1][1][1][1][3];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2150; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
        L2150:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][6];
        r3 = ((object**) lenv) [1][2];
        t = alloc_no_clear (UOTAG(7),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        r0[3] = r1;
        r0 = ((object******) lenv) [1][1][1][1][1][51];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object*) &constructed_68;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_68;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_481;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_481;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][51];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][51];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            ((object*******) lenv) [1][1][1][1][1][1][51] = r0;
            r0 = ((object*) lenv) [2];
            lenv = lenv[1];
          } break;
        }
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][4];
        r1[4] = r2;
        r2 = ((object****) lenv) [1][1][1][11];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2151; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2680_i4757_i4853;
        L2151:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case_noint (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = (object *) -1;
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(19),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object**) lenv) [1][3];
            r2 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(8),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object**) lenv) [1][3];
            r2 = (object *) -1;
            t = alloc_no_clear (UOTAG(8),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][3];
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = top[21];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2152; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
        L2152:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][4];
        r1[4] = r2;
        r2 = ((object****) lenv) [1][1][1][11];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2153; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2680_i4757_i4853;
        L2153:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object*) lenv) [5];
        switch (get_case_noint (r1)) {
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            // def lambda_17982_i1862_i4757_i4853
            goto L2154;
            FUN_lambda_17982_i1862_i4757_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][4];
              r1 = ((object**) lenv) [1][3];
              r2 = ((object*) lenv) [2];
              r3 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(9),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2154:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_17982_i1862_i4757_i4853; r1[2] = lenv;
            lenv = lenv[1];
          } break;
          case (UOTAG(6)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,1);
            r1[2] = r2;
            // def lambda_17996_i1862_i4757_i4853
            goto L2155;
            FUN_lambda_17996_i1862_i4757_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][4];
              r1 = ((object**) lenv) [1][2];
              r2 = ((object*) lenv) [2];
              r3 = (object *) -1;
              t = alloc_no_clear (UOTAG(9),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2155:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_17996_i1862_i4757_i4853; r1[2] = lenv;
            lenv = lenv[1];
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][5];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            // def lambda_18008_i1862_i4757_i4853
            goto L2156;
            FUN_lambda_18008_i1862_i4757_i4853:
              check_heap (0);
              r0 = ((object**) lenv) [1][2];
              r1 = ((object***) lenv) [1][1][4];
              r2 = ((object*) lenv) [2];
              t = alloc_no_clear (UOTAG(19),3);
              t[1] = r2;
              t[2] = r0;
              t[3] = r1;
              r0 = t;
              PXLL_RETURN(0);
            L2156:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_18008_i1862_i4757_i4853; r1[2] = lenv;
            lenv = lenv[1];
          } break;
        }
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = ((object*) lenv) [3];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object*) lenv) [4];
        r2[2] = r3;
        r3 = top[139];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2157; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_525;
        L2157:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = ((object*) lenv) [6];
        r1[3] = r2;
        r2 = ((object****) lenv) [1][1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2158; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
        L2158:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object****) lenv) [1][1][1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[3] = r1;
        r1 = ((object*) lenv) [5];
        r0[4] = r1;
        // def lambda_18310_i1866_i4757_i4853
        goto L2159;
        FUN_lambda_18310_i1866_i4757_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[2] = r1;
          r0 = ((object**) lenv) [1][2];
          r1 = ((object*) lenv) [2];
          r2 = ((object***) lenv) [1][1][4];
          r3 = ((object***) lenv) [1][1][5];
          r4 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (UOTAG(3),5);
          t[1] = r4;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          t[5] = r3;
          r0 = t;
          PXLL_RETURN(0);
        L2159:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_18310_i1866_i4757_i4853; r1[2] = lenv;
        r0[5] = r1;
        r1 = ((object****) lenv) [1][1][1][12];
        r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2685_i4757_i4853;
      } break;
      case (UITAG(8)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object***) lenv) [1][1][5];
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = ((object****) lenv) [1][1][1][2];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
                  r1 = ((pxll_vector*)r1)->val[0];
                  r0[2] = r1;
                  r0 = top[196];
                  r1 = ((object*) lenv) [2];
                  r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
                  lenv = lenv[1];
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 5);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][51];
                    r1[2] = r2;
                    r2 = top[21];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2160; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
                    L2160:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                    r1[2] = r2;
                    r2 = ((object*) lenv) [2];
                    r1[3] = r2;
                    r2 = top[5];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2161; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
                    L2161:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = ((object*) lenv) [3];
                    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,74)];
                    r0[4] = r1;
                    r1 = top[157];
                    r2 = ((object*) lenv) [4];
                    r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                    r0[5] = r1;
                    r0 = (object *) 6;
                    r1 = ((object*) lenv) [5];
                    r0 = PXLL_TEST(r1==r0);
                    lenv = lenv[1];
                  } else {
                    r0 = (object *) 6;
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_63;
                }
              }
              goto fatbar_63_over;
              fatbar_63:
              r0 = (object *) 6;
              fatbar_63_over: ;
              lenv = lenv[1];
            } else {
              r0 = (object *) 6;
            }
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][2];
              r2 = ((pxll_vector*)r2)->val[4];
              r1[2] = r2;
              r2 = top[121];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2162; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_varref__3ename_491;
              L2162:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 4);
              r2 = ((object*) lenv) [2];
              r1[2] = r2;
              r2 = (object *) 1;
              r1[3] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][4];
              r1[4] = r2;
              r2 = ((object******) lenv) [1][1][1][1][1][11];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2163; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2680_i4757_i4853;
              L2163:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              switch (get_case_noint (r0)) {
                case (UOTAG(7)): {
                  r0 = (object*) &constructed_68;
                  r0 = box((pxll_int)((pxll_string*)(r0))->len);
                  r1 = (object*) &constructed_68;
                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                  r0 = (object*) &constructed_483;
                  dump_object (r0, 0); fprintf (stdout, "\n");
                  r0 = (object*) &constructed_483;
                  PXLL_UNDEFINED; result=r0; goto Lreturn;
                  PXLL_RETURN(0);
                } break;
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = ((object***) lenv) [1][1][3];
                  r0[2] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][4];
                  r0[3] = r1;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[4] = r1;
                  // def lambda_18564_i4757_i4853_i8
                  goto L2164;
                  FUN_lambda_18564_i4757_i4853_i8:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    r2 = ((object**) lenv) [1][2];
                    t = alloc_no_clear (UOTAG(15),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  L2164:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN_lambda_18564_i4757_i4853_i8; r1[2] = lenv;
                  r0[5] = r1;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][12];
                  r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2685_i4757_i4853;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][3];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = ((object***) lenv) [1][1][3];
                  r0[2] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][4];
                  r0[3] = r1;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[4] = r1;
                  // def lambda_18564_i4757_i4853_i9
                  goto L2165;
                  FUN_lambda_18564_i4757_i4853_i9:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    r2 = ((object**) lenv) [1][2];
                    t = alloc_no_clear (UOTAG(15),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  L2165:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN_lambda_18564_i4757_i4853_i9; r1[2] = lenv;
                  r0[5] = r1;
                  r1 = ((object*******) lenv) [1][1][1][1][1][1][12];
                  r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2685_i4757_i4853;
                } break;
              }
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object*****) lenv) [1][1][1][1][2];
              if PXLL_IS_TRUE(r1) {
                r1 = ((object******) lenv) [1][1][1][1][1][21];
              } else {
                r1 = ((object******) lenv) [1][1][1][1][1][20];
              }
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[4];
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                  r2[2] = r3;
                  r3 = ((object**) lenv) [1][2];
                  r2[3] = r3;
                  r3 = top[5];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2166; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_vars_get_var_247;
                  L2166:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,74)];
                  r1[3] = r2;
                  r1 = top[158];
                  r2 = ((object*) lenv) [3];
                  r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                  lenv = lenv[1];
                  if PXLL_IS_TRUE(r1) {
                    r1 = ((object*) lenv) [2];
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r1;
                    r1 = t;
                  } else {
                    r1 = (object*)UITAG(1);
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_62;
                }
              }
              goto fatbar_62_over;
              fatbar_62:
              r1 = (object*)UITAG(1);
              fatbar_62_over: ;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def make-call_2943_i1868_i4757_i4853
              goto L2167;
              FUN_make_call_2943_i1868_i4757_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = (object *) 6;
                r0[2] = r1;
                r1 = ((object****) lenv) [1][1][1][2];
                r0[3] = r1;
                r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = ((object******) lenv) [1][1][1][1][1][2];
                r3[2] = r4;
                r4 = top[139];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2168; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_525;
                L2168:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = ((object*) lenv) [2];
                r3 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r1[2] = r2;
                // def lambda_18674_i1868_i4757_i4853
                goto L2169;
                FUN_lambda_18674_i1868_i4757_i4853:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = ((object****) lenv) [1][1][1][4];
                  r0[2] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[3] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r0[4] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][2];
                  r0[5] = r1;
                  r1 = ((object****) lenv) [1][1][1][2];
                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2169:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_lambda_18674_i1868_i4757_i4853; r2[2] = lenv;
                r1[3] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2170; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
                L2170:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
              L2167:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_make_call_2943_i1868_i4757_i4853; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object****) lenv) [1][1][1][3];
              r1[2] = r2;
              r2 = top[24];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2171; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
              L2171:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = (object *) 1;
              r1 = ((object*) lenv) [2];
              r0 = PXLL_TEST(unbox(r1)>unbox(r0));
              lenv = lenv[1];
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object*****) lenv) [1][1][1][1][2];
                r2[2] = r3;
                r3 = top[139];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2172; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_525;
                L2172:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2173; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
                L2173:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 4);
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][51];
                r1[2] = r2;
                r2 = top[21];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2174; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
                L2174:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = top[159];
                r0[4] = r1;
                r1 = top[6];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2175; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
                L2175:
                ; lenv = k[2]; k = k[1];
                r0 = ((object****) lenv) [1][1][1][3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                    switch (get_case (r1)) {
                      case (UITAG(0)): {
                        r1 = (object *) 262;
                      } break;
                      default: {
                        goto fatbar_60;
                      }
                    }
                    goto fatbar_60_over;
                    fatbar_60:
                    r1 = (object *) 6;
                    fatbar_60_over: ;
                    r0[2] = r1;
                    r0 = ((object*) lenv) [2];
                    r1 = ((object**) lenv) [1][2];
                    r2 = (object *) 1;
                    t = alloc_no_clear (UOTAG(10),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_59;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_59_over;
                fatbar_59:
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*****) lenv) [1][1][1][1][3];
                r1[2] = r2;
                r2 = top[24];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2176; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                L2176:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                switch (get_case (r1)) {
                  case (UITAG(0)): {
                    r1 = (object *) 262;
                  } break;
                  default: {
                    goto fatbar_61;
                  }
                }
                goto fatbar_61_over;
                fatbar_61:
                r1 = (object *) 6;
                fatbar_61_over: ;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[139];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2177; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_525;
                L2177:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                // def lambda_18757_i1880_i4757_i4853
                goto L2178;
                FUN_lambda_18757_i1880_i4757_i4853:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 8);
                  r1 = (object *) 1;
                  r0[2] = r1;
                  r1 = (object *) 3;
                  r0[3] = r1;
                  r1 = ((object******) lenv) [1][1][1][1][1][3];
                  r0[4] = r1;
                  r1 = ((object*) lenv) [2];
                  r0[5] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object****) lenv) [1][1][1][2];
                  r2[2] = r3;
                  r3 = top[139];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2179; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_525;
                  L2179:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  r2 = ((object**) lenv) [1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  lenv = lenv[1];
                  r0[6] = r1;
                  r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                  r0[7] = r1;
                  r1 = ((object***) lenv) [1][1][2];
                  r0[8] = r1;
                  r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][16];
                  r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2693_i4757_i4853;
                L2178:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_lambda_18757_i1880_i4757_i4853; r2[2] = lenv;
                r1[3] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2180; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
                L2180:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r0 = ((object*) lenv) [3];
                r1 = ((object*) lenv) [4];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(10),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                PXLL_RETURN(0);
                fatbar_59_over: ;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) -1;
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[1] = r1[2]; lenv = r0; goto FUN_make_call_2943_i1868_i4757_i4853;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_68;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_68;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_484;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_484;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = (object *) constructed_486[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [5];
          r2[2] = r3;
          r3 = top[22];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2181; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cdr_312;
          L2181:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2182; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
          L2182:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r0[5] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
        } else {
          goto fatbar_64;
        }
        PXLL_RETURN(0);
        goto fatbar_64_over;
        fatbar_64:
        r0 = (object *) constructed_488[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [5];
          r1[2] = r2;
          r2 = top[21];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2183; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
          L2183:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r0[5] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
        } else {
          goto fatbar_65;
        }
        PXLL_RETURN(0);
        goto fatbar_65_over;
        fatbar_65:
        r0 = (object *) constructed_230[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 5;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2184; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2184:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2185; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2185:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r0 = ((object*) lenv) [5];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][5];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][5];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = (object *) constructed_490[0];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = ((object*) lenv) [3];
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = (object*)TC_NIL;
                        r0[2] = r1;
                        r1 = ((object*) lenv) [2];
                        r2 = ((object****) lenv) [1][1][1][3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object *) constructed_97[0];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object**) lenv) [1][2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[3] = r2;
                        r2 = top[106];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2186; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                        L2186:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r0 = allocate (TC_TUPLE, 7);
                        r1 = ((object*****) lenv) [1][1][1][1][5];
                        r0[2] = r1;
                        r1 = ((object*****) lenv) [1][1][1][1][2];
                        r0[3] = r1;
                        r1 = ((object*****) lenv) [1][1][1][1][3];
                        r0[4] = r1;
                        r1 = ((object*) lenv) [4];
                        r0[5] = r1;
                        r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                        r0[6] = r1;
                        r1 = ((object*****) lenv) [1][1][1][1][4];
                        r0[7] = r1;
                        r1 = ((object********) lenv) [1][1][1][1][1][1][1][14];
                        r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2687_i4757_i4853;
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_67;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_67;
                  }
                }
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_67;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_67;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_67_over;
          fatbar_67:
          r0 = (object*) &constructed_68;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_67;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_67;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
          fatbar_67_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_66;
        }
        PXLL_RETURN(0);
        goto fatbar_66_over;
        fatbar_66:
        r0 = (object *) constructed_492[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2187; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2187:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[114];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2188; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_record_sig_471;
          L2188:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[3];
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[34];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2189; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
          L2189:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object**) lenv) [1][5];
          r0[2] = r1;
          r1 = (object *) constructed_266[0];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object**) lenv) [1][6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[6] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[7] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][14];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2687_i4757_i4853;
        } else {
          goto fatbar_68;
        }
        PXLL_RETURN(0);
        goto fatbar_68_over;
        fatbar_68:
        r0 = (object *) constructed_494[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2190; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2190:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[114];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2191; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_record_sig_471;
          L2191:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = top[3];
          r1[2] = r2;
          r2 = ((object*) lenv) [4];
          r1[3] = r2;
          r2 = top[34];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2192; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
          L2192:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object*) lenv) [5];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object**) lenv) [1][5];
          r0[2] = r1;
          r1 = (object *) constructed_277[0];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r3 = ((object**) lenv) [1][6];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r3 = ((object***) lenv) [1][1][3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = ((object*) lenv) [4];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r0[4] = r1;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[6] = r1;
          r1 = ((object**) lenv) [1][4];
          r0[7] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][14];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2687_i4757_i4853;
        } else {
          goto fatbar_69;
        }
        PXLL_RETURN(0);
        goto fatbar_69_over;
        fatbar_69:
        r0 = (object *) constructed_500[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_3059_i1912_i4757_i4853
          goto L2193;
          FUN_loop_3059_i1912_i4757_i4853:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = ((pxll_vector*)r1)->val[4];
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            switch (get_case (r0)) {
              case (UOTAG(12)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_497[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 9);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  // def lambda_19420_i1912_i4757_i4853
                  goto L2194;
                  FUN_lambda_19420_i1912_i4757_i4853:
                    check_heap (0);
                    r0 = ((object*) lenv) [2];
                    switch (get_case_noint (r0)) {
                      default: {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = ((object**) lenv) [1][3];
                        switch (get_case_noint (r0)) {
                          default: {
                            r0 = allocate (TC_TUPLE, 5);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object***) lenv) [1][1][3];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][2];
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = ((object***) lenv) [1][1][2];
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r1 = ((object*) lenv) [2];
                            lenv = lenv[1];
                            r0[3] = r1;
                            r1 = ((object*) lenv) [2];
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = ((object**) lenv) [1][2];
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r1 = ((object*) lenv) [2];
                            lenv = lenv[1];
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = ((object*) lenv) [3];
                            r1[2] = r2;
                            r2 = ((object*) lenv) [4];
                            r1[3] = r2;
                            r2 = top[52];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2195; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
                            L2195:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[5] = r1;
                            r0 = (object *) 1;
                            r1 = ((object*) lenv) [5];
                            r0 = PXLL_TEST(unbox(r1)<unbox(r0));
                            PXLL_RETURN(0);
                          } break;
                        }
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                  L2194:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_lambda_19420_i1912_i4757_i4853; r2[2] = lenv;
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r1[3] = r2;
                  r2 = top[46];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2196; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_sort_342;
                  L2196:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[19];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2197; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L2197:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = top[20];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  r1[3] = r2;
                  r2 = top[34];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2198; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
                  L2198:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[4] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def loop_3096_i1915_i4757_i4853
                  goto L2199;
                  FUN_loop_3096_i1915_i4757_i4853:
                    check_heap (0);
                    r0 = ((object*) lenv) [2];
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = ((object**) lenv) [1][2];
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = ((object*) lenv) [2];
                        switch (get_case_noint (r0)) {
                          default: {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = ((object**) lenv) [1][2];
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object**) lenv) [1][2];
                            r1[2] = r2;
                            r2 = top[24];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2200; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                            L2200:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = ((object******) lenv) [1][1][1][1][1][3];
                            r1[2] = r2;
                            r2 = top[24];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2201; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                            L2201:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[3] = r1;
                            r0 = ((object*) lenv) [3];
                            r1 = ((object*) lenv) [2];
                            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                            lenv = lenv[1];
                            if PXLL_IS_TRUE(r0) {
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = top[14];
                              r0[2] = r1;
                              r1 = ((object*) lenv) [2];
                              r0[3] = r1;
                              r1 = ((object*****) lenv) [1][1][1][1][3];
                              r0[4] = r1;
                              r1 = top[43];
                              t = allocate (TC_SAVE, 3);
                              t[1] = k; t[2] = lenv; t[3] = &&L2202; ; k = t;
                              r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_337;
                              L2202:
                              ; lenv = k[2]; k = k[1];
                              r0 = result;
                            } else {
                              r0 = (object *) 6;
                            }
                            if PXLL_IS_TRUE(r0) {
                              r0 = ((object*) lenv) [3];
                              PXLL_RETURN(0);
                            } else {
                              r0 = ((object**) lenv) [1][3];
                              lenv = ((object **)lenv)[1][1];
                              lenv[2] = r0;
                              goto FUN_loop_3096_i1915_i4757_i4853;
                            }
                            PXLL_RETURN(0);
                          } break;
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                        r2 = ((pxll_vector*)r2)->val[11];
                        r1[2] = r2;
                        r2 = top[24];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2203; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                        L2203:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][18];
                        r0[2] = r1;
                        r1 = ((object****) lenv) [1][1][1][3];
                        r0[3] = r1;
                        r1 = top[37];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2204; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
                        L2204:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (UOTAG(1), 2);
                        r2 = ((object*****) lenv) [1][1][1][1][3];
                        r1[1] = r2;
                        r2 = ((object**) lenv) [1][2];
                        r1[2] = r2;
                        r0[2] = r1;
                        r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                        r1 = ((pxll_vector*)r1)->val[11];
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        r1 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r1 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][2];
                        ((pxll_vector*)r1)->val[11] = r0;
                        r0 = ((object*) lenv) [2];
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                  L2199:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_loop_3096_i1915_i4757_i4853; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                  r2 = ((pxll_vector*)r2)->val[11];
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2205; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_loop_3096_i1915_i4757_i4853;
                  L2205:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r0[5] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object******) lenv) [1][1][1][1][1][4];
                  r1[2] = r2;
                  r2 = top[139];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2206; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
                  L2206:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[6] = r1;
                  r1 = ((object*) lenv) [5];
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r0[7] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = ((object*) lenv) [4];
                  r1[2] = r2;
                  r2 = top[24];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2207; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                  L2207:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[8] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = ((object*) lenv) [6];
                  r1[2] = r2;
                  // def lambda_19459_i1912_i4757_i4853
                  goto L2208;
                  FUN_lambda_19459_i1912_i4757_i4853:
                    check_heap (0);
                    r0 = allocate (TC_TUPLE, 8);
                    r1 = (object *) 1;
                    r0[2] = r1;
                    r1 = (object *) 1;
                    r0[3] = r1;
                    r1 = ((object**) lenv) [1][4];
                    r0[4] = r1;
                    r1 = ((object*) lenv) [2];
                    r0[5] = r1;
                    r1 = ((object**) lenv) [1][6];
                    r2 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                    r0[7] = r1;
                    r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                    r0[8] = r1;
                    r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][16];
                    r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2693_i4757_i4853;
                  L2208:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_lambda_19459_i1912_i4757_i4853; r2[2] = lenv;
                  r1[3] = r2;
                  r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2209; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
                  L2209:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[9] = r1;
                  r0 = ((object*) lenv) [8];
                  r1 = ((object*) lenv) [9];
                  r2 = ((object*) lenv) [7];
                  t = alloc_no_clear (UOTAG(11),3);
                  t[1] = r2;
                  t[2] = r0;
                  t[3] = r1;
                  r0 = t;
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_72;
                }
                PXLL_RETURN(0);
                goto fatbar_72_over;
                fatbar_72:
                r0 = (object *) constructed_500[0];
                r1 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = ((object*) lenv) [3];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][3];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = ((object****) lenv) [1][1][1][2];
                      r1 = ((pxll_vector*)r1)->val[3];
                      r0[3] = r1;
                      r0 = ((object*) lenv) [3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = ((object**) lenv) [1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = ((object*) lenv) [3];
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = ((object**) lenv) [1][3];
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = ((object*) lenv) [3];
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (UOTAG(1), 2);
                                  r2 = ((object****) lenv) [1][1][1][2];
                                  r1[1] = r2;
                                  r2 = ((object**) lenv) [1][2];
                                  r1[2] = r2;
                                  r0[2] = r1;
                                  r0 = ((object*******) lenv) [1][1][1][1][1][1][3];
                                  r1 = ((object*) lenv) [2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r1;
                                  t[2] = r0;
                                  r0 = t;
                                  lenv = lenv[1];
                                  r1 = ((object**) lenv) [1][2];
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  lenv[2] = r1;
                                  lenv[3] = r0;
                                  goto FUN_loop_3059_i1912_i4757_i4853;
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_73;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_73;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_73;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_73_over;
                      fatbar_73:
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_498;
                      r0[2] = r1;
                      r1 = ((object****) lenv) [1][1][1][2];
                      r0[3] = r1;
                      r1 = top[15];
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
                      fatbar_73_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_71;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_71;
                }
                PXLL_RETURN(0);
                fatbar_72_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_71;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_71_over;
            fatbar_71:
            r0 = (object*) &constructed_68;
            r0 = box((pxll_int)((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_68;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_501;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_501;
            PXLL_UNDEFINED; result=r0; goto Lreturn;
            PXLL_RETURN(0);
            fatbar_71_over: ;
            PXLL_RETURN(0);
          L2193:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_3059_i1912_i4757_i4853; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = ((object****) lenv) [1][1][1][3];
          r0[2] = r1;
          r1 = (object *) constructed_495[0];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_3059_i1912_i4757_i4853;
        } else {
          goto fatbar_70;
        }
        PXLL_RETURN(0);
        goto fatbar_70_over;
        fatbar_70:
        r0 = (object *) constructed_505[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object*) lenv) [3];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = ((object**) lenv) [1][2];
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = ((object*) lenv) [2];
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = ((object**) lenv) [1][2];
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = ((object**) lenv) [1][3];
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = ((object***) lenv) [1][1][3];
                          r1 = UOBJ_GET(r1,1);
                          r0[2] = r1;
                          r0 = ((object*) lenv) [2];
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = allocate (TC_TUPLE, 4);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 4);
                              r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                              r2 = ((pxll_vector*)r2)->val[16];
                              r1[2] = r2;
                              r2 = ((object***) lenv) [1][1][2];
                              r1[3] = r2;
                              r2 = (object*) &constructed_502;
                              r1[4] = r2;
                              r2 = top[68];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2210; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_398;
                              L2210:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object******) lenv) [1][1][1][1][1][4];
                              r1[2] = r2;
                              r2 = top[139];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2211; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
                              L2211:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = ((object******) lenv) [1][1][1][1][1][5];
                              r1[2] = r2;
                              r2 = top[24];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2212; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                              L2212:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[4] = r1;
                              r0 = (object *) 1;
                              r1 = ((object*) lenv) [4];
                              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][51];
                                r1[2] = r2;
                                r2 = top[21];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2213; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
                                L2213:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r1 = top[159];
                                r0[4] = r1;
                                r1 = top[6];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L2214; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
                                L2214:
                                ; lenv = k[2]; k = k[1];
                                r0 = result;
                              } else {
                                r0 = (object *) 14;
                              }
                              r0 = (object *) 1;
                              r1 = ((object*) lenv) [4];
                              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r1;
                                r1 = t;
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 3);
                                r2 = ((object**) lenv) [1][3];
                                r1[2] = r2;
                                // def lambda_19347_i1927_i4757_i4853
                                goto L2215;
                                FUN_lambda_19347_i1927_i4757_i4853:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 8);
                                  r1 = (object *) 1;
                                  r0[2] = r1;
                                  r1 = (object *) 1;
                                  r0[3] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                  r0[4] = r1;
                                  r1 = ((object*) lenv) [2];
                                  r0[5] = r1;
                                  r1 = ((object***) lenv) [1][1][3];
                                  r2 = ((object*) lenv) [2];
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  r0[6] = r1;
                                  r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                                  r0[7] = r1;
                                  r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                                  r0[8] = r1;
                                  r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][16];
                                  r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2693_i4757_i4853;
                                L2215:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_lambda_19347_i1927_i4757_i4853; r2[2] = lenv;
                                r1[3] = r2;
                                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2216; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
                                L2216:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r0 = ((object**) lenv) [1][4];
                                r1 = ((object*) lenv) [3];
                                r2 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(11),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                PXLL_RETURN(0);
                              } else {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = ((object**) lenv) [1][2];
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r1;
                                r1 = t;
                                r0[2] = r1;
                                r0 = (object *) 1;
                                r1 = ((object*******) lenv) [1][1][1][1][1][1][4];
                                r2 = ((object*) lenv) [2];
                                t = alloc_no_clear (UOTAG(11),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                PXLL_RETURN(0);
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_75;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_75;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_75;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_75;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_75;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_75_over;
          fatbar_75:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_503;
          r0[2] = r1;
          r1 = ((object*) lenv) [3];
          r0[3] = r1;
          r1 = top[15];
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          fatbar_75_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_74;
        }
        PXLL_RETURN(0);
        goto fatbar_74_over;
        fatbar_74:
        r0 = (object *) constructed_328[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][5];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2217; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L2217:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)>unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 4);
            r1 = ((object*****) lenv) [1][1][1][1][2];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*****) lenv) [1][1][1][1][51];
            r1[2] = r2;
            r2 = top[21];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2218; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
            L2218:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = top[159];
            r0[4] = r1;
            r1 = top[6];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2219; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
            L2219:
            ; lenv = k[2]; k = k[1];
            r0 = result;
          } else {
            r0 = (object *) 14;
          }
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object*) lenv) [5];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object*) lenv) [3];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[5];
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[6] = r1;
          r1 = ((object*) lenv) [4];
          r0[7] = r1;
          r1 = ((object****) lenv) [1][1][1][14];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2687_i4757_i4853;
        } else {
          goto fatbar_76;
        }
        PXLL_RETURN(0);
        goto fatbar_76_over;
        fatbar_76:
        r0 = (object *) constructed_507[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 7);
          r0[1] = lenv; lenv = r0;
          r1 = ((object*****) lenv) [1][1][1][1][22];
          r1 = ((pxll_vector*)r1)->val[1];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2220; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L2220:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(3),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = top[139];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2221; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
          L2221:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = top[140];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2222; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_526;
          L2222:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 5);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][5];
          r2[2] = r3;
          r3 = (object *) 1;
          r2[3] = r3;
          r3 = top[29];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2223; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
          L2223:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object*) lenv) [3];
          r1[4] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*) lenv) [4];
          r2[2] = r3;
          // def lambda_19215_i1940_i4757_i4853
          goto L2224;
          FUN_lambda_19215_i1940_i4757_i4853:
            check_heap (0);
            r0 = ((object**) lenv) [1][5];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(6),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          L2224:
          r3 = allocate (TC_CLOSURE, 2);
          r3[1] = &&FUN_lambda_19215_i1940_i4757_i4853; r3[2] = lenv;
          r2[3] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2225; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
          L2225:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[5] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2226; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
          L2226:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 5);
          r2 = ((object****) lenv) [1][1][1][2];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object**) lenv) [1][5];
          r2[2] = r3;
          r3 = (object *) 3;
          r2[3] = r3;
          r3 = top[29];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2227; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
          L2227:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = ((object****) lenv) [1][1][1][4];
          r1[4] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*) lenv) [4];
          r2[2] = r3;
          // def lambda_19232_i1940_i4757_i4853
          goto L2228;
          FUN_lambda_19232_i1940_i4757_i4853:
            check_heap (0);
            r0 = ((object**) lenv) [1][5];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (UOTAG(6),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          L2228:
          r3 = allocate (TC_CLOSURE, 2);
          r3[1] = &&FUN_lambda_19232_i1940_i4757_i4853; r3[2] = lenv;
          r2[3] = r3;
          r3 = ((object*****) lenv) [1][1][1][1][2];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2229; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
          L2229:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[5] = r2;
          r2 = ((object*****) lenv) [1][1][1][1][3];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2230; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
          L2230:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r0 = ((object**) lenv) [1][4];
          r1 = ((object*) lenv) [6];
          r2 = ((object*) lenv) [7];
          r3 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(20),4);
          t[1] = r3;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          goto fatbar_77;
        }
        PXLL_RETURN(0);
        goto fatbar_77_over;
        fatbar_77:
        r0 = (object *) constructed_510[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_3037_i1946_i4757_i4853
          goto L2231;
          FUN_loop_3037_i1946_i4757_i4853:
            check_heap (0);
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (UITAG(0)): {
                r0 = (object*) &constructed_68;
                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_68;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_508;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_508;
                PXLL_UNDEFINED; result=r0; goto Lreturn;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,1);
                r0[2] = r1;
                r0 = (object *) 3;
                r1 = ((object**) lenv) [1][2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                r1 = ((object*) lenv) [2];
                lenv = ((object *)lenv)[1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_3037_i1946_i4757_i4853;
              } break;
              case (UOTAG(2)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,2);
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                lenv = ((object *)lenv)[1];
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN_loop_3037_i1946_i4757_i4853;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = ((object**) lenv) [1][2];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(21),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L2231:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_3037_i1946_i4757_i4853; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][4];
          r0[3] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_3037_i1946_i4757_i4853;
        } else {
          goto fatbar_78;
        }
        PXLL_RETURN(0);
        goto fatbar_78_over;
        fatbar_78:
        r0 = allocate (TC_TUPLE, 7);
        r1 = ((object*) lenv) [5];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object*) lenv) [3];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[5];
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[6] = r1;
        r1 = ((object*) lenv) [4];
        r0[7] = r1;
        r1 = ((object****) lenv) [1][1][1][14];
        r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2687_i4757_i4853;
        fatbar_78_over: ;
        PXLL_RETURN(0);
        fatbar_77_over: ;
        PXLL_RETURN(0);
        fatbar_76_over: ;
        PXLL_RETURN(0);
        fatbar_74_over: ;
        PXLL_RETURN(0);
        fatbar_70_over: ;
        PXLL_RETURN(0);
        fatbar_69_over: ;
        PXLL_RETURN(0);
        fatbar_68_over: ;
        PXLL_RETURN(0);
        fatbar_66_over: ;
        PXLL_RETURN(0);
        fatbar_65_over: ;
        PXLL_RETURN(0);
        fatbar_64_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = (object *) constructed_49[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 7);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = top[139];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2232; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
          L2232:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2233; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2233:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [2];
          r1[2] = r2;
          r2 = (object *) 3;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2234; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2234:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r3 = ((object*) lenv) [2];
          r2[2] = r3;
          r3 = top[22];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2235; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cdr_312;
          L2235:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = top[22];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2236; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
          L2236:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def finish_3014_i1951_i4757_i4853
          goto L2237;
          FUN_finish_3014_i1951_i4757_i4853:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][4];
            r1[2] = r2;
            // def lambda_19109_i1951_i4757_i4853
            goto L2238;
            FUN_lambda_19109_i1951_i4757_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object******) lenv) [1][1][1][1][1][3];
              r1[2] = r2;
              r2 = top[140];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2239; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_526;
              L2239:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(6),2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2238:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_19109_i1951_i4757_i4853; r2[2] = lenv;
            r1[3] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2240; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
            L2240:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_19119_i1951_i4757_i4853
            goto L2241;
            FUN_lambda_19119_i1951_i4757_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 5);
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][4];
              r0[4] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[5] = r1;
              r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
            L2241:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_19119_i1951_i4757_i4853; r2[2] = lenv;
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][7];
            r1[3] = r2;
            r2 = top[34];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2242; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
            L2242:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = ((object****) lenv) [1][1][1][6];
            r1 = ((pxll_vector*)r1)->val[4];
            r0[4] = r1;
            r1 = ((object*) lenv) [4];
            switch (get_case (r1)) {
              case (UOTAG(12)): {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][4];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = (object *) constructed_512[0];
                r2 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                  r1 = (object *) 6;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_80;
                }
                lenv = lenv[1];
              } break;
              default: {
                goto fatbar_80;
              }
            }
            goto fatbar_80_over;
            fatbar_80:
            r1 = (object *) 262;
            fatbar_80_over: ;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 5);
              r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              r2[2] = r3;
              r3 = ((object*****) lenv) [1][1][1][1][6];
              r2[3] = r3;
              r3 = ((object********) lenv) [1][1][1][1][1][1][1][4];
              r2[4] = r3;
              r3 = ((object**) lenv) [1][2];
              r2[5] = r3;
              r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2243; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_compile_2668_i4757_i4853;
              L2243:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
            } else {
              r1 = (object*)UITAG(1);
            }
            r0[6] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object****) lenv) [1][1][1][3];
            r2 = ((object*****) lenv) [1][1][1][1][3];
            r3 = ((object*****) lenv) [1][1][1][1][4];
            r4 = ((object*) lenv) [6];
            r5 = ((object**) lenv) [1][2];
            t = alloc_no_clear (UOTAG(23),6);
            t[1] = r5;
            t[2] = r2;
            t[3] = r3;
            t[4] = r0;
            t[5] = r4;
            t[6] = r1;
            r0 = t;
            PXLL_RETURN(0);
          L2237:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_finish_3014_i1951_i4757_i4853; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 5);
          r1 = (object *) 6;
          r0[2] = r1;
          r1 = ((object**) lenv) [1][5];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = ((object*) lenv) [2];
          r1[3] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2244; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
          L2244:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = ((object******) lenv) [1][1][1][1][1][3];
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
        } else {
          goto fatbar_79;
        }
        PXLL_RETURN(0);
        goto fatbar_79_over;
        fatbar_79:
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = ((object****) lenv) [1][1][1][5];
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [3];
        r1[2] = r2;
        r2 = top[139];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2245; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
        L2245:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object******) lenv) [1][1][1][1][1][2];
        r2 = ((pxll_vector*)r2)->val[2];
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[67];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2246; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
        L2246:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r0 = ((object*) lenv) [5];
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_513;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r0[3] = r1;
            r1 = top[15];
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][5];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = (object *) 1;
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2247; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L2247:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = (object *) 3;
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2248; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L2248:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = top[22];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2249; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_cdr_312;
            L2249:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[22];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2250; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
            L2250:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def finish_2995_i1957_i4757_i4853
            goto L2251;
            FUN_finish_2995_i1957_i4757_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object*****) lenv) [1][1][1][1][4];
              r1[2] = r2;
              // def lambda_18992_i1957_i4757_i4853
              goto L2252;
              FUN_lambda_18992_i1957_i4757_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*******) lenv) [1][1][1][1][1][1][3];
                r1[2] = r2;
                r2 = top[140];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2253; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_526;
                L2253:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (UOTAG(6),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              L2252:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18992_i1957_i4757_i4853; r2[2] = lenv;
              r1[3] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2254; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
              L2254:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              // def lambda_19002_i1957_i4757_i4853
              goto L2255;
              FUN_lambda_19002_i1957_i4757_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                r0[2] = r1;
                r1 = ((object*) lenv) [2];
                r0[3] = r1;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                r0[4] = r1;
                r1 = ((object**) lenv) [1][2];
                r0[5] = r1;
                r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][3];
                r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
              L2255:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_19002_i1957_i4757_i4853; r2[2] = lenv;
              r1[2] = r2;
              r2 = ((object****) lenv) [1][1][1][5];
              r1[3] = r2;
              r2 = top[34];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2256; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
              L2256:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 4);
              r1[1] = lenv; lenv = r1;
              r2 = ((object*****) lenv) [1][1][1][1][2];
              r2 = ((pxll_vector*)r2)->val[3];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2257; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L2257:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object**) lenv) [1][3];
              r2[2] = r3;
              r3 = top[24];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2258; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
              L2258:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = ((object*) lenv) [3];
              r3 = ((object*) lenv) [2];
              r2 = PXLL_TEST(unbox(r3)==unbox(r2));
              r1[4] = r2;
              r1 = (object *) 6;
              r2 = ((object*) lenv) [4];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object*****) lenv) [1][1][1][1][4];
                r2 = ((pxll_vector*)r2)->val[4];
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                switch (get_case (r1)) {
                  case (UOTAG(12)): {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = ((object**) lenv) [1][2];
                    r2 = UOBJ_GET(r2,0);
                    r1[2] = r2;
                    r1 = (object *) constructed_512[0];
                    r2 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object*) &constructed_514;
                      r1[2] = r2;
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                      r1[3] = r2;
                      r2 = top[15];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2259; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                      L2259:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                    } else {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_81;
                    }
                    lenv = lenv[1];
                  } break;
                  default: {
                    goto fatbar_81;
                  }
                }
                goto fatbar_81_over;
                fatbar_81:
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 5);
                r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                r2[2] = r3;
                r3 = ((object******) lenv) [1][1][1][1][1][4];
                r2[3] = r3;
                r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][4];
                r2[4] = r3;
                r3 = ((object***) lenv) [1][1][2];
                r2[5] = r3;
                r3 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][3];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2260; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_compile_2668_i4757_i4853;
                L2260:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                fatbar_81_over: ;
                lenv = lenv[1];
              } else {
                r1 = (object*)UITAG(1);
              }
              r0[4] = r1;
              r0 = ((object*) lenv) [3];
              r1 = ((object*****) lenv) [1][1][1][1][3];
              r2 = ((object******) lenv) [1][1][1][1][1][2];
              r3 = ((object******) lenv) [1][1][1][1][1][3];
              r4 = ((object*) lenv) [4];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(22),6);
              t[1] = r5;
              t[2] = r2;
              t[3] = r3;
              t[4] = r0;
              t[5] = r4;
              t[6] = r1;
              r0 = t;
              PXLL_RETURN(0);
            L2251:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_finish_2995_i1957_i4757_i4853; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 5);
            r1 = (object *) 6;
            r0[2] = r1;
            r1 = ((object**) lenv) [1][3];
            r0[3] = r1;
            r1 = ((object******) lenv) [1][1][1][1][1][4];
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][4];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2261; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
            L2261:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
            r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
          } break;
        }
        PXLL_RETURN(0);
        fatbar_79_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 6);
        r1 = ((object***) lenv) [1][1][2];
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = ((object***) lenv) [1][1][4];
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][5];
        r0[6] = r1;
        r1 = ((object****) lenv) [1][1][1][17];
        r0[1] = r1[2]; lenv = r0; goto FUN_c_let_splat_2695_i4757_i4853;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object****) lenv) [1][1][1][3];
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = top[197];
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2262; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L2262:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 11;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(unbox(r1)<unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_18517_i1965_i4757_i4853
            goto L2263;
            FUN_lambda_18517_i1965_i4757_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][2];
              r1[3] = r2;
              r2 = top[5];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2264; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_247;
              L2264:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,74)];
              r0[3] = r1;
              r0 = top[157];
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
              PXLL_RETURN(0);
            L2263:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_18517_i1965_i4757_i4853; r2[2] = lenv;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            r1[3] = r2;
            r2 = top[41];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2265; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_some_question_335;
            L2265:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = ((object*) lenv) [2];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
          } else {
            r0 = (object *) 6;
          }
        } else {
          r0 = (object *) 6;
        }
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object****) lenv) [1][1][1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = ((object****) lenv) [1][1][1][5];
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_2964_i1970_i4757_i4853
          goto L2266;
          FUN_loop_2964_i1970_i4757_i4853:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2267; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L2267:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = (object *) 1;
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 5);
              r1 = ((object******) lenv) [1][1][1][1][1][2];
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*) lenv) [3];
              r1[2] = r2;
              r2 = top[21];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2268; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
              L2268:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*) lenv) [4];
              r0[4] = r1;
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 5);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,2);
                  r1[4] = r2;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = allocate (TC_TUPLE, 3);
                  r4 = ((object*) lenv) [3];
                  r3[2] = r4;
                  r4 = (object *) constructed_36[0];
                  r3[3] = r4;
                  r4 = top[23];
                  t = allocate (TC_SAVE, 6);
                  t[1] = k; t[2] = lenv; t[3] = &&L2269; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                  r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
                  L2269:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                  r3 = result;
                  r2[2] = r3;
                  r3 = ((object**) lenv) [1][5];
                  r2[3] = r3;
                  r3 = top[23];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2270; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
                  L2270:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[5] = r2;
                  r1 = ((object*) lenv) [5];
                  r2 = ((object*) lenv) [4];
                  r3 = ((object*) lenv) [2];
                  t = alloc_no_clear (UOTAG(0),3);
                  t[1] = r3;
                  t[2] = r1;
                  t[3] = r2;
                  r1 = t;
                  lenv = lenv[1];
                } break;
                default: {
                  r1 = (object*) &constructed_68;
                  r1 = box((pxll_int)((pxll_string*)(r1))->len);
                  r2 = (object*) &constructed_68;
                  (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
                  r1 = (object*) &constructed_516;
                  dump_object (r1, 0); fprintf (stdout, "\n");
                  r1 = (object*) &constructed_516;
                  PXLL_UNDEFINED; result=r1; goto Lreturn;
                } break;
              }
              r0[5] = r1;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
            } else {
              r0 = allocate (TC_TUPLE, 5);
              r1 = (object *) 6;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*) lenv) [3];
              r1[2] = r2;
              r2 = top[21];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2271; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
              L2271:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*) lenv) [4];
              r0[4] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][3];
              r3[2] = r4;
              r4 = top[139];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2272; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_525;
              L2272:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = allocate (TC_TUPLE, 3);
              r4 = ((object**) lenv) [1][5];
              r3[2] = r4;
              r4 = (object *) constructed_36[0];
              r3[3] = r4;
              r4 = top[23];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2273; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
              L2273:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = ((object*) lenv) [2];
              r2[3] = r3;
              r3 = top[23];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2274; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
              L2274:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r1[2] = r2;
              // def lambda_18860_i1970_i4757_i4853
              goto L2275;
              FUN_lambda_18860_i1970_i4757_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][2];
                r1[2] = r2;
                r2 = top[22];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2276; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
                L2276:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object**) lenv) [1][3];
                r1[2] = r2;
                r2 = top[22];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2277; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
                L2277:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object***) lenv) [1][1][2];
                r2[2] = r3;
                r3 = top[21];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2278; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_car_311;
                L2278:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = ((object**) lenv) [1][2];
                r2 = ((object***) lenv) [1][1][4];
                r3 = ((object*) lenv) [2];
                t = alloc_no_clear (UOTAG(2),3);
                t[1] = r3;
                t[2] = r1;
                t[3] = r2;
                r1 = t;
                lenv = lenv[1];
                r0[4] = r1;
                r1 = ((object**) lenv) [1][5];
                r2 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[5] = r1;
                r1 = ((object***) lenv) [1][1][2];
                r0[1] = r1[2]; lenv = r0; goto FUN_loop_2964_i1970_i4757_i4853;
              L2275:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18860_i1970_i4757_i4853; r2[2] = lenv;
              r1[3] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2279; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
              L2279:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[5] = r1;
              r1 = ((object*******) lenv) [1][1][1][1][1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
            }
            PXLL_RETURN(0);
          L2266:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_2964_i1970_i4757_i4853; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 5);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r0[3] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][4];
          r0[4] = r1;
          r1 = (object *) constructed_515[0];
          r0[5] = r1;
          r1 = ((object*) lenv) [2];
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_2964_i1970_i4757_i4853;
        } else {
          r0 = allocate (TC_TUPLE, 6);
          r1 = ((object***) lenv) [1][1][2];
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r1 = ((pxll_vector*)r1)->val[3];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][5];
          r0[6] = r1;
          r1 = ((object****) lenv) [1][1][1][17];
          r0[1] = r1[2]; lenv = r0; goto FUN_c_let_splat_2695_i4757_i4853;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_67;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_67;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2118:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_compile_2668_i4757_i4853; r2[2] = lenv;
  r1[3] = r2;
  // def add-literal_2669_i4757_i4853
  goto L2280;
  FUN_add_literal_2669_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[8];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2281; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L2281:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object*****) lenv) [1][1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[8];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object***) lenv) [1][1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    lenv = lenv[1];
    r1 = ((object****) lenv) [1][1][1][2];
    ((pxll_vector*)r1)->val[8] = r0;
    r0 = ((object*) lenv) [2];
    PXLL_RETURN(0);
  L2280:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_literal_2669_i4757_i4853; r2[2] = lenv;
  r1[4] = r2;
  // def get-literal-index_2670_i4757_i4853
  goto L2282;
  FUN_get_literal_index_2670_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[7];
    r1[2] = r2;
    r2 = top[12];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    r1[4] = r2;
    r2 = top[75];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2283; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_411;
    L2283:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2284; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2669_i4757_i4853;
        L2284:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = ((object*****) lenv) [1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[7];
        r0[2] = r1;
        r1 = top[12];
        r0[3] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[4] = r1;
        r1 = ((object*) lenv) [2];
        r0[5] = r1;
        r1 = top[74];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2285; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_409;
        L2285:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = ((object*****) lenv) [1][1][1][1][2];
        ((pxll_vector*)r1)->val[7] = r0;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2282:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_literal_index_2670_i4757_i4853; r2[2] = lenv;
  r1[5] = r2;
  // def get-symbol-index_2671_i4757_i4853
  goto L2286;
  FUN_get_symbol_index_2671_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object****) lenv) [1][1][1][2];
    r2 = ((pxll_vector*)r2)->val[15];
    r1[2] = r2;
    r2 = ((object**) lenv) [1][2];
    r1[3] = r2;
    r2 = top[67];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2287; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
    L2287:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = ((object****) lenv) [1][1][1][2];
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        r4 = ((object*****) lenv) [1][1][1][1][2];
        r4 = UOBJ_GET(r4,0);
        r3[2] = r4;
        r3 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2[2] = r3;
        r2 = ((object*) lenv) [2];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r2;
        r2 = t;
        lenv = lenv[1];
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2288; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2669_i4757_i4853;
        L2288:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object***) lenv) [1][1][2];
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = ((object****) lenv) [1][1][1][4];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2289; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2669_i4757_i4853;
        L2289:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[15];
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        r2 = ((object****) lenv) [1][1][1][2];
        t = alloc_no_clear (UOTAG(1),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        lenv = lenv[1];
        r1 = ((object*****) lenv) [1][1][1][1][2];
        ((pxll_vector*)r1)->val[15] = r0;
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2286:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_symbol_index_2671_i4757_i4853; r2[2] = lenv;
  r1[6] = r2;
  // def scan-literals_2672_i4757_i4853
  goto L2290;
  FUN_scan_literals_2672_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][6];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2291; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_get_symbol_index_2671_i4757_i4853;
            L2291:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][4];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2292; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_add_literal_2669_i4757_i4853;
            L2292:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
          } break;
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2293; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2672_i4757_i4853;
            L2293:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = ((object*) lenv) [2];
            r0[2] = r1;
            r1 = ((object****) lenv) [1][1][1][7];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2294; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2672_i4757_i4853;
            L2294:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
          } break;
          default: {
            goto fatbar_53;
          }
        }
        goto fatbar_53_over;
        fatbar_53:
        r0 = (object *) 1;
        fatbar_53_over: ;
        r0 = ((object*) lenv) [3];
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_scan_literals_2672_i4757_i4853;
      } break;
    }
    PXLL_RETURN(0);
  L2290:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_scan_literals_2672_i4757_i4853; r2[2] = lenv;
  r1[7] = r2;
  // def c-sequence_2674_i4757_i4853
  goto L2295;
  FUN_c_sequence_2674_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_68;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_68;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_475;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_475;
        PXLL_UNDEFINED; result=r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][3];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 5);
            r1 = ((object**) lenv) [1][2];
            r0[2] = r1;
            r1 = ((object*) lenv) [2];
            r0[3] = r1;
            r1 = ((object**) lenv) [1][4];
            r0[4] = r1;
            r1 = ((object**) lenv) [1][5];
            r0[5] = r1;
            r1 = ((object***) lenv) [1][1][3];
            r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
          } break;
          default: {
            goto fatbar_52;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_52_over;
        fatbar_52:
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object***) lenv) [1][1][5];
        r2[2] = r3;
        r3 = top[139];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2296; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_525;
        L2296:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 5);
        r3 = ((object***) lenv) [1][1][2];
        r2[2] = r3;
        r3 = ((object**) lenv) [1][3];
        r2[3] = r3;
        r3 = ((object***) lenv) [1][1][4];
        r2[4] = r3;
        r3 = ((object***) lenv) [1][1][5];
        r2[5] = r3;
        r3 = ((object****) lenv) [1][1][1][8];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2297; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_c_sequence_2674_i4757_i4853;
        L2297:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r1 = ((object*) lenv) [2];
        r2 = ((object*) lenv) [3];
        r3 = (object *) -1;
        t = alloc_no_clear (UOTAG(0),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        lenv = lenv[1];
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
        fatbar_52_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2295:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_sequence_2674_i4757_i4853; r2[2] = lenv;
  r1[8] = r2;
  // def extend-lenv_2677_i4757_i4853
  goto L2298;
  FUN_extend_lenv_2677_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = ((object*) lenv) [3];
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_51;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_51_over;
    fatbar_51:
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(1),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_51_over: ;
    PXLL_RETURN(0);
  L2298:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_extend_lenv_2677_i4757_i4853; r2[2] = lenv;
  r1[9] = r2;
  // def search-rib_2679_i4757_i4853
  goto L2299;
  FUN_search_rib_2679_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*)UITAG(1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = ((object**) lenv) [1][3];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 3;
          r1 = ((object**) lenv) [1][3];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          r1 = ((object*) lenv) [3];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_search_rib_2679_i4757_i4853;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2299:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_search_rib_2679_i4757_i4853; r2[2] = lenv;
  r1[10] = r2;
  // def lexical-address_2680_i4757_i4853
  goto L2300;
  FUN_lexical_address_2680_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [4];
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_474;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = top[15];
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        r1[4] = r2;
        r2 = ((object***) lenv) [1][1][10];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2301; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_search_rib_2679_i4757_i4853;
        L2301:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = ((object*) lenv) [4];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][4];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = (object*)UITAG(0);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            r1 = ((object***) lenv) [1][1][3];
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (UOTAG(6), 2);
              r1 = ((object***) lenv) [1][1][3];
              r0[1] = r1;
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (UOTAG(1), 2);
              r1 = ((object***) lenv) [1][1][3];
              r0[1] = r1;
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object *) 3;
            r1 = ((object**) lenv) [1][3];
            r0 = box((pxll_int)unbox(r1)+unbox(r0));
            r1 = ((object*) lenv) [3];
            r2 = ((object**) lenv) [1][2];
            lenv = ((object *)lenv)[1];
            lenv[2] = r2;
            lenv[3] = r0;
            lenv[4] = r1;
            goto FUN_lexical_address_2680_i4757_i4853;
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        r2 = ((object**) lenv) [1][2];
        lenv = ((object *)lenv)[1];
        lenv[2] = r2;
        lenv[3] = r0;
        lenv[4] = r1;
        goto FUN_lexical_address_2680_i4757_i4853;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = ((object**) lenv) [1][4];
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = ((object*) lenv) [2];
        r1 = ((object**) lenv) [1][2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (UOTAG(7), 1);
          r1 = ((object*) lenv) [3];
          r0[1] = r1;
          PXLL_RETURN(0);
        } else {
          r0 = ((object**) lenv) [1][3];
          r1 = ((object*) lenv) [4];
          r2 = ((object**) lenv) [1][2];
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_lexical_address_2680_i4757_i4853;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2300:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lexical_address_2680_i4757_i4853; r2[2] = lenv;
  r1[11] = r2;
  // def collect-primargs_2685_i4757_i4853
  goto L2302;
  FUN_collect_primargs_2685_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2303; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L2303:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def $loop_2882_i4757_i4853
    goto L2304;
    FUN__24loop_2882_i4757_i4853:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = ((object*) lenv) [3];
        r0[2] = r1;
        r1 = (object *) constructed_36[0];
        r0[3] = r1;
        r1 = top[23];
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (UOTAG(1), 2);
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*****) lenv) [1][1][1][1][2];
        r2[2] = r3;
        r3 = ((object**) lenv) [1][2];
        r2[3] = r3;
        r3 = top[29];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2305; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
        L2305:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[1] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r0[2] = r1;
        r0 = ((object**) lenv) [1][3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r1 = (object *) 3;
        r2 = ((object*) lenv) [2];
        r1 = box((pxll_int)unbox(r2)+unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN__24loop_2882_i4757_i4853;
      }
      PXLL_RETURN(0);
    L2304:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN__24loop_2882_i4757_i4853; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = ((object*) lenv) [2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2306; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2882_i4757_i4853;
    L2306:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    // def lambda_18375_i4757_i4853
    goto L2307;
    FUN_lambda_18375_i4757_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = ((object**) lenv) [1][3];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = ((object***) lenv) [1][1][3];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = ((pxll_vector*)r1)->val[2];
              r0[3] = r1;
              r1 = ((object*) lenv) [2];
              r1 = ((pxll_vector*)r1)->val[2];
              r0[4] = r1;
              r0 = ((object*) lenv) [4];
              r1 = ((object*) lenv) [3];
              r0 = PXLL_TEST(unbox(r1)>unbox(r0));
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L2307:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18375_i4757_i4853; r2[2] = lenv;
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = top[46];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2308; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_sort_342;
    L2308:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = top[20];
    r1[2] = r2;
    r2 = ((object*) lenv) [4];
    r1[3] = r2;
    r2 = top[34];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2309; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
    L2309:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = top[19];
    r1[2] = r2;
    r2 = ((object*) lenv) [4];
    r1[3] = r2;
    r2 = top[34];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2310; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
    L2310:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 7);
    r1 = ((object*) lenv) [6];
    r0[2] = r1;
    r1 = (object *) constructed_473[0];
    r0[3] = r1;
    r1 = ((object*) lenv) [5];
    r0[4] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[5] = r1;
    r1 = ((object**) lenv) [1][4];
    r0[6] = r1;
    r1 = ((object**) lenv) [1][5];
    r0[7] = r1;
    r1 = ((object***) lenv) [1][1][13];
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_splat_2686_i4757_i4853;
  L2302:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_collect_primargs_2685_i4757_i4853; r2[2] = lenv;
  r1[12] = r2;
  // def collect-primargs*_2686_i4757_i4853
  goto L2311;
  FUN_collect_primargs_splat_2686_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][3];
        r1[2] = r2;
        r2 = (object *) constructed_36[0];
        r1[3] = r2;
        r2 = top[23];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2312; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
        L2312:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][4];
        r1[2] = r2;
        r2 = top[24];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2313; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
        L2313:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_2901_i4757_i4853
        goto L2314;
        FUN__24loop_2901_i4757_i4853:
          check_heap (0);
          r0 = ((object***) lenv) [1][1][3];
          r1 = ((object*) lenv) [2];
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = ((object*) lenv) [3];
            r0[2] = r1;
            r1 = (object *) constructed_36[0];
            r0[3] = r1;
            r1 = top[23];
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][2];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object*****) lenv) [1][1][1][1][4];
            r2[3] = r3;
            r3 = top[30];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2315; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_index_eq_324;
            L2315:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = top[29];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2316; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
            L2316:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = ((object**) lenv) [1][3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r1 = (object *) 3;
            r2 = ((object*) lenv) [2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN__24loop_2901_i4757_i4853;
          }
          PXLL_RETURN(0);
        L2314:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_2901_i4757_i4853; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2317; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2901_i4757_i4853;
        L2317:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = ((object*) lenv) [4];
        r0[2] = r1;
        r1 = ((object**) lenv) [1][7];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = ((object**) lenv) [1][2];
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = ((object*) lenv) [2];
        r0[3] = r1;
        r1 = ((object**) lenv) [1][5];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object***) lenv) [1][1][6];
        r3[2] = r4;
        r4 = top[139];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2318; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_525;
        L2318:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = ((object*) lenv) [2];
        r3[2] = r4;
        r4 = (object *) constructed_36[0];
        r3[3] = r4;
        r4 = top[23];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2319; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_313;
        L2319:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = ((object***) lenv) [1][1][3];
        r2[3] = r3;
        r3 = top[23];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2320; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
        L2320:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r1[2] = r2;
        // def lambda_18472_i4757_i4853
        goto L2321;
        FUN_lambda_18472_i4757_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 7);
          r1 = ((object**) lenv) [1][3];
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][3];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[3] = r1;
          r1 = ((object***) lenv) [1][1][4];
          r0[4] = r1;
          r1 = ((object***) lenv) [1][1][5];
          r0[5] = r1;
          r1 = ((object***) lenv) [1][1][6];
          r0[6] = r1;
          r1 = ((object***) lenv) [1][1][7];
          r0[7] = r1;
          r1 = ((object****) lenv) [1][1][1][13];
          r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_splat_2686_i4757_i4853;
        L2321:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_18472_i4757_i4853; r2[2] = lenv;
        r1[3] = r2;
        r2 = ((object***) lenv) [1][1][2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2322; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
        L2322:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = ((object***) lenv) [1][1][3];
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
      } break;
    }
    PXLL_RETURN(0);
  L2311:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_collect_primargs_splat_2686_i4757_i4853; r2[2] = lenv;
  r1[13] = r2;
  // def c-primargs_2687_i4757_i4853
  goto L2323;
  FUN_c_primargs_2687_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = ((object*) lenv) [2];
    r0[2] = r1;
    r1 = ((object*) lenv) [6];
    r0[3] = r1;
    r1 = ((object*) lenv) [7];
    r0[4] = r1;
    // def lambda_18495_i4757_i4853
    goto L2324;
    FUN_lambda_18495_i4757_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      r1 = ((object**) lenv) [1][4];
      r2 = ((object**) lenv) [1][5];
      r3 = ((object**) lenv) [1][7];
      r4 = ((object**) lenv) [1][3];
      t = alloc_no_clear (UOTAG(18),5);
      t[1] = r4;
      t[2] = r1;
      t[3] = r2;
      t[4] = r0;
      t[5] = r3;
      r0 = t;
      PXLL_RETURN(0);
    L2324:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_18495_i4757_i4853; r1[2] = lenv;
    r0[5] = r1;
    r1 = ((object**) lenv) [1][12];
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2685_i4757_i4853;
  L2323:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_primargs_2687_i4757_i4853; r2[2] = lenv;
  r1[14] = r2;
  // def c-trcall_2690_i4757_i4853
  goto L2325;
  FUN_c_trcall_2690_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = ((object*) lenv) [4];
    r0[2] = r1;
    r1 = ((object*) lenv) [5];
    r0[3] = r1;
    r1 = ((object*) lenv) [6];
    r0[4] = r1;
    // def lambda_18564_i4757_i4853
    goto L2326;
    FUN_lambda_18564_i4757_i4853:
      check_heap (0);
      r0 = ((object**) lenv) [1][3];
      r1 = ((object*) lenv) [2];
      r2 = ((object**) lenv) [1][2];
      t = alloc_no_clear (UOTAG(15),3);
      t[1] = r2;
      t[2] = r0;
      t[3] = r1;
      r0 = t;
      PXLL_RETURN(0);
    L2326:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_18564_i4757_i4853; r1[2] = lenv;
    r0[5] = r1;
    r1 = ((object**) lenv) [1][12];
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2685_i4757_i4853;
  L2325:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_trcall_2690_i4757_i4853; r2[2] = lenv;
  r1[15] = r2;
  // def compile-store-args_2693_i4757_i4853
  goto L2327;
  FUN_compile_store_args_2693_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = (object *) 6;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2328; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
    L2328:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = ((object*) lenv) [7];
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [6];
    r1[2] = r2;
    // def lambda_18805_i4757_i4853
    goto L2329;
    FUN_lambda_18805_i4757_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object****) lenv) [1][1][1][4];
      r2[2] = r3;
      r3 = top[22];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2330; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_cdr_312;
      L2330:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = ((object*) lenv) [2];
      switch (get_case (r1)) {
        case (TC_NIL): {
          r1 = (object *) 262;
        } break;
        default: {
          goto fatbar_50;
        }
      }
      goto fatbar_50_over;
      fatbar_50:
      r1 = (object *) 6;
      fatbar_50_over: ;
      lenv = lenv[1];
      if PXLL_IS_TRUE(r1) {
        r1 = ((object***) lenv) [1][1][8];
      } else {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 8);
        r3 = (object *) 3;
        r4 = ((object****) lenv) [1][1][1][2];
        r3 = box((pxll_int)unbox(r4)+unbox(r3));
        r2[2] = r3;
        r3 = ((object****) lenv) [1][1][1][3];
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object****) lenv) [1][1][1][4];
        r3[2] = r4;
        r4 = top[22];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2331; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cdr_312;
        L2331:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = ((object****) lenv) [1][1][1][5];
        r2[5] = r3;
        r3 = ((object****) lenv) [1][1][1][6];
        r2[6] = r3;
        r3 = ((object****) lenv) [1][1][1][7];
        r2[7] = r3;
        r3 = ((object****) lenv) [1][1][1][8];
        r2[8] = r3;
        r3 = ((object*****) lenv) [1][1][1][1][16];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2332; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_compile_store_args_2693_i4757_i4853;
        L2332:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = ((object****) lenv) [1][1][1][6];
        r2 = ((object*) lenv) [2];
        r3 = (object *) -1;
        t = alloc_no_clear (UOTAG(0),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        lenv = lenv[1];
      }
      r0[2] = r1;
      r0 = ((object***) lenv) [1][1][2];
      r1 = ((object**) lenv) [1][2];
      r2 = ((object***) lenv) [1][1][5];
      r3 = ((object*) lenv) [2];
      r4 = ((object***) lenv) [1][1][3];
      t = alloc_no_clear (UOTAG(12),5);
      t[1] = r4;
      t[2] = r1;
      t[3] = r2;
      t[4] = r0;
      t[5] = r3;
      r0 = t;
      PXLL_RETURN(0);
    L2329:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18805_i4757_i4853; r2[2] = lenv;
    r1[3] = r2;
    r2 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2333; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
    L2333:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = ((object**) lenv) [1][3];
    r0[1] = r1[2]; lenv = r0; goto FUN_compile_2668_i4757_i4853;
  L2327:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_compile_store_args_2693_i4757_i4853; r2[2] = lenv;
  r1[16] = r2;
  // def c-let-splat_2695_i4757_i4853
  goto L2334;
  FUN_c_let_splat_2695_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 9);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][4];
    r1[2] = r2;
    r2 = (object *) constructed_36[0];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2335; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L2335:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2336; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
    L2336:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object*) lenv) [2];
    r1[2] = r2;
    r2 = top[22];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2337; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cdr_312;
    L2337:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object*) lenv) [4];
    r1[2] = r2;
    r2 = (object *) constructed_36[0];
    r1[3] = r2;
    r2 = top[23];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2338; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
    L2338:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][3];
    r1[2] = r2;
    r2 = top[24];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2339; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
    L2339:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object**) lenv) [1][6];
    r1[2] = r2;
    r2 = top[139];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2340; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_525;
    L2340:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[7] = r1;
    r1 = allocate (TC_TUPLE, 5);
    r2 = ((object**) lenv) [1][2];
    r1[2] = r2;
    r2 = ((object*) lenv) [3];
    r1[3] = r2;
    r2 = ((object**) lenv) [1][3];
    switch (get_case (r2)) {
      case (TC_NIL): {
        r2 = ((object**) lenv) [1][5];
      } break;
      default: {
        goto fatbar_49;
      }
    }
    goto fatbar_49_over;
    fatbar_49:
    r2 = ((object**) lenv) [1][5];
    r3 = ((object**) lenv) [1][3];
    t = alloc_no_clear (UOTAG(1),2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    fatbar_49_over: ;
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = allocate (TC_TUPLE, 2);
    r4 = ((object**) lenv) [1][6];
    r3[2] = r4;
    r4 = top[139];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L2341; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_525;
    L2341:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    // def lambda_18911_i4757_i4853
    goto L2342;
    FUN_lambda_18911_i4757_i4853:
      check_heap (0);
      r0 = ((object***) lenv) [1][1][6];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (UOTAG(17),2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L2342:
    r3 = allocate (TC_CLOSURE, 2);
    r3[1] = &&FUN_lambda_18911_i4757_i4853; r3[2] = lenv;
    r2[3] = r3;
    r3 = ((object***) lenv) [1][1][2];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2343; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
    L2343:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r2 = ((object***) lenv) [1][1][3];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2344; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
    L2344:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[8] = r1;
    r1 = ((object*) lenv) [7];
    r2 = ((object*) lenv) [8];
    r3 = (object *) -1;
    t = alloc_no_clear (UOTAG(0),3);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    r1 = t;
    r0[9] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object****) lenv) [1][1][1][2];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object****) lenv) [1][1][1][51];
    r1[2] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2345; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
    L2345:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[159];
    r0[4] = r1;
    r1 = top[6];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2346; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
    L2346:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][5];
    switch (get_case (r1)) {
      case (UITAG(0)): {
        r1 = (object *) 262;
      } break;
      default: {
        goto fatbar_48;
      }
    }
    goto fatbar_48_over;
    fatbar_48:
    r1 = (object *) 6;
    fatbar_48_over: ;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = ((object**) lenv) [1][7];
    r1[2] = r2;
    // def lambda_18947_i4757_i4853
    goto L2347;
    FUN_lambda_18947_i4757_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 8);
      r2 = (object *) 1;
      r1[2] = r2;
      r2 = (object *) 3;
      r1[3] = r2;
      r2 = ((object****) lenv) [1][1][1][5];
      r1[4] = r2;
      r2 = ((object**) lenv) [1][2];
      r1[5] = r2;
      r2 = ((object****) lenv) [1][1][1][7];
      r3 = ((object**) lenv) [1][2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      r1[6] = r2;
      r2 = ((object*****) lenv) [1][1][1][1][3];
      switch (get_case (r2)) {
        case (TC_NIL): {
          r2 = ((object*****) lenv) [1][1][1][1][5];
        } break;
        default: {
          goto fatbar_47;
        }
      }
      goto fatbar_47_over;
      fatbar_47:
      r2 = ((object*****) lenv) [1][1][1][1][5];
      r3 = ((object*****) lenv) [1][1][1][1][3];
      t = alloc_no_clear (UOTAG(1),2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      fatbar_47_over: ;
      r1[7] = r2;
      r2 = ((object****) lenv) [1][1][1][9];
      r1[8] = r2;
      r2 = ((object******) lenv) [1][1][1][1][1][16];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2348; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_compile_store_args_2693_i4757_i4853;
      L2348:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][7];
      r2 = ((object*) lenv) [2];
      r3 = (object *) -1;
      t = alloc_no_clear (UOTAG(0),3);
      t[1] = r3;
      t[2] = r1;
      t[3] = r2;
      r1 = t;
      r0[3] = r1;
      r0 = ((object*) lenv) [3];
      r1 = ((object**) lenv) [1][2];
      t = alloc_no_clear (UOTAG(16),2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L2347:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18947_i4757_i4853; r2[2] = lenv;
    r1[3] = r2;
    r2 = ((object****) lenv) [1][1][1][2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2349; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cont_2666_i4757_i4853;
    L2349:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = ((object*) lenv) [2];
    r1 = ((object*) lenv) [3];
    r2 = ((object**) lenv) [1][6];
    t = alloc_no_clear (UOTAG(10),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L2334:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_let_splat_2695_i4757_i4853; r2[2] = lenv;
  r1[17] = r2;
  // def record-label-tag_2703_i4757_i4853
  goto L2350;
  FUN_record_label_tag_2703_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3086_i4757_i4853
    goto L2351;
    FUN_loop_3086_i4757_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = ((object*****) lenv) [1][1][1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = ((object**) lenv) [1][3];
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                goto FUN_loop_3086_i4757_i4853;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object******) lenv) [1][1][1][1][1][2];
          r2 = ((pxll_vector*)r2)->val[6];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2352; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L2352:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(1), 2);
          r2 = ((object*****) lenv) [1][1][1][1][2];
          r1[1] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
          r1 = ((pxll_vector*)r1)->val[6];
          r0[3] = r1;
          r0 = ((object*) lenv) [3];
          r1 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          ((pxll_vector*)r1)->val[6] = r0;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L2351:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3086_i4757_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object****) lenv) [1][1][1][2];
    r1 = ((pxll_vector*)r1)->val[6];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3086_i4757_i4853;
  L2350:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_record_label_tag_2703_i4757_i4853; r2[2] = lenv;
  r1[18] = r2;
  // def gen-return_2706_i4757_i4853
  goto L2353;
  FUN_gen_return_2706_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2353:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_return_2706_i4757_i4853; r2[2] = lenv;
  r1[19] = r2;
  // def gen-invoke_2707_i4757_i4853
  goto L2354;
  FUN_gen_invoke_2707_i4757_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = ((object***) lenv) [1][1][2];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = ((object***) lenv) [1][1][51];
    r1[2] = r2;
    r2 = top[21];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2355; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_311;
    L2355:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = top[159];
    r0[4] = r1;
    r1 = top[6];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2356; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_249;
    L2356:
    ; lenv = k[2]; k = k[1];
    r0 = ((object*) lenv) [5];
    r1 = ((object*) lenv) [3];
    r2 = ((object*) lenv) [4];
    r3 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(13),4);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    t[4] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2354:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_invoke_2707_i4757_i4853; r2[2] = lenv;
  r1[20] = r2;
  // def gen-tail_2708_i4757_i4853
  goto L2357;
  FUN_gen_tail_2708_i4757_i4853:
    check_heap (0);
    r0 = ((object*) lenv) [3];
    r1 = ((object*) lenv) [4];
    r2 = ((object*) lenv) [2];
    t = alloc_no_clear (UOTAG(14),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L2357:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_tail_2708_i4757_i4853; r2[2] = lenv;
  r1[21] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) 1;
  r2[2] = r3;
  r3 = top[115];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2358; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
  L2358:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[22] = r2;
  r1 = allocate (TC_TUPLE, 5);
  r2 = (object *) 262;
  r1[2] = r2;
  r2 = ((object**) lenv) [1][50];
  r1[3] = r2;
  r2 = (object*)UITAG(0);
  r1[4] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = (object *) constructed_472[0];
  r2[2] = r3;
  r3 = ((object*) lenv) [19];
  r2[3] = r3;
  r3 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2359; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_cont_2666_i4757_i4853;
  L2359:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[5] = r2;
  r2 = ((object*) lenv) [3];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2360; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_compile_2668_i4757_i4853;
  L2360:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[52] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object*)UITAG(5);
  r1[2] = r2;
  r2 = (object *) constructed_471[0];
  r1[3] = r2;
  r2 = top[120];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2361; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
  L2361:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  ((object*) lenv) [32] = r1;
  r0[53] = r1;
  r1 = allocate (UOTAG(1), 3);
  r2 = (object *) 32769;
  r2 = box((pxll_int)string_tuple_length (unbox(r2)));
  ensure_heap (2, unbox(r2));
  r2 = (object *) 32769;
  r2 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r2))), ((pxll_string*)(t))->len = unbox(r2), t);
  r1[1] = r2;
  r2 = allocate (TC_TUPLE, 4);
  r3 = ((object*) lenv) [12];
  r2[2] = r3;
  r3 = allocate (TC_TUPLE, 2);
  r3[1] = lenv; lenv = r3;
  r4 = top[165];
  r5 = top[164];
  r4 = box((pxll_int)unbox(r5)|unbox(r4));
  r3[2] = r4;
  r3 = ((object*) lenv) [2];
  r4 = top[166];
  r3 = box((pxll_int)unbox(r4)|unbox(r3));
  lenv = lenv[1];
  r2[3] = r3;
  r3 = (object *) 841;
  r2[4] = r3;
  r3 = top[62];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2362; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_open_375;
  L2362:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = (object *) 1;
  r1[3] = r2;
  r0[54] = r1;
  r1 = (object *) 3;
  r0[55] = r1;
  r1 = allocate (TC_TUPLE, 7);
  r1[1] = lenv; lenv = r1;
  // def write-indent_4233_i4760_i4853
  goto L2363;
  FUN_write_indent_4233_i4760_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4239_i4760_i4853
    goto L2364;
    FUN_loop_4239_i4760_i4853:
      check_heap (0);
      r0 = (object *) 1;
      r1 = ((object*) lenv) [2];
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object*****) lenv) [1][1][1][1][54];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,6)];
        r0[2] = r1;
        r0 = (object*) &constructed_470;
        r0 = box((pxll_int)((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_470;
        r2 = ((object*) lenv) [2];
        r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
        lenv = lenv[1];
        r0 = (object *) 3;
        r1 = ((object*) lenv) [2];
        r0 = box((pxll_int)unbox(r1)-unbox(r0));
        lenv[2] = r0;
        goto FUN_loop_4239_i4760_i4853;
      } else {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L2364:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4239_i4760_i4853; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object***) lenv) [1][1][55];
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4239_i4760_i4853;
  L2363:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_write_indent_4233_i4760_i4853; r2[2] = lenv;
  r1[2] = r2;
  // def write-string_4234_i4760_i4853
  goto L2365;
  FUN_write_string_4234_i4760_i4853:
    check_heap (0);
    r0 = ((object**) lenv) [1][2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2366; ; k = t;
    lenv = r0[2]; goto FUN_write_indent_4233_i4760_i4853;
    L2366:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][54];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,6)];
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][54];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,6)];
    r0[2] = r1;
    r0 = (object*) &constructed_469;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_469;
    r2 = ((object*) lenv) [2];
    r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    lenv = lenv[1];
    r0 = (object *) 14;
    PXLL_RETURN(0);
  L2365:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_write_string_4234_i4760_i4853; r2[2] = lenv;
  r1[3] = r2;
  // def copy_4235_i4760_i4853
  goto L2367;
  FUN_copy_4235_i4760_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object****) lenv) [1][1][1][54];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,6)];
    r0[2] = r1;
    r0 = ((object**) lenv) [1][2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object**) lenv) [1][2];
    r2 = ((object*) lenv) [2];
    r0 = box((pxll_int)write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    PXLL_RETURN(0);
  L2367:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_copy_4235_i4760_i4853; r2[2] = lenv;
  r1[4] = r2;
  // def indent_4236_i4760_i4853
  goto L2368;
  FUN_indent_4236_i4760_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][55];
    r0[2] = r1;
    r0 = (object *) 3;
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)+unbox(r0));
    lenv = lenv[1];
    ((object**) lenv) [1][55] = r0;
    PXLL_RETURN(0);
  L2368:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_indent_4236_i4760_i4853; r2[2] = lenv;
  r1[5] = r2;
  // def dedent_4237_i4760_i4853
  goto L2369;
  FUN_dedent_4237_i4760_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][55];
    r0[2] = r1;
    r0 = (object *) 3;
    r1 = ((object*) lenv) [2];
    r0 = box((pxll_int)unbox(r1)-unbox(r0));
    lenv = lenv[1];
    ((object**) lenv) [1][55] = r0;
    PXLL_RETURN(0);
  L2369:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_dedent_4237_i4760_i4853; r2[2] = lenv;
  r1[6] = r2;
  // def close-file_4238_i4760_i4853
  goto L2370;
  FUN_close_file_4238_i4760_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object***) lenv) [1][1][54];
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,6)];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)close (unbox(r0)));
    PXLL_RETURN(0);
  L2370:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_close_file_4238_i4760_i4853; r2[2] = lenv;
  r1[7] = r2;
  r1 = allocate (UOTAG(0), 5);
  r2 = ((object*) lenv) [7];
  r1[1] = r2;
  r2 = ((object*) lenv) [4];
  r1[2] = r2;
  r2 = ((object*) lenv) [6];
  r1[3] = r2;
  r2 = ((object*) lenv) [5];
  r1[4] = r2;
  r2 = ((object*) lenv) [3];
  r1[5] = r2;
  lenv = lenv[1];
  r0[56] = r1;
  r0 = ((object*) lenv) [2];
  r0 = ((pxll_vector*)r0)->val[10];
  r0 = ((pxll_vector*)r0)->val[5];
  if PXLL_IS_TRUE(r0) {
    r0 = (object*) &constructed_468;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_468;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    r1 = ((object*) lenv) [52];
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = top[141];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2371; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_print_insn_529;
    L2371:
    ; lenv = k[2]; k = k[1];
    r0 = top[161];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2372; ; k = t;
    lenv = r0[2]; goto *r0[1];
    L2372:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_467;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_467;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_35172_i4853
    goto L2373;
    FUN_lambda_35172_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = top[119];
      r0[1] = r1[2]; lenv = r0; goto FUN_print_datatype_483;
    L2373:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_35172_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[2];
    r0[3] = r1;
    r1 = top[69];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2374; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
    L2374:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_466;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_466;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[6];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = dump_object (r0, 0); fprintf (stdout, "\n");
    lenv = lenv[1];
    r0 = (object*) &constructed_465;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_465;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[11];
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = dump_object (r0, 0); fprintf (stdout, "\n");
    lenv = lenv[1];
    r0 = (object*) &constructed_464;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_464;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_35220_i4853
    goto L2375;
    FUN_lambda_35220_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][3];
      r3[2] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2376; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
      L2376:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = ((object***) lenv) [1][1][2];
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = ((object****) lenv) [1][1][1][2];
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_463;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_462;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_461;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2377; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L2377:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L2375:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_35220_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[15];
    r0[3] = r1;
    r1 = top[69];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2378; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
    L2378:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_460;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_460;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_35254_i4853
    goto L2379;
    FUN_lambda_35254_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = ((object***) lenv) [1][1][3];
      r3[2] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2380; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
      L2380:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = ((object***) lenv) [1][1][2];
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = ((object****) lenv) [1][1][1][2];
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_459;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_458;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_457;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2381; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L2381:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L2379:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_35254_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[16];
    r0[3] = r1;
    r1 = top[69];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2382; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
    L2382:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_456;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_456;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_35290_i4853
    goto L2383;
    FUN_lambda_35290_i4853:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = ((object***) lenv) [1][1][2];
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = ((object****) lenv) [1][1][1][2];
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = ((object*) lenv) [2];
      lenv = lenv[1];
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = allocate (TC_TUPLE, 2);
      r5 = ((object***) lenv) [1][1][3];
      r4[2] = r5;
      r5 = top[143];
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L2384; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_apply_subst_534;
      L2384:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = top[109];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2385; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
      L2385:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_455;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_454;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_453;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2386; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L2386:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = ((object*) lenv) [2];
      r0 = box((pxll_int)((pxll_string*)(r0))->len);
      r1 = ((object*) lenv) [2];
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L2383:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_35290_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[3] = r1;
    r1 = top[69];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2387; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
    L2387:
    ; lenv = k[2]; k = k[1];
    r0 = (object *) 14;
  } else {
    r0 = (object *) 14;
  }
  r0 = (object*) &constructed_452;
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_452;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = (object*) &constructed_451;
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_451;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = ((object*) lenv) [12];
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = ((object*) lenv) [12];
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = top[161];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2388; ; k = t;
  lenv = r0[2]; goto *r0[1];
  L2388:
  ; lenv = k[2]; k = k[1];
  r0 = allocate (TC_TUPLE, 3);
  // def lambda_35327_i4853
  goto L2389;
  FUN_lambda_35327_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = ((object*) lenv) [2];
    r4 = (object*) &constructed_450;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object**) lenv) [1][2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = (object*) &constructed_449;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2390; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L2390:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = ((object**) lenv) [1][56];
    r1 = ((pxll_vector*)r1)->val[4];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L2389:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_35327_i4853; r1[2] = lenv;
  r0[2] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = ((object**) lenv) [1][2];
  r2 = ((pxll_vector*)r2)->val[0];
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [2];
  r1[2] = r2;
  r2 = (object *) constructed_36[0];
  r1[3] = r2;
  r2 = top[23];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2391; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
  L2391:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[3] = r1;
  r1 = top[37];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2392; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
  L2392:
  ; lenv = k[2]; k = k[1];
  r0 = allocate (TC_TUPLE, 3);
  r1 = ((object*) lenv) [56];
  r1 = ((pxll_vector*)r1)->val[4];
  r0[2] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = ((object**) lenv) [1][2];
  r2 = ((pxll_vector*)r2)->val[1];
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = ((object*) lenv) [2];
  r1[2] = r2;
  r2 = (object *) constructed_36[0];
  r1[3] = r2;
  r2 = top[23];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2393; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
  L2393:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[3] = r1;
  r1 = top[37];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2394; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
  L2394:
  ; lenv = k[2]; k = k[1];
  r0 = allocate (TC_TUPLE, 6);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_448;
  r1[2] = r2;
  r2 = top[63];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2395; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_file_2fopen_read_382;
  L2395:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[2] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def loop_4755_i4691_i4803_i4853
  goto L2396;
  FUN_loop_4755_i4691_i4803_i4853:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = box((pxll_int)((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = ((object*) lenv) [2];
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [3];
      r1[2] = r2;
      r2 = (object *) constructed_36[0];
      r1[3] = r2;
      r2 = top[23];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2397; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
      L2397:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = top[49];
      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
    } else {
      r0 = ((object*) lenv) [3];
      r1 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object***) lenv) [1][1][2];
      r1[2] = r2;
      r2 = top[65];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2398; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2fread_buffer_388;
      L2398:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv[2] = r1;
      lenv[3] = r0;
      goto FUN_loop_4755_i4691_i4803_i4853;
    }
    PXLL_RETURN(0);
  L2396:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_loop_4755_i4691_i4803_i4853; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = allocate (TC_TUPLE, 2);
  r3 = ((object**) lenv) [1][2];
  r2[2] = r3;
  r3 = top[65];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2399; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_file_2fread_buffer_388;
  L2399:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = (object *) constructed_447[0];
  r1[3] = r2;
  r2 = ((object*) lenv) [2];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2400; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_loop_4755_i4691_i4803_i4853;
  L2400:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r0[3] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = top[208];
  r1[2] = r2;
  r2 = ((object*) lenv) [3];
  r1[3] = r2;
  r2 = top[53];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2401; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_find_358;
  L2401:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[4] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = top[209];
  r1[2] = r2;
  r2 = ((object*) lenv) [3];
  r1[3] = r2;
  r2 = top[53];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2402; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_find_358;
  L2402:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[5] = r1;
  r1 = (object *) -1;
  r2 = ((object*) lenv) [4];
  if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
    r1 = (object *) 262;
  } else {
    r1 = (object *) -1;
    r2 = ((object*) lenv) [5];
    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
  }
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_446;
    r1[2] = r2;
    r2 = allocate (UOTAG(1), 2);
    r3 = ((object*) lenv) [4];
    r2[1] = r3;
    r3 = ((object*) lenv) [5];
    r2[2] = r3;
    r1[3] = r2;
    r2 = top[15];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2403; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
    L2403:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
  } else {
    r1 = allocate (TC_TUPLE, 8);
    r1[1] = lenv; lenv = r1;
    r2 = top[208];
    r2 = box((pxll_int)((pxll_string*)(r2))->len);
    r1[2] = r2;
    r2 = ((object*) lenv) [2];
    r3 = ((object**) lenv) [1][4];
    r2 = box((pxll_int)unbox(r3)+unbox(r2));
    r1[3] = r2;
    r2 = top[209];
    r2 = box((pxll_int)((pxll_string*)(r2))->len);
    r1[4] = r2;
    r2 = ((object*) lenv) [4];
    r3 = ((object**) lenv) [1][5];
    r2 = box((pxll_int)unbox(r3)+unbox(r2));
    r1[5] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = (object *) 1;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r2[4] = r3;
    r3 = top[47];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2404; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_347;
    L2404:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[6] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = ((object*) lenv) [3];
    r2[3] = r3;
    r3 = ((object*) lenv) [5];
    r2[4] = r3;
    r3 = top[47];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2405; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_347;
    L2405:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[7] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = ((object**) lenv) [1][3];
    r2[2] = r3;
    r3 = ((object*) lenv) [5];
    r2[3] = r3;
    r3 = ((object**) lenv) [1][3];
    r3 = box((pxll_int)((pxll_string*)(r3))->len);
    r2[4] = r3;
    r3 = top[47];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2406; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_347;
    L2406:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[8] = r2;
    r1 = allocate (UOTAG(8), 3);
    r2 = ((object*) lenv) [6];
    r1[1] = r2;
    r2 = ((object*) lenv) [7];
    r1[2] = r2;
    r2 = ((object*) lenv) [8];
    r1[3] = r2;
    lenv = lenv[1];
  }
  r0[6] = r1;
  r0 = ((object*) lenv) [6];
  switch (get_case_noint (r0)) {
    default: {
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][6];
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r1 = ((object**) lenv) [1][6];
      r1 = UOBJ_GET(r1,1);
      r0[3] = r1;
      r1 = ((object**) lenv) [1][6];
      r1 = UOBJ_GET(r1,2);
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [2];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][56];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2407; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2407:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 8);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[8];
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = (object *) constructed_36[0];
      r1[3] = r2;
      r2 = top[23];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2408; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
      L2408:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = ((object*) lenv) [3];
      r1[2] = r2;
      r2 = top[24];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2409; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
      L2409:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[4] = r1;
      r1 = (object*)UITAG(0);
      r0[5] = r1;
      r1 = (object *) constructed_445[0];
      r0[6] = r1;
      r1 = (object *) 1;
      r0[7] = r1;
      r1 = (object *) 1;
      r0[8] = r1;
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      // def uohead_4692_i4804_i4853
      goto L2410;
      FUN_uohead_4692_i4804_i4853:
        check_heap (0);
        r0 = (object *) constructed_51[0];
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_61[0];
          r1 = ((object*) lenv) [4];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_441;
            PXLL_RETURN(0);
          } else {
            goto fatbar_46;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_46;
        }
        PXLL_RETURN(0);
        goto fatbar_46_over;
        fatbar_46:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 8);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r2[2] = r3;
        r3 = top[58];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2411; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
        L2411:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][5];
        r2[2] = r3;
        r3 = top[58];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2412; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
        L2412:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = (object*) &constructed_444;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = ((object*) lenv) [5];
        r3 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = ((object*) lenv) [6];
        r3 = (object*) &constructed_443;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r2 = ((object*) lenv) [7];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[8] = r2;
        r1 = ((object*) lenv) [8];
        r2 = (object*) &constructed_442;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        fatbar_46_over: ;
        PXLL_RETURN(0);
      L2410:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_uohead_4692_i4804_i4853; r1[2] = lenv;
      r0[2] = r1;
      // def uitag_4693_i4804_i4853
      goto L2413;
      FUN_uitag_4693_i4804_i4853:
        check_heap (0);
        r0 = (object *) constructed_51[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_49[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_438;
            PXLL_RETURN(0);
          } else {
            goto fatbar_45;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_45;
        }
        PXLL_RETURN(0);
        goto fatbar_45_over;
        fatbar_45:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[58];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2414; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
        L2414:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_440;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_439;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        fatbar_45_over: ;
        PXLL_RETURN(0);
      L2413:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_uitag_4693_i4804_i4853; r1[2] = lenv;
      r0[3] = r1;
      // def walk_4694_i4804_i4853
      goto L2415;
      FUN_walk_4694_i4804_i4853:
        check_heap (0);
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 7);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r2 = ((pxll_vector*)r2)->val[2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = (object*) &constructed_426;
            r1[4] = r2;
            r2 = top[68];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2416; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_398;
            L2416:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object*) lenv) [5];
            r2 = ((pxll_vector*)r2)->val[1];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2417; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2417:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [4];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2418; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L2418:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r0 = (object *) 1;
            r1 = ((object*) lenv) [7];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = ((object****) lenv) [1][1][1][4];
              r1[2] = r2;
              r2 = ((object**) lenv) [1][4];
              r1[3] = r2;
              r2 = top[34];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2419; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
              L2419:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object*****) lenv) [1][1][1][1][6];
              r1[2] = r2;
              r2 = top[24];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2420; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
              L2420:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = ((object*) lenv) [3];
              r2 = (object *) 3;
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 5);
              r2 = ((object***) lenv) [1][1][7];
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = ((object***) lenv) [1][1][3];
              r1[4] = r2;
              r2 = ((object***) lenv) [1][1][6];
              r2 = ((pxll_vector*)r2)->val[1];
              r1[5] = r2;
              r2 = ((object*****) lenv) [1][1][1][1][2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2421; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_uohead_4692_i4804_i4853;
              L2421:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][6];
              r0[3] = r1;
              r0 = ((object*) lenv) [3];
              r1 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              ((object*****) lenv) [1][1][1][1][6] = r0;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_33882_i4804_i4853
              goto L2422;
              FUN_lambda_33882_i4804_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object*******) lenv) [1][1][1][1][1][1][6];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object******) lenv) [1][1][1][1][1][6] = r0;
                PXLL_RETURN(0);
              L2422:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_33882_i4804_i4853; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r0[3] = r1;
              r1 = top[37];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2423; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
              L2423:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 8);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object******) lenv) [1][1][1][1][1][7];
              r2[2] = r3;
              r3 = top[58];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2424; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
              L2424:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = ((object**) lenv) [1][4];
              r2[2] = r3;
              r3 = top[58];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2425; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
              L2425:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = (object*)TC_NIL;
              r1[4] = r2;
              r2 = ((object*) lenv) [4];
              r3 = (object*) &constructed_425;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = ((object*) lenv) [5];
              r3 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = ((object*) lenv) [6];
              r3 = (object*) &constructed_424;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[7] = r2;
              r2 = ((object*) lenv) [7];
              r3 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[8] = r2;
              r1 = ((object*) lenv) [8];
              r2 = (object*) &constructed_423;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r0[2] = r1;
              r1 = top[49];
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r1 = ((object*) lenv) [2];
              r0[2] = r1;
              r1 = ((object*) lenv) [3];
              r0[3] = r1;
              r1 = ((object*) lenv) [6];
              r1 = ((pxll_vector*)r1)->val[1];
              r0[4] = r1;
              r1 = ((object***) lenv) [1][1][3];
              r0[1] = r1[2]; lenv = r0; goto FUN_uitag_4693_i4804_i4853;
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object***) lenv) [1][1][4];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[34];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2426; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
            L2426:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2427; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L2427:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object****) lenv) [1][1][1][6];
            r1[2] = r2;
            r2 = top[24];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2428; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
            L2428:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = ((object*) lenv) [5];
            r2 = (object *) 3;
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            r0[6] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 5);
            r2[1] = lenv; lenv = r2;
            r3 = allocate (TC_TUPLE, 2);
            r4 = ((object***) lenv) [1][1][4];
            r3[2] = r4;
            r4 = top[58];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L2429; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
            L2429:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [3];
            r4 = (object*) &constructed_431;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[4] = r3;
            r3 = ((object*) lenv) [4];
            r4 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[5] = r3;
            r2 = ((object*) lenv) [5];
            r3 = (object*) &constructed_430;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r1[2] = r2;
            r2 = top[49];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2430; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
            L2430:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = ((object*****) lenv) [1][1][1][1][6];
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            ((object****) lenv) [1][1][1][6] = r0;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_33966_i4804_i4853
            goto L2431;
            FUN_lambda_33966_i4804_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object******) lenv) [1][1][1][1][1][6];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              ((object*****) lenv) [1][1][1][1][6] = r0;
              PXLL_RETURN(0);
            L2431:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_33966_i4804_i4853; r1[2] = lenv;
            r0[2] = r1;
            r1 = ((object*) lenv) [3];
            r0[3] = r1;
            r1 = top[37];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2432; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
            L2432:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 8);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*****) lenv) [1][1][1][1][7];
            r2[2] = r3;
            r3 = top[58];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2433; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
            L2433:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][6];
            r2[2] = r3;
            r3 = top[58];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2434; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
            L2434:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = (object*)TC_NIL;
            r1[4] = r2;
            r2 = ((object*) lenv) [4];
            r3 = (object*) &constructed_429;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r2 = ((object*) lenv) [5];
            r3 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = ((object*) lenv) [6];
            r3 = (object*) &constructed_428;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = ((object*) lenv) [7];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r1 = ((object*) lenv) [8];
            r2 = (object*) &constructed_427;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r0[2] = r1;
            r1 = top[49];
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
          } break;
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = ((object*******) lenv) [1][1][1][1][1][1][2];
            r2 = ((pxll_vector*)r2)->val[15];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = (object*) &constructed_434;
            r1[4] = r2;
            r2 = top[68];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2435; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_398;
            L2435:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = top[58];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2436; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
            L2436:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = (object*)TC_NIL;
            r1[3] = r2;
            r2 = ((object*) lenv) [3];
            r3 = (object*) &constructed_433;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = ((object*) lenv) [4];
            r3 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r1 = ((object*) lenv) [5];
            r2 = (object*) &constructed_432;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r0[2] = r1;
            r1 = top[49];
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object****) lenv) [1][1][1][5];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = top[67];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2437; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
            L2437:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = ((object*) lenv) [3];
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object**) lenv) [1][3];
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 5);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object**) lenv) [1][2];
                r2[2] = r3;
                r3 = top[58];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2438; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
                L2438:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = (object*)TC_NIL;
                r1[3] = r2;
                r2 = ((object*) lenv) [3];
                r3 = (object*) &constructed_436;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[4] = r2;
                r2 = ((object*) lenv) [4];
                r3 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[5] = r2;
                r1 = ((object*) lenv) [5];
                r2 = (object*) &constructed_435;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r0[2] = r1;
                r1 = top[49];
                r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
              } break;
              default: {
                r0 = (object*) &constructed_68;
                r0 = box((pxll_int)((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_68;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_437;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_437;
                PXLL_UNDEFINED; result=r0; goto Lreturn;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_44;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_44_over;
        fatbar_44:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object*) lenv) [2];
        r1[2] = r2;
        r2 = top[150];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2439; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_encode_immediate_561;
        L2439:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = top[58];
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_366;
        fatbar_44_over: ;
        PXLL_RETURN(0);
      L2415:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_walk_4694_i4804_i4853; r1[2] = lenv;
      r0[4] = r1;
      r0 = ((object*****) lenv) [1][1][1][1][56];
      r0 = ((pxll_vector*)r0)->val[2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2440; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2440:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object***) lenv) [1][1][4];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_4723_i4804_i4853
      goto L2441;
      FUN__24loop_4723_i4804_i4853:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) constructed_422[0];
          ((object*****) lenv) [1][1][1][1][6] = r0;
          r0 = ((object*) lenv) [2];
          ((object*****) lenv) [1][1][1][1][7] = r0;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object******) lenv) [1][1][1][1][1][3];
          r1[2] = r2;
          r2 = ((object**) lenv) [1][2];
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2442; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2442:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object*) lenv) [2];
              r1 = box((pxll_int)((pxll_string*)(r1))->len);
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
              r0[2] = r1;
              r0 = ((object****) lenv) [1][1][1][2];
              r1 = ((object*) lenv) [2];
              r2 = ((object**) lenv) [1][2];
              t = alloc_no_clear (UOTAG(1),3);
              t[1] = r2;
              t[2] = r0;
              t[3] = r1;
              r0 = t;
              lenv = lenv[1];
              ((object*******) lenv) [1][1][1][1][1][1][5] = r0;
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 14);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][2];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2443; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L2443:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2444; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L2444:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object**) lenv) [1][3];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2445; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L2445:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              // def loop_4738_i4596_i4804_i4853
              goto L2446;
              FUN_loop_4738_i4596_i4804_i4853:
                check_heap (0);
                r0 = ((object*) lenv) [3];
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = ((object*) lenv) [2];
                    r1[2] = r2;
                    r2 = (object *) constructed_36[0];
                    r1[3] = r2;
                    r2 = top[23];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2447; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
                    L2447:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = top[49];
                    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = ((object**) lenv) [1][3];
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = (object *) 8706;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_402;
                    } else {
                      goto fatbar_36;
                    }
                    goto fatbar_36_over;
                    fatbar_36:
                    r1 = (object *) 23554;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_403;
                    } else {
                      goto fatbar_37;
                    }
                    goto fatbar_37_over;
                    fatbar_37:
                    r1 = (object *) 2306;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_404;
                    } else {
                      goto fatbar_38;
                    }
                    goto fatbar_38_over;
                    fatbar_38:
                    r1 = (object *) 2562;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_405;
                    } else {
                      goto fatbar_39;
                    }
                    goto fatbar_39_over;
                    fatbar_39:
                    r1 = (object *) 3330;
                    r2 = ((object**) lenv) [1][2];
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_406;
                    } else {
                      goto fatbar_40;
                    }
                    goto fatbar_40_over;
                    fatbar_40:
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = ((object**) lenv) [1][2];
                    r1[2] = r2;
                    r2 = top[207];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2448; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L2448:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    if PXLL_IS_TRUE(r1) {
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object**) lenv) [1][2];
                      r1[2] = r2;
                      r2 = top[48];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2449; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_char__3estring_350;
                      L2449:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                    } else {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object***) lenv) [1][1][2];
                      r2 = box((pxll_int)GET_CHAR(r2));
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r2[1] = lenv; lenv = r2;
                      // def loop_1045_i4605_i4804_i4853
                      goto L2450;
                      FUN_loop_1045_i4605_i4804_i4853:
                        check_heap (0);
                        r0 = ((object*) lenv) [2];
                        r1 = (object *) 1;
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = (object *) 1;
                          r2 = ((object***) lenv) [1][1][2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
                            r1 = ((object*) lenv) [3];
                            r2 = (object *) 11522;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r2;
                            t[2] = r1;
                            r1 = t;
                          } else {
                            r1 = ((object*) lenv) [3];
                          }
                          r0[2] = r1;
                          r1 = top[56];
                          r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_363;
                        } else {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = (object *) 15;
                          r2 = ((object**) lenv) [1][2];
                          r1 = box((pxll_int)unbox(r2)&unbox(r1));
                          r2 = top[162];
                          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                          r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                          r0[2] = r1;
                          r0 = ((object**) lenv) [1][3];
                          r1 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r1;
                          t[2] = r0;
                          r0 = t;
                          lenv = lenv[1];
                          r1 = (object *) 7;
                          r2 = ((object*) lenv) [2];
                          r1 = box((pxll_int)unbox(r2)>>unbox(r1));
                          lenv[2] = r1;
                          lenv[3] = r0;
                          goto FUN_loop_1045_i4605_i4804_i4853;
                        }
                        PXLL_RETURN(0);
                      L2450:
                      r3 = allocate (TC_CLOSURE, 2);
                      r3[1] = &&FUN_loop_1045_i4605_i4804_i4853; r3[2] = lenv;
                      r2[2] = r3;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = (object *) 1;
                      r4 = ((object**) lenv) [1][2];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r4)<unbox(r3))) {
                        r3 = ((object**) lenv) [1][2];
                        r4 = (object *) 1;
                        r3 = box((pxll_int)unbox(r4)-unbox(r3));
                      } else {
                        r3 = ((object**) lenv) [1][2];
                      }
                      r2[2] = r3;
                      r3 = (object *) constructed_411[0];
                      r2[3] = r3;
                      r3 = ((object*) lenv) [2];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2451; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_loop_1045_i4605_i4804_i4853;
                      L2451:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      lenv = lenv[1];
                      r1[3] = r2;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 5);
                      r2[1] = lenv; lenv = r2;
                      r3 = ((object**) lenv) [1][3];
                      r3 = box((pxll_int)((pxll_string*)(r3))->len);
                      r2[2] = r3;
                      r3 = (object *) 5;
                      r4 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_407;
                      } else {
                        goto fatbar_41;
                      }
                      goto fatbar_41_over;
                      fatbar_41:
                      r3 = (object *) 3;
                      r4 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_408;
                      } else {
                        goto fatbar_42;
                      }
                      goto fatbar_42_over;
                      fatbar_42:
                      r3 = (object *) 1;
                      r4 = ((object*) lenv) [2];
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_409;
                      } else {
                        goto fatbar_43;
                      }
                      goto fatbar_43_over;
                      fatbar_43:
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = (object*) &constructed_410;
                      r3[2] = r4;
                      r4 = ((object****) lenv) [1][1][1][2];
                      r3[3] = r4;
                      r4 = top[15];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2452; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_error1_294;
                      L2452:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      fatbar_43_over: ;
                      fatbar_42_over: ;
                      fatbar_41_over: ;
                      r2[3] = r3;
                      r3 = (object*)TC_NIL;
                      r2[4] = r3;
                      r3 = ((object*) lenv) [4];
                      r4 = ((object**) lenv) [1][3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      r2[5] = r3;
                      r2 = ((object*) lenv) [5];
                      r3 = ((object*) lenv) [3];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      lenv = lenv[1];
                      r1[2] = r2;
                      r2 = top[49];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2453; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                      L2453:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                    }
                    fatbar_40_over: ;
                    fatbar_39_over: ;
                    fatbar_38_over: ;
                    fatbar_37_over: ;
                    fatbar_36_over: ;
                    r0[2] = r1;
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r1 = ((object*) lenv) [3];
                    lenv = ((object *)lenv)[1];
                    lenv[2] = r0;
                    lenv[3] = r1;
                    goto FUN_loop_4738_i4596_i4804_i4853;
                  } break;
                }
                PXLL_RETURN(0);
              L2446:
              r4 = allocate (TC_CLOSURE, 2);
              r4[1] = &&FUN_loop_4738_i4596_i4804_i4853; r4[2] = lenv;
              r3[2] = r4;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_401[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][2];
              r4[2] = r5;
              r5 = top[57];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2454; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string__3elist_364;
              L2454:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = ((object*) lenv) [2];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2455; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_loop_4738_i4596_i4804_i4853;
              L2455:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              lenv = lenv[1];
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_400;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_399;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[9] = r3;
              r3 = ((object*) lenv) [9];
              r4 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[10] = r3;
              r3 = ((object*) lenv) [10];
              r4 = (object*) &constructed_398;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[11] = r3;
              r3 = ((object*) lenv) [11];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[12] = r3;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_397;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[13] = r3;
              r3 = ((object*) lenv) [13];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[14] = r3;
              r2 = ((object*) lenv) [14];
              r3 = (object*) &constructed_396;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[2] = r2;
              r2 = top[49];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2456; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
              L2456:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][56];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2457; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2457:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
            } break;
            case (UOTAG(4)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = ((object**) lenv) [1][2];
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = ((object***) lenv) [1][1][2];
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = ((object*) lenv) [2];
              lenv = lenv[1];
              r2[2] = r3;
              r3 = (object*)TC_NIL;
              r2[3] = r3;
              r3 = ((object*) lenv) [3];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = ((object*) lenv) [4];
              r3 = (object*) &constructed_417;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[2] = r2;
              r2 = top[49];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2458; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
              L2458:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][56];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2459; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2459:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 14);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][2];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2460; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L2460:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object****) lenv) [1][1][1][2];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2461; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L2461:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][7];
              r4[2] = r5;
              r4 = (object *) 3;
              r5 = ((object*) lenv) [2];
              r4 = box((pxll_int)unbox(r5)-unbox(r4));
              lenv = lenv[1];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2462; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L2462:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object********) lenv) [1][1][1][1][1][1][1][8];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2463; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L2463:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_416;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_415;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[9] = r3;
              r3 = ((object*) lenv) [9];
              r4 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[10] = r3;
              r3 = ((object*) lenv) [10];
              r4 = (object*) &constructed_414;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[11] = r3;
              r3 = ((object*) lenv) [11];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[12] = r3;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_413;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[13] = r3;
              r3 = ((object*) lenv) [13];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[14] = r3;
              r2 = ((object*) lenv) [14];
              r3 = (object*) &constructed_412;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[2] = r2;
              r2 = top[49];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2464; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
              L2464:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][56];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2465; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2465:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object********) lenv) [1][1][1][1][1][1][1][8];
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              r1 = (object *) 3;
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv = lenv[1];
              ((object*******) lenv) [1][1][1][1][1][1][8] = r0;
              lenv = lenv[1];
            } break;
            default: {
              goto fatbar_35;
            }
          }
          goto fatbar_35_over;
          fatbar_35:
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r3 = ((object*******) lenv) [1][1][1][1][1][1][3];
          r2[2] = r3;
          r3 = ((object***) lenv) [1][1][2];
          r2[3] = r3;
          r3 = top[29];
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2466; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
          L2466:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = ((object******) lenv) [1][1][1][1][1][4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2467; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_4694_i4804_i4853;
          L2467:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][6];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object*) lenv) [3];
          r1[2] = r2;
          r2 = (object *) constructed_36[0];
          r1[3] = r2;
          r2 = top[23];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2468; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
          L2468:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = ((object*) lenv) [4];
          r2 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 8);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object****) lenv) [1][1][1][2];
          r3[2] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2469; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
          L2469:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = top[16];
          r4[2] = r5;
          r5 = ((object**) lenv) [1][5];
          r4[3] = r5;
          r5 = top[34];
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L2470; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
          L2470:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_421;
          r3[3] = r4;
          r4 = top[50];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2471; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
          L2471:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_420;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = (object*) &constructed_419;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r2 = ((object*) lenv) [8];
          r3 = (object*) &constructed_418;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2472; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L2472:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][56];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2473; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2473:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          fatbar_35_over: ;
          lenv = lenv[1];
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_4723_i4804_i4853;
        }
        PXLL_RETURN(0);
      L2441:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_4723_i4804_i4853; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2474; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4723_i4804_i4853;
      L2474:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_395[0];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_34309_i4804_i4853
      goto L2475;
      FUN_lambda_34309_i4804_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 5);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object***) lenv) [1][1][3];
        r3[2] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2476; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
        L2476:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*)TC_NIL;
        r2[3] = r3;
        r3 = ((object*) lenv) [3];
        r4 = (object*) &constructed_394;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[4] = r3;
        r3 = ((object*) lenv) [4];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[5] = r3;
        r2 = ((object*) lenv) [5];
        r3 = (object*) &constructed_393;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r1[2] = r2;
        r2 = top[49];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2477; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
        L2477:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object***) lenv) [1][1][2];
        r0[3] = r1;
        r0 = ((object*) lenv) [3];
        r1 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        ((object**) lenv) [1][2] = r0;
        PXLL_RETURN(0);
      L2475:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_34309_i4804_i4853; r1[2] = lenv;
      r0[2] = r1;
      r1 = ((object******) lenv) [1][1][1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[15];
      r0[3] = r1;
      r1 = top[69];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2478; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_399;
      L2478:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = allocate (TC_TUPLE, 2);
      r5 = ((object**) lenv) [1][2];
      r4[2] = r5;
      r5 = top[24];
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L2479; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_length_316;
      L2479:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = top[58];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2480; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
      L2480:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 3);
      r4 = allocate (TC_TUPLE, 3);
      r5 = top[16];
      r4[2] = r5;
      r5 = ((object**) lenv) [1][2];
      r4[3] = r5;
      r5 = top[34];
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L2481; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_map_328;
      L2481:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = (object*) &constructed_392;
      r3[3] = r4;
      r4 = top[50];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2482; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string_join_355;
      L2482:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = ((object*) lenv) [4];
      r4 = (object*) &constructed_391;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = ((object*) lenv) [5];
      r4 = ((object*) lenv) [3];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = ((object*) lenv) [6];
      r4 = (object*) &constructed_390;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = ((object*) lenv) [7];
      r4 = ((object*) lenv) [2];
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = ((object*) lenv) [8];
      r3 = (object*) &constructed_389;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r1[2] = r2;
      r2 = top[49];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2483; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
      L2483:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object******) lenv) [1][1][1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2484; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2484:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = ((object*****) lenv) [1][1][1][1][56];
      r0 = ((pxll_vector*)r0)->val[3];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2485; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2485:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [3];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][56];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2486; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2486:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = ((object****) lenv) [1][1][1][2];
      r1 = ((pxll_vector*)r1)->val[12];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2487; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L2487:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      r2 = (object *) 3;
      r1 = box((pxll_int)unbox(r2)+unbox(r1));
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = ((object**) lenv) [1][3];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_4680_i4805_i4853
      goto L2488;
      FUN__24loop_4680_i4805_i4853:
        check_heap (0);
        r0 = ((object***) lenv) [1][1][2];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][2];
          r3[2] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2489; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
          L2489:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = (object*) &constructed_388;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = ((object*) lenv) [5];
          r3 = (object*) &constructed_387;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2490; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L2490:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*******) lenv) [1][1][1][1][1][1][56];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2491; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2491:
          ; lenv = k[2]; k = k[1];
          r0 = (object *) 3;
          r1 = ((object*) lenv) [2];
          r0 = box((pxll_int)unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_4680_i4805_i4853;
        }
        PXLL_RETURN(0);
      L2488:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_4680_i4805_i4853; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2492; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4680_i4805_i4853;
      L2492:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_386;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2493; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2493:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_385;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2494; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2494:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_33671_i4805_i4853
      goto L2495;
      FUN_lambda_33671_i4805_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 11);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 3;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2496; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
        L2496:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 7;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2497; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
        L2497:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2498; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
        L2498:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = (object*)TC_NIL;
        r2[5] = r3;
        r3 = ((object*) lenv) [5];
        r4 = (object*) &constructed_384;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[6] = r3;
        r3 = ((object*) lenv) [6];
        r4 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[7] = r3;
        r3 = ((object*) lenv) [7];
        r4 = (object*) &constructed_383;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[8] = r3;
        r3 = ((object*) lenv) [8];
        r4 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = ((object*) lenv) [9];
        r4 = (object*) &constructed_382;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = ((object*) lenv) [10];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r2 = ((object*) lenv) [11];
        r3 = (object*) &constructed_381;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r1[2] = r2;
        r2 = top[49];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2499; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
        L2499:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][56];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2495:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_33671_i4805_i4853; r1[2] = lenv;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][3];
      r2[2] = r3;
      r3 = top[32];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2500; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_range_326;
      L2500:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = (object *) constructed_36[0];
      r1[3] = r2;
      r2 = top[23];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2501; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
      L2501:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv = lenv[1];
      r0[3] = r1;
      r1 = top[37];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2502; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
      L2502:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_380;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2503; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2503:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_379;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2504; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2504:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_378;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2505; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2505:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_33732_i4805_i4853
      goto L2506;
      FUN_lambda_33732_i4805_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 11);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 3;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2507; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
        L2507:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = ((object**) lenv) [1][2];
        r3[2] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2508; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
        L2508:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 7;
        r5 = ((object**) lenv) [1][2];
        r4 = box((pxll_int)unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = top[58];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2509; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
        L2509:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = (object*)TC_NIL;
        r2[5] = r3;
        r3 = ((object*) lenv) [5];
        r4 = (object*) &constructed_377;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[6] = r3;
        r3 = ((object*) lenv) [6];
        r4 = ((object*) lenv) [4];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[7] = r3;
        r3 = ((object*) lenv) [7];
        r4 = (object*) &constructed_376;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[8] = r3;
        r3 = ((object*) lenv) [8];
        r4 = ((object*) lenv) [3];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = ((object*) lenv) [9];
        r4 = (object*) &constructed_375;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = ((object*) lenv) [10];
        r4 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r2 = ((object*) lenv) [11];
        r3 = (object*) &constructed_374;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r1[2] = r2;
        r2 = top[49];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2510; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
        L2510:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = ((object*****) lenv) [1][1][1][1][56];
        r1 = ((pxll_vector*)r1)->val[4];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2506:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_33732_i4805_i4853; r1[2] = lenv;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = ((object**) lenv) [1][3];
      r2[2] = r3;
      r3 = top[32];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2511; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_range_326;
      L2511:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 3);
      r2 = ((object*) lenv) [2];
      r1[2] = r2;
      r2 = (object *) constructed_36[0];
      r1[3] = r2;
      r2 = top[23];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2512; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_313;
      L2512:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv = lenv[1];
      r0[3] = r1;
      r1 = top[37];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2513; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
      L2513:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_373;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2514; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2514:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object*) lenv) [4];
      r0[2] = r1;
      r1 = ((object***) lenv) [1][1][56];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2515; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2515:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 8);
      r0[1] = lenv; lenv = r0;
      // def emit_4294_i4806_i4853
      goto L2516;
      FUN_emit_4294_i4806_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = ((object**) lenv) [1][2];
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2517; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2517:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_74;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_73;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2518; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2518:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2519; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2519:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
          } break;
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2520; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2520:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = top[150];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2521; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_encode_immediate_561;
            L2521:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = (object *) -1;
            r3 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
              r2 = (object*) &constructed_77;
            } else {
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 4);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2522; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2522:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r3 = ((object*) lenv) [4];
              r4 = (object*) &constructed_78;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2523; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2523:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
            }
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 6);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2524; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2524:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_76;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = (object*) &constructed_75;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r3 = ((object*) lenv) [6];
            r4 = ((object**) lenv) [1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2525; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2525:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2526; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2526:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = ((object*) lenv) [3];
            lenv = lenv[1];
          } break;
          case (UOTAG(2)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2527; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2527:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = (object *) constructed_86[0];
              r2 = ((object**) lenv) [1][3];
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2528; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2528:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2529; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2529:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_81;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = (object*) &constructed_80;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = ((object*) lenv) [8];
                r4 = (object*) &constructed_79;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2530; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2530:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2531; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2531:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2532; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2532:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2533; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2533:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_84;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = (object*) &constructed_83;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = ((object*) lenv) [8];
                r4 = (object*) &constructed_82;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2534; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2534:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2535; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2535:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              }
            } else {
              r1 = (object *) 14;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
          } break;
          case (UOTAG(4)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2536; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2536:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_90;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_89;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2537; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2537:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2538; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2538:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2539; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2539:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2540; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
            L2540:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2541; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2541:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_88;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2542; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2542:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2543; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2543:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [4];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2544; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
            L2544:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2545; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2545:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_87;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2546; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2546:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
          } break;
          case (UOTAG(5)): {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UOTAG(1)): {
                r1 = allocate (TC_TUPLE, 3);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,1);
                r1[3] = r2;
                r1 = (object *) constructed_97[0];
                r2 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 6);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r2 = allocate (TC_TUPLE, 3);
                      // def lambda_29892_i3328_i4806_i4853
                      goto L2547;
                      FUN_lambda_29892_i3328_i4806_i4853:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = ((object**) lenv) [1][2];
                        r2[2] = r3;
                        r3 = top[58];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2548; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
                        L2548:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = ((object*) lenv) [4];
                        r2 = (object*) &constructed_95;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r0[2] = r1;
                        r1 = top[49];
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                      L2547:
                      r3 = allocate (TC_CLOSURE, 2);
                      r3[1] = &&FUN_lambda_29892_i3328_i4806_i4853; r3[2] = lenv;
                      r2[2] = r3;
                      r3 = ((object***) lenv) [1][1][2];
                      r2[3] = r3;
                      r3 = top[34];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2549; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_map_328;
                      L2549:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[4] = r2;
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = top[151];
                      r2[2] = r3;
                      r3 = ((object*) lenv) [3];
                      r2[3] = r3;
                      r3 = ((object*) lenv) [4];
                      r2[4] = r3;
                      r3 = top[35];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2550; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_map2_329;
                      L2550:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[5] = r2;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = ((object*) lenv) [2];
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = ((object***) lenv) [1][1][4];
                      r3[2] = r4;
                      r4 = ((object*) lenv) [5];
                      r3[3] = r4;
                      r4 = top[154];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2551; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_cexp_subst_565;
                      L2551:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = top[153];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2552; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_564;
                      L2552:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[6] = r2;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = allocate (TC_TUPLE, 4);
                      r3[1] = lenv; lenv = r3;
                      r4 = (object*)TC_NIL;
                      r3[2] = r4;
                      r4 = ((object*) lenv) [2];
                      r5 = (object*) &constructed_94;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r5;
                      t[2] = r4;
                      r4 = t;
                      r3[3] = r4;
                      r4 = ((object*) lenv) [3];
                      r5 = ((object**) lenv) [1][6];
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r5;
                      t[2] = r4;
                      r4 = t;
                      r3[4] = r4;
                      r3 = ((object*) lenv) [4];
                      r4 = (object*) &constructed_93;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      lenv = lenv[1];
                      r2[2] = r3;
                      r3 = top[49];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2553; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                      L2553:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2554; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2554:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2555; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2555:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object***) lenv) [1][1][5];
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2556; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
                      L2556:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2557; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2557:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_92;
                      r1[2] = r2;
                      r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2558; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2558:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2559; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2559:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object***) lenv) [1][1][6];
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2560; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
                      L2560:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2561; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2561:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_91;
                      r1[2] = r2;
                      r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2562; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2562:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_6;
                    }
                  }
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_6;
                }
                lenv = lenv[1];
              } break;
              default: {
                goto fatbar_6;
              }
            }
            goto fatbar_6_over;
            fatbar_6:
            r1 = (object*) &constructed_68;
            r1 = box((pxll_int)((pxll_string*)(r1))->len);
            r2 = (object*) &constructed_68;
            (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
            r1 = (object*) &constructed_67;
            dump_object (r1, 0); fprintf (stdout, "\n");
            r1 = (object*) &constructed_67;
            PXLL_UNDEFINED; result=r1; goto Lreturn;
            fatbar_6_over: ;
            r1 = ((object*) lenv) [7];
            lenv = lenv[1];
          } break;
          case (UOTAG(6)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object*) lenv) [2];
            r1[2] = r2;
            r2 = ((object*) lenv) [3];
            r1[3] = r2;
            r2 = ((object****) lenv) [1][1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2563; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_move_4295_i4806_i4853;
            L2563:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
          } break;
          case (UOTAG(3)): {
            r1 = allocate (TC_TUPLE, 6);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][6];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2564; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2564:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            switch (get_case (r2)) {
              case (UOTAG(1)): {
                r2 = allocate (TC_TUPLE, 3);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,1);
                r2[3] = r3;
                r2 = (object *) constructed_97[0];
                r3 = ((object*) lenv) [2];
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = ((object*) lenv) [3];
                  switch (get_case (r2)) {
                    case (TC_PAIR): {
                      r2 = allocate (TC_TUPLE, 5);
                      r2[1] = lenv; lenv = r2;
                      r3 = ((object**) lenv) [1][3];
                      r3 = UOBJ_GET(r3,0);
                      r2[2] = r3;
                      r3 = ((object**) lenv) [1][3];
                      r3 = UOBJ_GET(r3,1);
                      r2[3] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      // def lambda_30003_i3340_i4806_i4853
                      goto L2565;
                      FUN_lambda_30003_i3340_i4806_i4853:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = ((object**) lenv) [1][2];
                        r2[2] = r3;
                        r3 = top[58];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2566; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
                        L2566:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = ((object*) lenv) [3];
                        r3 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = ((object*) lenv) [4];
                        r2 = (object*) &constructed_102;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r0[2] = r1;
                        r1 = top[49];
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
                      L2565:
                      r4 = allocate (TC_CLOSURE, 2);
                      r4[1] = &&FUN_lambda_30003_i3340_i4806_i4853; r4[2] = lenv;
                      r3[2] = r4;
                      r4 = ((object****) lenv) [1][1][1][5];
                      r3[3] = r4;
                      r4 = top[34];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2567; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_map_328;
                      L2567:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[4] = r3;
                      r3 = allocate (TC_TUPLE, 4);
                      r4 = top[151];
                      r3[2] = r4;
                      r4 = ((object*) lenv) [3];
                      r3[3] = r4;
                      r4 = ((object*) lenv) [4];
                      r3[4] = r4;
                      r4 = top[35];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2568; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_map2_329;
                      L2568:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[5] = r3;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = ((object****) lenv) [1][1][1][3];
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = ((object****) lenv) [1][1][1][4];
                      r3[2] = r4;
                      r4 = ((object*) lenv) [5];
                      r3[3] = r4;
                      r4 = top[154];
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2569; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_cexp_subst_565;
                      L2569:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = top[153];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2570; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_564;
                      L2570:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_7;
                    }
                  }
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_7;
                }
                lenv = lenv[1];
              } break;
              default: {
                goto fatbar_7;
              }
            }
            goto fatbar_7_over;
            fatbar_7:
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object**) lenv) [1][4];
            r2[3] = r3;
            r3 = top[153];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2571; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_564;
            L2571:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            fatbar_7_over: ;
            r1[3] = r2;
            r1 = (object *) -1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 3);
              r3[1] = lenv; lenv = r3;
              r4 = (object*)TC_NIL;
              r3[2] = r4;
              r4 = ((object*) lenv) [2];
              r5 = (object*) &constructed_98;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[3] = r4;
              r3 = ((object*) lenv) [3];
              r4 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2572; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2572:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2573; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2573:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 7);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2574; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2574:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_101;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = (object*) &constructed_100;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r3 = ((object*) lenv) [7];
              r4 = (object*) &constructed_99;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2575; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2575:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2576; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2576:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [6];
            lenv = lenv[1];
          } break;
          case (UOTAG(7)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2577; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2577:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][2];
            r2[2] = r3;
            r3 = ((object*****) lenv) [1][1][1][1][4];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2578; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_gen_function_label_4302_i4806_i4853;
            L2578:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = top[205];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2579; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L2579:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = ((object***) lenv) [1][1][2];
            r4 = allocate (TC_TUPLE, 2);
            r4[1] = lenv; lenv = r4;
            r5 = ((object****) lenv) [1][1][1][2];
            r5 = UOBJ_GET(r5,0);
            r4[2] = r5;
            r4 = ((object*) lenv) [2];
            lenv = lenv[1];
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = ((object*) lenv) [4];
            r4 = (object*) &constructed_116;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2580; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2580:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2581; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2581:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_115;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = ((object**) lenv) [1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = ((object*) lenv) [4];
            r4 = (object*) &constructed_114;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2582; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2582:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2583; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2583:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_113;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = ((object*) lenv) [3];
            r4 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2584; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2584:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2585; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2585:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2586; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2586:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r1 = ((pxll_vector*)r1)->val[10];
            r1 = ((pxll_vector*)r1)->val[4];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 4);
              r3[1] = lenv; lenv = r3;
              r4 = (object*)TC_NIL;
              r3[2] = r4;
              r4 = ((object*) lenv) [2];
              r5 = (object*) &constructed_112;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r3 = ((object*) lenv) [4];
              r4 = (object*) &constructed_111;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2587; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2587:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2588; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2588:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
            r2[2] = r3;
            r3 = ((object***) lenv) [1][1][2];
            r2[3] = r3;
            r3 = top[5];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2589; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_vars_get_var_247;
            L2589:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,74)];
            r1[3] = r2;
            r1 = top[159];
            r2 = ((object*) lenv) [3];
            r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
            lenv = lenv[1];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = (object*) &constructed_110;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2590; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2590:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][3];
            r1[2] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2591; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
            L2591:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2592; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2592:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_109;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = ((object*) lenv) [3];
            r4 = ((object**) lenv) [1][4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2593; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2593:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2594; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2594:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2595; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2595:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_108;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_107;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2596; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2596:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2597; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2597:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 10);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2598; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2598:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2599; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2599:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = (object*) &constructed_106;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = (object*) &constructed_105;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r4 = ((object*) lenv) [8];
            r5 = (object*) &constructed_104;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[9] = r4;
            r4 = ((object*) lenv) [9];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[10] = r4;
            r3 = ((object*) lenv) [10];
            r4 = (object*) &constructed_103;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2600; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2600:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2601; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2601:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
          } break;
          case (UOTAG(8)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2602; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2602:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) -1;
              r3 = ((object***) lenv) [1][1][2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object****) lenv) [1][1][1][3];
                r6 = (object *) 5;
                r5 = box((pxll_int)unbox(r6)+unbox(r5));
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2603; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2603:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_120;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_119;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2604; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2604:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
              } else {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 11);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = allocate (TC_TUPLE, 3);
                r6 = ((object****) lenv) [1][1][1][2];
                r5[2] = r6;
                r6 = (object*) &constructed_126;
                r5[3] = r6;
                r6 = top[33];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L2605; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
                L2605:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[49];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2606; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
                L2606:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = allocate (TC_TUPLE, 3);
                r6 = ((object****) lenv) [1][1][1][2];
                r5[2] = r6;
                r6 = (object*) &constructed_125;
                r5[3] = r6;
                r6 = top[33];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L2607; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
                L2607:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[49];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2608; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
                L2608:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = (object *) 5;
                r6 = ((object****) lenv) [1][1][1][3];
                r5 = box((pxll_int)unbox(r6)+unbox(r5));
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2609; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2609:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[4] = r4;
                r4 = (object*)TC_NIL;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = (object*) &constructed_124;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = ((object*) lenv) [4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = (object*) &constructed_123;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r4 = ((object*) lenv) [8];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[9] = r4;
                r4 = ((object*) lenv) [9];
                r5 = (object*) &constructed_122;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[10] = r4;
                r4 = ((object*) lenv) [10];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[11] = r4;
                r3 = ((object*) lenv) [11];
                r4 = (object*) &constructed_121;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2610; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2610:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
              }
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][2];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2611; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2611:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_118;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_117;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2612; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2612:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2613; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2613:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
            } else {
              r1 = (object *) 14;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
          } break;
          case (UOTAG(9)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = (object *) -1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][3];
              r6 = (object *) 5;
              r5 = box((pxll_int)unbox(r6)+unbox(r5));
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2614; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2614:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][4];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2615; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2615:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_129;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_128;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_127;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2616; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2616:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2617; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2617:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 14);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][2];
              r5[2] = r6;
              r6 = (object*) &constructed_136;
              r5[3] = r6;
              r6 = top[33];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2618; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
              L2618:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[49];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2619; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
              L2619:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][2];
              r5[2] = r6;
              r6 = (object*) &constructed_135;
              r5[3] = r6;
              r6 = top[33];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2620; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
              L2620:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[49];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2621; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
              L2621:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = (object *) 5;
              r6 = ((object**) lenv) [1][3];
              r5 = box((pxll_int)unbox(r6)+unbox(r5));
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2622; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2622:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][4];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2623; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2623:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[5] = r4;
              r4 = (object*)TC_NIL;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_134;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [5];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_133;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = ((object*) lenv) [10];
              r5 = (object*) &constructed_132;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = ((object*) lenv) [11];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r4 = ((object*) lenv) [12];
              r5 = (object*) &constructed_131;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[13] = r4;
              r4 = ((object*) lenv) [13];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[14] = r4;
              r3 = ((object*) lenv) [14];
              r4 = (object*) &constructed_130;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2624; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2624:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2625; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2625:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            }
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
          } break;
          case (UOTAG(10)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2626; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2626:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 8);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2627; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2627:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = (object *) 3;
            r6 = ((object***) lenv) [1][1][2];
            r5 = box((pxll_int)unbox(r6)+unbox(r5));
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2628; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2628:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = (object*) &constructed_141;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = (object*) &constructed_140;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r3 = ((object*) lenv) [8];
            r4 = (object*) &constructed_139;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2629; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2629:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2630; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2630:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object**) lenv) [1][3];
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 5);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2631; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2631:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_138;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r3 = ((object*) lenv) [5];
              r4 = (object*) &constructed_137;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2632; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2632:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2633; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2633:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
          } break;
          case (UOTAG(11)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2634; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2634:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object**) lenv) [1][2];
            switch (get_case (r2)) {
              case (UOTAG(0)): {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object*) lenv) [2];
                r2[2] = r3;
                r3 = top[58];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2635; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
                L2635:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 6);
                r3[1] = lenv; lenv = r3;
                r4 = (object *) 1;
                r5 = ((object****) lenv) [1][1][1][3];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r5)==unbox(r4))) {
                  r4 = (object*) &constructed_150;
                } else {
                  r4 = (object*) &constructed_151;
                }
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2636; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2636:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_149;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r3 = ((object*) lenv) [6];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2637; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2637:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
              } break;
            }
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = ((object**) lenv) [1][3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 7);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2638; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2638:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_144;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = (object*) &constructed_143;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r3 = ((object*) lenv) [7];
              r4 = (object*) &constructed_142;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2639; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2639:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2640; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2640:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 10);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][2];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2641; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2641:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2642; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2642:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_148;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_147;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object**) lenv) [1][3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_146;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r3 = ((object*) lenv) [10];
              r4 = (object*) &constructed_145;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2643; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2643:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2644; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2644:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
          } break;
          case (UOTAG(12)): {
            r1 = allocate (TC_TUPLE, 6);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 11);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][4];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2645; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2645:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = allocate (TC_TUPLE, 2);
            r5[1] = lenv; lenv = r5;
            r6 = ((object***) lenv) [1][1][2];
            r7 = ((object***) lenv) [1][1][5];
            r6 = box((pxll_int)unbox(r7)+unbox(r6));
            r5[2] = r6;
            r5 = ((object*) lenv) [2];
            r6 = (object *) 3;
            r5 = box((pxll_int)unbox(r6)+unbox(r5));
            lenv = lenv[1];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2646; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2646:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2647; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2647:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[4] = r4;
            r4 = (object*)TC_NIL;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = (object*) &constructed_155;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = ((object*) lenv) [4];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = (object*) &constructed_154;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r4 = ((object*) lenv) [8];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[9] = r4;
            r4 = ((object*) lenv) [9];
            r5 = (object*) &constructed_153;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[10] = r4;
            r4 = ((object*) lenv) [10];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[11] = r4;
            r3 = ((object*) lenv) [11];
            r4 = (object*) &constructed_152;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2648; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2648:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2649; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2649:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [6];
            lenv = lenv[1];
          } break;
          case (UOTAG(13)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = top[12];
            r2[2] = r3;
            r3 = allocate (TC_TUPLE, 2);
            r4 = ((object**) lenv) [1][5];
            r3[2] = r4;
            r4 = top[139];
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L2650; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_525;
            L2650:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[3] = r3;
            r3 = top[46];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2651; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_sort_342;
            L2651:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = top[205];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2652; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L2652:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object*) lenv) [2];
            r2[2] = r3;
            r3 = top[24];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2653; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
            L2653:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][5];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2654; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2654:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][4];
            r6 = (object *) 7;
            r5 = box((pxll_int)unbox(r6)+unbox(r5));
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2655; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2655:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_181;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_180;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2656; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2656:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2657; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2657:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_4494_i3473_i4806_i4853
            goto L2658;
            FUN__24loop_4494_i3473_i4806_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [3];
                r0[2] = r1;
                r1 = (object *) constructed_36[0];
                r0[3] = r1;
                r1 = top[23];
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 7);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = (object *) 9;
                r5 = ((object***) lenv) [1][1][2];
                r4 = box((pxll_int)unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = top[58];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2659; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                L2659:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = ((object******) lenv) [1][1][1][1][1][2];
                r4[2] = r5;
                r5 = ((object***) lenv) [1][1][2];
                r4[3] = r5;
                r5 = top[29];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2660; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_323;
                L2660:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = top[58];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2661; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                L2661:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_179;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = ((object*) lenv) [6];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r2 = ((object*) lenv) [7];
                r3 = (object*) &constructed_178;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r1[2] = r2;
                r2 = top[49];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2662; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                L2662:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object**) lenv) [1][3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_4494_i3473_i4806_i4853;
              }
              PXLL_RETURN(0);
            L2658:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_4494_i3473_i4806_i4853; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2663; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_4494_i3473_i4806_i4853;
            L2663:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 7);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 3);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = (object*) &constructed_177;
            r4[3] = r5;
            r5 = top[50];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2664; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_string_join_355;
            L2664:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_176;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = (object*) &constructed_175;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = ((object***) lenv) [1][1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r3 = ((object*) lenv) [7];
            r4 = (object*) &constructed_174;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2665; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2665:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2666; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2666:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            switch (get_case (r2)) {
              case (UITAG(1)): {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object****) lenv) [1][1][1][3];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2667; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2667:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_171;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_170;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2668; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2668:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object****) lenv) [1][1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2669; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4302_i4806_i4853;
                L2669:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_173;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_172;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2670; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2670:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
              } break;
            }
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object***) lenv) [1][1][4];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 12);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][4];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2671; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2671:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][3];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2672; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2672:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][4];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2673; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2673:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = (object*)TC_NIL;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_167;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_166;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = ((object*) lenv) [10];
              r5 = (object*) &constructed_165;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = ((object*) lenv) [11];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_164;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2674; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2674:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2675; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2675:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object****) lenv) [1][1][1][3];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2676; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2676:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_169;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_168;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2677; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2677:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2678; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2678:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            }
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = ((object*) lenv) [2];
            r5 = (object*) &constructed_163;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = ((object*) lenv) [3];
            r4 = ((object**) lenv) [1][3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2679; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2679:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2680; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2680:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][4];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_4501_i3473_i4806_i4853
            goto L2681;
            FUN__24loop_4501_i3473_i4806_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [3];
                r0[2] = r1;
                r1 = (object *) constructed_36[0];
                r0[3] = r1;
                r1 = top[23];
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_313;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 8);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = ((object******) lenv) [1][1][1][1][1][2];
                r4[2] = r5;
                r5 = ((object***) lenv) [1][1][2];
                r4[3] = r5;
                r5 = top[29];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2682; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_323;
                L2682:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = top[58];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2683; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                L2683:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = (object *) 9;
                r5 = ((object***) lenv) [1][1][2];
                r4 = box((pxll_int)unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = top[58];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2684; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                L2684:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_162;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = ((object*) lenv) [6];
                r4 = (object*) &constructed_161;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r3 = ((object*) lenv) [7];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[8] = r3;
                r2 = ((object*) lenv) [8];
                r3 = (object*) &constructed_160;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r1[2] = r2;
                r2 = top[49];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2685; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                L2685:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = ((object**) lenv) [1][3];
                r1 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = box((pxll_int)unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_4501_i3473_i4806_i4853;
              }
              PXLL_RETURN(0);
            L2681:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_4501_i3473_i4806_i4853; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2686; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_4501_i3473_i4806_i4853;
            L2686:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 3);
            r5 = ((object**) lenv) [1][3];
            r4[2] = r5;
            r5 = (object*) &constructed_159;
            r4[3] = r5;
            r5 = top[50];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2687; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_string_join_355;
            L2687:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_158;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = ((object*) lenv) [4];
            r4 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2688; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2688:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2689; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2689:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = (object *) 1;
            r2 = ((object*) lenv) [5];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 5);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object**) lenv) [1][5];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2690; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2690:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_157;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r3 = ((object*) lenv) [5];
              r4 = (object*) &constructed_156;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2691; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2691:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2692; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2692:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
          } break;
          case (UOTAG(14)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            switch (get_case (r2)) {
              case (UITAG(1)): {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][3];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2693; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2693:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_189;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_188;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2694; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2694:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = ((object***) lenv) [1][1][2];
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = ((object*******) lenv) [1][1][1][1][1][1][4];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2695; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4302_i4806_i4853;
                L2695:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = ((object*) lenv) [3];
                r5 = (object*) &constructed_191;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = ((object*) lenv) [5];
                r4 = (object*) &constructed_190;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2696; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2696:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
              } break;
            }
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object**) lenv) [1][4];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 12);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][4];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2697; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2697:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2698; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2698:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][4];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2699; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2699:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = (object*)TC_NIL;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_185;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [4];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = ((object*) lenv) [8];
              r5 = (object*) &constructed_184;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = ((object*) lenv) [9];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = ((object*) lenv) [10];
              r5 = (object*) &constructed_183;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = ((object*) lenv) [11];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r3 = ((object*) lenv) [12];
              r4 = (object*) &constructed_182;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2700; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2700:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2701; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2701:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2702; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2702:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = ((object**) lenv) [1][2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_187;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_186;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2703; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2703:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2704; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2704:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            }
            lenv = lenv[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
          } break;
          case (UOTAG(15)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[24];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2705; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
            L2705:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = (object *) 3;
            r3 = ((object**) lenv) [1][2];
            r2 = box((pxll_int)unbox(r3)-unbox(r2));
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = (object *) 3;
              r2 = ((object*) lenv) [3];
              r1 = box((pxll_int)unbox(r2)+unbox(r1));
              ((object*) lenv) [3] = r1;
            } else {
              r1 = (object *) 14;
            }
            r1 = (object *) 1;
            r2 = ((object*) lenv) [3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_201;
              r5[3] = r6;
              r6 = top[33];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2706; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
              L2706:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[49];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2707; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
              L2707:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_200;
              r5[3] = r6;
              r6 = top[33];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2708; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
              L2708:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[49];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2709; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
              L2709:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_199;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_198;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_197;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2710; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2710:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2711; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2711:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4511_i3567_i4806_i4853
            goto L2712;
            FUN__24loop_4511_i3567_i4806_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 8);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = ((object**) lenv) [1][2];
                r5 = (object *) 5;
                r4 = box((pxll_int)unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = top[58];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2713; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                L2713:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = ((object******) lenv) [1][1][1][1][1][4];
                r4[2] = r5;
                r5 = ((object**) lenv) [1][2];
                r4[3] = r5;
                r5 = top[29];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2714; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_323;
                L2714:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = top[58];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2715; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                L2715:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_196;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = ((object*) lenv) [6];
                r4 = (object*) &constructed_195;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r3 = ((object*) lenv) [7];
                r4 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[8] = r3;
                r2 = ((object*) lenv) [8];
                r3 = (object*) &constructed_194;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r1[2] = r2;
                r2 = top[49];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2716; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                L2716:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2717; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2717:
                ; lenv = k[2]; k = k[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4511_i3567_i4806_i4853;
              }
              PXLL_RETURN(0);
            L2712:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4511_i3567_i4806_i4853; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2718; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4511_i3567_i4806_i4853;
            L2718:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object***) lenv) [1][1][3];
            r4[2] = r5;
            r5 = ((object******) lenv) [1][1][1][1][1][4];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2719; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4302_i4806_i4853;
            L2719:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_193;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_192;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2720; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2720:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2721; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2721:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
          } break;
          case (UOTAG(16)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 8);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2722; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2722:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2723; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2723:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = (object*) &constructed_204;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = ((object*) lenv) [5];
            r5 = ((object*) lenv) [3];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = ((object*) lenv) [6];
            r5 = (object*) &constructed_203;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = ((object*) lenv) [7];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r3 = ((object*) lenv) [8];
            r4 = (object*) &constructed_202;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2724; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2724:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2725; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2725:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [3];
            lenv = lenv[1];
          } break;
          case (UOTAG(17)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][3];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2726; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2726:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_205;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2727; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2727:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            r1[3] = r2;
            r2 = ((object*****) lenv) [1][1][1][1][3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2728; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_move_4295_i4806_i4853;
            L2728:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = ((object*) lenv) [3];
            lenv = lenv[1];
          } break;
          case (UOTAG(18)): {
            r1 = allocate (TC_TUPLE, 6);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def primop-error_4540_i3600_i4806_i4853
            goto L2729;
            FUN_primop_error_4540_i3600_i4806_i4853:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_208;
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r0[3] = r1;
              r1 = top[15];
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_294;
            L2729:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_primop_error_4540_i3600_i4806_i4853; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object***) lenv) [1][1][6];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2730; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2730:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object***) lenv) [1][1][5];
            r2[2] = r3;
            r3 = top[24];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2731; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
            L2731:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = (object *) constructed_210[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2732; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2732:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = (object*)TC_NIL;
                          r3[3] = r4;
                          r4 = ((object*) lenv) [3];
                          r5 = (object*) &constructed_207;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = ((object*) lenv) [5];
                          r4 = (object*) &constructed_206;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2733; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2733:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2734; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2734:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = ((object*) lenv) [2];
                          r1[2] = r2;
                          r2 = ((object***) lenv) [1][1][2];
                          r1[3] = r2;
                          r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2735; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_move_4295_i4806_i4853;
                          L2735:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_9;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_9;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_9;
                }
              }
              goto fatbar_9_over;
              fatbar_9:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2736; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2736:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_9_over: ;
            } else {
              goto fatbar_8;
            }
            goto fatbar_8_over;
            fatbar_8:
            r1 = (object *) constructed_214[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_NIL): {
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = allocate (TC_TUPLE, 5);
                  r3[1] = lenv; lenv = r3;
                  r4 = allocate (TC_TUPLE, 2);
                  r5 = ((object**) lenv) [1][2];
                  r4[2] = r5;
                  r5 = top[58];
                  t = allocate (TC_SAVE, 7);
                  t[1] = k; t[2] = lenv; t[3] = &&L2737; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                  L2737:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                  r4 = result;
                  r3[2] = r4;
                  r4 = (object*)TC_NIL;
                  r3[3] = r4;
                  r4 = ((object*) lenv) [3];
                  r5 = (object*) &constructed_212;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[4] = r4;
                  r4 = ((object*) lenv) [4];
                  r5 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[5] = r4;
                  r3 = ((object*) lenv) [5];
                  r4 = (object*) &constructed_211;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r4;
                  t[2] = r3;
                  r3 = t;
                  lenv = lenv[1];
                  r2[2] = r3;
                  r3 = top[49];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2738; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                  L2738:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                  r2 = ((pxll_vector*)r2)->val[4];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2739; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L2739:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                } break;
                default: {
                  goto fatbar_11;
                }
              }
              goto fatbar_11_over;
              fatbar_11:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2740; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2740:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_11_over: ;
            } else {
              goto fatbar_10;
            }
            goto fatbar_10_over;
            fatbar_10:
            r1 = (object *) constructed_230[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [3];
                          switch (get_case (r1)) {
                            case (TC_NIL): {
                              r1 = ((object******) lenv) [1][1][1][1][1][4];
                              switch (get_case (r1)) {
                                case (UOTAG(1)): {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r2 = ((object*******) lenv) [1][1][1][1][1][1][4];
                                  r2 = UOBJ_GET(r2,1);
                                  r1[3] = r2;
                                  r1 = (object *) constructed_97[0];
                                  r2 = ((object*) lenv) [2];
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = ((object*) lenv) [3];
                                    switch (get_case (r1)) {
                                      case (TC_PAIR): {
                                        r1 = allocate (TC_TUPLE, 3);
                                        r1[1] = lenv; lenv = r1;
                                        r2 = ((object**) lenv) [1][3];
                                        r2 = UOBJ_GET(r2,0);
                                        r1[2] = r2;
                                        r2 = ((object**) lenv) [1][3];
                                        r2 = UOBJ_GET(r2,1);
                                        r1[3] = r2;
                                        r1 = ((object*) lenv) [3];
                                        switch (get_case (r1)) {
                                          case (TC_PAIR): {
                                            r1 = allocate (TC_TUPLE, 3);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = ((object**) lenv) [1][3];
                                            r2 = UOBJ_GET(r2,0);
                                            r1[2] = r2;
                                            r2 = ((object**) lenv) [1][3];
                                            r2 = UOBJ_GET(r2,1);
                                            r1[3] = r2;
                                            r1 = ((object*) lenv) [3];
                                            switch (get_case (r1)) {
                                              case (TC_NIL): {
                                                r1 = allocate (TC_TUPLE, 4);
                                                r1[1] = lenv; lenv = r1;
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = allocate (TC_TUPLE, 4);
                                                r3[1] = lenv; lenv = r3;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object******) lenv) [1][1][1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[58];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2741; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                L2741:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[2] = r4;
                                                r4 = (object*)TC_NIL;
                                                r3[3] = r4;
                                                r4 = ((object*) lenv) [3];
                                                r5 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[4] = r4;
                                                r3 = ((object*) lenv) [4];
                                                r4 = (object*) &constructed_228;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                lenv = lenv[1];
                                                r2[2] = r3;
                                                r3 = top[49];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2742; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                L2742:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[2] = r2;
                                                r2 = ((object***) lenv) [1][1][2];
                                                switch (get_case (r2)) {
                                                  case (UOTAG(1)): {
                                                    r2 = allocate (TC_TUPLE, 2);
                                                    r2[1] = lenv; lenv = r2;
                                                    r3 = ((object****) lenv) [1][1][1][2];
                                                    r3 = UOBJ_GET(r3,0);
                                                    r2[2] = r3;
                                                    r2 = ((object***) lenv) [1][1][2];
                                                    switch (get_case (r2)) {
                                                      case (UOTAG(1)): {
                                                        r2 = allocate (TC_TUPLE, 2);
                                                        r2[1] = lenv; lenv = r2;
                                                        r3 = ((object****) lenv) [1][1][1][2];
                                                        r3 = UOBJ_GET(r3,0);
                                                        r2[2] = r3;
                                                        r2 = (object *) constructed_226[0];
                                                        r3 = ((object*) lenv) [2];
                                                        if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                                                          r2 = allocate (TC_TUPLE, 3);
                                                          r3 = ((object**) lenv) [1][2];
                                                          r2[2] = r3;
                                                          r3 = top[206];
                                                          r2[3] = r3;
                                                          r3 = top[27];
                                                          t = allocate (TC_SAVE, 5);
                                                          t[1] = k; t[2] = lenv; t[3] = &&L2743; t[4] = r0; t[5] = r1; k = t;
                                                          r2[1] = r3[2]; lenv = r2; goto FUN_member_eq_question_321;
                                                          L2743:
                                                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                          r2 = result;
                                                          if PXLL_IS_TRUE(r2) {
                                                            r2 = allocate (TC_TUPLE, 2);
                                                            r3 = allocate (TC_TUPLE, 7);
                                                            r3[1] = lenv; lenv = r3;
                                                            r4 = ((object***) lenv) [1][1][2];
                                                            r4 = allocate (TC_TUPLE, 2);
                                                            r4[1] = lenv; lenv = r4;
                                                            r5 = ((object****) lenv) [1][1][1][2];
                                                            r5 = UOBJ_GET(r5,0);
                                                            r4[2] = r5;
                                                            r4 = ((object*) lenv) [2];
                                                            lenv = lenv[1];
                                                            r3[2] = r4;
                                                            r4 = (object*)TC_NIL;
                                                            r3[3] = r4;
                                                            r4 = ((object*) lenv) [3];
                                                            r5 = (object*) &constructed_223;
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[4] = r4;
                                                            r4 = ((object*) lenv) [4];
                                                            r5 = ((object****) lenv) [1][1][1][2];
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[5] = r4;
                                                            r4 = ((object*) lenv) [5];
                                                            r5 = (object*) &constructed_222;
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[6] = r4;
                                                            r4 = ((object*) lenv) [6];
                                                            r5 = ((object*) lenv) [2];
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r5;
                                                            t[2] = r4;
                                                            r4 = t;
                                                            r3[7] = r4;
                                                            r3 = ((object*) lenv) [7];
                                                            r4 = (object*) &constructed_221;
                                                            t = alloc_no_clear (TC_PAIR,2);
                                                            t[1] = r4;
                                                            t[2] = r3;
                                                            r3 = t;
                                                            lenv = lenv[1];
                                                            r2[2] = r3;
                                                            r3 = top[49];
                                                            t = allocate (TC_SAVE, 5);
                                                            t[1] = k; t[2] = lenv; t[3] = &&L2744; t[4] = r0; t[5] = r1; k = t;
                                                            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                            L2744:
                                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                            r2 = result;
                                                          } else {
                                                            r2 = allocate (TC_TUPLE, 3);
                                                            r3 = (object*) &constructed_224;
                                                            r2[2] = r3;
                                                            r3 = ((object**) lenv) [1][2];
                                                            r2[3] = r3;
                                                            r3 = top[15];
                                                            t = allocate (TC_SAVE, 5);
                                                            t[1] = k; t[2] = lenv; t[3] = &&L2745; t[4] = r0; t[5] = r1; k = t;
                                                            r2[1] = r3[2]; lenv = r2; goto FUN_error1_294;
                                                            L2745:
                                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                            r2 = result;
                                                          }
                                                        } else {
                                                          lenv = ((object **)lenv)[1][1];
                                                          goto fatbar_14;
                                                        }
                                                        lenv = lenv[1];
                                                      } break;
                                                      default: {
                                                        lenv = ((object *)lenv)[1];
                                                        goto fatbar_14;
                                                      }
                                                    }
                                                    lenv = lenv[1];
                                                  } break;
                                                  default: {
                                                    goto fatbar_14;
                                                  }
                                                }
                                                goto fatbar_14_over;
                                                fatbar_14:
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = (object*) &constructed_227;
                                                r2[2] = r3;
                                                r3 = allocate (UOTAG(1), 2);
                                                r4 = ((object***) lenv) [1][1][2];
                                                r3[1] = r4;
                                                r4 = ((object**) lenv) [1][2];
                                                r3[2] = r4;
                                                r2[3] = r3;
                                                r3 = top[15];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2746; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_error1_294;
                                                L2746:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                fatbar_14_over: ;
                                                r1[3] = r2;
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = allocate (TC_TUPLE, 11);
                                                r3[1] = lenv; lenv = r3;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object****) lenv) [1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[109];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2747; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_type_repr_464;
                                                L2747:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[2] = r4;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[58];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2748; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                L2748:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[3] = r4;
                                                r4 = allocate (TC_TUPLE, 2);
                                                r5 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                r4[2] = r5;
                                                r5 = top[58];
                                                t = allocate (TC_SAVE, 7);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2749; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                L2749:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                r4 = result;
                                                r3[4] = r4;
                                                r4 = (object*)TC_NIL;
                                                r3[5] = r4;
                                                r4 = ((object*) lenv) [5];
                                                r5 = (object*) &constructed_220;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[6] = r4;
                                                r4 = ((object*) lenv) [6];
                                                r5 = ((object*) lenv) [4];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[7] = r4;
                                                r4 = ((object*) lenv) [7];
                                                r5 = (object*) &constructed_219;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[8] = r4;
                                                r4 = ((object*) lenv) [8];
                                                r5 = ((object*) lenv) [3];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[9] = r4;
                                                r4 = ((object*) lenv) [9];
                                                r5 = (object*) &constructed_218;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[10] = r4;
                                                r4 = ((object*) lenv) [10];
                                                r5 = ((object*) lenv) [2];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[11] = r4;
                                                r3 = ((object*) lenv) [11];
                                                r4 = (object*) &constructed_217;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                lenv = lenv[1];
                                                r2[2] = r3;
                                                r3 = top[49];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2750; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                L2750:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[4] = r2;
                                                r1 = allocate (TC_TUPLE, 2);
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = allocate (TC_TUPLE, 5);
                                                r3[1] = lenv; lenv = r3;
                                                r4 = (object*)TC_NIL;
                                                r3[2] = r4;
                                                r4 = ((object*) lenv) [2];
                                                r5 = (object*) &constructed_216;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[3] = r4;
                                                r4 = ((object*) lenv) [3];
                                                r5 = ((object**) lenv) [1][3];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[4] = r4;
                                                r4 = ((object*) lenv) [4];
                                                r5 = (object*) &constructed_215;
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r5;
                                                t[2] = r4;
                                                r4 = t;
                                                r3[5] = r4;
                                                r3 = ((object*) lenv) [5];
                                                r4 = ((object**) lenv) [1][4];
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                lenv = lenv[1];
                                                r2[2] = r3;
                                                r3 = top[49];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2751; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                L2751:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[2] = r2;
                                                r2 = ((object****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                                                r2 = ((pxll_vector*)r2)->val[4];
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L2752; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                L2752:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                lenv = lenv[1];
                                              } break;
                                              default: {
                                                lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                goto fatbar_13;
                                              }
                                            }
                                            lenv = lenv[1];
                                          } break;
                                          default: {
                                            lenv = ((object *****)lenv)[1][1][1][1][1];
                                            goto fatbar_13;
                                          }
                                        }
                                        lenv = lenv[1];
                                      } break;
                                      default: {
                                        lenv = ((object ****)lenv)[1][1][1][1];
                                        goto fatbar_13;
                                      }
                                    }
                                  } else {
                                    lenv = ((object ****)lenv)[1][1][1][1];
                                    goto fatbar_13;
                                  }
                                  lenv = lenv[1];
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_13;
                                }
                              }
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_13;
                            }
                          }
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_13;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_13;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_13;
                }
              }
              goto fatbar_13_over;
              fatbar_13:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2753; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2753:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_13_over: ;
            } else {
              goto fatbar_12;
            }
            goto fatbar_12_over;
            fatbar_12:
            r1 = (object *) constructed_239[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 11);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r4[2] = r5;
                          r5 = top[109];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2754; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_type_repr_464;
                          L2754:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2755; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2755:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2756; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2756:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = (object*)TC_NIL;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = (object*) &constructed_237;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = ((object*) lenv) [4];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = (object*) &constructed_236;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r4 = ((object*) lenv) [8];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[9] = r4;
                          r4 = ((object*) lenv) [9];
                          r5 = (object*) &constructed_235;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[10] = r4;
                          r4 = ((object*) lenv) [10];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[11] = r4;
                          r3 = ((object*) lenv) [11];
                          r4 = (object*) &constructed_234;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2757; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2757:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object*****) lenv) [1][1][1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2758; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2758:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = ((object*******) lenv) [1][1][1][1][1][1][4];
                          r4[2] = r5;
                          r5 = ((object**) lenv) [1][2];
                          r4[3] = r5;
                          r5 = top[153];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2759; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_wrap_out_564;
                          L2759:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_233;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_232;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_231;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2760; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2760:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2761; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2761:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_16;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_16;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_16;
                }
              }
              goto fatbar_16_over;
              fatbar_16:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2762; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2762:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_16_over: ;
            } else {
              goto fatbar_15;
            }
            goto fatbar_15_over;
            fatbar_15:
            r1 = (object *) constructed_243[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 5);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = ((object****) lenv) [1][1][1][5];
              r5[2] = r6;
              r6 = top[21];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2763; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_car_311;
              L2763:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2764; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2764:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = ((object*) lenv) [3];
              r5 = (object*) &constructed_241;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r3 = ((object*) lenv) [5];
              r4 = (object*) &constructed_240;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2765; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2765:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2766; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2766:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              goto fatbar_17;
            }
            goto fatbar_17_over;
            fatbar_17:
            r1 = (object *) constructed_250[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object****) lenv) [1][1][1][3];
              r2[2] = r3;
              r3 = top[200];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2767; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              lenv = r3[2]; goto *r3[1];
              L2767:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = top[113];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2768; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_parse_type_splat_469;
              L2768:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = ((object**) lenv) [1][2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 11);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2769; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2769:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[152];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2770; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_irken_type__3ec_type_563;
                L2770:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = allocate (TC_TUPLE, 2);
                r6 = ((object*****) lenv) [1][1][1][1][5];
                r5[2] = r6;
                r6 = top[21];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L2771; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                r5[1] = r6[2]; lenv = r5; goto FUN_car_311;
                L2771:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2772; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2772:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[4] = r4;
                r4 = (object*)TC_NIL;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = (object*) &constructed_247;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = ((object*) lenv) [4];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = (object*) &constructed_246;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r4 = ((object*) lenv) [8];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[9] = r4;
                r4 = ((object*) lenv) [9];
                r5 = (object*) &constructed_245;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[10] = r4;
                r4 = ((object*) lenv) [10];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[11] = r4;
                r3 = ((object*) lenv) [11];
                r4 = (object*) &constructed_244;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2773; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2773:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][56];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2774; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2774:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              } else {
                r1 = allocate (TC_TUPLE, 3);
                r2 = (object*) &constructed_248;
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[15];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2775; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                L2775:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              }
              lenv = lenv[1];
            } else {
              goto fatbar_18;
            }
            goto fatbar_18_over;
            fatbar_18:
            r1 = (object *) constructed_255[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = allocate (TC_TUPLE, 2);
              r7 = ((object****) lenv) [1][1][1][6];
              r6[2] = r7;
              r7 = top[139];
              t = allocate (TC_SAVE, 9);
              t[1] = k; t[2] = lenv; t[3] = &&L2776; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; t[9] = r5; k = t;
              r6[1] = r7[2]; lenv = r6; goto FUN_k_2ffree_525;
              L2776:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; r5 = k[9]; lenv = k[2]; k = k[1];
              r6 = result;
              r5[2] = r6;
              r6 = top[24];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2777; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_length_316;
              L2777:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2778; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2778:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = ((object****) lenv) [1][1][1][5];
              r5[2] = r6;
              r6 = top[21];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2779; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_car_311;
              L2779:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2780; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2780:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_253;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_252;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_251;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2781; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2781:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2782; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2782:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              goto fatbar_19;
            }
            goto fatbar_19_over;
            fatbar_19:
            r1 = (object *) constructed_266[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [2];
                      switch (get_case (r1)) {
                        case (UOTAG(1)): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = ((object**) lenv) [1][3];
                          switch (get_case (r1)) {
                            case (TC_PAIR): {
                              r1 = allocate (TC_TUPLE, 3);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,1);
                              r1[3] = r2;
                              r1 = ((object*) lenv) [2];
                              switch (get_case (r1)) {
                                case (UOTAG(0)): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object**) lenv) [1][2];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r1 = ((object**) lenv) [1][3];
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = ((object*) lenv) [3];
                                          switch (get_case (r1)) {
                                            case (TC_PAIR): {
                                              r1 = allocate (TC_TUPLE, 3);
                                              r1[1] = lenv; lenv = r1;
                                              r2 = ((object**) lenv) [1][3];
                                              r2 = UOBJ_GET(r2,0);
                                              r1[2] = r2;
                                              r2 = ((object**) lenv) [1][3];
                                              r2 = UOBJ_GET(r2,1);
                                              r1[3] = r2;
                                              r1 = ((object*) lenv) [3];
                                              switch (get_case (r1)) {
                                                case (TC_NIL): {
                                                  r1 = allocate (TC_TUPLE, 3);
                                                  r1[1] = lenv; lenv = r1;
                                                  r2 = allocate (TC_TUPLE, 3);
                                                  r3 = ((object******) lenv) [1][1][1][1][1][2];
                                                  r2[2] = r3;
                                                  r3 = ((object*****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                                  r2[3] = r3;
                                                  r3 = top[9];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2783; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_lookup_label_code_254;
                                                  L2783:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = ((object****) lenv) [1][1][1][2];
                                                  r2[2] = r3;
                                                  r3 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][5];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2784; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_guess_record_type_4315_i4806_i4853;
                                                  L2784:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[3] = r2;
                                                  r1 = ((object*) lenv) [3];
                                                  switch (get_case (r1)) {
                                                    case (UOTAG(0)): {
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r1[1] = lenv; lenv = r1;
                                                      r2 = ((object**) lenv) [1][3];
                                                      r2 = UOBJ_GET(r2,0);
                                                      r1[2] = r2;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = allocate (TC_TUPLE, 2);
                                                      r3 = allocate (TC_TUPLE, 11);
                                                      r3[1] = lenv; lenv = r3;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object*****) lenv) [1][1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[58];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2785; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                      L2785:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[2] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = allocate (TC_TUPLE, 3);
                                                      r6 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                                      r5[2] = r6;
                                                      r6 = ((object**) lenv) [1][2];
                                                      r5[3] = r6;
                                                      r6 = top[30];
                                                      t = allocate (TC_SAVE, 8);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2786; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                                      r5[1] = r6[2]; lenv = r5; goto FUN_index_eq_324;
                                                      L2786:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                                      r5 = result;
                                                      r4[2] = r5;
                                                      r5 = top[58];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2787; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                      L2787:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[3] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object****) lenv) [1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[58];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2788; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                      L2788:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[4] = r4;
                                                      r4 = (object*)TC_NIL;
                                                      r3[5] = r4;
                                                      r4 = ((object*) lenv) [5];
                                                      r5 = (object*) &constructed_259;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[6] = r4;
                                                      r4 = ((object*) lenv) [6];
                                                      r5 = ((object*) lenv) [4];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[7] = r4;
                                                      r4 = ((object*) lenv) [7];
                                                      r5 = (object*) &constructed_258;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[8] = r4;
                                                      r4 = ((object*) lenv) [8];
                                                      r5 = ((object*) lenv) [3];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[9] = r4;
                                                      r4 = ((object*) lenv) [9];
                                                      r5 = (object*) &constructed_257;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[10] = r4;
                                                      r4 = ((object*) lenv) [10];
                                                      r5 = ((object*) lenv) [2];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[11] = r4;
                                                      r3 = ((object*) lenv) [11];
                                                      r4 = (object*) &constructed_256;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r4;
                                                      t[2] = r3;
                                                      r3 = t;
                                                      lenv = lenv[1];
                                                      r2[2] = r3;
                                                      r3 = top[49];
                                                      t = allocate (TC_SAVE, 5);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2789; t[4] = r0; t[5] = r1; k = t;
                                                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                      L2789:
                                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                      r2 = result;
                                                      r1[2] = r2;
                                                      r2 = ((object******************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                                                      r2 = ((pxll_vector*)r2)->val[4];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2790; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                      L2790:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      lenv = lenv[1];
                                                    } break;
                                                    default: {
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = allocate (TC_TUPLE, 2);
                                                      r3 = allocate (TC_TUPLE, 14);
                                                      r3[1] = lenv; lenv = r3;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object****) lenv) [1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[58];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2791; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                      L2791:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[2] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object****) lenv) [1][1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[58];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2792; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                      L2792:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[3] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object**) lenv) [1][2];
                                                      r4[2] = r5;
                                                      r5 = top[58];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2793; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                      L2793:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[4] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = ((object***) lenv) [1][1][2];
                                                      r4[2] = r5;
                                                      r5 = top[58];
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2794; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                      L2794:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[5] = r4;
                                                      r4 = (object*)TC_NIL;
                                                      r3[6] = r4;
                                                      r4 = ((object*) lenv) [6];
                                                      r5 = (object*) &constructed_264;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[7] = r4;
                                                      r4 = ((object*) lenv) [7];
                                                      r5 = ((object*) lenv) [5];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[8] = r4;
                                                      r4 = ((object*) lenv) [8];
                                                      r5 = (object*) &constructed_263;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[9] = r4;
                                                      r4 = ((object*) lenv) [9];
                                                      r5 = ((object*) lenv) [4];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[10] = r4;
                                                      r4 = ((object*) lenv) [10];
                                                      r5 = (object*) &constructed_262;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[11] = r4;
                                                      r4 = ((object*) lenv) [11];
                                                      r5 = ((object*) lenv) [3];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[12] = r4;
                                                      r4 = ((object*) lenv) [12];
                                                      r5 = (object*) &constructed_261;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[13] = r4;
                                                      r4 = ((object*) lenv) [13];
                                                      r5 = ((object*) lenv) [2];
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[14] = r4;
                                                      r3 = ((object*) lenv) [14];
                                                      r4 = (object*) &constructed_260;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r4;
                                                      t[2] = r3;
                                                      r3 = t;
                                                      lenv = lenv[1];
                                                      r2[2] = r3;
                                                      r3 = top[49];
                                                      t = allocate (TC_SAVE, 5);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2795; t[4] = r0; t[5] = r1; k = t;
                                                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                      L2795:
                                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                      r2 = result;
                                                      r1[2] = r2;
                                                      r2 = ((object*****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                                                      r2 = ((pxll_vector*)r2)->val[4];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2796; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                      L2796:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                    } break;
                                                  }
                                                  lenv = lenv[1];
                                                } break;
                                                default: {
                                                  lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                  goto fatbar_21;
                                                }
                                              }
                                              lenv = lenv[1];
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_21;
                                            }
                                          }
                                          lenv = lenv[1];
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_21;
                                        }
                                      }
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_21;
                                    }
                                  }
                                  lenv = lenv[1];
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_21;
                                }
                              }
                              lenv = lenv[1];
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_21;
                            }
                          }
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_21;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_21;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_21;
                }
              }
              goto fatbar_21_over;
              fatbar_21:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2797; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2797:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_21_over: ;
            } else {
              goto fatbar_20;
            }
            goto fatbar_20_over;
            fatbar_20:
            r1 = (object *) constructed_277[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [2];
                      switch (get_case (r1)) {
                        case (UOTAG(1)): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = ((object**) lenv) [1][3];
                          switch (get_case (r1)) {
                            case (TC_PAIR): {
                              r1 = allocate (TC_TUPLE, 3);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r2 = ((object***) lenv) [1][1][3];
                              r2 = UOBJ_GET(r2,1);
                              r1[3] = r2;
                              r1 = ((object*) lenv) [2];
                              switch (get_case (r1)) {
                                case (UOTAG(0)): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object**) lenv) [1][2];
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r1 = ((object**) lenv) [1][3];
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = ((object*) lenv) [3];
                                          switch (get_case (r1)) {
                                            case (TC_NIL): {
                                              r1 = allocate (TC_TUPLE, 3);
                                              r1[1] = lenv; lenv = r1;
                                              r2 = allocate (TC_TUPLE, 3);
                                              r3 = ((object*****) lenv) [1][1][1][1][2];
                                              r2[2] = r3;
                                              r3 = ((object****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][2];
                                              r2[3] = r3;
                                              r3 = top[9];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2798; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_lookup_label_code_254;
                                              L2798:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[2] = r2;
                                              r2 = allocate (TC_TUPLE, 2);
                                              r3 = ((object***) lenv) [1][1][2];
                                              r2[2] = r3;
                                              r3 = ((object*************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][5];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2799; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_guess_record_type_4315_i4806_i4853;
                                              L2799:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[3] = r2;
                                              r1 = ((object*) lenv) [3];
                                              switch (get_case (r1)) {
                                                case (UOTAG(0)): {
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r1[1] = lenv; lenv = r1;
                                                  r2 = ((object**) lenv) [1][3];
                                                  r2 = UOBJ_GET(r2,0);
                                                  r1[2] = r2;
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = allocate (TC_TUPLE, 11);
                                                  r3[1] = lenv; lenv = r3;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[58];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2800; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                  L2800:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[2] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object****) lenv) [1][1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[58];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2801; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                  L2801:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[3] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = allocate (TC_TUPLE, 3);
                                                  r6 = ((object*******) lenv) [1][1][1][1][1][1][2];
                                                  r5[2] = r6;
                                                  r6 = ((object**) lenv) [1][2];
                                                  r5[3] = r6;
                                                  r6 = top[30];
                                                  t = allocate (TC_SAVE, 8);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2802; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                                  r5[1] = r6[2]; lenv = r5; goto FUN_index_eq_324;
                                                  L2802:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                                  r5 = result;
                                                  r4[2] = r5;
                                                  r5 = top[58];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2803; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                  L2803:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[4] = r4;
                                                  r4 = (object*)TC_NIL;
                                                  r3[5] = r4;
                                                  r4 = ((object*) lenv) [5];
                                                  r5 = (object*) &constructed_270;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[6] = r4;
                                                  r4 = ((object*) lenv) [6];
                                                  r5 = ((object*) lenv) [4];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[7] = r4;
                                                  r4 = ((object*) lenv) [7];
                                                  r5 = (object*) &constructed_269;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[8] = r4;
                                                  r4 = ((object*) lenv) [8];
                                                  r5 = ((object*) lenv) [3];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[9] = r4;
                                                  r4 = ((object*) lenv) [9];
                                                  r5 = (object*) &constructed_268;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[10] = r4;
                                                  r4 = ((object*) lenv) [10];
                                                  r5 = ((object*) lenv) [2];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[11] = r4;
                                                  r3 = ((object*) lenv) [11];
                                                  r4 = (object*) &constructed_267;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r4;
                                                  t[2] = r3;
                                                  r3 = t;
                                                  lenv = lenv[1];
                                                  r2[2] = r3;
                                                  r3 = top[49];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2804; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                  L2804:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = ((object*****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                                                  r2 = ((pxll_vector*)r2)->val[4];
                                                  t = allocate (TC_SAVE, 4);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2805; t[4] = r0; k = t;
                                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                  L2805:
                                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                                  r1 = result;
                                                  lenv = lenv[1];
                                                } break;
                                                default: {
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = allocate (TC_TUPLE, 14);
                                                  r3[1] = lenv; lenv = r3;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[58];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2806; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                  L2806:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[2] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object***) lenv) [1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[58];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2807; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                  L2807:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[3] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object***) lenv) [1][1][2];
                                                  r4[2] = r5;
                                                  r5 = top[58];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2808; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                  L2808:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[4] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = ((object**) lenv) [1][2];
                                                  r4[2] = r5;
                                                  r5 = top[58];
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2809; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                                  L2809:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[5] = r4;
                                                  r4 = (object*)TC_NIL;
                                                  r3[6] = r4;
                                                  r4 = ((object*) lenv) [6];
                                                  r5 = (object*) &constructed_275;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[7] = r4;
                                                  r4 = ((object*) lenv) [7];
                                                  r5 = ((object*) lenv) [5];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[8] = r4;
                                                  r4 = ((object*) lenv) [8];
                                                  r5 = (object*) &constructed_274;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[9] = r4;
                                                  r4 = ((object*) lenv) [9];
                                                  r5 = ((object*) lenv) [4];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[10] = r4;
                                                  r4 = ((object*) lenv) [10];
                                                  r5 = (object*) &constructed_273;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[11] = r4;
                                                  r4 = ((object*) lenv) [11];
                                                  r5 = ((object*) lenv) [3];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[12] = r4;
                                                  r4 = ((object*) lenv) [12];
                                                  r5 = (object*) &constructed_272;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[13] = r4;
                                                  r4 = ((object*) lenv) [13];
                                                  r5 = ((object*) lenv) [2];
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[14] = r4;
                                                  r3 = ((object*) lenv) [14];
                                                  r4 = (object*) &constructed_271;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r4;
                                                  t[2] = r3;
                                                  r3 = t;
                                                  lenv = lenv[1];
                                                  r2[2] = r3;
                                                  r3 = top[49];
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2810; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                                  L2810:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = ((object****************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                                                  r2 = ((pxll_vector*)r2)->val[4];
                                                  t = allocate (TC_SAVE, 4);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2811; t[4] = r0; k = t;
                                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                  L2811:
                                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                                  r1 = result;
                                                } break;
                                              }
                                              lenv = lenv[1];
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_23;
                                            }
                                          }
                                          lenv = lenv[1];
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_23;
                                        }
                                      }
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_23;
                                    }
                                  }
                                  lenv = lenv[1];
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_23;
                                }
                              }
                              lenv = lenv[1];
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_23;
                            }
                          }
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_23;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_23;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_23;
                }
              }
              goto fatbar_23_over;
              fatbar_23:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2812; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2812:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_23_over: ;
            } else {
              goto fatbar_22;
            }
            goto fatbar_22_over;
            fatbar_22:
            r1 = (object *) constructed_286[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][3];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [3];
                          switch (get_case (r1)) {
                            case (TC_NIL): {
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 2);
                              r3 = allocate (TC_TUPLE, 8);
                              r3[1] = lenv; lenv = r3;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object****) lenv) [1][1][1][2];
                              r4[2] = r5;
                              r5 = top[58];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2813; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                              L2813:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[2] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object***) lenv) [1][1][2];
                              r4[2] = r5;
                              r5 = top[58];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2814; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                              L2814:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[3] = r4;
                              r4 = (object*)TC_NIL;
                              r3[4] = r4;
                              r4 = ((object*) lenv) [4];
                              r5 = (object*) &constructed_284;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[5] = r4;
                              r4 = ((object*) lenv) [5];
                              r5 = ((object*) lenv) [3];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[6] = r4;
                              r4 = ((object*) lenv) [6];
                              r5 = (object*) &constructed_283;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[7] = r4;
                              r4 = ((object*) lenv) [7];
                              r5 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[8] = r4;
                              r3 = ((object*) lenv) [8];
                              r4 = (object*) &constructed_282;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              lenv = lenv[1];
                              r2[2] = r3;
                              r3 = top[49];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2815; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                              L2815:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                              r2 = ((pxll_vector*)r2)->val[4];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2816; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                              L2816:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 2);
                              r3 = allocate (TC_TUPLE, 11);
                              r3[1] = lenv; lenv = r3;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object****) lenv) [1][1][1][2];
                              r4[2] = r5;
                              r5 = top[58];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2817; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                              L2817:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[2] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object***) lenv) [1][1][2];
                              r4[2] = r5;
                              r5 = top[58];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2818; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                              L2818:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[3] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = ((object**) lenv) [1][2];
                              r4[2] = r5;
                              r5 = top[58];
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2819; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                              L2819:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[4] = r4;
                              r4 = (object*)TC_NIL;
                              r3[5] = r4;
                              r4 = ((object*) lenv) [5];
                              r5 = (object*) &constructed_281;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[6] = r4;
                              r4 = ((object*) lenv) [6];
                              r5 = ((object*) lenv) [4];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[7] = r4;
                              r4 = ((object*) lenv) [7];
                              r5 = (object*) &constructed_280;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[8] = r4;
                              r4 = ((object*) lenv) [8];
                              r5 = ((object*) lenv) [3];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[9] = r4;
                              r4 = ((object*) lenv) [9];
                              r5 = (object*) &constructed_279;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[10] = r4;
                              r4 = ((object*) lenv) [10];
                              r5 = ((object*) lenv) [2];
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[11] = r4;
                              r3 = ((object*) lenv) [11];
                              r4 = (object*) &constructed_278;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              lenv = lenv[1];
                              r2[2] = r3;
                              r3 = top[49];
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2820; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                              L2820:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                              r2 = ((pxll_vector*)r2)->val[4];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2821; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                              L2821:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_25;
                            }
                          }
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_25;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_25;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_25;
                }
              }
              goto fatbar_25_over;
              fatbar_25:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2822; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2822:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_25_over: ;
            } else {
              goto fatbar_24;
            }
            goto fatbar_24_over;
            fatbar_24:
            r1 = (object *) constructed_295[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2823; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2823:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object**) lenv) [1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2824; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2824:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_293;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_292;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_291;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2825; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2825:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2826; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2826:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 11);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2827; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2827:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2828; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2828:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object**) lenv) [1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2829; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2829:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = (object*)TC_NIL;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = (object*) &constructed_290;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = ((object*) lenv) [4];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = (object*) &constructed_289;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r4 = ((object*) lenv) [8];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[9] = r4;
                          r4 = ((object*) lenv) [9];
                          r5 = (object*) &constructed_288;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[10] = r4;
                          r4 = ((object*) lenv) [10];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[11] = r4;
                          r3 = ((object*) lenv) [11];
                          r4 = (object*) &constructed_287;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2830; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2830:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2831; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2831:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_27;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_27;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_27;
                }
              }
              goto fatbar_27_over;
              fatbar_27:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2832; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2832:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_27_over: ;
            } else {
              goto fatbar_26;
            }
            goto fatbar_26_over;
            fatbar_26:
            r1 = (object *) constructed_308[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][5];
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][5];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = ((object*) lenv) [3];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][3];
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = ((object*) lenv) [3];
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2833; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2833:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2834; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2834:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_306;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_305;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_304;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2835; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2835:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2836; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2836:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2837; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2837:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = (object*)TC_NIL;
                          r3[3] = r4;
                          r4 = ((object*) lenv) [3];
                          r5 = (object*) &constructed_303;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = ((object*) lenv) [5];
                          r4 = (object*) &constructed_302;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2838; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2838:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2839; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2839:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object***) lenv) [1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2840; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2840:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object**) lenv) [1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2841; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2841:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = (object*) &constructed_301;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = ((object*) lenv) [5];
                          r5 = ((object*) lenv) [3];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = ((object*) lenv) [6];
                          r5 = (object*) &constructed_300;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = ((object*) lenv) [7];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = ((object*) lenv) [8];
                          r4 = (object*) &constructed_299;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2842; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2842:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2843; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2843:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = ((object****) lenv) [1][1][1][2];
                          r4[2] = r5;
                          r5 = top[58];
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2844; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                          L2844:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = (object*)TC_NIL;
                          r3[3] = r4;
                          r4 = ((object*) lenv) [3];
                          r5 = (object*) &constructed_298;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[4] = r4;
                          r4 = ((object*) lenv) [4];
                          r5 = ((object*) lenv) [2];
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = ((object*) lenv) [5];
                          r4 = (object*) &constructed_297;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r2[2] = r3;
                          r3 = top[49];
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2845; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                          L2845:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2846; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2846:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = (object*) &constructed_296;
                          r1[2] = r2;
                          r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2847; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2847:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_29;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_29;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_29;
                }
              }
              goto fatbar_29_over;
              fatbar_29:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2848; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2848:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_29_over: ;
            } else {
              goto fatbar_28;
            }
            goto fatbar_28_over;
            fatbar_28:
            r1 = (object *) constructed_314[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][2];
                      r2 = UOBJ_GET(r2,1);
                      r1[2] = r2;
                      r1 = ((object*) lenv) [2];
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = ((object**) lenv) [1][2];
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = ((object*) lenv) [2];
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = ((object**) lenv) [1][2];
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = ((object**) lenv) [1][3];
                              switch (get_case (r1)) {
                                case (TC_PAIR): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = ((object***) lenv) [1][1][3];
                                  r2 = UOBJ_GET(r2,1);
                                  r1[2] = r2;
                                  r1 = ((object*) lenv) [2];
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = ((object*) lenv) [3];
                                          switch (get_case (r1)) {
                                            case (TC_NIL): {
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = allocate (TC_TUPLE, 2);
                                              r3 = allocate (TC_TUPLE, 11);
                                              r3[1] = lenv; lenv = r3;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                                              r4[2] = r5;
                                              r5 = top[58];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2849; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                              L2849:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[2] = r4;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object**) lenv) [1][2];
                                              r4[2] = r5;
                                              r5 = top[58];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2850; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                              L2850:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[3] = r4;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = ((object****) lenv) [1][1][1][2];
                                              r4[2] = r5;
                                              r5 = top[58];
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2851; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                                              L2851:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[4] = r4;
                                              r4 = (object*)TC_NIL;
                                              r3[5] = r4;
                                              r4 = ((object*) lenv) [5];
                                              r5 = (object*) &constructed_312;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[6] = r4;
                                              r4 = ((object*) lenv) [6];
                                              r5 = ((object*) lenv) [4];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[7] = r4;
                                              r4 = ((object*) lenv) [7];
                                              r5 = (object*) &constructed_311;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[8] = r4;
                                              r4 = ((object*) lenv) [8];
                                              r5 = ((object*) lenv) [3];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[9] = r4;
                                              r4 = ((object*) lenv) [9];
                                              r5 = (object*) &constructed_310;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[10] = r4;
                                              r4 = ((object*) lenv) [10];
                                              r5 = ((object*) lenv) [2];
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[11] = r4;
                                              r3 = ((object*) lenv) [11];
                                              r4 = (object*) &constructed_309;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r4;
                                              t[2] = r3;
                                              r3 = t;
                                              lenv = lenv[1];
                                              r2[2] = r3;
                                              r3 = top[49];
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2852; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                                              L2852:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[2] = r2;
                                              r2 = ((object***************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                                              r2 = ((pxll_vector*)r2)->val[4];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2853; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                              L2853:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_31;
                                            }
                                          }
                                          lenv = lenv[1];
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_31;
                                        }
                                      }
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_31;
                                    }
                                  }
                                  lenv = lenv[1];
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_31;
                                }
                              }
                              lenv = lenv[1];
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_31;
                            }
                          }
                          lenv = lenv[1];
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_31;
                        }
                      }
                      lenv = lenv[1];
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_31;
                    }
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_31;
                }
              }
              goto fatbar_31_over;
              fatbar_31:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2854; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2854:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_31_over: ;
            } else {
              goto fatbar_30;
            }
            goto fatbar_30_over;
            fatbar_30:
            r1 = (object *) constructed_328[0];
            r2 = ((object***) lenv) [1][1][2];
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = ((object***) lenv) [1][1][3];
              switch (get_case (r1)) {
                case (UOTAG(9)): {
                  r1 = allocate (TC_TUPLE, 4);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = ((object****) lenv) [1][1][1][3];
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][2];
                  r3 = ((pxll_vector*)r3)->val[2];
                  r2[2] = r3;
                  r3 = ((object*) lenv) [2];
                  r2[3] = r3;
                  r3 = top[67];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2855; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_396;
                  L2855:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[4] = r2;
                  r1 = ((object*) lenv) [4];
                  switch (get_case (r1)) {
                    case (UITAG(1)): {
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object*) &constructed_315;
                      r1[2] = r2;
                      r2 = ((object*) lenv) [2];
                      r1[3] = r2;
                      r2 = top[15];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2856; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                      L2856:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                    } break;
                    default: {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object**) lenv) [1][4];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = ((object**) lenv) [1][3];
                      r2[2] = r3;
                      r3 = ((object*) lenv) [2];
                      r3 = ((pxll_vector*)r3)->val[1];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2857; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto *r3[1];
                      L2857:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[3] = r2;
                      r1 = (object *) 1;
                      r2 = ((object***) lenv) [1][1][3];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 8);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = ((object****) lenv) [1][1][1][2];
                        r4[2] = r5;
                        r5 = top[58];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2858; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                        L2858:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = allocate (TC_TUPLE, 4);
                        r5 = ((object***) lenv) [1][1][2];
                        r4[2] = r5;
                        r5 = ((object***) lenv) [1][1][3];
                        r4[3] = r5;
                        r5 = ((object**) lenv) [1][3];
                        r5 = ((pxll_vector*)r5)->val[1];
                        r4[4] = r5;
                        r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][7];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2859; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_get_uitag_4317_i4806_i4853;
                        L2859:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[3] = r4;
                        r4 = (object*)TC_NIL;
                        r3[4] = r4;
                        r4 = ((object*) lenv) [4];
                        r5 = (object*) &constructed_318;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r4 = ((object*) lenv) [5];
                        r5 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[6] = r4;
                        r4 = ((object*) lenv) [6];
                        r5 = (object*) &constructed_317;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[7] = r4;
                        r4 = ((object*) lenv) [7];
                        r5 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[8] = r4;
                        r3 = ((object*) lenv) [8];
                        r4 = (object*) &constructed_316;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r2[2] = r3;
                        r3 = top[49];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2860; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                        L2860:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2861; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2861:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                      } else {
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 8);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 4);
                        r5 = ((object***) lenv) [1][1][2];
                        r4[2] = r5;
                        r5 = ((object***) lenv) [1][1][3];
                        r4[3] = r5;
                        r5 = ((object**) lenv) [1][3];
                        r5 = ((pxll_vector*)r5)->val[1];
                        r4[4] = r5;
                        r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][6];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2862; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_get_uotag_4316_i4806_i4853;
                        L2862:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = ((object****) lenv) [1][1][1][3];
                        r4[2] = r5;
                        r5 = top[58];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2863; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                        L2863:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[3] = r4;
                        r4 = (object*)TC_NIL;
                        r3[4] = r4;
                        r4 = ((object*) lenv) [4];
                        r5 = (object*) &constructed_326;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r4 = ((object*) lenv) [5];
                        r5 = ((object*) lenv) [3];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[6] = r4;
                        r4 = ((object*) lenv) [6];
                        r5 = (object*) &constructed_325;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[7] = r4;
                        r4 = ((object*) lenv) [7];
                        r5 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[8] = r4;
                        r3 = ((object*) lenv) [8];
                        r4 = (object*) &constructed_324;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r2[2] = r3;
                        r3 = top[49];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2864; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                        L2864:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2865; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2865:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        r2 = ((object****) lenv) [1][1][1][3];
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        // def $loop_4621_i3600_i4806_i4853
                        goto L2866;
                        FUN__24loop_4621_i3600_i4806_i4853:
                          check_heap (0);
                          r0 = ((object***) lenv) [1][1][2];
                          r1 = ((object*) lenv) [2];
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = (object *) 14;
                            PXLL_RETURN(0);
                          } else {
                            r0 = allocate (TC_TUPLE, 2);
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = allocate (TC_TUPLE, 8);
                            r2[1] = lenv; lenv = r2;
                            r3 = allocate (TC_TUPLE, 2);
                            r4 = (object *) 3;
                            r5 = ((object**) lenv) [1][2];
                            r4 = box((pxll_int)unbox(r5)+unbox(r4));
                            r3[2] = r4;
                            r4 = top[58];
                            t = allocate (TC_SAVE, 6);
                            t[1] = k; t[2] = lenv; t[3] = &&L2867; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                            L2867:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                            r3 = result;
                            r2[2] = r3;
                            r3 = allocate (TC_TUPLE, 2);
                            r4 = allocate (TC_TUPLE, 3);
                            r5 = ((object*********) lenv) [1][1][1][1][1][1][1][1][5];
                            r4[2] = r5;
                            r5 = ((object**) lenv) [1][2];
                            r4[3] = r5;
                            r5 = top[29];
                            t = allocate (TC_SAVE, 7);
                            t[1] = k; t[2] = lenv; t[3] = &&L2868; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                            r4[1] = r5[2]; lenv = r4; goto FUN_nth_323;
                            L2868:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                            r4 = result;
                            r3[2] = r4;
                            r4 = top[58];
                            t = allocate (TC_SAVE, 6);
                            t[1] = k; t[2] = lenv; t[3] = &&L2869; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                            L2869:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                            r3 = result;
                            r2[3] = r3;
                            r3 = (object*)TC_NIL;
                            r2[4] = r3;
                            r3 = ((object*) lenv) [4];
                            r4 = (object*) &constructed_323;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[5] = r3;
                            r3 = ((object*) lenv) [5];
                            r4 = ((object*) lenv) [3];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[6] = r3;
                            r3 = ((object*) lenv) [6];
                            r4 = (object*) &constructed_322;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[7] = r3;
                            r3 = ((object*) lenv) [7];
                            r4 = ((object*) lenv) [2];
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[8] = r3;
                            r2 = ((object*) lenv) [8];
                            r3 = (object*) &constructed_321;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r3;
                            t[2] = r2;
                            r2 = t;
                            lenv = lenv[1];
                            r1[2] = r2;
                            r2 = top[49];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2870; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                            L2870:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                            r1 = ((pxll_vector*)r1)->val[4];
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L2871; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto *r1[1];
                            L2871:
                            ; lenv = k[2]; k = k[1];
                            r0 = (object *) 3;
                            r1 = ((object*) lenv) [2];
                            r0 = box((pxll_int)unbox(r1)+unbox(r0));
                            lenv[2] = r0;
                            goto FUN__24loop_4621_i3600_i4806_i4853;
                          }
                          PXLL_RETURN(0);
                        L2866:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN__24loop_4621_i3600_i4806_i4853; r2[2] = lenv;
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = (object *) 1;
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2872; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4621_i3600_i4806_i4853;
                        L2872:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        lenv = lenv[1];
                        lenv = lenv[1];
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 5);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = ((object****) lenv) [1][1][1][2];
                        r4[2] = r5;
                        r5 = top[58];
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2873; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                        L2873:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = (object*)TC_NIL;
                        r3[3] = r4;
                        r4 = ((object*) lenv) [3];
                        r5 = (object*) &constructed_320;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[4] = r4;
                        r4 = ((object*) lenv) [4];
                        r5 = ((object*) lenv) [2];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r3 = ((object*) lenv) [5];
                        r4 = (object*) &constructed_319;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r2[2] = r3;
                        r3 = top[49];
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2874; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                        L2874:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2875; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2875:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                      }
                      lenv = lenv[1];
                    } break;
                  }
                  lenv = lenv[1];
                } break;
                default: {
                  goto fatbar_33;
                }
              }
              goto fatbar_33_over;
              fatbar_33:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = ((object***) lenv) [1][1][2];
              r1[3] = r2;
              r2 = top[15];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2876; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
              L2876:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              fatbar_33_over: ;
            } else {
              goto fatbar_32;
            }
            goto fatbar_32_over;
            fatbar_32:
            r1 = allocate (TC_TUPLE, 3);
            r2 = (object*) &constructed_208;
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r1[3] = r2;
            r2 = top[15];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2877; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
            L2877:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            fatbar_32_over: ;
            fatbar_30_over: ;
            fatbar_28_over: ;
            fatbar_26_over: ;
            fatbar_24_over: ;
            fatbar_22_over: ;
            fatbar_20_over: ;
            fatbar_19_over: ;
            fatbar_18_over: ;
            fatbar_17_over: ;
            fatbar_15_over: ;
            fatbar_12_over: ;
            fatbar_10_over: ;
            fatbar_8_over: ;
            lenv = lenv[1];
            lenv = lenv[1];
            r1 = ((object*) lenv) [6];
            lenv = lenv[1];
          } break;
          case (UOTAG(19)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][4];
            r2[2] = r3;
            r3 = top[140];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2878; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_526;
            L2878:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = ((object**) lenv) [1][3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = ((object***) lenv) [1][1][2];
              r3 = ((object***) lenv) [1][1][3];
              r2 = PXLL_TEST(unbox(r3)==unbox(r2));
              r1[2] = r2;
              r1 = (object *) 6;
              r2 = ((object*) lenv) [2];
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
            } else {
              r1 = (object *) 6;
            }
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][2];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2879; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2879:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = ((object***) lenv) [1][1][3];
              r4[2] = r5;
              r5 = top[58];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2880; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
              L2880:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_331;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_330;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_329;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2881; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2881:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2882; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2882:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 1;
              r2 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object***) lenv) [1][1][2];
                r3 = ((object**) lenv) [1][2];
                r2 = PXLL_TEST(unbox(r3)==unbox(r2));
                r1[2] = r2;
                r1 = (object *) 6;
                r2 = ((object*) lenv) [2];
                r1 = PXLL_TEST(r2==r1);
                lenv = lenv[1];
              } else {
                r1 = (object *) 6;
              }
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object**) lenv) [1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2883; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2883:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = ((object***) lenv) [1][1][2];
                r4[2] = r5;
                r5 = top[58];
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2884; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                L2884:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = ((object*) lenv) [4];
                r5 = (object*) &constructed_334;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = ((object*) lenv) [5];
                r5 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = ((object*) lenv) [6];
                r5 = (object*) &constructed_333;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = ((object*) lenv) [7];
                r5 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = ((object*) lenv) [8];
                r4 = (object*) &constructed_332;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r2[2] = r3;
                r3 = top[49];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2885; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                L2885:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2886; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2886:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              } else {
                r1 = (object *) 14;
              }
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [4];
            lenv = lenv[1];
          } break;
          case (UOTAG(20)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [3];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2887; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
            L2887:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2888; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2888:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_340;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_339;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2889; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2889:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2890; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2890:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2891; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2891:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_338;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_337;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2892; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2892:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2893; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2893:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object*) lenv) [4];
            r1[2] = r2;
            r2 = ((object****) lenv) [1][1][1][2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2894; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
            L2894:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2895; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2895:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_336;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_335;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2896; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2896:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2897; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2897:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = ((object*) lenv) [5];
            lenv = lenv[1];
          } break;
          case (UOTAG(21)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = ((object*) lenv) [3];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_347;
              r5[3] = r6;
              r6 = top[33];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2898; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
              L2898:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[49];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2899; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
              L2899:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object**) lenv) [1][3];
              r5[2] = r6;
              r6 = (object*) &constructed_346;
              r5[3] = r6;
              r6 = top[33];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2900; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_327;
              L2900:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = top[49];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2901; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_354;
              L2901:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = ((object*) lenv) [4];
              r5 = (object*) &constructed_345;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = ((object*) lenv) [5];
              r5 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = ((object*) lenv) [6];
              r5 = (object*) &constructed_344;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = ((object*) lenv) [7];
              r5 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = ((object*) lenv) [8];
              r4 = (object*) &constructed_343;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r2[2] = r3;
              r3 = top[49];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2902; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
              L2902:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2903; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2903:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2904; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2904:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_342;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_341;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2905; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2905:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2906; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2906:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
          } break;
          case (UOTAG(22)): {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][6];
            switch (get_case (r2)) {
              case (UOTAG(0)): {
                r2 = (object *) 262;
              } break;
              default: {
                r2 = (object *) 6;
              } break;
            }
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = ((object********) lenv) [1][1][1][1][1][1][1][2];
            r3 = ((pxll_vector*)r3)->val[2];
            r2[2] = r3;
            r3 = ((object**) lenv) [1][3];
            r2[3] = r3;
            r3 = top[67];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2907; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_396;
            L2907:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = ((object*) lenv) [3];
            switch (get_case (r1)) {
              case (UITAG(1)): {
                r1 = allocate (TC_TUPLE, 3);
                r2 = (object*) &constructed_348;
                r1[2] = r2;
                r2 = ((object**) lenv) [1][3];
                r1[3] = r2;
                r2 = top[15];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2908; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                L2908:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
              } break;
              default: {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object**) lenv) [1][3];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = ((object****) lenv) [1][1][1][5];
                r2[2] = r3;
                r3 = top[24];
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2909; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
                L2909:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = (object *) 3;
                r2 = ((object*) lenv) [2];
                r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                lenv = lenv[1];
                if PXLL_IS_TRUE(r1) {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = ((pxll_vector*)r2)->val[3];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2910; t[4] = r0; t[5] = r1; k = t;
                  lenv = r2[2]; goto *r2[1];
                  L2910:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = (object *) 3;
                  r2 = ((object*) lenv) [2];
                  r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                  lenv = lenv[1];
                } else {
                  r1 = (object *) 6;
                }
                if PXLL_IS_TRUE(r1) {
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = ((object***) lenv) [1][1][5];
                  r2[2] = r3;
                  r3 = (object *) 1;
                  r2[3] = r3;
                  r3 = top[29];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2911; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_nth_323;
                  L2911:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = ((object******) lenv) [1][1][1][1][1][2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2912; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
                  L2912:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                } else {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = (object*) &constructed_359;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = allocate (TC_TUPLE, 7);
                  r3[1] = lenv; lenv = r3;
                  r4 = allocate (TC_TUPLE, 2);
                  r5 = ((object*****) lenv) [1][1][1][1][2];
                  r4[2] = r5;
                  r5 = top[58];
                  t = allocate (TC_SAVE, 7);
                  t[1] = k; t[2] = lenv; t[3] = &&L2913; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
                  L2913:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                  r4 = result;
                  r3[2] = r4;
                  r4 = (object*)TC_NIL;
                  r3[3] = r4;
                  r4 = ((object*) lenv) [3];
                  r5 = (object*) &constructed_358;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[4] = r4;
                  r4 = ((object*) lenv) [4];
                  r5 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[5] = r4;
                  r4 = ((object*) lenv) [5];
                  r5 = (object*) &constructed_357;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[6] = r4;
                  r4 = ((object*) lenv) [6];
                  r5 = ((object**) lenv) [1][2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[7] = r4;
                  r3 = ((object*) lenv) [7];
                  r4 = (object*) &constructed_356;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r4;
                  t[2] = r3;
                  r3 = t;
                  lenv = lenv[1];
                  r2[2] = r3;
                  r3 = top[49];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2914; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
                  L2914:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][56];
                  r2 = ((pxll_vector*)r2)->val[4];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2915; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L2915:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = ((object*****) lenv) [1][1][1][1][4];
                  r2[2] = r3;
                  r3 = top[24];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2916; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
                  L2916:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def $loop_4647_i3846_i4806_i4853
                  goto L2917;
                  FUN__24loop_4647_i3846_i4806_i4853:
                    check_heap (0);
                    r0 = ((object***) lenv) [1][1][2];
                    r1 = ((object*) lenv) [2];
                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                      r0 = (object *) 14;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 7);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[29];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2918; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                      L2918:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][5];
                      r1[2] = r2;
                      r2 = ((object**) lenv) [1][2];
                      r1[3] = r2;
                      r2 = top[29];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2919; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                      L2919:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [2];
                      r1[2] = r2;
                      r2 = ((object******) lenv) [1][1][1][1][1][2];
                      r2 = ((pxll_vector*)r2)->val[1];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2920; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2920:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r1 = ((object*) lenv) [4];
                      r1 = ((pxll_vector*)r1)->val[0];
                      r0[5] = r1;
                      r1 = (object *) 6;
                      r0[6] = r1;
                      r1 = (object *) 1;
                      r2 = ((object*) lenv) [5];
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
                        r1 = allocate (TC_TUPLE, 4);
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        r1[3] = r2;
                        r2 = ((object*) lenv) [4];
                        r2 = ((pxll_vector*)r2)->val[1];
                        r1[4] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][7];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2921; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_uitag_4317_i4806_i4853;
                        L2921:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                      } else {
                        r1 = allocate (TC_TUPLE, 4);
                        r2 = ((object********) lenv) [1][1][1][1][1][1][1][3];
                        r1[2] = r2;
                        r2 = ((object*) lenv) [2];
                        r1[3] = r2;
                        r2 = ((object*) lenv) [4];
                        r2 = ((pxll_vector*)r2)->val[1];
                        r1[4] = r2;
                        r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][6];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2922; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_uotag_4316_i4806_i4853;
                        L2922:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                      }
                      r0[7] = r1;
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                      r0 = ((pxll_vector*)r0)->val[3];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2923; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2923:
                      ; lenv = k[2]; k = k[1];
                      r0 = (object *) 6;
                      r1 = ((object*******) lenv) [1][1][1][1][1][1][2];
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][4];
                        r1[2] = r2;
                        r2 = top[24];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2924; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
                        L2924:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = (object *) 3;
                        r2 = ((object*) lenv) [2];
                        r1 = box((pxll_int)unbox(r2)-unbox(r1));
                        r0[3] = r1;
                        r0 = ((object*) lenv) [3];
                        r1 = ((object***) lenv) [1][1][2];
                        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                        lenv = lenv[1];
                      } else {
                        r0 = (object *) 6;
                      }
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = (object*) &constructed_353;
                        r0[2] = r1;
                        r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                        r1 = ((pxll_vector*)r1)->val[4];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2925; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto *r1[1];
                        L2925:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      } else {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 4);
                        r2[1] = lenv; lenv = r2;
                        r3 = (object*)TC_NIL;
                        r2[2] = r3;
                        r3 = ((object*) lenv) [2];
                        r4 = (object*) &constructed_355;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        r2[3] = r3;
                        r3 = ((object*) lenv) [3];
                        r4 = ((object**) lenv) [1][7];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        r2[4] = r3;
                        r2 = ((object*) lenv) [4];
                        r3 = (object*) &constructed_354;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        lenv = lenv[1];
                        r1[2] = r2;
                        r2 = top[49];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2926; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                        L2926:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                        r1 = ((pxll_vector*)r1)->val[4];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2927; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto *r1[1];
                        L2927:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      }
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                      r0 = ((pxll_vector*)r0)->val[3];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2928; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2928:
                      ; lenv = k[2]; k = k[1];
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = ((object*) lenv) [3];
                      r0[2] = r1;
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2929; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_emit_4294_i4806_i4853;
                      L2929:
                      ; lenv = k[2]; k = k[1];
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                      r0 = ((pxll_vector*)r0)->val[2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2930; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2930:
                      ; lenv = k[2]; k = k[1];
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object*) &constructed_352;
                      r0[2] = r1;
                      r1 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[4];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2931; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L2931:
                      ; lenv = k[2]; k = k[1];
                      r0 = ((object**************) lenv) [1][1][1][1][1][1][1][1][1][1][1][1][1][56];
                      r0 = ((pxll_vector*)r0)->val[2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2932; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2932:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = (object *) 3;
                      r1 = ((object*) lenv) [2];
                      r0 = box((pxll_int)unbox(r1)+unbox(r0));
                      lenv[2] = r0;
                      goto FUN__24loop_4647_i3846_i4806_i4853;
                    }
                    PXLL_RETURN(0);
                  L2917:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN__24loop_4647_i3846_i4806_i4853; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = (object *) 1;
                  r1[2] = r2;
                  r2 = ((object*) lenv) [2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2933; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4647_i3846_i4806_i4853;
                  L2933:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  lenv = lenv[1];
                  r1 = ((object****) lenv) [1][1][1][6];
                  switch (get_case (r1)) {
                    case (UOTAG(0)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = ((object*****) lenv) [1][1][1][1][6];
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2934; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2934:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_351;
                      r1[2] = r2;
                      r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2935; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2935:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2936; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2936:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = ((object*) lenv) [2];
                      r1[2] = r2;
                      r2 = ((object********) lenv) [1][1][1][1][1][1][1][2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2937; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
                      L2937:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2938; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2938:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_350;
                      r1[2] = r2;
                      r2 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2939; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2939:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = ((object***********) lenv) [1][1][1][1][1][1][1][1][1][1][56];
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2940; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2940:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                    } break;
                    default: {
                      goto fatbar_34;
                    }
                  }
                  goto fatbar_34_over;
                  fatbar_34:
                  r1 = (object *) 14;
                  fatbar_34_over: ;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = (object*) &constructed_349;
                  r1[2] = r2;
                  r2 = ((object**********) lenv) [1][1][1][1][1][1][1][1][1][56];
                  r2 = ((pxll_vector*)r2)->val[4];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2941; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L2941:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                }
                lenv = lenv[1];
              } break;
            }
            lenv = lenv[1];
            r1 = ((object*) lenv) [7];
            lenv = lenv[1];
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = ((object***) lenv) [1][1][2];
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = ((object**) lenv) [1][2];
            r4[2] = r5;
            r5 = top[58];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2942; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_366;
            L2942:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = ((object*) lenv) [3];
            r5 = (object*) &constructed_372;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = ((object*) lenv) [4];
            r5 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = ((object*) lenv) [5];
            r4 = (object*) &constructed_371;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r2[2] = r3;
            r3 = top[49];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2943; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_354;
            L2943:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = ((object*******) lenv) [1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2944; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2944:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][6];
            switch (get_case (r2)) {
              case (UOTAG(0)): {
                r2 = (object *) 262;
              } break;
              default: {
                r2 = (object *) 6;
              } break;
            }
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = ((object**) lenv) [1][5];
            r2[2] = r3;
            r3 = top[24];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2945; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_316;
            L2945:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = ((object**) lenv) [1][3];
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4664_i3867_i4806_i4853
            goto L2946;
            FUN__24loop_4664_i3867_i4806_i4853:
              check_heap (0);
              r0 = ((object***) lenv) [1][1][2];
              r1 = ((object*) lenv) [2];
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 9);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][3];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2947; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L2947:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][4];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2948; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L2948:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object******) lenv) [1][1][1][1][1][5];
                r1[2] = r2;
                r2 = ((object**) lenv) [1][2];
                r1[3] = r2;
                r2 = top[29];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2949; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
                L2949:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][2];
                r2 = ((pxll_vector*)r2)->val[16];
                r1[2] = r2;
                r2 = ((object*) lenv) [2];
                r1[3] = r2;
                r2 = top[67];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2950; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_396;
                L2950:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = ((object*) lenv) [5];
                switch (get_case (r1)) {
                  case (UOTAG(0)): {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = ((object**) lenv) [1][5];
                    r2 = UOBJ_GET(r2,0);
                    r1[2] = r2;
                    r1 = ((object*) lenv) [2];
                    lenv = lenv[1];
                  } break;
                  default: {
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = (object*) &constructed_370;
                    r1[2] = r2;
                    r2 = ((object*) lenv) [2];
                    r1[3] = r2;
                    r2 = top[15];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2951; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_error1_294;
                    L2951:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                  } break;
                }
                r0[6] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 6);
                r2[1] = lenv; lenv = r2;
                r3 = (object *) 1;
                r4 = ((object**) lenv) [1][3];
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r4)==unbox(r3))) {
                  r3 = (object*) &constructed_368;
                } else {
                  r3 = (object*) &constructed_369;
                }
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = ((object**) lenv) [1][6];
                r3[2] = r4;
                r4 = top[58];
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2952; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
                L2952:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = ((object*) lenv) [4];
                r4 = (object*) &constructed_367;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = ((object*) lenv) [5];
                r4 = ((object*) lenv) [3];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r2 = ((object*) lenv) [6];
                r3 = ((object*) lenv) [2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r1[2] = r2;
                r2 = top[49];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2953; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                L2953:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[7] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 4);
                r2[1] = lenv; lenv = r2;
                r3 = (object*)TC_NIL;
                r2[2] = r3;
                r3 = ((object*) lenv) [2];
                r4 = (object*) &constructed_366;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[3] = r3;
                r3 = ((object*) lenv) [3];
                r4 = ((object**) lenv) [1][7];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[4] = r3;
                r2 = ((object*) lenv) [4];
                r3 = (object*) &constructed_365;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r1[2] = r2;
                r2 = top[49];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2954; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                L2954:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[8] = r1;
                r1 = (object *) 6;
                r2 = ((object*****) lenv) [1][1][1][1][2];
                if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = (object *) 3;
                  r3 = ((object******) lenv) [1][1][1][1][1][3];
                  r2 = box((pxll_int)unbox(r3)-unbox(r2));
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  r2 = ((object***) lenv) [1][1][2];
                  r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                  lenv = lenv[1];
                } else {
                  r1 = (object *) 6;
                }
                if PXLL_IS_TRUE(r1) {
                  r1 = (object*) &constructed_364;
                } else {
                  r1 = ((object*) lenv) [8];
                }
                r0[9] = r1;
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                r0 = ((pxll_vector*)r0)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2955; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2955:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object*) lenv) [9];
                r0[2] = r1;
                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2956; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2956:
                ; lenv = k[2]; k = k[1];
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                r0 = ((pxll_vector*)r0)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2957; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2957:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = ((object*) lenv) [4];
                r0[2] = r1;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2958; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_emit_4294_i4806_i4853;
                L2958:
                ; lenv = k[2]; k = k[1];
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                r0 = ((pxll_vector*)r0)->val[2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2959; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2959:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object*) &constructed_363;
                r0[2] = r1;
                r1 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2960; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2960:
                ; lenv = k[2]; k = k[1];
                r0 = ((object************) lenv) [1][1][1][1][1][1][1][1][1][1][1][56];
                r0 = ((pxll_vector*)r0)->val[2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2961; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2961:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = ((object*) lenv) [2];
                r0 = box((pxll_int)unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4664_i3867_i4806_i4853;
              }
              PXLL_RETURN(0);
            L2946:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4664_i3867_i4806_i4853; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = ((object*) lenv) [2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2962; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4664_i3867_i4806_i4853;
            L2962:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            lenv = lenv[1];
            r1 = ((object**) lenv) [1][6];
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = ((object***) lenv) [1][1][6];
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2963; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L2963:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = allocate (TC_TUPLE, 2);
                r2 = (object*) &constructed_362;
                r1[2] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2964; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2964:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2965; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L2965:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = allocate (TC_TUPLE, 2);
                r2 = ((object*) lenv) [2];
                r1[2] = r2;
                r2 = ((object******) lenv) [1][1][1][1][1][2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2966; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_emit_4294_i4806_i4853;
                L2966:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                r1 = ((pxll_vector*)r1)->val[2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2967; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L2967:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = allocate (TC_TUPLE, 2);
                r2 = (object*) &constructed_361;
                r1[2] = r2;
                r2 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2968; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2968:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = ((object*********) lenv) [1][1][1][1][1][1][1][1][56];
                r1 = ((pxll_vector*)r1)->val[2];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2969; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L2969:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
              } break;
              default: {
                r1 = (object *) 14;
              } break;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_360;
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][56];
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2970; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2970:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = ((object*) lenv) [7];
            lenv = lenv[1];
          } break;
        }
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = ((object*) lenv) [2];
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r0;
            goto FUN_emit_4294_i4806_i4853;
          } break;
          default: {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L2516:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_emit_4294_i4806_i4853; r1[2] = lenv;
      r0[2] = r1;
      // def move_4295_i4806_i4853
      goto L2971;
      FUN_move_4295_i4806_i4853:
        check_heap (0);
        r0 = (object *) 1;
        r1 = ((object*) lenv) [3];
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>=unbox(r0))) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][3];
          r2 = ((object**) lenv) [1][2];
          r1 = PXLL_TEST(unbox(r2)==unbox(r1));
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
        } else {
          r0 = (object *) 6;
        }
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 8);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][3];
          r3[2] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2972; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
          L2972:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][2];
          r3[2] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2973; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
          L2973:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = (object*) &constructed_72;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = ((object*) lenv) [5];
          r4 = ((object*) lenv) [3];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = ((object*) lenv) [6];
          r4 = (object*) &constructed_71;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = ((object*) lenv) [7];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r2 = ((object*) lenv) [8];
          r3 = (object*) &constructed_70;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2974; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L2974:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object*****) lenv) [1][1][1][1][56];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } else {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L2971:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_move_4295_i4806_i4853; r1[2] = lenv;
      r0[3] = r1;
      // def gen-function-label_4302_i4806_i4853
      goto L2975;
      FUN_gen_function_label_4302_i4806_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][2];
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        r4 = ((object***) lenv) [1][1][2];
        r4 = UOBJ_GET(r4,0);
        r3[2] = r4;
        r3 = ((object*) lenv) [2];
        lenv = lenv[1];
        r2[2] = r3;
        r3 = ((object***) lenv) [1][1][8];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2976; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto *r3[1];
        L2976:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = ((object*) lenv) [4];
        r2 = (object*) &constructed_69;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
      L2975:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_gen_function_label_4302_i4806_i4853; r1[2] = lenv;
      r0[4] = r1;
      // def guess-record-type_4315_i4806_i4853
      goto L2977;
      FUN_guess_record_type_4315_i4806_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_31278_i4806_i4853
        goto L2978;
        FUN_lambda_31278_i4806_i4853:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = ((object*) lenv) [2];
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_5;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_5_over;
          fatbar_5:
          r0 = (object*) &constructed_68;
          r0 = box((pxll_int)((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_68;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_67;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_67;
          PXLL_UNDEFINED; result=r0; goto Lreturn;
          PXLL_RETURN(0);
          fatbar_5_over: ;
          PXLL_RETURN(0);
        L2978:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_31278_i4806_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object**) lenv) [1][2];
        r1[3] = r2;
        r2 = top[34];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2979; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_328;
        L2979:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_31289_i4806_i4853
        goto L2980;
        FUN_lambda_31289_i4806_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_66[0];
          r2 = ((object**) lenv) [1][2];
          r1 = PXLL_TEST(r2==r1);
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = ((object*) lenv) [2];
          r0 = PXLL_TEST(r1==r0);
          PXLL_RETURN(0);
        L2980:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_31289_i4806_i4853; r2[2] = lenv;
        r1[2] = r2;
        r2 = ((object*) lenv) [2];
        r1[3] = r2;
        r2 = top[36];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2981; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_filter_330;
        L2981:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = (object *) constructed_64[0];
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_31317_i4806_i4853
        goto L2982;
        FUN_lambda_31317_i4806_i4853:
          check_heap (0);
          r0 = ((object*) lenv) [2];
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = ((object**) lenv) [1][2];
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_31259_i4185_i4806_i4853
              goto L2983;
              FUN_lambda_31259_i4185_i4806_i4853:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = ((object*) lenv) [2];
                r0[2] = r1;
                r1 = ((object**) lenv) [1][2];
                r0[3] = r1;
                r1 = top[27];
                r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_321;
              L2983:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_31259_i4185_i4806_i4853; r1[2] = lenv;
              r0[2] = r1;
              r1 = ((object***) lenv) [1][1][3];
              r0[3] = r1;
              r1 = top[42];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2984; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_every_question_336;
              L2984:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = ((object****) lenv) [1][1][1][4];
                r0[2] = r1;
                r0 = ((object*) lenv) [2];
                r1 = ((object**) lenv) [1][2];
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                ((object***) lenv) [1][1][4] = r0;
                PXLL_RETURN(0);
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L2982:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_31317_i4806_i4853; r1[2] = lenv;
        r0[2] = r1;
        r1 = ((object******) lenv) [1][1][1][1][1][2];
        r1 = ((pxll_vector*)r1)->val[11];
        r0[3] = r1;
        r1 = top[37];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2985; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
        L2985:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = ((object**) lenv) [1][4];
        r1[2] = r2;
        r2 = top[24];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2986; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
        L2986:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = ((object*) lenv) [2];
        r1 = (object *) 3;
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = ((object**) lenv) [1][4];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = top[29];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2987; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_323;
          L2987:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L2977:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_guess_record_type_4315_i4806_i4853; r1[2] = lenv;
      r0[5] = r1;
      // def get-uotag_4316_i4806_i4853
      goto L2988;
      FUN_get_uotag_4316_i4806_i4853:
        check_heap (0);
        r0 = (object *) constructed_58[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_56[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_54;
            PXLL_RETURN(0);
          } else {
            goto fatbar_3;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_3;
        }
        PXLL_RETURN(0);
        goto fatbar_3_over;
        fatbar_3:
        r0 = (object *) constructed_51[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_61[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_59;
            PXLL_RETURN(0);
          } else {
            goto fatbar_4;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_4;
        }
        PXLL_RETURN(0);
        goto fatbar_4_over;
        fatbar_4:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[58];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2989; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
        L2989:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_63;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_62;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        fatbar_4_over: ;
        PXLL_RETURN(0);
        fatbar_3_over: ;
        PXLL_RETURN(0);
      L2988:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_get_uotag_4316_i4806_i4853; r1[2] = lenv;
      r0[6] = r1;
      // def get-uitag_4317_i4806_i4853
      goto L2990;
      FUN_get_uitag_4317_i4806_i4853:
        check_heap (0);
        r0 = (object *) constructed_46[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_41[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_39;
            PXLL_RETURN(0);
          } else {
            goto fatbar_1;
          }
          PXLL_RETURN(0);
          goto fatbar_1_over;
          fatbar_1:
          r0 = (object *) constructed_44[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_42;
            PXLL_RETURN(0);
          } else {
            goto fatbar_0;
          }
          PXLL_RETURN(0);
          fatbar_1_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_0;
        }
        PXLL_RETURN(0);
        goto fatbar_0_over;
        fatbar_0:
        r0 = (object *) constructed_51[0];
        r1 = ((object*) lenv) [2];
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_49[0];
          r1 = ((object*) lenv) [3];
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_47;
            PXLL_RETURN(0);
          } else {
            goto fatbar_2;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_2;
        }
        PXLL_RETURN(0);
        goto fatbar_2_over;
        fatbar_2:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = ((object**) lenv) [1][4];
        r2[2] = r3;
        r3 = top[58];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2991; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_366;
        L2991:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = ((object*) lenv) [3];
        r3 = (object*) &constructed_53;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = ((object*) lenv) [4];
        r3 = ((object*) lenv) [2];
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = ((object*) lenv) [5];
        r2 = (object*) &constructed_52;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r0[2] = r1;
        r1 = top[49];
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_354;
        fatbar_2_over: ;
        PXLL_RETURN(0);
        fatbar_0_over: ;
        PXLL_RETURN(0);
      L2990:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_get_uitag_4317_i4806_i4853; r1[2] = lenv;
      r0[7] = r1;
      r1 = allocate (TC_TUPLE, 4);
      r1[1] = lenv; lenv = r1;
      // def frob-name_4243_i4507_i4806_i4853
      goto L2992;
      FUN_frob_name_4243_i4507_i4806_i4853:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        // def loop_4248_i3203_i4507_i4806_i4853
        goto L2993;
        FUN_loop_4248_i3203_i4507_i4806_i4853:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = ((object******) lenv) [1][1][1][1][1][2];
          r1 = box((pxll_int)((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = ((object*) lenv) [2];
          r1 = ((object**) lenv) [1][2];
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          if PXLL_IS_TRUE(r0) {
            r0 = ((object*) lenv) [3];
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = ((object**) lenv) [1][2];
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = ((object**) lenv) [1][2];
            r2 = ((object******) lenv) [1][1][1][1][1][2];
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = ((object**) lenv) [1][2];
            r1[2] = r2;
            r2 = ((object********) lenv) [1][1][1][1][1][1][1][4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2994; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2994:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = ((object**) lenv) [1][2];
              r1[2] = r2;
              r2 = top[48];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2995; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_char__3estring_350;
              L2995:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = ((object*********) lenv) [1][1][1][1][1][1][1][1][3];
              r2[2] = r3;
              r3 = ((object***) lenv) [1][1][2];
              r2[3] = r3;
              r3 = top[67];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2996; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_396;
              L2996:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = ((object*) lenv) [2];
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = ((object**) lenv) [1][2];
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = ((object*) lenv) [2];
                  lenv = lenv[1];
                } break;
                default: {
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 4);
                  r2[1] = lenv; lenv = r2;
                  r3 = allocate (TC_TUPLE, 2);
                  r4 = ((object****) lenv) [1][1][1][2];
                  r4 = box((pxll_int)GET_CHAR(r4));
                  r3[2] = r4;
                  r4 = top[59];
                  t = allocate (TC_SAVE, 6);
                  t[1] = k; t[2] = lenv; t[3] = &&L2997; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                  r3[1] = r4[2]; lenv = r3; goto FUN_int__3ehex_string_367;
                  L2997:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                  r3 = result;
                  r2[2] = r3;
                  r3 = (object*)TC_NIL;
                  r2[3] = r3;
                  r3 = ((object*) lenv) [3];
                  r4 = ((object*) lenv) [2];
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r4;
                  t[2] = r3;
                  r3 = t;
                  r2[4] = r3;
                  r2 = ((object*) lenv) [4];
                  r3 = (object*) &constructed_38;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  lenv = lenv[1];
                  r1[2] = r2;
                  r2 = top[49];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2998; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
                  L2998:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                } break;
              }
              lenv = lenv[1];
            }
            r0[2] = r1;
            r0 = ((object***) lenv) [1][1][3];
            r1 = ((object*) lenv) [2];
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r1 = (object *) 3;
            r2 = ((object**) lenv) [1][2];
            r1 = box((pxll_int)unbox(r2)+unbox(r1));
            lenv = ((object *)lenv)[1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_4248_i3203_i4507_i4806_i4853;
          }
          PXLL_RETURN(0);
        L2993:
        r4 = allocate (TC_CLOSURE, 2);
        r4[1] = &&FUN_loop_4248_i3203_i4507_i4806_i4853; r4[2] = lenv;
        r3[2] = r4;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 1;
        r3[2] = r4;
        r4 = (object *) constructed_37[0];
        r3[3] = r4;
        r4 = ((object*) lenv) [2];
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2999; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_loop_4248_i3203_i4507_i4806_i4853;
        L2999:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        lenv = lenv[1];
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = ((object*) lenv) [2];
        r2[2] = r3;
        r3 = (object *) constructed_36[0];
        r2[3] = r3;
        r3 = top[23];
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L3000; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_313;
        L3000:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r1[2] = r2;
        r2 = top[49];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L3001; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
        L3001:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = ((object**) lenv) [1][2];
        r1[2] = r2;
        r2 = (object*) &constructed_35;
        r1[3] = r2;
        r2 = top[52];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L3002; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_357;
        L3002:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = ((object*) lenv) [2];
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        if PXLL_IS_TRUE(r0) {
          r0 = (object*) &constructed_34;
          PXLL_RETURN(0);
        } else {
          r0 = ((object*) lenv) [2];
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L2992:
      r2 = allocate (TC_CLOSURE, 2);
      r2[1] = &&FUN_frob_name_4243_i4507_i4806_i4853; r2[2] = lenv;
      r1[2] = r2;
      r2 = (object *) constructed_33[0];
      r1[3] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r3 = allocate (TC_TUPLE, 2);
      r4 = (object*) &constructed_26;
      r3[2] = r4;
      r4 = top[57];
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L3003; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string__3elist_364;
      L3003:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = top[85];
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L3004; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_char_class_425;
      L3004:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[4] = r2;
      r1 = ((object*) lenv) [2];
      lenv = lenv[1];
      r0[8] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = ((object****) lenv) [1][1][1][52];
      r0[2] = r1;
      r1 = ((object*) lenv) [2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L3005; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_emit_4294_i4806_i4853;
      L3005:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_25;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L3006; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L3006:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_24;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L3007; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L3007:
      ; lenv = k[2]; k = k[1];
      r0 = ((object****) lenv) [1][1][1][56];
      r0 = ((pxll_vector*)r0)->val[2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L3008; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L3008:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_23;
      r0[2] = r1;
      r1 = ((object****) lenv) [1][1][1][56];
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L3009; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L3009:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      lenv = lenv[1];
    } break;
  }
  lenv = lenv[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (TC_TUPLE, 2);
  r2 = ((object**) lenv) [1][2];
  r2 = ((pxll_vector*)r2)->val[11];
  r1[2] = r2;
  r2 = top[24];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L3010; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
  L3010:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[2] = r1;
  r0 = (object *) 1;
  r1 = ((object*) lenv) [2];
  r0 = PXLL_TEST(unbox(r1)>unbox(r0));
  lenv = lenv[1];
  if PXLL_IS_TRUE(r0) {
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_22;
    r0[2] = r1;
    r1 = ((object*) lenv) [56];
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L3011; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L3011:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_21;
    r0[2] = r1;
    r1 = ((object*) lenv) [56];
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L3012; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L3012:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_34610_i4807_i4853
    goto L3013;
    FUN_lambda_34610_i4807_i4853:
      check_heap (0);
      r0 = ((object*) lenv) [2];
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = ((object**) lenv) [1][2];
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = ((object**) lenv) [1][3];
          r3[2] = r4;
          r4 = top[58];
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L3014; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
          L3014:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = ((object*) lenv) [3];
          r4 = (object*) &constructed_20;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = ((object*) lenv) [4];
          r4 = ((object*) lenv) [2];
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = ((object*) lenv) [5];
          r3 = (object*) &constructed_19;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r1[2] = r2;
          r2 = top[49];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L3015; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
          L3015:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][56];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L3016; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L3016:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object*) &constructed_18;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][56];
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L3017; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L3017:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = ((object**) lenv) [1][2];
          r1[2] = r2;
          r2 = top[24];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L3018; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_316;
          L3018:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def $loop_4749_i4807_i4853
          goto L3019;
          FUN__24loop_4749_i4807_i4853:
            check_heap (0);
            r0 = ((object***) lenv) [1][1][2];
            r1 = ((object*) lenv) [2];
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 8);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 3);
              r5 = allocate (TC_TUPLE, 3);
              r6 = ((object*****) lenv) [1][1][1][1][2];
              r5[2] = r6;
              r6 = ((object**) lenv) [1][2];
              r5[3] = r6;
              r6 = top[29];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L3020; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_nth_323;
              L3020:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = ((object*******) lenv) [1][1][1][1][1][1][2];
              r4[3] = r5;
              r5 = top[9];
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L3021; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_lookup_label_code_254;
              L3021:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L3022; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L3022:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = ((object**) lenv) [1][2];
              r3[2] = r4;
              r4 = top[58];
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L3023; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_366;
              L3023:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = ((object*) lenv) [4];
              r4 = (object*) &constructed_17;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r3 = ((object*) lenv) [5];
              r4 = ((object*) lenv) [3];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[6] = r3;
              r3 = ((object*) lenv) [6];
              r4 = (object*) &constructed_16;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = ((object*) lenv) [7];
              r4 = ((object*) lenv) [2];
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r2 = ((object*) lenv) [8];
              r3 = (object*) &constructed_15;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r1[2] = r2;
              r2 = top[49];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L3024; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
              L3024:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = ((object******) lenv) [1][1][1][1][1][56];
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L3025; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L3025:
              ; lenv = k[2]; k = k[1];
              r0 = (object *) 3;
              r1 = ((object*) lenv) [2];
              r0 = box((pxll_int)unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_4749_i4807_i4853;
            }
            PXLL_RETURN(0);
          L3019:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN__24loop_4749_i4807_i4853; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = ((object*) lenv) [2];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L3026; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4749_i4807_i4853;
          L3026:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object*) &constructed_14;
          r0[2] = r1;
          r1 = ((object***) lenv) [1][1][56];
          r1 = ((pxll_vector*)r1)->val[4];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
      }
      PXLL_RETURN(0);
    L3013:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_34610_i4807_i4853; r1[2] = lenv;
    r0[2] = r1;
    r1 = ((object*) lenv) [2];
    r1 = ((pxll_vector*)r1)->val[11];
    r0[3] = r1;
    r1 = top[37];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L3027; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_331;
    L3027:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_13;
    r0[2] = r1;
    r1 = ((object*) lenv) [56];
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L3028; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L3028:
    ; lenv = k[2]; k = k[1];
    r0 = result;
  } else {
    r0 = (object *) 14;
  }
  r0 = (object*) &constructed_12;
  r0 = box((pxll_int)((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_12;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = ((object*) lenv) [56];
  r0 = ((pxll_vector*)r0)->val[0];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L3029; ; k = t;
  lenv = r0[2]; goto *r0[1];
  L3029:
  ; lenv = k[2]; k = k[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = ((object**) lenv) [1][2];
  r1 = ((pxll_vector*)r1)->val[10];
  r1 = ((pxll_vector*)r1)->val[2];
  r0[2] = r1;
  r0 = (object *) 6;
  r1 = ((object*) lenv) [2];
  r0 = PXLL_TEST(r1==r0);
  lenv = lenv[1];
  if PXLL_IS_TRUE(r0) {
    r0 = (object*) &constructed_11;
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_11;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = ((object**) lenv) [1][2];
    r1 = ((pxll_vector*)r1)->val[10];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_10;
    r1[2] = r2;
    r2 = top[210];
    r1[3] = r2;
    r2 = top[155];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L3030; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_getenv_or_575;
    L3030:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_9;
    r1[2] = r2;
    r2 = top[211];
    r1[3] = r2;
    r2 = top[155];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L3031; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_getenv_or_575;
    L3031:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 8);
    r2[1] = lenv; lenv = r2;
    r3 = ((object**) lenv) [1][2];
    r3 = ((pxll_vector*)r3)->val[3];
    if PXLL_IS_TRUE(r3) {
      r3 = (object*) &constructed_7;
    } else {
      r3 = (object*) &constructed_8;
    }
    r2[2] = r3;
    r3 = ((object**) lenv) [1][2];
    r3 = ((pxll_vector*)r3)->val[1];
    r2[3] = r3;
    r3 = (object*)TC_NIL;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object*) lenv) [3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r3 = ((object*) lenv) [5];
    r4 = (object*) &constructed_6;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[6] = r3;
    r3 = ((object*) lenv) [6];
    r4 = ((object*) lenv) [2];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[7] = r3;
    r3 = ((object*) lenv) [7];
    r4 = (object*) &constructed_5;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[8] = r3;
    r2 = ((object*) lenv) [8];
    r3 = ((object**) lenv) [1][4];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L3032; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L3032:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 8);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = ((object*) lenv) [2];
    r4 = ((object***) lenv) [1][1][11];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = (object*) &constructed_4;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r3 = ((object*) lenv) [4];
    r4 = ((object***) lenv) [1][1][11];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r3 = ((object*) lenv) [5];
    r4 = (object*) &constructed_3;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[6] = r3;
    r3 = ((object*) lenv) [6];
    r4 = ((object**) lenv) [1][5];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[7] = r3;
    r3 = ((object*) lenv) [7];
    r4 = (object*) &constructed_2;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[8] = r3;
    r2 = ((object*) lenv) [8];
    r3 = ((object**) lenv) [1][3];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L3033; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L3033:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = ((object*) lenv) [2];
    r4 = (object*) &constructed_1;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r3 = ((object*) lenv) [3];
    r4 = ((object***) lenv) [1][1][6];
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = ((object*) lenv) [4];
    r3 = (object*) &constructed_0;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r1[2] = r2;
    r2 = top[49];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L3034; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_354;
    L3034:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = ((object*) lenv) [2];
    r0 = box((pxll_int)((pxll_string*)(r0))->len);
    r1 = ((object*) lenv) [2];
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = ((object*) lenv) [6];
    r0[2] = r1;
    r1 = top[55];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L3035; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_zero_terminate_362;
    L3035:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    r0 = box((pxll_int)system (((pxll_string*)(r0))->data));
    lenv = lenv[1];
    r0 = (object *) 14;
    PXLL_RETURN(0);
  } else {
    r0 = (object *) 14;
    PXLL_RETURN(0);
  }
  PXLL_RETURN(0);
  Lreturn:
  return (pxll_int) result;
}
static int lookup_field (int tag, int label)
{ switch (tag) {
  case 25:
  switch (label) {
     case 88: return 0; break;
     case 74: return 1; break;
     case 89: return 2; break;
     case 72: return 3; break;
     case 90: return 4; break;
  } break;
  case 24:
  switch (label) {
     case 5: return 0; break;
     case 87: return 1; break;
     case 6: return 2; break;
     case 7: return 3; break;
  } break;
  case 23:
  switch (label) {
     case 84: return 0; break;
     case 85: return 1; break;
     case 86: return 2; break;
  } break;
  case 22:
  switch (label) {
     case 11: return 0; break;
     case 83: return 1; break;
  } break;
  case 21:
  switch (label) {
     case 11: return 0; break;
     case 79: return 1; break;
     case 80: return 2; break;
     case 81: return 3; break;
     case 82: return 4; break;
  } break;
  case 20:
  switch (label) {
     case 74: return 0; break;
     case 75: return 1; break;
     case 76: return 2; break;
     case 77: return 3; break;
     case 53: return 4; break;
     case 78: return 5; break;
  } break;
  case 19:
  switch (label) {
     case 70: return 0; break;
     case 16: return 1; break;
     case 71: return 2; break;
     case 72: return 3; break;
     case 73: return 4; break;
  } break;
  case 18:
  switch (label) {
     case 68: return 0; break;
     case 69: return 1; break;
  } break;
  case 17:
  switch (label) {
     case 63: return 0; break;
     case 64: return 1; break;
     case 65: return 2; break;
     case 66: return 3; break;
     case 67: return 4; break;
  } break;
  case 16:
  switch (label) {
     case 62: return 0; break;
     case 52: return 1; break;
  } break;
  case 15:
  switch (label) {
     case 61: return 0; break;
     case 52: return 1; break;
  } break;
  case 14:
  switch (label) {
     case 10: return 0; break;
     case 11: return 1; break;
     case 56: return 2; break;
     case 57: return 3; break;
     case 25: return 4; break;
     case 58: return 5; break;
     case 59: return 6; break;
     case 60: return 7; break;
  } break;
  case 13:
  switch (label) {
     case 55: return 0; break;
     case 52: return 1; break;
     case 53: return 2; break;
  } break;
  case 12:
  switch (label) {
     case 10: return 0; break;
     case 11: return 1; break;
     case 54: return 2; break;
     case 25: return 3; break;
  } break;
  case 11:
  switch (label) {
     case 52: return 0; break;
     case 53: return 1; break;
  } break;
  case 10:
  switch (label) {
     case 46: return 0; break;
     case 47: return 1; break;
     case 48: return 2; break;
     case 49: return 3; break;
     case 50: return 4; break;
     case 51: return 5; break;
  } break;
  case 9:
  switch (label) {
     case 44: return 0; break;
     case 45: return 1; break;
  } break;
  case 8:
  switch (label) {
     case 26: return 0; break;
     case 27: return 1; break;
     case 28: return 2; break;
     case 29: return 3; break;
     case 30: return 4; break;
     case 31: return 5; break;
     case 32: return 6; break;
     case 33: return 7; break;
     case 34: return 8; break;
     case 35: return 9; break;
     case 36: return 10; break;
     case 37: return 11; break;
     case 38: return 12; break;
     case 39: return 13; break;
     case 40: return 14; break;
     case 41: return 15; break;
     case 42: return 16; break;
     case 43: return 17; break;
  } break;
  case 7:
  switch (label) {
     case 10: return 0; break;
     case 11: return 1; break;
     case 21: return 2; break;
     case 22: return 3; break;
     case 23: return 4; break;
     case 24: return 5; break;
     case 25: return 6; break;
     case 16: return 7; break;
  } break;
  case 6:
  switch (label) {
     case 18: return 0; break;
     case 16: return 1; break;
     case 19: return 2; break;
     case 20: return 3; break;
  } break;
  case 5:
  switch (label) {
     case 15: return 0; break;
     case 9: return 1; break;
     case 16: return 2; break;
     case 17: return 3; break;
  } break;
  case 4:
  switch (label) {
     case 13: return 0; break;
     case 14: return 1; break;
  } break;
  case 3:
  switch (label) {
     case 10: return 0; break;
     case 11: return 1; break;
     case 12: return 2; break;
  } break;
  case 2:
  switch (label) {
     case 8: return 0; break;
     case 9: return 1; break;
  } break;
  case 1:
  switch (label) {
     case 5: return 0; break;
     case 6: return 1; break;
     case 7: return 2; break;
  } break;
  case 0:
  switch (label) {
     case 0: return 0; break;
     case 1: return 1; break;
     case 2: return 2; break;
     case 3: return 3; break;
     case 4: return 4; break;
  } break;
}}
